@@ -298,12 +298,14 @@ Canvas::FrameHandle Canvas::frameHitTest(QPointF canvasPoint, PageItem* item) co
 	// be huge, into account.
 	// ### might be interesting to investigate if it would be painless to just change 
 	// PageItem::getTransform.
-	double extraS = (item->visualHeight() - item->height()) / - 2.0;
+	double extraS = - item->visualLineWidth() / 2.0;
 //	if (item->lineColor() != CommonStrings::None)
 //		extraS = (item->lineWidth() / -2.0);
 	if (item->isTextFrame() && (m_doc->appMode == modeEdit) && !item->asTextFrame()->availableRegion().contains(item->getTransform().inverted().map(canvasPoint.toPoint())))
 		return OUTSIDE;
-	Canvas::FrameHandle result = frameHitTest(item->getTransform().inverted().map(canvasPoint), QRectF(extraS, extraS, item->visualWidth(), item->visualHeight()));
+	QRectF visualRect = item->isLine() ? QRectF(0, extraS, item->visualWidth(), item->visualHeight()) 
+		                               : QRectF(extraS, extraS, item->visualWidth(), item->visualHeight());
+	Canvas::FrameHandle result = frameHitTest(item->getTransform().inverted().map(canvasPoint), visualRect);
 //	qDebug() << "frameHitTest for item" << item->ItemNr 
 //		<< item->getTransform().inverted().map(canvasPoint) 
 //		<< item->getTransform().inverted() 
@@ -407,7 +409,7 @@ PageItem* Canvas::itemUnderCursor(QPoint globalPos, PageItem* itemAbove, bool al
 	// look for masterpage items first
 	if (allowMasterItems && !m_doc->masterPageMode() && m_doc->currentPage()->FromMaster.count() != 0)
 	{
-		ScPage* Mp = m_doc->MasterPages.at(m_doc->MasterNames[m_doc->currentPage()->MPageNam]);
+		ScPage* Mp = m_doc->MasterPages.at(m_doc->MasterNames[m_doc->currentPage()->masterPageName()]);
 		// if itemAbove is given, we expect to find it among the masterpage items of this page
 		int currNr = itemAbove? m_doc->currentPage()->FromMaster.indexOf(itemAbove)-1 : m_doc->currentPage()->FromMaster.count()-1;
 		if (currNr < 0)
@@ -416,17 +418,29 @@ PageItem* Canvas::itemUnderCursor(QPoint globalPos, PageItem* itemAbove, bool al
 		{
 			currItem = m_doc->currentPage()->FromMaster.at(currNr);
 			QTransform itemPos;
-			if (((currItem->m_layerID == m_doc->activeLayer()) || (m_doc->layerSelectable(currItem->m_layerID))) && (!m_doc->layerLocked(currItem->m_layerID)))
+			if (m_doc->canSelectItemOnLayer(currItem->m_layerID))
 			{
 				if (!currItem->ChangedMasterItem)
 				{
 					itemPos.translate(-Mp->xOffset() + m_doc->currentPage()->xOffset(), -Mp->yOffset() + m_doc->currentPage()->yOffset());
 				}
 				currItem->getTransform(itemPos);
-				QPainterPath currPath(itemPos.map(QPointF(0,0)));
-				currPath.lineTo(itemPos.map(QPointF(currItem->width(), 0)));
-				currPath.lineTo(itemPos.map(QPointF(currItem->width(), currItem->height())));
-				currPath.lineTo(itemPos.map(QPointF(0, currItem->height())));
+				QPainterPath currPath;
+				if (currItem->isLine())
+				{
+					double visualLineWidth = currItem->visualLineWidth();
+					currPath.moveTo(itemPos.map(QPointF(0.0, -visualLineWidth / 2.0)));
+					currPath.lineTo(itemPos.map(QPointF(currItem->width(), -visualLineWidth / 2.0)));
+					currPath.lineTo(itemPos.map(QPointF(currItem->width(),  visualLineWidth / 2.0)));
+					currPath.lineTo(itemPos.map(QPointF(0.0,  visualLineWidth / 2.0)));
+				}
+				else
+				{
+					currPath.moveTo(itemPos.map(QPointF(0, 0)));
+					currPath.lineTo(itemPos.map(QPointF(currItem->width(), 0)));
+					currPath.lineTo(itemPos.map(QPointF(currItem->width(), currItem->height())));
+					currPath.lineTo(itemPos.map(QPointF(0, currItem->height())));
+				}
 				currPath.closeSubpath();
 				QPainterPath currClip;
 				currClip.addPolygon(itemPos.map(QPolygonF(currItem->Clip)));
@@ -447,13 +461,14 @@ PageItem* Canvas::itemUnderCursor(QPoint globalPos, PageItem* itemAbove, bool al
 		}
 	}
 	// now look for normal items
-	if (m_doc->Items->count() == 0)
+	if (m_doc->Items->isEmpty())
 		return nullptr;
 
-	int currNr = itemAbove? m_doc->Items->indexOf(itemAbove)-1 : m_doc->Items->count()-1;
+	QList<PageItem*> *itemList = (itemAbove && itemAbove->isGroupChild()) ? &itemAbove->parentGroup()->groupItemList : m_doc->Items;
+	int currNr = itemAbove ? itemList->indexOf(itemAbove) - 1 : itemList->count() - 1;
 	while (currNr >= 0)
 	{
-		currItem = m_doc->Items->at(currNr);
+		currItem = itemList->at(currNr);
 		if ((m_doc->masterPageMode())  && (!((currItem->OwnPage == -1) || (currItem->OwnPage == static_cast<int>(m_doc->currentPage()->pageNr())))))
 		{
 			--currNr;
@@ -464,13 +479,25 @@ PageItem* Canvas::itemUnderCursor(QPoint globalPos, PageItem* itemAbove, bool al
 			--currNr;
 			continue;
 		}
-		if (((currItem->m_layerID == m_doc->activeLayer()) || (m_doc->layerSelectable(currItem->m_layerID))) && (!m_doc->layerLocked(currItem->m_layerID)))
+		if (m_doc->canSelectItemOnLayer(currItem->m_layerID))
 		{
 			QTransform itemPos = currItem->getTransform();
-			QPainterPath currPath(itemPos.map(QPointF(0,0)));
-			currPath.lineTo(itemPos.map(QPointF(currItem->width(), 0)));
-			currPath.lineTo(itemPos.map(QPointF(currItem->width(), currItem->height())));
-			currPath.lineTo(itemPos.map(QPointF(0, currItem->height())));
+			QPainterPath currPath;
+			if (currItem->isLine())
+			{
+				double visualLineWidth = currItem->visualLineWidth();
+				currPath.moveTo(itemPos.map(QPointF(0.0, -visualLineWidth / 2.0)));
+				currPath.lineTo(itemPos.map(QPointF(currItem->width(), -visualLineWidth / 2.0)));
+				currPath.lineTo(itemPos.map(QPointF(currItem->width(),  visualLineWidth / 2.0)));
+				currPath.lineTo(itemPos.map(QPointF(0.0,  visualLineWidth / 2.0)));
+			}
+			else
+			{
+				currPath.moveTo(itemPos.map(QPointF(0, 0)));
+				currPath.lineTo(itemPos.map(QPointF(currItem->width(), 0)));
+				currPath.lineTo(itemPos.map(QPointF(currItem->width(), currItem->height())));
+				currPath.lineTo(itemPos.map(QPointF(0, currItem->height())));
+			}
 			currPath.closeSubpath();
 			QPainterPath currClip;
 			currClip.addPolygon(itemPos.map(QPolygonF(currItem->Clip)));
@@ -782,7 +809,7 @@ void Canvas::paintEvent ( QPaintEvent * p )
 {
 //	qDebug()<<"Canvas::paintEvent"<<p->rect()<<m_viewMode.forceRedraw<<m_viewMode.operItemSelecting;
 // 	printBacktrace(62);
-	if (m_doc->isLoading())
+	if (m_doc->isLoading() || !m_doc->DoDrawing)
 		return;
 // #define SHOW_ME_WHAT_YOU_GET_IN_D_CANVA
 #ifdef SHOW_ME_WHAT_YOU_GET_IN_D_CANVA
@@ -1143,9 +1170,7 @@ void Canvas::drawControlsMovingItemsRect(QPainter* pp)
 	if (selectedItemCount >= moveWithBoxesOnlyThreshold)
 	{
 		double gx, gy, gw, gh;
-		m_doc->m_Selection->setGroupRect();
 		m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
-		//QPoint out = contentsToViewport(QPoint(0, 0));
 		pp->translate(gx, gy);
 		pp->drawRect(QRectF(0.0, 0.0, gw, gh));
 		return;
@@ -1169,11 +1194,11 @@ void Canvas::drawControlsMovingItemsRect(QPainter* pp)
 				for (int cg = 0; cg < itemCountG; cg++)
 				{
 					currItem = gItem->groupItemList.at(cg);
-					if (!(currItem->asLine()))
+					if (!(currItem->isLine()))
 						currItem->DrawPolyL(pp, currItem->Clip);
 					else
 					{
-						if (currItem->asLine())
+						if (currItem->isLine())
 						{
 							int lw2 = 1;
 							int lw = 1;
@@ -1189,7 +1214,7 @@ void Canvas::drawControlsMovingItemsRect(QPainter* pp)
 							}
 							else
 							{
-								multiLine ml = m_doc->MLineStyles[currItem->NamedLStyle];
+								multiLine ml = m_doc->docLineStyles[currItem->NamedLStyle];
 								lw2 = qRound(ml[ml.size()-1].Width  / 2.0);
 								lw = qRound(qMax(ml[ml.size()-1].Width, 1.0));
 								le = static_cast<Qt::PenCapStyle>(ml[ml.size()-1].LineEnd);
@@ -1223,7 +1248,7 @@ void Canvas::drawControlsMovingItemsRect(QPainter* pp)
 				}
 				else
 				{
-					multiLine ml = m_doc->MLineStyles[currItem->NamedLStyle];
+					multiLine ml = m_doc->docLineStyles[currItem->NamedLStyle];
 					lw2 = qRound(ml[ml.size()-1].Width  / 2.0);
 					lw = qRound(qMax(ml[ml.size()-1].Width, 1.0));
 					le = static_cast<Qt::PenCapStyle>(ml[ml.size()-1].LineEnd);
@@ -1334,7 +1359,7 @@ void Canvas::DrawMasterItems(ScPainter *painter, ScPage *page, ScLayer& layer, Q
 		return;
 	if (!layer.isViewable)
 		return;
-	if (page->MPageNam.isEmpty())
+	if (page->masterPageNameEmpty())
 		return;
 	if (page->FromMaster.count() <= 0)
 		return;
@@ -1344,7 +1369,7 @@ void Canvas::DrawMasterItems(ScPainter *painter, ScPage *page, ScLayer& layer, Q
 							  qRound(clip.width() / m_viewMode.scale + 0.5), qRound(clip.height() / m_viewMode.scale + 0.5));
 
 	PageItem *currItem;
-	ScPage* Mp = m_doc->MasterPages.at(m_doc->MasterNames[page->MPageNam]);
+	ScPage* Mp = m_doc->MasterPages.at(m_doc->MasterNames[page->masterPageName()]);
 	int layerCount = m_doc->layerCount();
 	if ((layerCount > 1) && ((layer.blendMode != 0) || (layer.transparency != 1.0)) && (!layer.outlineMode))
 		painter->beginLayer(layer.transparency, layer.blendMode);
@@ -1491,7 +1516,7 @@ void Canvas::DrawPageItems(ScPainter *painter, ScLayer& layer, QRect clip, bool
 				currItem->DrawObj_Decoration(painter);
 			}
 			getLinkedFrames(currItem);
-/*			if ((currItem->asTextFrame()) && ((currItem->nextInChain() != 0) || (currItem->prevInChain() != 0)))
+/*			if ((currItem->isTextFrame()) && ((currItem->nextInChain() != 0) || (currItem->prevInChain() != 0)))
 			{
 				PageItem *nextItem = currItem;
 				while (nextItem != 0)
@@ -1663,7 +1688,7 @@ void Canvas::getLinkedFrames(PageItem* currItem)
 		}
 
 	}
-	else if ((currItem->asTextFrame()) && ((currItem->nextInChain() != nullptr) || (currItem->prevInChain() != nullptr)))
+	else if ((currItem->isTextFrame()) && ((currItem->nextInChain() != nullptr) || (currItem->prevInChain() != nullptr)))
 	{
 		PageItem *nextItem = currItem;
 		while (nextItem != nullptr)
@@ -2117,48 +2142,24 @@ void Canvas::DrawPageIndicator(ScPainter *p, const QRectF& clip, bool master)
  */
 void Canvas::drawFrameLinks(ScPainter* painter)
 {
-	painter->save();
-	PageItem *currItem;
-	if ((m_doc->guidesPrefs().linkShown || m_viewMode.drawFramelinksWithContents) && (m_viewMode.linkedFramesToShow.count() != 0))
-		currItem = m_viewMode.linkedFramesToShow.at(0);
-	else
+	PageItem *currItem = nullptr;
+	if ((m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames))
 	{
-		if (m_viewMode.linkedFramesToShow.count() != 0)
-			currItem = m_viewMode.linkedFramesToShow.at(0);
-		else
+		if (m_doc->m_Selection->count() > 0)
 			currItem = m_doc->m_Selection->itemAt(0);
+		else if (m_viewMode.linkedFramesToShow.count() > 0)
+			currItem = m_viewMode.linkedFramesToShow.at(0);
+		if (currItem && (currItem->itemType() != PageItem::TextFrame))
+			currItem = nullptr;
 	}
+
 	//Draw the frame links
-	if ((((m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames))
-		 && (currItem->itemType() == PageItem::TextFrame)) || (m_doc->guidesPrefs().linkShown || m_viewMode.drawFramelinksWithContents))
+	painter->save();
+	if (m_doc->guidesPrefs().linkShown || m_viewMode.drawFramelinksWithContents)
 	{
-		PageItem *nextItem = currItem;
-		if (m_doc->guidesPrefs().linkShown || m_viewMode.drawFramelinksWithContents)
+		for (int i = 0; i < m_viewMode.linkedFramesToShow.count(); ++i)
 		{
-			for (int lks = 0; lks < m_viewMode.linkedFramesToShow.count(); ++lks)
-			{
-				nextItem = m_viewMode.linkedFramesToShow.at(lks);
-				while (nextItem != nullptr)
-				{
-					if (nextItem->nextInChain() != nullptr)
-					{
-						FPoint start, end;
-						calculateFrameLinkPoints(nextItem, nextItem->nextInChain(), start, end);
-						drawLinkFrameLine(painter, start, end);
-					}
-					nextItem = nextItem->nextInChain();
-				}
-			}
-		}
-		else
-		{
-			while (nextItem != nullptr)
-			{
-				if (nextItem->prevInChain() != nullptr)
-					nextItem = nextItem->prevInChain();
-				else
-					break;
-			}
+			PageItem* nextItem = m_viewMode.linkedFramesToShow.at(i);
 			while (nextItem != nullptr)
 			{
 				if (nextItem->nextInChain() != nullptr)
@@ -2171,6 +2172,20 @@ void Canvas::drawFrameLinks(ScPainter* painter)
 			}
 		}
 	}
+	else if ((((m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames)) && (currItem != nullptr)))
+	{
+		PageItem *nextItem = currItem->firstInChain();
+		while (nextItem != nullptr)
+		{
+			if (nextItem->nextInChain() != nullptr)
+			{
+				FPoint start, end;
+				calculateFrameLinkPoints(nextItem, nextItem->nextInChain(), start, end);
+				drawLinkFrameLine(painter, start, end);
+			}
+			nextItem = nextItem->nextInChain();
+		}
+	}
 	painter->setLineWidth(1);
 	painter->setPenOpacity(1.0);
 	painter->restore();
@@ -2411,7 +2426,6 @@ void Canvas::displayXYHUD(QPoint m)
 	double gx, gy, gh, gw, r;
 	if (m_doc->m_Selection->isMultipleSelection())
 	{
-		m_doc->m_Selection->setGroupRect();
 		m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
 		r = 0.0;
 	}
