@@ -39,9 +39,6 @@
 
 CanvasMode_CopyProperties::CanvasMode_CopyProperties(ScribusView* view) : CanvasMode(view), m_ScMW(view->m_ScMW) 
 {
-	Mxp = Myp = -1;
-	Dxp = Dyp = -1;
-	frameResizeHandle = -1;
 }
 
 inline bool CanvasMode_CopyProperties::GetItem(PageItem** pi)
@@ -71,6 +68,8 @@ void CanvasMode_CopyProperties::leaveEvent(QEvent *e)
 void CanvasMode_CopyProperties::activate(bool fromGesture)
 {
 //	qDebug() << "CanvasMode_CopyProperties::activate" << fromGesture;
+	CanvasMode::activate(fromGesture);
+
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m_doc->DragP = false;
@@ -88,10 +87,21 @@ void CanvasMode_CopyProperties::activate(bool fromGesture)
 	}
 }
 
-void CanvasMode_CopyProperties::deactivate(bool  /*forGesture*/)
+void CanvasMode_CopyProperties::deactivate(bool forGesture)
 {
 //	qDebug() << "CanvasMode_CopyProperties::deactivate" << forGesture;
 	m_view->setRedrawMarkerShown(false);
+	CanvasMode::deactivate(forGesture);
+}
+
+void CanvasMode_CopyProperties::keyPressEvent(QKeyEvent *e)
+{
+	commonkeyPressEvent_Default(e);
+}
+
+void CanvasMode_CopyProperties::keyReleaseEvent(QKeyEvent *e)
+{
+	commonkeyReleaseEvent(e);
 }
 
 void CanvasMode_CopyProperties::mouseDoubleClickEvent(QMouseEvent *m)
@@ -102,7 +112,6 @@ void CanvasMode_CopyProperties::mouseDoubleClickEvent(QMouseEvent *m)
 //	m_view->stopDragTimer();
 }
 
-
 void CanvasMode_CopyProperties::mouseMoveEvent(QMouseEvent *m)
 {
 	m->accept();
@@ -124,8 +133,6 @@ void CanvasMode_CopyProperties::mousePressEvent(QMouseEvent *m)
 // 	const double mouseY = m->globalY();
 	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
 
-	double Rxp = 0, Ryp = 0;
-	PageItem *currItem;
 	m_canvas->PaintSizeRect(QRect());
 	m_canvas->m_viewMode.m_MouseButtonPressed = true;
 	m_canvas->m_viewMode.operItemMoving = false;
@@ -136,9 +143,9 @@ void CanvasMode_CopyProperties::mousePressEvent(QMouseEvent *m)
 	m_view->registerMousePress(m->globalPos());
 	Mxp = mousePointDoc.x(); //qRound(m->x()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.x());
 	Myp = mousePointDoc.y(); //qRound(m->y()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.y());
-	Rxp = m_doc->ApplyGridF(FPoint(Mxp, Myp)).x();
+	double Rxp = m_doc->ApplyGridF(FPoint(Mxp, Myp)).x();
 	Mxp = qRound(Rxp);
-	Ryp = m_doc->ApplyGridF(FPoint(Mxp, Myp)).y();
+	double Ryp = m_doc->ApplyGridF(FPoint(Mxp, Myp)).y();
 	Myp = qRound(Ryp);
 	if (m->button() == Qt::MidButton)
 	{
@@ -150,6 +157,7 @@ void CanvasMode_CopyProperties::mousePressEvent(QMouseEvent *m)
 	if (m->button() != Qt::LeftButton)
 		return;
 	SeleItem(m);
+	PageItem *currItem;
 	if (GetItem(&currItem))
 	{
 		double sx, sy, ex, ey, r, skx, sky, fx, fy, ss, sk, sp;
@@ -204,13 +212,14 @@ void CanvasMode_CopyProperties::mousePressEvent(QMouseEvent *m)
 	{
 		m_doc->ElemToLink = nullptr;
 		m_view->requestMode(submodePaintingDone);
+		m_view->canvasMode()->mousePressEvent(m);
 	}
 }
 
 void CanvasMode_CopyProperties::mouseReleaseEvent(QMouseEvent *m)
 {
 #ifdef GESTURE_FRAME_PREVIEW
-        clearPixmapCache();
+	clearPixmapCache();
 #endif // GESTURE_FRAME_PREVIEW
 	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
 	PageItem *currItem;
@@ -280,8 +289,8 @@ bool CanvasMode_CopyProperties::SeleItem(QMouseEvent *m)
 		{
 			if (m_doc->currentPageNumber() != pgNum)
 			{
-				m_doc->setCurrentPage(m_doc->Pages->at(unsigned(pgNum)));
-				m_view->m_ScMW->slotSetCurrentPage(unsigned(pgNum));
+				m_doc->setCurrentPage(m_doc->Pages->at(pgNum));
+				m_view->m_ScMW->slotSetCurrentPage(pgNum);
 				m_view->DrawNew();
 			}
 		}
@@ -302,7 +311,7 @@ bool CanvasMode_CopyProperties::SeleItem(QMouseEvent *m)
 	}
 	else if ( (m->modifiers() & SELECT_MULTIPLE) == Qt::NoModifier || (m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames) )
 	{
-		m_view->Deselect(false);
+		m_view->deselectItems(false);
 	}
 	currItem = m_canvas->itemUnderCursor(m->globalPos(), currItem, (m->modifiers() & SELECT_IN_GROUP));
 	if (currItem)
@@ -334,7 +343,6 @@ bool CanvasMode_CopyProperties::SeleItem(QMouseEvent *m)
 				PageItem *bb = m_doc->m_Selection->itemAt(aa);
 				bb->update();
 			}
-			m_doc->m_Selection->setGroupRect();
 			double x, y, w, h;
 			m_doc->m_Selection->getGroupRect(&x, &y, &w, &h);
 			m_view->getGroupRectScreen(&x, &y, &w, &h);
@@ -354,7 +362,7 @@ bool CanvasMode_CopyProperties::SeleItem(QMouseEvent *m)
 	}
 	m_doc->m_Selection->connectItemToGUI();
 	if ( !(m->modifiers() & SELECT_MULTIPLE) || (m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames))
-		m_view->Deselect(true);
+		m_view->deselectItems(true);
 	return false;
 }
 
