@@ -48,7 +48,6 @@
 #include "ui/basepointwidget.h"
 #include "ui/hruler.h"
 #include "ui/insertTable.h"
-#include "ui/oneclick.h"
 #include "ui/pageselector.h"
 #include "ui/propertiespalette.h"
 #include "ui/scrapbookpalette.h"
@@ -58,23 +57,12 @@
 #include "util.h"
 #include "util_math.h"
 
-
-
-
-
 CreateMode::CreateMode(ScribusView* view) : CanvasMode(view) 
 {
 	canvasPressCoord.setXY(-1.0, -1.0);
 	mouseGlobalCoord.setXY(-1.0, -1.0);
-	inItemCreation = false;
-	createObjectMode     = 0;
-	createObjectSubMode  = 0;
-	modifiers            = Qt::NoModifier;
-	m_MouseButtonPressed = false;
-	m_createTransaction  = nullptr;
 }
 
-
 void CreateMode::drawControls(QPainter* p) 
 {
 	if (!inItemCreation) return;
@@ -184,7 +172,7 @@ inline bool CreateMode::GetItem(PageItem** pi)
 // the following code was moved from scribusview.cpp:
 
 
-void CreateMode::enterEvent(QEvent *)
+void CreateMode::enterEvent(QEvent *e)
 {
 	if (!m_MouseButtonPressed)
 	{
@@ -200,8 +188,10 @@ void CreateMode::leaveEvent(QEvent *e)
 
 void CreateMode::activate(bool fromGesture)
 {
-	PageItem* currItem;
 //	qDebug() << "CreateMode::activate" << fromGesture;
+	CanvasMode::activate(fromGesture);
+
+	PageItem* currItem;
 	if (!fromGesture || !GetItem(&currItem) || !m_createTransaction)
 	{
 		if (m_createTransaction)
@@ -229,6 +219,18 @@ void CreateMode::deactivate(bool forGesture)
 			m_createTransaction.reset();
 		}
 	}
+
+	CanvasMode::deactivate(forGesture);
+}
+
+void CreateMode::keyPressEvent(QKeyEvent *e)
+{
+	commonkeyPressEvent_Default(e);
+}
+
+void CreateMode::keyReleaseEvent(QKeyEvent *e)
+{
+	commonkeyReleaseEvent(e);
 }
 
 void CreateMode::mouseDoubleClickEvent(QMouseEvent *m)
@@ -238,7 +240,6 @@ void CreateMode::mouseDoubleClickEvent(QMouseEvent *m)
 	m_canvas->resetRenderMode();
 }
 
-
 void CreateMode::mouseMoveEvent(QMouseEvent *m)
 {
 	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
@@ -257,84 +258,80 @@ void CreateMode::mouseMoveEvent(QMouseEvent *m)
 		return;
 	if (GetItem(&currItem))
 	{
-		newX = mousePointDoc.x(); //m_view->translateToDoc(m->x(), m->y()).x());
-		newY = mousePointDoc.y(); //m_view->translateToDoc(m->x(), m->y()).y());
-		
-		if (m_doc->DragP)
-			return;
+//		newX = mousePointDoc.x(); //m_view->translateToDoc(m->x(), m->y()).x());
+//		newY = mousePointDoc.y(); //m_view->translateToDoc(m->x(), m->y()).y());
+		return;
+	}
+	if ((!m_MouseButtonPressed) || !(m->buttons() & Qt::LeftButton))
+	{
+		m_canvas->displayCorrectedXYHUD(m->globalPos(), mousePointDoc.x(), mousePointDoc.y());
+		return;
+	}
+
+	newX = mousePointDoc.x();
+	newY = mousePointDoc.y();
+	if (createObjectMode == modeDrawLine)
+	{
+		if (m_doc->SnapGrid)
+		{
+			newX = qRound(newX / m_doc->guidesPrefs().minorGridSpacing) * m_doc->guidesPrefs().minorGridSpacing;
+			newY = qRound(newY / m_doc->guidesPrefs().minorGridSpacing) * m_doc->guidesPrefs().minorGridSpacing;
+		}
+		if (m->modifiers() & Qt::ControlModifier)
+		{
+			QRectF bounds(QPointF(createObjectPos.x(), createObjectPos.y()), QPointF(newX, newY));
+			double newRot = xy2Deg(bounds.width(), bounds.height());
+			if (newRot < 0.0)
+				newRot += 360;
+			newRot = constrainAngle(newRot, m_doc->opToolPrefs().constrain);
+			double len = qMax(0.01, distance(bounds.width(), bounds.height()));
+			bounds.setSize(len * QSizeF(cosd(newRot), sind(newRot)));
+			newX = bounds.right();
+			newY = bounds.bottom();
+		}
+	}
+	//CB: #8099: Readd snapping for drag creation of lines by commenting this else..
+	//else
+	//{
+		FPoint np2 = m_doc->ApplyGridF(FPoint(newX, newY));
+		double nx = np2.x();
+		double ny = np2.y();
+		m_doc->ApplyGuides(&nx, &ny);
+		m_doc->ApplyGuides(&nx, &ny,true);
+		if (nx != np2.x())
+			xSnap = nx;
+		if (ny != np2.y())
+			ySnap = ny;
+		// #8959 : suppress qRound here as this prevent drawing line with angle constrain
+		// precisely and does not allow to stick precisely to grid or guides
+		newX = /*qRound(*/nx/*)*/;
+		newY = /*qRound(*/ny/*)*/;
+	//}
+
+	canvasCurrCoord.setXY(newX, newY);
+	m_view->HaveSelRect = true;
+
+	double wSize = canvasCurrCoord.x() - createObjectPos.x();
+	double hSize = canvasCurrCoord.y() - createObjectPos.y();
+	QRectF createObjectRect(createObjectPos.x(), createObjectPos.y(), wSize, hSize);
+	createObjectRect = createObjectRect.normalized();
+	if (createObjectMode != modeDrawLine)
+	{
+		if (modifiers == Qt::ControlModifier)
+			hSize = wSize;
+		m_canvas->displaySizeHUD(m->globalPos(), wSize, hSize, false);
 	}
 	else
 	{
-		if ((m_MouseButtonPressed) && (m->buttons() & Qt::LeftButton))
-		{
-			newX = mousePointDoc.x();
-			newY = mousePointDoc.y();
-			if (createObjectMode == modeDrawLine)
-			{
-				if (m_doc->SnapGrid)
-				{
-					newX = qRound(newX / m_doc->guidesPrefs().minorGridSpacing) * m_doc->guidesPrefs().minorGridSpacing;
-					newY = qRound(newY / m_doc->guidesPrefs().minorGridSpacing) * m_doc->guidesPrefs().minorGridSpacing;
-				}
-				if (m->modifiers() & Qt::ControlModifier)
-				{
-					QRectF bounds(QPointF(createObjectPos.x(), createObjectPos.y()), QPointF(newX, newY));
-					double newRot = xy2Deg(bounds.width(), bounds.height());
-					if (newRot < 0.0)
-						newRot += 360;
-					newRot = constrainAngle(newRot, m_doc->opToolPrefs().constrain);
-					double len = qMax(0.01, distance(bounds.width(), bounds.height()));
-					bounds.setSize(len * QSizeF(cosd(newRot), sind(newRot)));
-					newX = bounds.right();
-					newY = bounds.bottom();
-				}
-			}
-			//CB: #8099: Readd snapping for drag creation of lines by commenting this else..
-			//else
-			//{
-				FPoint np2 = m_doc->ApplyGridF(FPoint(newX, newY));
-				double nx = np2.x();
-				double ny = np2.y();
-				m_doc->ApplyGuides(&nx, &ny);
-				m_doc->ApplyGuides(&nx, &ny,true);
-				if (nx!=np2.x())
-					xSnap = nx;
-				if (ny!=np2.y())
-					ySnap = ny;
-				// #8959 : suppress qRound here as this prevent drawing line with angle constrain
-				// precisely and does not allow to stick precisely to grid or guides
-				newX = /*qRound(*/nx/*)*/;
-				newY = /*qRound(*/ny/*)*/;
-			//}
-
-			canvasCurrCoord.setXY(newX, newY);
-			m_view->HaveSelRect = true;
-
-			double wSize = canvasCurrCoord.x() - createObjectPos.x();
-			double hSize = canvasCurrCoord.y() - createObjectPos.y();
-			QRectF createObjectRect(createObjectPos.x(), createObjectPos.y(), wSize, hSize);
-			createObjectRect = createObjectRect.normalized();
-			if (createObjectMode != modeDrawLine)
-			{
-				if (modifiers == Qt::ControlModifier)
-					hSize = wSize;
-				m_canvas->displaySizeHUD(m->globalPos(), wSize, hSize, false);
-			}
-			else
-			{
-				double angle = -xy2Deg(wSize, hSize);
-				if (angle < 0.0)
-					angle = angle + 360;
-				double trueLength = sqrt(pow(createObjectRect.width(), 2) + pow(createObjectRect.height(), 2));
-				m_canvas->displaySizeHUD(m->globalPos(), trueLength, angle, true);
-			}
-
-			// Necessary for drawControls to be called
-			m_canvas->repaint();
-		}
-		else
-			m_canvas->displayCorrectedXYHUD(m->globalPos(), mousePointDoc.x(), mousePointDoc.y());
+		double angle = -xy2Deg(wSize, hSize);
+		if (angle < 0.0)
+			angle = angle + 360;
+		double trueLength = sqrt(pow(createObjectRect.width(), 2) + pow(createObjectRect.height(), 2));
+		m_canvas->displaySizeHUD(m->globalPos(), trueLength, angle, true);
 	}
+
+	// Necessary for drawControls to be called
+	m_canvas->repaint();
 }
 
 void CreateMode::mousePressEvent(QMouseEvent *m)
@@ -388,15 +385,13 @@ void CreateMode::mousePressEvent(QMouseEvent *m)
 	switch (m_doc->appMode)
 	{
 		case modeDrawTable2:
-			m_view->Deselect(false);
+			m_view->deselectItems(false);
 			break;
 	}
 
 	inItemCreation = true;
 }
 
-
-
 void CreateMode::mouseReleaseEvent(QMouseEvent *m)
 {
 	modifiers = m->modifiers();
@@ -441,8 +436,6 @@ void CreateMode::mouseReleaseEvent(QMouseEvent *m)
 	inItemCreation = false;
 }
 
-
-
 void CreateMode::selectPage(QMouseEvent *m)
 {
 	m_MouseButtonPressed = true;
@@ -451,7 +444,7 @@ void CreateMode::selectPage(QMouseEvent *m)
 //	QRect mpo(m->x()-m_doc->guidesPrefs().grabRadius, m->y()-m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius*2, m_doc->guidesPrefs().grabRadius*2);
 //	mpo.moveBy(qRound(Doc->minCanvasCoordinate.x() * m_canvas->scale()), qRound(m_doc->minCanvasCoordinate.y() * m_canvas->scale()));
 	m_doc->nodeEdit.deselect();
-	m_view->Deselect(false);
+	m_view->deselectItems(false);
 	if (!m_doc->masterPageMode())
 	{
 		int i = m_doc->OnPage(canvasPressCoord.x(), canvasPressCoord.y());
@@ -775,7 +768,7 @@ PageItem* CreateMode::doCreateNewObject()
 		break;
 	case modeDrawTable2:
 		// TODO: Figure out what these conditions actually do.
-		if ((m_doc->m_Selection->count() == 0) && (m_view->HaveSelRect) && (!m_view->MidButt))
+		if ((m_doc->m_Selection->isEmpty()) && (m_view->HaveSelRect) && (!m_view->MidButt))
 		{
 			m_view->HaveSelRect = false;
 			// Calculate table rectangle.
@@ -871,76 +864,66 @@ bool CreateMode::doOneClick(FPoint& startPoint, FPoint& endPoint)
 		ySize = sizes->getDouble("defAngle", 0.0);
 		originPoint = sizes->getInt("OriginL", 0);
 	}
-	//#12577 Remove one click dialog
-	//#12577 OneClick *dia = new OneClick(m_view, ScribusView::tr("Enter Object Size"), m_doc->unitIndex(), xSize, ySize, doRemember, originPoint, lmode);
-	//#12577 if (dia->exec())
+
+	if (lmode == 0)
 	{
-		//#12577 doRemember = dia->checkRemember->isChecked();
-		if (lmode == 0)
+		if (doRemember)
 		{
-			//#12577 xSize = dia->spinWidth->value() / unitGetRatioFromIndex(m_doc->unitIndex());
-			//#12577 ySize = dia->spinHeight->value() / unitGetRatioFromIndex(m_doc->unitIndex());
-			//#12577 originPoint = dia->RotationGroup->checkedId();
-			if (doRemember)
-			{
-				sizes->set("defWidth", xSize);
-				sizes->set("defHeight", ySize);
-				sizes->set("Origin", originPoint);
-			}
-			endPoint.setXY(startPoint.x() + xSize, startPoint.y() + ySize);
-			switch (originPoint)
-			{
-				case 0:
-					break;
-				case 1:
-					startPoint.setX(startPoint.x() - xSize);
-					endPoint.setX(endPoint.x() - xSize);
-					break;
-				case 2:
-					startPoint.setXY(startPoint.x() - xSize / 2.0, startPoint.y() - ySize / 2.0);
-					endPoint.setXY(endPoint.x() - xSize / 2.0, endPoint.y() - ySize / 2.0);
-					break;
-				case 3:
-					startPoint.setY(startPoint.y() - ySize);
-					endPoint.setY(endPoint.y() - ySize);
-					break;
-				case 4:
-					startPoint.setXY(startPoint.x() - xSize, startPoint.y() - ySize);
-					endPoint.setXY(endPoint.x() - xSize, endPoint.y() - ySize);
-					break;
-			}
+			sizes->set("defWidth", xSize);
+			sizes->set("defHeight", ySize);
+			sizes->set("Origin", originPoint);
 		}
-		else
+		endPoint.setXY(startPoint.x() + xSize, startPoint.y() + ySize);
+		switch (originPoint)
 		{
-			FPoint oldStart = startPoint;
-			//#12577 xSize = dia->spinWidth->value() / unitGetRatioFromIndex(m_doc->unitIndex());
-			//#12577 ySize = dia->spinHeight->value();
-			//#12577 originPoint = dia->RotationGroup->checkedId();
-			if (doRemember)
-			{
-				sizes->set("defLength", xSize);
-				sizes->set("defAngle", ySize);
-				sizes->set("OriginL", originPoint);
-			}
-			double angle = -ySize * M_PI / 180.0;
-			switch (originPoint)
-			{
-				case 0:
-					endPoint = FPoint(startPoint.x() + xSize * cos(angle), startPoint.y() + xSize * sin(angle));
-					break;
-				case 1:
-					startPoint = FPoint(oldStart.x() - xSize * cos(angle), oldStart.y() - xSize * sin(angle));
-					endPoint   = oldStart;
-					break;
-				case 2:
-					startPoint = FPoint(oldStart.x() - xSize / 2.0 * cos(angle), oldStart.y() - xSize / 2.0 * sin(angle));
-					endPoint   = FPoint(oldStart.x() + xSize / 2.0 * cos(angle), oldStart.y() + xSize / 2.0 * sin(angle));
-					break;
-			}
+			case 0:
+				break;
+			case 1:
+				startPoint.setX(startPoint.x() - xSize);
+				endPoint.setX(endPoint.x() - xSize);
+				break;
+			case 2:
+				startPoint.setXY(startPoint.x() - xSize / 2.0, startPoint.y() - ySize / 2.0);
+				endPoint.setXY(endPoint.x() - xSize / 2.0, endPoint.y() - ySize / 2.0);
+				break;
+			case 3:
+				startPoint.setY(startPoint.y() - ySize);
+				endPoint.setY(endPoint.y() - ySize);
+				break;
+			case 4:
+				startPoint.setXY(startPoint.x() - xSize, startPoint.y() - ySize);
+				endPoint.setXY(endPoint.x() - xSize, endPoint.y() - ySize);
+				break;
 		}
-		sizes->set("Remember", doRemember);
-		doCreate = true;
 	}
+	else
+	{
+		FPoint oldStart = startPoint;
+		if (doRemember)
+		{
+			sizes->set("defLength", xSize);
+			sizes->set("defAngle", ySize);
+			sizes->set("OriginL", originPoint);
+		}
+		double angle = -ySize * M_PI / 180.0;
+		switch (originPoint)
+		{
+			case 0:
+				endPoint = FPoint(startPoint.x() + xSize * cos(angle), startPoint.y() + xSize * sin(angle));
+				break;
+			case 1:
+				startPoint = FPoint(oldStart.x() - xSize * cos(angle), oldStart.y() - xSize * sin(angle));
+				endPoint   = oldStart;
+				break;
+			case 2:
+				startPoint = FPoint(oldStart.x() - xSize / 2.0 * cos(angle), oldStart.y() - xSize / 2.0 * sin(angle));
+				endPoint   = FPoint(oldStart.x() + xSize / 2.0 * cos(angle), oldStart.y() + xSize / 2.0 * sin(angle));
+				break;
+		}
+	}
+	sizes->set("Remember", doRemember);
+	doCreate = true;
+
 	//delete dia;
 	return doCreate;
 }
