@@ -20,6 +20,7 @@
 #include <QButtonGroup>
 #include <QCheckBox>
 #include <QCursor>
+#include <QDebug>
 #include <QEvent>
 #include <QMessageBox>
 #include <QMouseEvent>
@@ -29,7 +30,6 @@
 #include <QRect>
 #include <QTimer>
 #include <QWidgetAction>
-#include <QDebug>
 
 #include "appmodes.h"
 #include "canvas.h"
@@ -63,18 +63,9 @@
 
 CanvasMode_Edit::CanvasMode_Edit(ScribusView* view) : CanvasMode(view), m_ScMW(view->m_ScMW) 
 {
-	Mxp = Myp = -1;
-	Dxp = Dyp = -1;
-	SeRx = SeRy = -1;
-	oldCp = Cp = -1;
-	frameResizeHandle = -1;
-	m_blinker = new QTimer(view);	
+	m_blinker = new QTimer(view);
 	connect(m_blinker, SIGNAL(timeout()), this, SLOT(blinkTextCursor()));
 	connect(view->horizRuler, SIGNAL(MarkerMoved(double,double)), this, SLOT(rulerPreview(double,double)));
-	mRulerGuide = -1;
-	m_cursorVisible = false;
-	m_longCursorTime = false;
-	m_keyRepeat = false;
 }
 
 inline bool CanvasMode_Edit::GetItem(PageItem** pi)
@@ -118,11 +109,11 @@ void CanvasMode_Edit::keyPressEvent(QKeyEvent *e)
 		return;
 	}
 
-	if (currItem->asImageFrame() && !currItem->locked())
+	if (currItem->isImageFrame() && !currItem->locked())
 	{
 		currItem->handleModeEditKey(e, m_keyRepeat);
 	}
-	if (currItem->asTextFrame())
+	if (currItem->isTextFrame())
 	{
 		bool oldKeyRepeat = m_keyRepeat;
 
@@ -147,11 +138,15 @@ void CanvasMode_Edit::keyPressEvent(QKeyEvent *e)
 		currItem->handleModeEditKey(e, m_keyRepeat);
 		if (currItem->isAutoNoteFrame() && currItem->asNoteFrame()->notesList().isEmpty())
 		{
-			if (!currItem->asNoteFrame()->isEndNotesFrame())
+			PageItem_NoteFrame* noteFrame = currItem->asNoteFrame();
+			if (!noteFrame->isEndNotesFrame() && noteFrame->masterFrame())
 			{
-				currItem->asNoteFrame()->masterFrame()->invalidateLayout(false);
-				currItem->asNoteFrame()->masterFrame()->updateLayout();
+				PageItem_TextFrame* masterFrame = noteFrame->masterFrame();
+				masterFrame->invalidateLayout(false);
+				masterFrame->updateLayout();
 			}
+			else if (!noteFrame->isEndNotesFrame() && !noteFrame->masterFrame())
+				qDebug() << "Broken note frame without master frame detected";
 		}
 		m_keyRepeat = oldKeyRepeat;
 		m_doc->regionsChanged()->update(QRectF());
@@ -202,7 +197,7 @@ void CanvasMode_Edit::drawControls(QPainter* p)
 			}
 			drawTextCursor(p, textframe);
 		}
-		else if (currItem->asImageFrame())
+		else if (currItem->isImageFrame())
 		{
 			QTransform mm = currItem->getTransform();
 			p->save();
@@ -255,7 +250,7 @@ void CanvasMode_Edit::drawTextCursor ( QPainter *p, PageItem_TextFrame* textfram
 	}
 }
 
-void CanvasMode_Edit::enterEvent(QEvent *)
+void CanvasMode_Edit::enterEvent(QEvent *e)
 {
 	if (!m_canvas->m_viewMode.m_MouseButtonPressed)
 	{
@@ -269,6 +264,8 @@ void CanvasMode_Edit::leaveEvent(QEvent *e)
 
 void CanvasMode_Edit::activate(bool fromGesture)
 {
+	CanvasMode::activate(fromGesture);
+
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m_doc->DragP = false;
@@ -290,7 +287,7 @@ void CanvasMode_Edit::activate(bool fromGesture)
 	PageItem * it(nullptr);
 	if (GetItem(&it))
 	{
-		if (it->asTextFrame())
+		if (it->isTextFrame())
 		{
 			m_canvas->setupEditHRuler(it, true);
 			if (m_doc->appMode == modeEdit)
@@ -312,6 +309,7 @@ void CanvasMode_Edit::deactivate(bool forGesture)
 		mRulerGuide = -1;
 		m_blinker->stop();
 	}
+	CanvasMode::deactivate(forGesture);
 }
 
 void CanvasMode_Edit::mouseDoubleClickEvent(QMouseEvent *m)
@@ -320,7 +318,7 @@ void CanvasMode_Edit::mouseDoubleClickEvent(QMouseEvent *m)
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	PageItem *currItem = nullptr;
-	if (GetItem(&currItem) && (m_doc->appMode == modeEdit) && currItem->asTextFrame())
+	if (GetItem(&currItem) && (m_doc->appMode == modeEdit) && currItem->isTextFrame())
 	{
 		//CB if annotation, open the annotation dialog
 		if (currItem->isAnnotation())
@@ -378,11 +376,10 @@ void CanvasMode_Edit::mouseDoubleClickEvent(QMouseEvent *m)
 				}
 				else
 				{
-					int newPos = currItem->itemText.selectWord(oldCp);
-					currItem->itemText.setCursorPosition(newPos);
+					currItem->itemText.selectWord(oldCp);
 				}
 			}
-			currItem->HasSel = (currItem->itemText.selectionLength() > 0);
+			currItem->HasSel = currItem->itemText.hasSelection();
 		}
 	}
 	else
@@ -413,7 +410,7 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 			return;
 		if (m_canvas->m_viewMode.m_MouseButtonPressed && (m_doc->appMode == modeEdit))
 		{
-			if (currItem->asImageFrame())
+			if (currItem->isImageFrame())
 			{
 				if (m->modifiers() & Qt::ShiftModifier)
 				{
@@ -438,7 +435,7 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 				Mxp = newX;
 				Myp = newY;
 			}
-			if (currItem->asTextFrame())
+			if (currItem->isTextFrame())
 			{
 				int refStartSel(currItem->asTextFrame()->itemText.startOfSelection());
 				int refEndSel(currItem->asTextFrame()->itemText.endOfSelection());
@@ -459,9 +456,9 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 						currItem->HasSel = true;
 					}
 				}
+				m_ScMW->setCopyCutEnabled(currItem->HasSel);
 				if (currItem->HasSel)
 				{
-					m_ScMW->EnableTxEdit();
 					m_canvas->m_viewMode.operTextSelecting = true;
 					if ((refStartSel != currItem->asTextFrame()->itemText.startOfSelection()) ||
 						(refEndSel   != currItem->asTextFrame()->itemText.endOfSelection()))
@@ -469,9 +466,10 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 						QRectF br(currItem->getBoundingRect());
 						m_canvas->update(QRectF(m_canvas->canvasToLocal(br.topLeft()), br.size() * m_canvas->scale()).toRect());
 					}
+					// We have to call this unconditionally because slotSetCurs() doesn't know selection
+					// when it is called
+					m_doc->scMW()->setTBvals(currItem);
 				}
-				else
-					m_ScMW->DisableTxEdit();
 			}
 		}
 		if (!m_canvas->m_viewMode.m_MouseButtonPressed)
@@ -491,9 +489,9 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 				{
 					if (hitTest == Canvas::INSIDE)
 					{
-						if (currItem->asTextFrame())
+						if (currItem->isTextFrame())
 							m_view->setCursor(QCursor(Qt::IBeamCursor));
-						if (currItem->asImageFrame())
+						if (currItem->isImageFrame())
 						{
 							if (m->modifiers() & Qt::ShiftModifier)
 								m_view->setCursor(IconManager::instance().loadCursor("Rotieren2.png"));
@@ -579,18 +577,18 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 	if (GetItem(&currItem))
 	{
 //		m_view->slotDoCurs(false);
-		if ((!currItem->locked() || currItem->isTextFrame()) && !currItem->asLine())
+		if ((!currItem->locked() || currItem->isTextFrame()) && !currItem->isLine())
 		{
 			FPoint canvasPoint = m_canvas->globalToCanvas(m->globalPos());
 			if (m_canvas->frameHitTest(QPointF(canvasPoint.x(), canvasPoint.y()), currItem) < 0)
 			{
 				m_doc->m_Selection->delaySignalsOn();
-				m_view->Deselect(true);
+				m_view->deselectItems(true);
 				bool wantNormal = true;
 				if (SeleItem(m))
 				{
 					currItem = m_doc->m_Selection->itemAt(0);
-					if ((currItem->asTextFrame()) || (currItem->asImageFrame()))
+					if ((currItem->isTextFrame()) || (currItem->isImageFrame()))
 					{
 						m_view->requestMode(modeEdit);
 						wantNormal = false;
@@ -600,7 +598,7 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 						m_view->requestMode(submodePaintingDone);
 						m_view->setCursor(QCursor(Qt::ArrowCursor));
 					}
-					if (currItem->asTextFrame())
+					if (currItem->isTextFrame())
 					{
 						m_view->slotSetCurs(m->globalPos().x(), m->globalPos().y());
 						oldCp = currItem->itemText.cursorPosition();
@@ -622,14 +620,14 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 		}
 		oldP = currItem->itemText.cursorPosition();
 		//CB Where we set the cursor for a click in text frame
-		if (currItem->asTextFrame())
+		if (currItem->isTextFrame())
 		{
 			inText = m_view->slotSetCurs(m->globalPos().x(), m->globalPos().y());
 			//CB If we clicked outside a text frame to go out of edit mode and deselect the frame
 			if (!inText)
 			{
 				currItem->invalidateLayout();
-				m_view->Deselect(true);
+				m_view->deselectItems(true);
 				//m_view->slotDoCurs(true);
 				m_view->requestMode(modeNormal);
 				m_view->canvasMode()->mousePressEvent(m);
@@ -642,7 +640,7 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 				//<<CB Add in shift select to text frames
 				if (m->modifiers() & Qt::ShiftModifier)
 				{
-					if (currItem->itemText.selectionLength() > 0)
+					if (currItem->itemText.hasSelection())
 					{
 						if (currItem->itemText.cursorPosition() < (currItem->itemText.startOfSelection() + currItem->itemText.endOfSelection()) / 2)
 						{
@@ -708,13 +706,13 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 				}
 			}
 		}
-		else if (!currItem->asImageFrame() || m_canvas->frameHitTest(QPointF(mousePointDoc.x(),mousePointDoc.y()), currItem) < 0)
+		else if (!currItem->isImageFrame() || m_canvas->frameHitTest(QPointF(mousePointDoc.x(),mousePointDoc.y()), currItem) < 0)
 		{
-			m_view->Deselect(true);
+			m_view->deselectItems(true);
 			if (SeleItem(m))
 			{
 				currItem = m_doc->m_Selection->itemAt(0);
-				if ((currItem->asTextFrame()) || (currItem->asImageFrame()))
+				if ((currItem->isTextFrame()) || (currItem->isImageFrame()))
 				{
 					m_view->requestMode(modeEdit);
 				}
@@ -738,7 +736,7 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 {
 #ifdef GESTURE_FRAME_PREVIEW
-        clearPixmapCache();
+	clearPixmapCache();
 #endif // GESTURE_FRAME_PREVIEW
 	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
 	PageItem *currItem;
@@ -760,7 +758,7 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 			m_doc->setRedrawBounding(currItem);
 			currItem->OwnPage = m_doc->OnPage(currItem);
 			m_canvas->m_viewMode.operItemResizing = false;
-			if (currItem->asLine())
+			if (currItem->isLine())
 				m_view->updateContents();
 		}
 		if (m_canvas->m_viewMode.operItemMoving)
@@ -772,7 +770,6 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 				{
 					m_view->startGroupTransaction(Um::Move, "", Um::IMove);
 				}
-				m_doc->m_Selection->setGroupRect();
 				double gx, gy, gh, gw;
 				m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
 				double nx = gx;
@@ -780,23 +777,22 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 				if (!m_doc->ApplyGuides(&nx, &ny) && !m_doc->ApplyGuides(&nx, &ny,true))
 				{
 					FPoint npx = m_doc->ApplyGridF(FPoint(gx, gy));
-					FPoint npw = m_doc->ApplyGridF(FPoint(gx+gw, gy+gh));
-					if ((fabs(gx-npx.x())) > (fabs((gx+gw)-npw.x())))
+					FPoint npw = m_doc->ApplyGridF(FPoint(gx + gw, gy + gh));
+					if ((fabs(gx - npx.x())) > (fabs((gx + gw) - npw.x())))
 						nx = npw.x() - gw;
 					else
 						nx = npx.x();
-					if ((fabs(gy-npx.y())) > (fabs((gy+gh)-npw.y())))
+					if ((fabs(gy - npx.y())) > (fabs((gy + gh) - npw.y())))
 						ny = npw.y() - gh;
 					else
 						ny = npx.y();
 				}
-				m_doc->moveGroup(nx-gx, ny-gy);
-				m_doc->m_Selection->setGroupRect();
+				m_doc->moveGroup(nx - gx, ny - gy);
 				m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
-				nx = gx+gw;
-				ny = gy+gh;
+				nx = gx + gw;
+				ny = gy + gh;
 				if (m_doc->ApplyGuides(&nx, &ny) || m_doc->ApplyGuides(&nx,&ny,true))
-					m_doc->moveGroup(nx-(gx+gw), ny-(gy+gh));
+					m_doc->moveGroup(nx - (gx + gw), ny - (gy + gh));
 				m_doc->m_Selection->setGroupRect();
 			}
 			else
@@ -808,16 +804,15 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 					double ny = currItem->yPos();
 					if (!m_doc->ApplyGuides(&nx, &ny) && !m_doc->ApplyGuides(&nx, &ny,true))
 					{
-						m_doc->m_Selection->setGroupRect();
 						double gx, gy, gh, gw;
 						m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
 						FPoint npx = m_doc->ApplyGridF(FPoint(gx, gy));
-						FPoint npw = m_doc->ApplyGridF(FPoint(gx+gw, gy+gh));
-						if ((fabs(gx-npx.x())) > (fabs((gx+gw)-npw.x())))
+						FPoint npw = m_doc->ApplyGridF(FPoint(gx + gw, gy + gh));
+						if ((fabs(gx - npx.x())) > (fabs((gx + gw) - npw.x())))
 							nx = npw.x() - gw;
 						else
 							nx = npx.x();
-						if ((fabs(gy-npx.y())) > (fabs((gy+gh)-npw.y())))
+						if ((fabs(gy - npx.y())) > (fabs((gy + gh) - npw.y())))
 							ny = npw.y() - gh;
 						else
 							ny = npx.y();
@@ -832,8 +827,8 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 			{
 				double gx, gy, gh, gw;
 				m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
-				FPoint maxSize(gx+gw+m_doc->scratch()->right(), gy+gh+m_doc->scratch()->bottom());
-				FPoint minSize(gx-m_doc->scratch()->left(), gy-m_doc->scratch()->top());
+				FPoint maxSize(gx + gw + m_doc->scratch()->right(), gy + gh + m_doc->scratch()->bottom());
+				FPoint minSize(gx - m_doc->scratch()->left(), gy - m_doc->scratch()->top());
 				m_doc->adjustCanvas(minSize, maxSize);
 			}
 			m_doc->setRedrawBounding(currItem);
@@ -854,7 +849,7 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 		}
 	}
 	//CB Drag selection performed here
-	if ((m_doc->m_Selection->count() == 0) && (m_view->HaveSelRect) && (!m_view->MidButt))
+	if ((m_doc->m_Selection->isEmpty()) && (m_view->HaveSelRect) && (!m_view->MidButt))
 	{
 		QRectF Sele = QRectF(Dxp, Dyp, SeRx-Dxp, SeRy-Dyp).normalized();
 		if (!m_doc->masterPageMode())
@@ -888,16 +883,15 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 				QRect apr2(docItem->getRedrawBounding(1.0));
 				if ((m_doc->masterPageMode()) && (docItem->OnMasterPage != m_doc->currentPage()->pageName()))
 					continue;
-				if (((Sele.contains(apr.boundingRect())) || (Sele.contains(apr2))) && ((docItem->m_layerID == m_doc->activeLayer()) || (m_doc->layerSelectable(docItem->m_layerID))) && (!m_doc->layerLocked(docItem->m_layerID)))
+				if (((Sele.contains(apr.boundingRect())) || (Sele.contains(apr2))) && m_doc->canSelectItemOnLayer(docItem->m_layerID))
 				{
 					bool redrawSelection=false;
-					m_view->SelectItemNr(a, redrawSelection);
+					m_view->selectItemByNumber(a, redrawSelection);
 				}
 			}
 			m_doc->m_Selection->delaySignalsOff();
 			if (m_doc->m_Selection->count() > 1)
 			{
-				m_doc->m_Selection->setGroupRect();
 				double x, y, w, h;
 				m_doc->m_Selection->getGroupRect(&x, &y, &w, &h);
 				m_view->getGroupRectScreen(&x, &y, &w, &h);
@@ -911,7 +905,6 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 	{
 		if (m_doc->m_Selection->count() > 1)
 		{
-			m_doc->m_Selection->setGroupRect();
 			double x, y, w, h;
 			m_doc->m_Selection->getGroupRect(&x, &y, &w, &h);
 			m_canvas->m_viewMode.operItemMoving = false;
@@ -948,13 +941,8 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 		currItem = m_doc->m_Selection->itemAt(0);
 		m_doc->nodeEdit.finishTransaction(currItem);
 	}
-	if (GetItem(&currItem) && currItem->asTextFrame())
-	{
-		if (currItem->itemText.selectionLength() > 0)
-			m_ScMW->EnableTxEdit();
-		else
-			m_ScMW->DisableTxEdit();
-	}
+	if (GetItem(&currItem) && currItem->isTextFrame())
+		m_ScMW->setCopyCutEnabled(currItem->itemText.hasSelection());
 }
 
 //CB-->Doc/Fix
@@ -1018,8 +1006,8 @@ bool CanvasMode_Edit::SeleItem(QMouseEvent *m)
 		{
 			if (m_doc->currentPageNumber() != pgNum)
 			{
-				m_doc->setCurrentPage(m_doc->Pages->at(unsigned(pgNum)));
-				m_view->m_ScMW->slotSetCurrentPage(unsigned(pgNum));
+				m_doc->setCurrentPage(m_doc->Pages->at(pgNum));
+				m_view->m_ScMW->slotSetCurrentPage(pgNum);
 				m_view->DrawNew();
 			}
 		}
@@ -1041,7 +1029,7 @@ bool CanvasMode_Edit::SeleItem(QMouseEvent *m)
 	}
 	else if ( (m->modifiers() & SELECT_MULTIPLE) == Qt::NoModifier)
 	{
-		m_view->Deselect(false);
+		m_view->deselectItems(false);
 	}
 	currItem = m_canvas->itemUnderCursor(m->globalPos(), currItem, (m->modifiers() & SELECT_IN_GROUP));
 	if (currItem)
@@ -1068,7 +1056,6 @@ bool CanvasMode_Edit::SeleItem(QMouseEvent *m)
 		m_doc->m_Selection->delaySignalsOff();
 		if (m_doc->m_Selection->count() > 1)
 		{
-			m_doc->m_Selection->setGroupRect();
 			double x, y, w, h;
 			m_doc->m_Selection->getGroupRect(&x, &y, &w, &h);
 			m_view->getGroupRectScreen(&x, &y, &w, &h);
@@ -1088,7 +1075,7 @@ bool CanvasMode_Edit::SeleItem(QMouseEvent *m)
 	}
 	m_doc->m_Selection->connectItemToGUI();
 	if ( !(m->modifiers() & SELECT_MULTIPLE))
-		m_view->Deselect(true);
+		m_view->deselectItems(true);
 	return false;
 }
 
