@@ -64,13 +64,7 @@
 
 CanvasMode_EditMeshPatch::CanvasMode_EditMeshPatch(ScribusView* view) : CanvasMode(view), m_ScMW(view->m_ScMW)
 {
-	m_Mxp = m_Myp = -1;
-	m_patchPoint = noPointDefined;
-	m_gradientPoint = noControlPointDefined;
-	m_keyRepeat = false;
-	m_click_count = 0;
 	m_old_mesh = new MeshPoint();
-	m_currItem = nullptr;
 }
 
 CanvasMode_EditMeshPatch::~CanvasMode_EditMeshPatch()
@@ -277,7 +271,7 @@ void CanvasMode_EditMeshPatch::drawControlsMeshPatch(QPainter* psx, PageItem* cu
 	}
 }
 
-void CanvasMode_EditMeshPatch::enterEvent(QEvent *)
+void CanvasMode_EditMeshPatch::enterEvent(QEvent *e)
 {
 	if (!m_canvas->m_viewMode.m_MouseButtonPressed)
 	{
@@ -292,6 +286,8 @@ void CanvasMode_EditMeshPatch::leaveEvent(QEvent *e)
 
 void CanvasMode_EditMeshPatch::activate(bool fromGesture)
 {
+	CanvasMode::activate(fromGesture);
+
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m_doc->DragP = false;
@@ -322,6 +318,8 @@ void CanvasMode_EditMeshPatch::deactivate(bool forGesture)
 	m_currItem->selectedMeshControlPoint = m_gradientPoint;
 	m_ScMW->propertiesPalette->updateColorSpecialGradient();
 	m_currItem->snapToPatchGrid = false;
+
+	CanvasMode::deactivate(forGesture);
 }
 
 void CanvasMode_EditMeshPatch::keyPressEvent(QKeyEvent *e)
@@ -553,7 +551,7 @@ void CanvasMode_EditMeshPatch::mouseDoubleClickEvent(QMouseEvent *m)
 			}
 			return;
 		}
-		if (!(GetItem(&m_currItem) && (m_doc->appMode == modeEdit) && m_currItem->asTextFrame()))
+		if (!(GetItem(&m_currItem) && (m_doc->appMode == modeEdit) && m_currItem->isTextFrame()))
 		{
 			mousePressEvent(m);
 			return;
@@ -631,8 +629,10 @@ void CanvasMode_EditMeshPatch::mouseMoveEvent(QMouseEvent *m)
 					m_canvas->displayXYHUD(m->globalPos(), npf.x(), npf.y());
 					if (m_view->editStrokeGradient == 9)
 					{
-						FPoint mp, mp_orig;
-						double xx, yy;
+						FPoint mp;
+						FPoint mp_orig;
+						double xx = 0.0;
+						double yy = 0.0;
 						if (m_patchPoint == useTL)
 						{
 							mp_orig = m_currItem->meshGradientPatches[m_currItem->selectedMeshPointX].TL.gridPoint;
