@@ -61,11 +61,10 @@
 #include "util_math.h"
 
 
-CanvasMode_EditPolygon::CanvasMode_EditPolygon(ScribusView* view) : CanvasMode(view), m_ScMW(view->m_ScMW) 
+CanvasMode_EditPolygon::CanvasMode_EditPolygon(ScribusView* view) :
+	CanvasMode(view),
+	m_ScMW(view->m_ScMW)
 {
-	m_Mxp = m_Myp = -1;
-	m_blockUpdateFromItem = 0;
-	m_polygonPoint = noPointDefined;
 }
 
 inline bool CanvasMode_EditPolygon::GetItem(PageItem** pi)
@@ -131,7 +130,7 @@ void CanvasMode_EditPolygon::drawControlsPolygon(QPainter* psx, PageItem* currIt
 	}
 }
 
-void CanvasMode_EditPolygon::enterEvent(QEvent *)
+void CanvasMode_EditPolygon::enterEvent(QEvent *e)
 {
 	if (!m_canvas->m_viewMode.m_MouseButtonPressed)
 		setModeCursor();
@@ -175,6 +174,8 @@ void CanvasMode_EditPolygon::updateFromItem()
 
 void CanvasMode_EditPolygon::activate(bool fromGesture)
 {
+	CanvasMode::activate(fromGesture);
+
 	m_polygonPoint = noPointDefined;
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
@@ -226,6 +227,8 @@ void CanvasMode_EditPolygon::deactivate(bool forGesture)
 	m_view->setRedrawMarkerShown(false);
 	m_polygonPoint = noPointDefined;
 	disconnect(m_doc, SIGNAL(docChanged()), this, SLOT(updateFromItem()));
+
+	CanvasMode::deactivate(forGesture);
 }
 
 void CanvasMode_EditPolygon::endEditing(bool active)
@@ -313,6 +316,16 @@ double CanvasMode_EditPolygon::GetMaxFactor()
 	return ret;
 }
 
+void CanvasMode_EditPolygon::keyPressEvent(QKeyEvent *e)
+{
+	commonkeyPressEvent_Default(e);
+}
+
+void CanvasMode_EditPolygon::keyReleaseEvent(QKeyEvent *e)
+{
+	commonkeyReleaseEvent(e);
+}
+
 void CanvasMode_EditPolygon::mouseDoubleClickEvent(QMouseEvent *m)
 {
 	m->accept();
