@@ -54,9 +54,6 @@
 
 CanvasMode_FrameLinks::CanvasMode_FrameLinks(ScribusView* view) : CanvasMode(view), m_ScMW(view->m_ScMW) 
 {
-	m_Mxp = m_Myp = -1;
-	m_Dxp = m_Dyp = -1;
-	m_frameResizeHandle = -1;
 }
 
 inline bool CanvasMode_FrameLinks::GetItem(PageItem** pi)
@@ -70,7 +67,7 @@ void CanvasMode_FrameLinks::drawControls(QPainter* p)
 	commonDrawControls(p, false);
 }
 
-void CanvasMode_FrameLinks::enterEvent(QEvent *)
+void CanvasMode_FrameLinks::enterEvent(QEvent *e)
 {
 	if (!m_canvas->m_viewMode.m_MouseButtonPressed)
 	{
@@ -86,6 +83,8 @@ void CanvasMode_FrameLinks::leaveEvent(QEvent *e)
 void CanvasMode_FrameLinks::activate(bool fromGesture)
 {
 //	qDebug() << "CanvasMode_FrameLinks::activate" << fromGesture;
+	CanvasMode::activate(fromGesture);
+
 	if (m_doc->m_Selection->count() >= 2)
 	{
 		switch (m_doc->appMode)
@@ -96,8 +95,8 @@ void CanvasMode_FrameLinks::activate(bool fromGesture)
 			{
 				PageItem* item1 = m_doc->m_Selection->itemAt(i);
 				PageItem* item2 = m_doc->m_Selection->itemAt(i+1);
-				if ((item1 != nullptr && item1->asTextFrame()) &&
-					(item2 != nullptr && item2->asTextFrame()) &&
+				if ((item1 != nullptr && item1->isTextFrame()) &&
+					(item2 != nullptr && item2->isTextFrame()) &&
 				     item1->canBeLinkedTo(item2))
 				{
 					item1->link(item2);
@@ -116,7 +115,6 @@ void CanvasMode_FrameLinks::activate(bool fromGesture)
 	m_canvas->m_viewMode.operItemResizing = false;
 	m_view->MidButt = false;
 	m_Mxp = m_Myp = -1;
-	m_Dxp = m_Dyp = -1;
 	m_frameResizeHandle = -1;
 	setModeCursor();
 	if (fromGesture)
@@ -129,6 +127,17 @@ void CanvasMode_FrameLinks::deactivate(bool forGesture)
 {
 //	qDebug() << "CanvasMode_FrameLinks::deactivate" << forGesture;
 	m_view->setRedrawMarkerShown(false);
+	CanvasMode::deactivate(forGesture);
+}
+
+void CanvasMode_FrameLinks::keyPressEvent(QKeyEvent *e)
+{
+	commonkeyPressEvent_Default(e);
+}
+
+void CanvasMode_FrameLinks::keyReleaseEvent(QKeyEvent *e)
+{
+	commonkeyReleaseEvent(e);
 }
 
 void CanvasMode_FrameLinks::mouseDoubleClickEvent(QMouseEvent *m)
@@ -149,7 +158,7 @@ void CanvasMode_FrameLinks::mouseMoveEvent(QMouseEvent *m)
 		return;
 	if ((m_canvas->m_viewMode.m_MouseButtonPressed) && (m->buttons() & Qt::LeftButton))
 	{
-		QPoint startP = m_canvas->canvasToGlobal(m_doc->appMode == modeDrawTable2 ? QPointF(m_Dxp, m_Dyp) : QPointF(m_Mxp, m_Myp));
+		QPoint startP = m_canvas->canvasToGlobal(QPointF(m_Mxp, m_Myp));
 		m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(m->globalPos())).normalized());
 		m_view->setRedrawMarkerShown(true);
 		m_view->HaveSelRect = true;
@@ -197,7 +206,7 @@ void CanvasMode_FrameLinks::mousePressEvent(QMouseEvent *m)
 			// #14334: delay selection signals so that (un)link actions get properly enabled/disabled
 			m_doc->m_Selection->delaySignalsOn();
 			SeleItem(m);
-			if (GetItem(&bb) && (bb->asTextFrame()))
+			if (GetItem(&bb) && (bb->isTextFrame()))
 			{
 				PageItem* bblast = bb;
 				while (bblast->nextInChain())
@@ -277,6 +286,13 @@ void CanvasMode_FrameLinks::mousePressEvent(QMouseEvent *m)
 					ScMessageBox::warning(m_view, tr("Linking Text Frames"),
 										"<qt>" + tr("You are trying to link a frame to itself.") + "</qt>");
 				}
+				else if (currItem->nextInChain() != nullptr)
+				{
+					//CB Mouse is released when this messagebox takes focus
+					m_canvas->m_viewMode.m_MouseButtonPressed = false;
+					ScMessageBox::warning(m_view, tr("Linking Text Frames"),
+										 "<qt>" + tr("Frame is already linked. Unlink it before linking it to another frame.") + "</qt>");
+				}
 				else
 				{
 					//CB Mouse is released when this messagebox takes focus
@@ -295,7 +311,7 @@ void CanvasMode_FrameLinks::mousePressEvent(QMouseEvent *m)
 			// #14334: delay selection signals so that (un)link actions get properly enabled/disabled
 			m_doc->m_Selection->delaySignalsOn();
 			SeleItem(m);
-			if (GetItem(&currItem) && (currItem->asTextFrame()))
+			if (GetItem(&currItem) && (currItem->isTextFrame()))
 			{
 				if (currItem->prevInChain() != nullptr)
 				{
@@ -312,7 +328,7 @@ void CanvasMode_FrameLinks::mousePressEvent(QMouseEvent *m)
 void CanvasMode_FrameLinks::mouseReleaseEvent(QMouseEvent *m)
 {
 #ifdef GESTURE_FRAME_PREVIEW
-        clearPixmapCache();
+	clearPixmapCache();
 #endif // GESTURE_FRAME_PREVIEW
 	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
 	PageItem *currItem;
@@ -353,7 +369,7 @@ void CanvasMode_FrameLinks::selectPage(QMouseEvent *m)
 	m_Mxp = mousePointDoc.x(); //static_cast<int>(m->x()/m_canvas->scale());
 	m_Myp = mousePointDoc.y(); //static_cast<int>(m->y()/m_canvas->scale());
 	m_doc->nodeEdit.deselect();
-	m_view->Deselect(false);
+	m_view->deselectItems(false);
 	if (!m_doc->masterPageMode())
 	{
 		int i = m_doc->OnPage(m_Mxp, m_Myp);
@@ -428,8 +444,8 @@ bool CanvasMode_FrameLinks::SeleItem(QMouseEvent *m)
 		{
 			if (m_doc->currentPageNumber() != pgNum)
 			{
-				m_doc->setCurrentPage(m_doc->Pages->at(unsigned(pgNum)));
-				m_view->m_ScMW->slotSetCurrentPage(unsigned(pgNum));
+				m_doc->setCurrentPage(m_doc->Pages->at(pgNum));
+				m_view->m_ScMW->slotSetCurrentPage(pgNum);
 				m_view->DrawNew();
 			}
 		}
@@ -451,7 +467,7 @@ bool CanvasMode_FrameLinks::SeleItem(QMouseEvent *m)
 	}
 	else if ( (m->modifiers() & SELECT_MULTIPLE) == Qt::NoModifier || (m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames) )
 	{
-		m_view->Deselect(false);
+		m_view->deselectItems(false);
 	}
 	currItem = m_canvas->itemUnderCursor(m->globalPos(), currItem, (m->modifiers() & SELECT_IN_GROUP));
 	if (currItem)
@@ -483,7 +499,6 @@ bool CanvasMode_FrameLinks::SeleItem(QMouseEvent *m)
 				PageItem *bb = m_doc->m_Selection->itemAt(aa);
 				bb->update();
 			}
-			m_doc->m_Selection->setGroupRect();
 			double x, y, w, h;
 			m_doc->m_Selection->getGroupRect(&x, &y, &w, &h);
 			m_view->getGroupRectScreen(&x, &y, &w, &h);
@@ -503,7 +518,7 @@ bool CanvasMode_FrameLinks::SeleItem(QMouseEvent *m)
 	}
 	m_doc->m_Selection->connectItemToGUI();
 	if ( !(m->modifiers() & SELECT_MULTIPLE) || (m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames))
-		m_view->Deselect(true);
+		m_view->deselectItems(true);
 	return false;
 }
 
