@@ -38,22 +38,14 @@
 #include "undomanager.h"
 #include "util_math.h"
 
-CanvasMode_NodeEdit::CanvasMode_NodeEdit(ScribusView* view) : CanvasMode(view), m_rectangleSelect(nullptr)
+CanvasMode_NodeEdit::CanvasMode_NodeEdit(ScribusView* view) : CanvasMode(view)
 {
-	m_Mxp = -1;  // last mouse position
-	m_Myp = -1;
-	m_Dxp = -1;  // last mouse press position for rectangle select
-	m_Dyp = -1;
-	m_GxM = -1;  // guide position
-	m_GyM = -1;
-	m_MoveGX = m_MoveGY = false;
 	m_ScMW = m_view->m_ScMW;
 }
 
 void CanvasMode_NodeEdit::drawControls(QPainter* p) 
 {
-	double x, y;
-	if (m_doc->m_Selection->count() == 0)
+	if (m_doc->m_Selection->isEmpty())
 		return;
 	if (m_doc->nodeEdit.previewMode())
 		return;
@@ -91,15 +83,15 @@ void CanvasMode_NodeEdit::drawControls(QPainter* p)
 	const double onePerScale = 1 / scale;
 	if (cli.size() > 3)
 	{
-		for (int poi=0; poi<cli.size()-3; poi += 4)
+		for (int i = 0; i < cli.size() - 3; i += 4)
 		{
-			if (cli.isMarker(poi))
+			if (cli.isMarker(i))
 				continue;
 			p->setPen(QPen(Qt::blue, onePerScale, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-			const FPoint& a1 = cli.point(poi);
-			const FPoint& a2 = cli.point(poi+1);
-			const FPoint& a3 = cli.point(poi+3);
-			const FPoint& a4 =	cli.point(poi+2);
+			const FPoint& a1 = cli.point(i);
+			const FPoint& a2 = cli.point(i + 1);
+			const FPoint& a3 = cli.point(i + 3);
+			const FPoint& a4 =	cli.point(i + 2);
 			QPainterPath Bez;
 			Bez.moveTo(a1.x(), a1.y());
 			Bez.cubicTo(a2.x(), a2.y(), a3.x(), a3.y(), a4.x(), a4.y());
@@ -109,39 +101,31 @@ void CanvasMode_NodeEdit::drawControls(QPainter* p)
 			p->drawLine(QPointF(a3.x(), a3.y()), QPointF(a4.x(), a4.y()));
 		}
 	}
+	double x = 0.0;
+	double y = 0.0;
 	// draw points
-	for (int a = 0; a < cli.size()-1; a += 2)
+	for (int i = 0; i < cli.size() - 1; i += 2)
 	{
-		if (cli.isMarker(a))
+		if (cli.isMarker(i))
 			continue;
+		Qt::GlobalColor color1 = (m_doc->nodeEdit.clre() == (i + 1)) ? Qt::red : Qt::magenta;
+		Qt::GlobalColor color2 = (m_doc->nodeEdit.clre() == i) ? Qt::red : Qt::blue;
 		if (m_doc->nodeEdit.edPoints())
 		{
-			if (m_doc->nodeEdit.clre() == static_cast<int>(a+1))
-				p->setPen(QPen(Qt::red, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
-			else
-				p->setPen(QPen(Qt::magenta, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
-			cli.point(a+1, &x, &y);
+			p->setPen(QPen(color1, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
+			cli.point(i + 1, &x, &y);
 			p->drawPoint(QPointF(x, y));
-			if (m_doc->nodeEdit.clre() == static_cast<int>(a))
-				p->setPen(QPen(Qt::red, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
-			else
-				p->setPen(QPen(Qt::blue, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
-			cli.point(a, &x, &y);
+			p->setPen(QPen(color2, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
+			cli.point(i, &x, &y);
 			p->drawPoint(QPointF(x, y));
 		}
 		else
 		{
-			if (m_doc->nodeEdit.clre() == static_cast<int>(a))
-				p->setPen(QPen(Qt::red, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
-			else
-				p->setPen(QPen(Qt::blue, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
-			cli.point(a, &x, &y);
+			p->setPen(QPen(color2, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
+			cli.point(i, &x, &y);
 			p->drawPoint(QPointF(x, y));
-			if (m_doc->nodeEdit.clre() == static_cast<int>(a+1))
-				p->setPen(QPen(Qt::red, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
-			else
-				p->setPen(QPen(Qt::magenta, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
-			cli.point(a+1, &x, &y);
+			p->setPen(QPen(color1, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
+			cli.point(i + 1, &x, &y);
 			p->drawPoint(QPointF(x, y));
 		}
 	}
@@ -154,7 +138,8 @@ void CanvasMode_NodeEdit::drawControls(QPainter* p)
 		const auto& selectedNodes = m_doc->nodeEdit.selNode();
 		for (int i = 0; i < selectedNodes.count(); ++i)
 		{
-			cli.point(i, &x, &y);
+			int selectedNode = selectedNodes.at(i);
+			cli.point(selectedNode, &x, &y);
 			p->drawPoint(QPointF(x, y));
 		}
 	}
@@ -174,6 +159,7 @@ void CanvasMode_NodeEdit::drawControls(QPainter* p)
 
 void CanvasMode_NodeEdit::activate(bool fromGesture)
 {
+	CanvasMode::activate(fromGesture);
 	if (fromGesture && m_rectangleSelect)
 	{
 		m_canvas->m_viewMode.m_MouseButtonPressed = false;
@@ -236,7 +222,6 @@ void CanvasMode_NodeEdit::activate(bool fromGesture)
 	}
 }
 
-
 void CanvasMode_NodeEdit::deactivate(bool forGesture)
 {
 	if (!forGesture && m_rectangleSelect)
@@ -245,6 +230,7 @@ void CanvasMode_NodeEdit::deactivate(bool forGesture)
 		delete m_rectangleSelect;
 		m_rectangleSelect = nullptr;
 	}
+	CanvasMode::deactivate(forGesture);
 }
 
 
@@ -256,7 +242,7 @@ inline bool CanvasMode_NodeEdit::GetItem(PageItem** pi)
 
 
 
-void CanvasMode_NodeEdit::enterEvent(QEvent *)
+void CanvasMode_NodeEdit::enterEvent(QEvent *e)
 {
 }
 
@@ -459,9 +445,14 @@ void CanvasMode_NodeEdit::mouseReleaseEvent(QMouseEvent *m)
 			}
 			m_doc->nodeEdit.moveClipPoint(currItem, npf);
 		}
-		m_doc->adjustItemSize(currItem, true, true);
+		m_doc->adjustItemSize(currItem, true);
 		if (!m_doc->nodeEdit.isContourLine())
-			currItem->ContourLine.translate(xposOrig - currItem->xPos(), yposOrig - currItem->yPos());
+		{
+			// Move the contour accordingly in the item's coordinate space
+			QTransform m = QTransform().rotate(-currItem->rotation());
+			QPointF delta = m.map(QPointF(xposOrig, yposOrig)) - m.map(QPointF(currItem->xPos(), currItem->yPos()));
+			currItem->ContourLine.translate(delta.x(), delta.y());
+		}
 		m_doc->regionsChanged()->update(QRectF());
 		if (state)
 			m_doc->nodeEdit.finishTransaction2(currItem, state);
@@ -505,14 +496,16 @@ void CanvasMode_NodeEdit::keyReleaseEvent(QKeyEvent *e)
 	commonkeyReleaseEvent(e);
 }
 
-void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
+void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect r)
 {
 	FPoint npf2;
+	bool edited = false;
+	bool pfound = false;
 	
 	PageItem* currItem = m_doc->m_Selection->itemAt(0);
 	FPointArray Clip = m_doc->nodeEdit.beginTransaction(currItem);
-	bool edited = false;
-	bool pfound = false;
+	m_doc->nodeEdit.deselect();
+
 	QTransform pm2 = currItem->getTransform();
 	npf2 = m_canvas->globalToCanvas(m->globalPos()).transformPoint(pm2, true);
 	if ((currItem->isSymbol() || currItem->isGroup()) && (!m_doc->nodeEdit.isContourLine()))
@@ -595,19 +588,19 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 			double nearT = 0.0;
 			QRect mpo2(0, 0, m_doc->guidesPrefs().grabRadius*3, m_doc->guidesPrefs().grabRadius*3);
 			mpo2.moveCenter(QPoint(qRound(npf2.x()), qRound(npf2.y())));
-			for (int poi=0; poi<Clip.size()-3; poi += 4)
+			for (int poi = 0; poi < Clip.size() - 3; poi += 4)
 			{
 				const FPoint& a1 = Clip.point(poi);
-				const FPoint& a2 = Clip.point(poi+1);
-				const FPoint& a3 = Clip.point(poi+3);
-				const FPoint& a4 = Clip.point(poi+2);
+				const FPoint& a2 = Clip.point(poi + 1);
+				const FPoint& a3 = Clip.point(poi + 3);
+				const FPoint& a4 = Clip.point(poi + 2);
 				QPainterPath Bez;
 				Bez.moveTo(a1.x(), a1.y());
 				Bez.cubicTo(a2.x(), a2.y(), a3.x(), a3.y(), a4.x(), a4.y());
 				QPolygon cli2 = Bez.toFillPolygon().toPolygon();
 				for (int clp = 0; clp < cli2.size()-1; ++clp)
 				{
-					if (m_view->PointOnLine(cli2.point(clp), cli2.point(clp+1), mpo2))
+					if (m_view->PointOnLine(cli2.point(clp), cli2.point(clp + 1), mpo2))
 					{
 						seg = poi;
 						double sp = 0.0;
@@ -628,19 +621,19 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 					}
 				}
 			}
-			cli.putPoints(0, m_doc->nodeEdit.clre2()+2, Clip);
+			cli.putPoints(0, m_doc->nodeEdit.clre2() + 2, Clip);
 			if (foundP)
 			{
 				npf2 = nearPoint;
-				FPoint base = cli.point(cli.size()-2);
-				FPoint c1 = cli.point(cli.size()-1);
-				FPoint base2 =  Clip.point(m_doc->nodeEdit.clre2()+2);
-				FPoint c2 = Clip.point(m_doc->nodeEdit.clre2()+3);
+				FPoint base = cli.point(cli.size() - 2);
+				FPoint c1 = cli.point(cli.size() - 1);
+				FPoint base2 =  Clip.point(m_doc->nodeEdit.clre2() + 2);
+				FPoint c2 = Clip.point(m_doc->nodeEdit.clre2() + 3);
 				if ((base == c1) && (base2 == c2))
 				{
 					cli.resize(cli.size()+4);
-					cli.putPoints(cli.size()-4, 4, npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y());
-					cli.putPoints(cli.size(), Clip.size()-(m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2()+2);
+					cli.putPoints(cli.size() - 4, 4, npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y());
+					cli.putPoints(cli.size(), Clip.size() - (m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2() + 2);
 				}
 				else
 				{
@@ -649,15 +642,15 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 					FPoint cn3 = (1.0 - nearT) * ((1.0 - nearT) * c1 + nearT * c2) + nearT * ((1.0 - nearT) * c2 + nearT * base2);
 					FPoint cn4 = (1.0 - nearT) * c2 + nearT * base2;
 					cli.setPoint(cli.size()-1, cn1);
-					cli.resize(cli.size()+4);
-					int basind = cli.size()+1;
-					cli.putPoints(cli.size()-4, 4, npf2.x(), npf2.y(), cn2.x(), cn2.y(), npf2.x(), npf2.y(), cn3.x(), cn3.y());
-					cli.putPoints(cli.size(), Clip.size()-(m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2()+2);
+					cli.resize(cli.size() + 4);
+					int basind = cli.size() + 1;
+					cli.putPoints(cli.size() - 4, 4, npf2.x(), npf2.y(), cn2.x(), cn2.y(), npf2.x(), npf2.y(), cn3.x(), cn3.y());
+					cli.putPoints(cli.size(), Clip.size() - (m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2() + 2);
 					cli.setPoint(basind, cn4);
 				}
 				Clip = cli.copy();
 				cli.resize(0);
-				m_doc->nodeEdit.setClre(m_doc->nodeEdit.clre2()+2);
+				m_doc->nodeEdit.setClre(m_doc->nodeEdit.clre2() + 2);
 				m_doc->nodeEdit.setClre2(-1);
 				EndInd = Clip.size();
 				StartInd = 0;
@@ -686,14 +679,14 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 		}
 		if (m_doc->nodeEdit.hasNodeSelected())
 		{
-			if (currItem->asPolygon())
+			if (currItem->isPolygon())
 			{
-				if ((m_doc->nodeEdit.clre() != 0) && (m_doc->nodeEdit.clre() != static_cast<int>(EndInd-2)))
+				if ((m_doc->nodeEdit.clre() != 0) && (m_doc->nodeEdit.clre() != (EndInd - 2)))
 				{
 					if (currItem->Segments.count() == 0)
 					{
-						cli.putPoints(0, EndInd-(m_doc->nodeEdit.clre()+2), Clip, m_doc->nodeEdit.clre()+2);
-						cli.putPoints(cli.size(), m_doc->nodeEdit.clre()+2, Clip);
+						cli.putPoints(0, EndInd - (m_doc->nodeEdit.clre() + 2), Clip, m_doc->nodeEdit.clre() + 2);
+						cli.putPoints(cli.size(), m_doc->nodeEdit.clre() + 2, Clip);
 					}
 					else
 					{
@@ -709,25 +702,25 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 							if (m_doc->nodeEdit.isContourLine())
 							{
 								bb->ContourLine.putPoints(0, StartInd - 4, Clip);
-								bb->ContourLine.putPoints(bb->ContourLine.size(), Clip.size()-EndInd, Clip, EndInd);
+								bb->ContourLine.putPoints(bb->ContourLine.size(), Clip.size() -EndInd, Clip, EndInd);
 							}
 							else
 							{
 								bb->PoLine.putPoints(0, StartInd - 4, Clip);
-								bb->PoLine.putPoints(bb->PoLine.size(), Clip.size()-EndInd, Clip, EndInd);
+								bb->PoLine.putPoints(bb->PoLine.size(), Clip.size() - EndInd, Clip, EndInd);
 							}
 						}
 						else
 						{
 							if (m_doc->nodeEdit.isContourLine())
-								bb->ContourLine.putPoints(0, Clip.size()-EndInd-4, Clip, EndInd+4);
+								bb->ContourLine.putPoints(0, Clip.size() - EndInd - 4, Clip, EndInd + 4);
 							else
-								bb->PoLine.putPoints(0, Clip.size()-EndInd-4, Clip, EndInd+4);
+								bb->PoLine.putPoints(0, Clip.size() - EndInd - 4, Clip, EndInd + 4);
 						}
 						bb->setRotation(currItem->rotation());
 						bb->ClipEdited = true;
 						m_doc->Items->insert(m_doc->Items->indexOf(currItem), bb);
-						m_doc->adjustItemSize(bb, true, true);
+						m_doc->adjustItemSize(bb, true);
 					}
 					currItem->PoLine = cli.copy();
 				}
@@ -743,22 +736,22 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 			}
 			else
 			{
-				if ((currItem->asPolyLine()) || (currItem->asPathText()))
+				if ((currItem->isPolyLine()) || (currItem->isPathText()))
 				{
-					if ((m_doc->nodeEdit.clre() > 1) && (m_doc->nodeEdit.clre() < static_cast<int>(Clip.size()-2)))
+					if ((m_doc->nodeEdit.clre() > 1) && (m_doc->nodeEdit.clre() < (Clip.size() - 2)))
 					{
 						int z = m_doc->itemAdd(PageItem::PolyLine, PageItem::Unspecified, currItem->xPos(), currItem->yPos(), currItem->width(), currItem->height(), currItem->lineWidth(), currItem->fillColor(), currItem->lineColor());
 						PageItem* bb = m_doc->Items->at(z);
 						if (m_doc->nodeEdit.isContourLine())
-							bb->ContourLine.putPoints(0, Clip.size()-(m_doc->nodeEdit.clre()+2), Clip, m_doc->nodeEdit.clre()+2);
+							bb->ContourLine.putPoints(0, Clip.size() - (m_doc->nodeEdit.clre() + 2), Clip, m_doc->nodeEdit.clre() + 2);
 						else
-							bb->PoLine.putPoints(0, Clip.size()-(m_doc->nodeEdit.clre()+2), Clip, m_doc->nodeEdit.clre()+2);
+							bb->PoLine.putPoints(0, Clip.size() - (m_doc->nodeEdit.clre() + 2), Clip, m_doc->nodeEdit.clre() + 2);
 						bb->setRotation(currItem->rotation());
-						m_doc->adjustItemSize(bb, true, true);
+						m_doc->adjustItemSize(bb, true);
 						bb->ClipEdited = true;
 						bb->setFrameType(currItem->frameType());
 						cli.resize(0);
-						cli.putPoints(0, m_doc->nodeEdit.clre()+2, Clip);
+						cli.putPoints(0, m_doc->nodeEdit.clre() + 2, Clip);
 						currItem->PoLine = cli.copy();
 						m_doc->m_Selection->clear();
 						m_doc->m_Selection->addItem(currItem);
@@ -793,10 +786,10 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 		if ((currItem->Segments.count() > 0) && ((EndInd - StartInd) <= minClipSize) && (numPoints > 0))
 		{
 			if (StartInd != 0)
-				cli.putPoints(0, StartInd-4, Clip);
+				cli.putPoints(0, StartInd - 4, Clip);
 			cli.putPoints(cli.size(), Clip.size() - EndInd, Clip, EndInd);
 		}
-		else if (m_doc->nodeEdit.clre() == static_cast<int>(StartInd))
+		else if (m_doc->nodeEdit.clre() == StartInd)
 		{
 			if (!currItem->isLine() && !currItem->isPathText() && !currItem->isPolyLine())
 			{
@@ -814,7 +807,7 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 				cli.putPoints(cli.size(), Clip.size() - EndInd, Clip, EndInd);
 			}
 		}
-		else if (m_doc->nodeEdit.clre() == static_cast<int>(EndInd - 2))
+		else if (m_doc->nodeEdit.clre() == (EndInd - 2))
 		{
 			Clip.remove(m_doc->nodeEdit.clre() - 2, 4);
 			cli = Clip.copy();
@@ -823,7 +816,7 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 		{
 			if (m_doc->nodeEdit.clre() != 0)
 				cli.putPoints(0, m_doc->nodeEdit.clre(), Clip);
-			cli.putPoints(cli.size(), Clip.size()-(m_doc->nodeEdit.clre() + 4), Clip, m_doc->nodeEdit.clre() + 4);
+			cli.putPoints(cli.size(), Clip.size() - (m_doc->nodeEdit.clre() + 4), Clip, m_doc->nodeEdit.clre() + 4);
 		}
 		while (cli.isMarker(0))
 			cli.remove(0, 4);
@@ -845,21 +838,21 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 		FPoint tangent = FPoint(0, 0);
 		FPoint nearPoint = FPoint(0, 0);
 		double nearT = 0.0;
-		QRect mpo2(0, 0, m_doc->guidesPrefs().grabRadius*3, m_doc->guidesPrefs().grabRadius*3);
+		QRect mpo2(0, 0, m_doc->guidesPrefs().grabRadius * 3, m_doc->guidesPrefs().grabRadius * 3);
 		mpo2.moveCenter(QPoint(qRound(npf2.x()), qRound(npf2.y())));
-		for (int poi = 0; poi < Clip.size()-3; poi += 4)
+		for (int poi = 0; poi < Clip.size() - 3; poi += 4)
 		{
 			const FPoint& a1 = Clip.point(poi);
-			const FPoint& a2 = Clip.point(poi+1);
-			const FPoint& a3 = Clip.point(poi+3);
-			const FPoint& a4 = Clip.point(poi+2);
+			const FPoint& a2 = Clip.point(poi + 1);
+			const FPoint& a3 = Clip.point(poi + 3);
+			const FPoint& a4 = Clip.point(poi + 2);
 			QPainterPath Bez;
 			Bez.moveTo(a1.x(), a1.y());
 			Bez.cubicTo(a2.x(), a2.y(), a3.x(), a3.y(), a4.x(), a4.y());
 			QPolygon cli2 = Bez.toFillPolygon().toPolygon();
-			for (int clp = 0; clp < cli2.size()-1; ++clp)
+			for (int clp = 0; clp < cli2.size() - 1; ++clp)
 			{
-				if (m_view->PointOnLine(cli2.point(clp), cli2.point(clp+1), mpo2))
+				if (m_view->PointOnLine(cli2.point(clp), cli2.point(clp + 1), mpo2))
 				{
 					seg = poi;
 					double sp = 0.0;
@@ -880,19 +873,19 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 				}
 			}
 		}
-		cli.putPoints(0, m_doc->nodeEdit.clre2()+2, Clip);
+		cli.putPoints(0, m_doc->nodeEdit.clre2() + 2, Clip);
 		if (foundP)
 		{
 			npf2 = nearPoint;
-			FPoint base = cli.point(cli.size()-2);
-			FPoint c1 = cli.point(cli.size()-1);
-			const FPoint& base2 =  Clip.point(m_doc->nodeEdit.clre2()+2);
-			const FPoint& c2 = Clip.point(m_doc->nodeEdit.clre2()+3);
+			FPoint base = cli.point(cli.size() - 2);
+			FPoint c1 = cli.point(cli.size() - 1);
+			const FPoint& base2 =  Clip.point(m_doc->nodeEdit.clre2() + 2);
+			const FPoint& c2 = Clip.point(m_doc->nodeEdit.clre2() + 3);
 			if ((base == c1) && (base2 == c2))
 			{
-				cli.resize(cli.size()+4);
-				cli.putPoints(cli.size()-4, 4, npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y());
-						cli.putPoints(cli.size(), Clip.size()-(m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2()+2);
+				cli.resize(cli.size() + 4);
+				cli.putPoints(cli.size() - 4, 4, npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y());
+				cli.putPoints(cli.size(), Clip.size() - (m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2() + 2);
 			}
 			else
 			{
@@ -900,19 +893,19 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 				FPoint cn2 = (1.0 - nearT) * cn1 + nearT * ((1.0 - nearT) * c1 + nearT * c2);
 				FPoint cn3 = (1.0 - nearT) * ((1.0 - nearT) * c1 + nearT * c2) + nearT * ((1.0 - nearT) * c2 + nearT * base2);
 				FPoint cn4 = (1.0 - nearT) * c2 + nearT * base2;
-				cli.setPoint(cli.size()-1, cn1);
-				cli.resize(cli.size()+4);
-				uint basind = cli.size()+1;
-				cli.putPoints(cli.size()-4, 4, npf2.x(), npf2.y(), cn2.x(), cn2.y(), npf2.x(), npf2.y(), cn3.x(), cn3.y());
-				cli.putPoints(cli.size(), Clip.size()-(m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2()+2);
+				cli.setPoint(cli.size() - 1, cn1);
+				cli.resize(cli.size() + 4);
+				uint basind = cli.size() + 1;
+				cli.putPoints(cli.size() - 4, 4, npf2.x(), npf2.y(), cn2.x(), cn2.y(), npf2.x(), npf2.y(), cn3.x(), cn3.y());
+				cli.putPoints(cli.size(), Clip.size() - (m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2() + 2);
 				cli.setPoint(basind, cn4);
 			}
 		}
 		else
 		{
-			cli.resize(cli.size()+4);
-			cli.putPoints(cli.size()-4, 4, npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y());
-			cli.putPoints(cli.size(), Clip.size()-(m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2()+2);
+			cli.resize(cli.size() + 4);
+			cli.putPoints(cli.size() - 4, 4, npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y(), npf2.x(), npf2.y());
+			cli.putPoints(cli.size(), Clip.size() - (m_doc->nodeEdit.clre2() + 2), Clip, m_doc->nodeEdit.clre2() + 2);
 		}
 		if (m_doc->nodeEdit.isContourLine())
 			currItem->ContourLine = cli.copy();
@@ -930,7 +923,7 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 		yp = currItem->yPos();
 		w = currItem->width();
 		h = currItem->height();
-		m_doc->adjustItemSize(currItem, true, true);
+		m_doc->adjustItemSize(currItem, true);
 		xp2 = currItem->xPos();
 		yp2 = currItem->yPos();
 		w2 = currItem->width();
@@ -955,8 +948,8 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 	{
 		m_Mxp = m->x();
 		m_Myp = m->y();
-		m_Dxp = qRound(m->x()/m_canvas->scale());  // + m_doc->minCanvasCoordinate.x());
-		m_Dyp = qRound(m->y()/m_canvas->scale());  // + m_doc->minCanvasCoordinate.y());
+		m_Dxp = qRound(m->x() / m_canvas->scale());  // + m_doc->minCanvasCoordinate.x());
+		m_Dyp = qRound(m->y() / m_canvas->scale());  // + m_doc->minCanvasCoordinate.y());
 		if (!m_rectangleSelect)
 			m_rectangleSelect = new RectSelect(this);
 		m_rectangleSelect->prepare(m->globalPos());
@@ -967,7 +960,7 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect)
 
 
 
-bool CanvasMode_NodeEdit::handleNodeEditMove(QMouseEvent* m, QRect, PageItem* currItem, const QTransform&)
+bool CanvasMode_NodeEdit::handleNodeEditMove(QMouseEvent* m, QRect /*r*/, PageItem* currItem, const QTransform& /*t*/)
 {
 	QTransform itemPos = currItem->getTransform();
 	if ((currItem->isSymbol() || currItem->isGroup()) && (!m_doc->nodeEdit.isContourLine()))
@@ -995,11 +988,11 @@ bool CanvasMode_NodeEdit::handleNodeEditMove(QMouseEvent* m, QRect, PageItem* cu
 		(m_doc->nodeEdit.submode() == NodeEditContext::MOVE_POINT) ||
 		(m_doc->nodeEdit.submode() == NodeEditContext::SPLIT_PATH))
 	{
-		for (int a=0; a < signed(Clip.size()); ++a)
+		for (int i = 0; i < Clip.size(); ++i)
 		{
-			if (((m_doc->nodeEdit.edPoints()) && (a % 2 != 0)) || ((!m_doc->nodeEdit.edPoints()) && (a % 2 == 0)))
+			if (((m_doc->nodeEdit.edPoints()) && (i % 2 != 0)) || ((!m_doc->nodeEdit.edPoints()) && (i % 2 == 0)))
 				continue;
-			QPointF point = Clip.pointQF(a);
+			QPointF point = Clip.pointQF(i);
 			if (m_canvas->hitsCanvasPoint(m->globalPos(), itemPos.map(point)))
 			{
 				if (m_doc->nodeEdit.submode() == NodeEditContext::MOVE_POINT)
@@ -1016,13 +1009,13 @@ bool CanvasMode_NodeEdit::handleNodeEditMove(QMouseEvent* m, QRect, PageItem* cu
 		(m_doc->nodeEdit.submode() == NodeEditContext::MOVE_POINT) ||
 		(m_doc->nodeEdit.submode() == NodeEditContext::SPLIT_PATH && m_doc->nodeEdit.edPoints()))
 	{
-		for (int poi = 0; poi < Clip.size()-3; poi += 4)
+		for (int poi = 0; poi < Clip.size() - 3; poi += 4)
 		{
 			// create bezier curve in canvas coords
 			QPointF a1 = itemPos.map(Clip.pointQF(poi));
-			QPointF a2 = itemPos.map(Clip.pointQF(poi+1));
-			QPointF a3 = itemPos.map(Clip.pointQF(poi+3));
-			QPointF a4 = itemPos.map(Clip.pointQF(poi+2));
+			QPointF a2 = itemPos.map(Clip.pointQF(poi + 1));
+			QPointF a3 = itemPos.map(Clip.pointQF(poi + 3));
+			QPointF a4 = itemPos.map(Clip.pointQF(poi + 2));
 			QPainterPath Bez;
 			Bez.moveTo(a1);
 			Bez.cubicTo(a2, a3, a4);
@@ -1132,7 +1125,8 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 				}
 
 				//Control Modifier to have parallele shape
-				if (m->modifiers() == Qt::ControlModifier){
+				if (m->modifiers() == Qt::ControlModifier)
+				{
 					FPointArray cli;
 					if (m_doc->nodeEdit.isContourLine())
 						cli = currItem->ContourLine;
@@ -1140,20 +1134,21 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 						cli = currItem->PoLine;
 					FPoint npf1(npf);
 					int tmpNode;
-					int curr = (m_doc->nodeEdit.clre()==0) ? cli.size()-2 : m_doc->nodeEdit.clre();
-					int prev = (curr+cli.size()-4)%cli.size();
-					int next = (curr+4)%cli.size();
+					int curr = (m_doc->nodeEdit.clre() == 0) ? cli.size() - 2 : m_doc->nodeEdit.clre();
+					int prev = (curr + cli.size() - 4) % cli.size();
+					int next = (curr+4) % cli.size();
 
-					if (std::abs(cli.point(prev).x()-cli.point(curr).x())<std::abs(cli.point(next).x()-cli.point(curr).x()))
-						tmpNode=next;
-					else if (std::abs(cli.point(prev).x()-cli.point(curr).x())==std::abs(cli.point(next).x()-cli.point(curr).x())){
-						if (cli.point(prev).y()!=cli.point(curr).y())
-							tmpNode=next;
+					if (std::abs(cli.point(prev).x() - cli.point(curr).x()) < std::abs(cli.point(next).x() - cli.point(curr).x()))
+						tmpNode = next;
+					else if (std::abs(cli.point(prev).x() - cli.point(curr).x()) == std::abs(cli.point(next).x() - cli.point(curr).x()))
+					{
+						if (cli.point(prev).y() != cli.point(curr).y())
+							tmpNode = next;
 						else
-							tmpNode=prev;
+							tmpNode = prev;
 					}
 					else
-						tmpNode=prev;
+						tmpNode = prev;
 
 					m_doc->nodeEdit.moveClipPoint(currItem, npf);
 
@@ -1166,7 +1161,7 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 
 					m_doc->nodeEdit.moveClipPoint(currItem, npf1);
 
-					if (m_doc->nodeEdit.clre()==prev)
+					if (m_doc->nodeEdit.clre() == prev)
 						m_doc->nodeEdit.setClre(next);
 					else
 						m_doc->nodeEdit.setClre(prev);
