@@ -31,17 +31,10 @@ for which a new license (GPL+exception) is in place.
 #include <QString>
 
 CollectForOutput::CollectForOutput(ScribusDoc* doc, const QString& outputDirectory, bool withFonts, bool withProfiles, bool compressDoc)
-	: QObject(ScCore),
-	m_Doc(nullptr),
-	m_outputDirectory(QString::null),
-	profileCount(0),
-	itemCount(0),
-	fontCount(0),
-	patternCount(0),
-	uiCollect(false)
+	: QObject(ScCore)
 {
 	m_Doc=doc;
-	if (outputDirectory!=QString::null)
+	if (!outputDirectory.isEmpty())
 		m_outputDirectory=outputDirectory;
 	m_compressDoc = compressDoc;
 	m_withFonts = withFonts;
@@ -148,7 +141,7 @@ QString CollectForOutput::collect(QString &newFileName)
 	collectedFiles.clear();
 	newFileName = newName;
 
-	return QString::null;
+	return QString();
 }
 
 bool CollectForOutput::collectDocument()
@@ -270,7 +263,7 @@ bool CollectForOutput::collectItems()
 
 void CollectForOutput::processItem(PageItem *ite)
 {
-	if (ite->asImageFrame())
+	if (ite->isImageFrame())
 	{
 		/* hack for subsequent c4o "./" -> "/doc/full/path" */
 		if (!ite->isInlineImage)
@@ -293,7 +286,7 @@ void CollectForOutput::processItem(PageItem *ite)
 		}
 	}
 #ifdef HAVE_OSG
-	if (ite->asOSGFrame())
+	if (ite->isOSGFrame())
 	{
 		PageItem_OSGFrame *osgframe = ite->asOSGFrame();
 		QString ofName(osgframe->modelFile);
@@ -310,7 +303,7 @@ void CollectForOutput::processItem(PageItem *ite)
 		}
 	}
 #endif
-	if (ite->asTextFrame())
+	if (ite->isTextFrame())
 	{
 		if (ite->isAnnotation())
 		{
