@@ -250,11 +250,16 @@ public:
 	static QString trMaxGlyphExtension;
 
 	//PostScript or other PDL strings
+	static QString File;
+	static QString trFile;
 	static QString PostScript;
 	static QString trPostScript;
+	static QString PDF;
+	static QString trPDF;
 	static QString PDF_1_3;
 	static QString PDF_1_4;
 	static QString PDF_1_5;
+	static QString PDF_1_6;
 	static QString PDF_X1a;
 	static QString PDF_X3;
 	static QString PDF_X4;
