@@ -43,7 +43,7 @@ class MissingGlyphsPainter: public TextLayoutPainter
 //	const TextLayout& m_textLayout;
 
 public:
-	MissingGlyphsPainter(errorCodes& itemError, const TextLayout& textLayout)
+	MissingGlyphsPainter(errorCodes& itemError, const TextLayout&  /*textLayout*/)
 		: m_itemError(itemError)
 //		, m_textLayout(textLayout)
 	{ }
@@ -117,7 +117,7 @@ void DocumentChecker::checkPages(ScribusDoc *currDoc, struct CheckerPrefs checke
 			bool error = false;
 			int masterPageNumber = -1, masterPageLocation = -1;
 			PageLocation pageLoc = currDoc->locationOfPage(i);
-			masterPageNumber = currDoc->MasterNames.value(currDoc->DocPages[i]->MPageNam, -1);
+			masterPageNumber = currDoc->MasterNames.value(currDoc->DocPages[i]->masterPageName(), -1);
 			if (masterPageNumber >= 0)
 				masterPageLocation = currDoc->MasterPages[masterPageNumber]->LeftPg;
 			if (currDoc->pagePositioning() == singlePage)
@@ -195,11 +195,19 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 			itemError.clear();
 			if (((currItem->isAnnotation()) || (currItem->isBookmark)) && (checkerSettings.checkAnnotations))
 				itemError.insert(PDFAnnotField, 0);
-			if ((currItem->hasSoftShadow() || (currItem->fillTransparency() != 0.0) || (currItem->lineTransparency() != 0.0) || (currItem->fillBlendmode() != 0) || (currItem->lineBlendmode() != 0)) && (checkerSettings.checkTransparency))
+			if (currItem->hasSoftShadow() && checkerSettings.checkTransparency)
 				itemError.insert(Transparency, 0);
+			if ((currItem->GrType == 0) && (checkerSettings.checkTransparency))
+			{
+				if (currItem->fillColor() != CommonStrings::None)
+				{
+					if ((currItem->fillTransparency() != 0.0) || (currItem->fillBlendmode() != 0))
+						itemError.insert(Transparency, 0);
+				}
+			}
 			if ((currItem->GrType != 0) && (checkerSettings.checkTransparency))
 			{
-				if (currItem->GrType == 9)
+				if (currItem->GrType == Gradient_4Colors)
 				{
 					if (currItem->GrCol1transp != 1.0)
 						itemError.insert(Transparency, 0);
@@ -210,7 +218,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 					else if (currItem->GrCol4transp != 1.0)
 						itemError.insert(Transparency, 0);
 				}
-				else if (currItem->GrType == 11)
+				else if (currItem->GrType == Gradient_Mesh)
 				{
 					for (int grow = 0; grow < currItem->meshGradientArray.count(); grow++)
 					{
@@ -221,7 +229,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 						}
 					}
 				}
-				else if (currItem->GrType == 12)
+				else if (currItem->GrType == Gradient_PatchMesh)
 				{
 					for (int grow = 0; grow < currItem->meshGradientPatches.count(); grow++)
 					{
@@ -249,6 +257,14 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 					}
 				}
 			}
+			if ((currItem->GrTypeStroke == 0) && (checkerSettings.checkTransparency))
+			{
+				if ((currItem->lineColor() != CommonStrings::None) || !currItem->NamedLStyle.isEmpty())
+				{
+					if ((currItem->lineTransparency() != 0.0) || (currItem->lineBlendmode() != 0))
+						itemError.insert(Transparency, 0);
+				}
+			}
 			if ((currItem->GrTypeStroke != 0) && (checkerSettings.checkTransparency))
 			{
 				QList<VColorStop*> colorStops = currItem->stroke_gradient.colorStops();
@@ -265,7 +281,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 				itemError.insert(Transparency, 0);
 			if ((currItem->OwnPage == -1) && (checkerSettings.checkOrphans))
 				itemError.insert(ObjectNotOnPage, 0);
-			if (currItem->asImageFrame() && !currItem->asOSGFrame())
+			if (currItem->isImageFrame() && !currItem->isOSGFrame())
 			{
 
 				// check image vs. frame sizes
@@ -371,7 +387,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 					}
 				}
 			}
-			if ((currItem->asTextFrame()) || (currItem->asPathText()))
+			if ((currItem->isTextFrame()) || (currItem->isPathText()))
 			{
 				if ( currItem->frameOverflows() && (checkerSettings.checkOverflow) && (!((currItem->isAnnotation()) && ((currItem->annotation().Type() == Annotation::Combobox) || (currItem->annotation().Type() == Annotation::Listbox)))))
 					itemError.insert(TextOverflow, 0);
@@ -441,11 +457,19 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 			if (!(currDoc->layerPrintable(currItem->m_layerID)) && (checkerSettings.ignoreOffLayers))
 				continue;
 			itemError.clear();
-			if ((currItem->hasSoftShadow() || (currItem->fillTransparency() != 0.0) || (currItem->lineTransparency() != 0.0) || (currItem->fillBlendmode() != 0) || (currItem->lineBlendmode() != 0)) && (checkerSettings.checkTransparency))
+			if (currItem->hasSoftShadow() && checkerSettings.checkTransparency)
 				itemError.insert(Transparency, 0);
+			if ((currItem->GrType == 0) && (checkerSettings.checkTransparency))
+			{
+				if (currItem->fillColor() != CommonStrings::None)
+				{
+					if ((currItem->fillTransparency() != 0.0) || (currItem->fillBlendmode() != 0))
+						itemError.insert(Transparency, 0);
+				}
+			}
 			if ((currItem->GrType != 0) && (checkerSettings.checkTransparency))
 			{
-				if (currItem->GrType == 9)
+				if (currItem->GrType == Gradient_4Colors)
 				{
 					if (currItem->GrCol1transp != 1.0)
 						itemError.insert(Transparency, 0);
@@ -456,7 +480,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 					else if (currItem->GrCol4transp != 1.0)
 						itemError.insert(Transparency, 0);
 				}
-				else if (currItem->GrType == 11)
+				else if (currItem->GrType == Gradient_Mesh)
 				{
 					for (int grow = 0; grow < currItem->meshGradientArray.count(); grow++)
 					{
@@ -467,7 +491,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 						}
 					}
 				}
-				else if (currItem->GrType == 12)
+				else if (currItem->GrType == Gradient_PatchMesh)
 				{
 					for (int grow = 0; grow < currItem->meshGradientPatches.count(); grow++)
 					{
@@ -495,6 +519,14 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 					}
 				}
 			}
+			if ((currItem->GrTypeStroke == 0) && (checkerSettings.checkTransparency))
+			{
+				if ((currItem->lineColor() != CommonStrings::None) || !currItem->NamedLStyle.isEmpty())
+				{
+					if ((currItem->lineTransparency() != 0.0) || (currItem->lineBlendmode() != 0))
+						itemError.insert(Transparency, 0);
+				}
+			}
 			if ((currItem->GrTypeStroke != 0) && (checkerSettings.checkTransparency))
 			{
 				QList<VColorStop*> colorStops = currItem->stroke_gradient.colorStops();
@@ -513,7 +545,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 				itemError.insert(PDFAnnotField, 0);
 			if ((currItem->OwnPage == -1) && (checkerSettings.checkOrphans))
 				itemError.insert(ObjectNotOnPage, 0);
-			if (currItem->asImageFrame() && !currItem->asOSGFrame())
+			if (currItem->isImageFrame() && !currItem->isOSGFrame())
 			{
 
 				// check image vs. frame sizes
@@ -619,7 +651,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, struct CheckerPrefs checke
 					}
 				}
 			}
-			if ((currItem->asTextFrame()) || (currItem->asPathText()))
+			if ((currItem->isTextFrame()) || (currItem->isPathText()))
 			{
 				if ( currItem->frameOverflows() && (checkerSettings.checkOverflow) && (!((currItem->isAnnotation()) && ((currItem->annotation().Type() == Annotation::Combobox) || (currItem->annotation().Type() == Annotation::Listbox)))))
 					itemError.insert(TextOverflow, 0);
