@@ -11,10 +11,8 @@
 #include <QUrl>
 
 
-ScDLThread::ScDLThread(QObject *parent) : QThread(parent),
-	m_downloadedCount(0), m_totalCount(0)
+ScDLThread::ScDLThread(QObject *parent) : QThread(parent)
 {
-	m_currentDownload = nullptr;
 	connect(this, SIGNAL(runSignal()), this, SLOT(runSlot()));
 }
 
@@ -46,7 +44,7 @@ void ScDLThread::addURLs(const QStringList &urlList, bool overwrite, const QStri
 	QString l(QDir::cleanPath(location));
 	if (!l.endsWith("/"))
 		l += "/";
-	for (const QString& u : m_urlList)
+	for (const QString& u : qAsConst(m_urlList))
 	{
 		QUrl url(u);
 		if (!urlOK(u))
