@@ -88,73 +88,73 @@ public:
 	typedef uint ucs4_type;
 	struct GlyphEncoding
 	{
-		GlyphEncoding() { charcode = 0; toUnicode = "0000"; }
-		ucs4_type charcode;
-		QString   glyphName;
-		QString   toUnicode;
+		ucs4_type charcode {0};
+		QString glyphName;
+		QString toUnicode {"0000"};
 	};
 	typedef QMap<gid_type, GlyphEncoding> FaceEncoding;
 
 	static const gid_type CONTROL_GLYPHS = 2000000000; // 2 billion
 
-	struct GlyphData { 
+	struct GlyphData
+	{ 
 		FPointArray Outlines;
-		qreal x;
-		qreal y;
-		qreal bbox_width;
-		qreal bbox_ascent;
-		qreal bbox_descent;
-		bool broken;
-		GlyphData() : Outlines(), x(0), y(0), bbox_width(1), bbox_ascent(1), bbox_descent(0), broken(true) {}
+		qreal x {0.0};
+		qreal y {0.0};
+		qreal bbox_width {1.0};
+		qreal bbox_ascent {1.0};
+		qreal bbox_descent {0.0};
+		bool broken {true};
+		GlyphData() {}
 	};
 
     
 	/// see accessors for ScFace for docs
-	class ScFaceData {
+	class ScFaceData 
+	{
 	public:
+		ScFaceData();
+		virtual ~ScFaceData();
+
 		/// controls destruction
-		mutable int refs;
+		mutable int refs {0};
 		/// controls load()
-		mutable int usage;
+		mutable int usage {0};
 
-		QString scName;
-		QString fontFile;
-		int     faceIndex;
-		QString psName;
 		QString family;
+		QString fontFile {"(None)"};
+		QString forDocument;
+		QString psName;
+		QString scName;
 		QString style;
 		QString variant;
 		QStringList fontFeatures;
+		int     faceIndex {-1};
 
-		QString forDocument;
+		mutable ScFace::Status status {ScFace::NULLFACE};
+		ScFace::FontType typeCode {ScFace::UNKNOWN_TYPE};
+		ScFace::FontFormat formatCode {ScFace::UNKNOWN_FORMAT};
 
-		mutable ScFace::Status status;
-		ScFace::FontType typeCode;
-		ScFace::FontFormat formatCode;
+		bool usable {false};
+		bool embedPs {false};
+		bool subset {false};
+		bool outline {false};
 
-		bool usable;
-		bool embedPs;
-		bool subset;
-		bool outline;
+		bool isCIDFont {false};
+		bool isStroked {false};
+		bool isFixedPitch {false};
+		bool hasGlyphNames {false};
+		gid_type maxGlyph {0};
 
-		bool isCIDFont;
-		bool isStroked;
-		bool isFixedPitch;
-		bool hasGlyphNames;
-		gid_type maxGlyph;
-
-		ScFaceData();
-		virtual ~ScFaceData();
 	protected:
-
 		friend class ScFace;
-		Status m_cachedStatus;
+		Status m_cachedStatus {ScFace::UNKNOWN};
 
 		// caches
 		mutable QHash<gid_type, qreal>     m_glyphWidth;
 		mutable QHash<gid_type, GlyphData> m_glyphOutline;
 		//mutable QHash<gid_type, uint>      m_cMap;
-		void* m_hbFont;
+		void* m_hbFont {nullptr};
 
 		// fill caches & members
 
@@ -180,7 +180,7 @@ public:
 
 		// dummy implementations
 		virtual qreal ascent(qreal sz)           const { return sz; }
-		virtual QString pdfAscentAsString()      const { return "0" ; }
+		virtual QString pdfAscentAsString()      const { return "0"; }
 		virtual QString pdfDescentAsString()     const { return "0"; }
 		virtual QString pdfCapHeightAsString()   const { return "0"; }
 		virtual QString pdfFontBBoxAsString()    const { return "0 0 0 0"; }
@@ -209,9 +209,9 @@ public:
 		virtual bool glyphNames(ScFace::FaceEncoding& gList) const;
 
 		// these use the cache:
-		virtual qreal       glyphWidth(gid_type gl, qreal sz)   const;
-		virtual FPointArray glyphOutline(gid_type gl, qreal sz) const;
-		virtual FPoint      glyphOrigin (gid_type gl, qreal sz) const;
+		virtual qreal       glyphWidth(gid_type gl, qreal size)   const;
+		virtual FPointArray glyphOutline(gid_type gl, qreal size) const;
+		virtual FPoint      glyphOrigin (gid_type gl, qreal size) const;
 
 		virtual bool isSymbolic() const { return false; }
 	};
@@ -272,7 +272,7 @@ public:
 		return result; 
 	}
 
-	void chReplacementTo(ScFace& other, QString doc) { 
+	void chReplacementTo(ScFace& other, const QString& doc) {
 		QString oldName = m_replacedName;
 		(*this) = other;
 		m_replacedName = oldName;
@@ -399,7 +399,7 @@ public:
 	/// translate unicode to glyph index
 	gid_type char2CMap(uint ch)   const;
 
-	gid_type emulateGlyph(uint u) const;
+	gid_type emulateGlyph(uint ch) const;
 
 	gid_type hyphenGlyph() const;
 	gid_type hyphenGlyph(const CharStyle& style) const;
@@ -410,7 +410,7 @@ private:
 
 	friend class SCFonts;
 
-	ScFace(ScFaceData* md);
+	ScFace(ScFaceData* data);
 	ScFaceData* m_m;
 	QString m_replacedName;
 	QString m_replacedInDoc;
