@@ -27,9 +27,7 @@ ScFace_ttf::ScFace_ttf (const QString& fam, const QString& sty, const QString& a
 	formatCode = ScFace::SFNT;
 }
 
-ScFace_ttf::~ ScFace_ttf()
-{
-}
+ScFace_ttf::~ScFace_ttf() = default;
 
 bool ScFace_ttf::isSymbolic() const
 {
@@ -49,7 +47,7 @@ void ScFace_ttf::load() const
 //		qDebug() << "can't use post table from " << face->family_name << face->style_name << ":" << checkPost.errorMsg;
 //	else
 //		qDebug() << "posttable from" << face->family_name << face->style_name << "has names for" << checkPost.numberOfGlyphs() << "glyphs and" << maxGlyph << "glyphs in charmap";
-	const_cast<bool&>(hasGlyphNames) = checkPost.usable && checkPost.numberOfGlyphs() >= maxGlyph;
+	const_cast<bool&>(hasGlyphNames) = checkPost.usable() && checkPost.numberOfGlyphs() >= maxGlyph;
 }
 
 void ScFace_ttf::unload() const
@@ -72,7 +70,7 @@ bool ScFace_ttf::hasNames() const
 	return FtFace::hasNames();
 }
 
-bool ScFace_ttf::glyphNames(ScFace::FaceEncoding& GList) const
+bool ScFace_ttf::glyphNames(ScFace::FaceEncoding& glyphList) const
 {
 	FT_ULong  charcode;
 	FT_UInt gindex = 0;
@@ -85,25 +83,39 @@ bool ScFace_ttf::glyphNames(ScFace::FaceEncoding& GList) const
 	// For those fonts we consequently use Adobe Glyph names whenever possible.
 	const bool avoidFntNames = (formatCode != ScFace::TYPE42 && typeCode == ScFace::TTF) && hasMicrosoftUnicodeCmap(face);
 	if (!avoidFntNames)
-		return FtFace::glyphNames(GList);
+		return FtFace::glyphNames(glyphList);
 	
 //	qDebug() << "reading metrics for" << face->family_name << face->style_name;
+	int spaceGlyphIndex = -1;
+
 	charcode = FT_Get_First_Char(face, &gindex);
 	while (gindex != 0)
 	{
+		// #16289 : Protect space character in case several characters are
+		// mapped to same glyph as space
+		if (charcode == ' ')
+			spaceGlyphIndex = gindex;
+		if ((gindex == spaceGlyphIndex) && (charcode != ' '))
+		{
+			charcode = FT_Get_Next_Char(face, charcode, &gindex);
+			continue;
+		}
+
 		ScFace::GlyphEncoding glEncoding;
 		glEncoding.charcode  = charcode;
 		glEncoding.glyphName = adobeGlyphName(charcode);
-		glEncoding.toUnicode = QString().sprintf("%04lX", charcode);
-		GList.insert(gindex, glEncoding);
-		charcode = FT_Get_Next_Char(face, charcode, &gindex );
+		glEncoding.toUnicode = QString::asprintf("%04lX", charcode);
+		glyphList.insert(gindex, glEncoding);
+		charcode = FT_Get_Next_Char(face, charcode, &gindex);
 	}
 
 	return true;
 }
 
-void ScFace_ttf::rawData(QByteArray & bb) const {
-	if (formatCode == ScFace::TTCF) {
+void ScFace_ttf::rawData(QByteArray & bb) const
+{
+	if (formatCode == ScFace::TTCF)
+	{
 		QByteArray coll;
 		FtFace::rawData(coll);
 		// access table for faceIndex
@@ -120,13 +132,13 @@ void ScFace_ttf::rawData(QByteArray & bb) const {
 		uint headerLength = OFFSET_TABLE_LEN + TDIR_ENTRY_LEN * nTables;
 		uint tableLengths = 0;
 		// sum table lengths incl padding
-		for (uint i=0; i < nTables; ++i)
+		for (uint i = 0; i < nTables; ++i)
 		{
 			tableLengths += sfnt::word(coll, faceOffset + OFFSET_TABLE_LEN + TDIR_ENTRY_LEN * i + 12);
 			tableLengths = (tableLengths+3) & ~3;
 		}
 		bb.resize(headerLength + tableLengths);
-		if (! bb.data())
+		if (!bb.data())
 			return;
 		// write header
 //		sDebug(QObject::tr("memcpy header: %1 %2 %3").arg(0).arg(faceOffset).arg(headerLength));
@@ -134,7 +146,7 @@ void ScFace_ttf::rawData(QByteArray & bb) const {
 			return;
 
 		uint pos = headerLength;
-		for (uint i=0; i < nTables; ++i)
+		for (uint i = 0; i < nTables; ++i)
 		{
             uint dirEntry = faceOffset + OFFSET_TABLE_LEN + TDIR_ENTRY_LEN * i;
 			uint tableSize  = sfnt::word(coll,  dirEntry + 12);
@@ -155,32 +167,27 @@ void ScFace_ttf::rawData(QByteArray & bb) const {
 				bb.data()[pos++] = '\0';
 		}
 	}
-	else if (formatCode == ScFace::TYPE42) {
+	else if (formatCode == ScFace::TYPE42)
 		FtFace::rawData(bb);
-	}
-	else {
+	else
 		FtFace::rawData(bb);
-	}
 }
 
 bool ScFace_ttf::embedFont(QByteArray &str) const
 {
-    QByteArray bb;
-    FtFace::rawData(bb);
+	QByteArray bb;
+	FtFace::rawData(bb);
 	if (formatCode == ScFace::TYPE42)
 	{
 		//easy:
 		str = bb;
 		return true;
 	}
-    
-	QString tmp4;
-	QString tmp2 = "";
-	QString tmp3 = "";
+
 	int counter = 0;
 	char *buf[50];
-	FT_ULong  charcode;
-	FT_UInt   gindex;
+	FT_ULong charcode;
+	FT_UInt gindex;
 	FT_Face face = ftFace();
 	if (!face)
 		return false;
@@ -188,49 +195,52 @@ bool ScFace_ttf::embedFont(QByteArray &str) const
 	if (ftIOFunc(fts, 0L, nullptr, 0))
 		return(false);
 
-	str+="%!PS-TrueTypeFont\n";
-	str+="11 dict begin\n";
-	str+="/FontName /" + psName + " def\n";
-	str+="/Encoding /ISOLatin1Encoding where {pop ISOLatin1Encoding} {StandardEncoding} ifelse def\n";
-	str+="/PaintType 0 def\n/FontMatrix [1 0 0 1 0 0] def\n";
-	str+="/FontBBox ["+m_pdfFontBBox+"] def\n";
-	str+="/FontType 42 def\n";
-	str+="/FontInfo 8 dict dup begin\n";
-	str+="/FamilyName (" + psName + ") def\n";
-	str+="end readonly def\n";
+	str += "%!PS-TrueTypeFont\n";
+	str += "11 dict begin\n";
+	str += "/FontName /" + psName + " def\n";
+	str += "/Encoding /ISOLatin1Encoding where {pop ISOLatin1Encoding} {StandardEncoding} ifelse def\n";
+	str += "/PaintType 0 def\n/FontMatrix [1 0 0 1 0 0] def\n";
+	str += "/FontBBox ["+m_pdfFontBBox+"] def\n";
+	str += "/FontType 42 def\n";
+	str += "/FontInfo 8 dict dup begin\n";
+	str += "/FamilyName (" + psName + ") def\n";
+	str += "end readonly def\n";
 	unsigned char *tmp = new unsigned char[65535];
 	int length;
 	char linebuf[80];
 	str += "/sfnts [";
-	int poso=0;
-	do {
-		int posi=0;
-		length= fts->size - fts->pos;
-		if (length > 65534) {
+	int poso = 0;
+	do
+	{
+		int posi = 0;
+		length = fts->size - fts->pos;
+		if (length > 65534)
 			length = 65534;
-		}
 		if (!ftIOFunc(fts, 0L, tmp, length))
 		{
-			str+="\n<\n";
+			str += "\n<\n";
 			for (int j = 0; j < length; j++)
 			{
-				unsigned char u=tmp[posi];
-				linebuf[poso]=((u >> 4) & 15) + '0';
-				if (u>0x9f) linebuf[poso]+='a'-':';
+				unsigned char u = tmp[posi];
+				linebuf[poso] = ((u >> 4) & 15) + '0';
+				if (u > 0x9f)
+					linebuf[poso] += 'a'-':';
 				++poso;
-				u&=15; linebuf[poso]=u + '0';
-				if (u>0x9) linebuf[poso]+='a'-':';
+				u &= 15;
+				linebuf[poso] = u + '0';
+				if (u > 0x9)
+					linebuf[poso] += 'a'-':';
 				++posi;
 				++poso;
 				if (poso > 70)
 				{
-					linebuf[poso++]='\n';
-					linebuf[poso++]=0;
+					linebuf[poso++] = '\n';
+					linebuf[poso++] = 0;
 					str += linebuf;
 					poso = 0;
 				}
 			}
-			linebuf[poso++]=0;
+			linebuf[poso++] = 0;
 			str += linebuf;
 			poso = 0;
 			str += "00\n>";
@@ -242,21 +252,23 @@ bool ScFace_ttf::embedFont(QByteArray &str) const
 			status = qMax(status,ScFace::BROKENGLYPHS);
 			return false;
 		}
-	} while (length==65534);
+	}
+	while (length == 65534);
 	
 	str += "\n] def\n";
 	delete[] tmp;
 	gindex = 0;
 	charcode = FT_Get_First_Char(face, &gindex );
+	QString tmp2, tmp3, tmp4;
 	while (gindex != 0)
 	{
 		FT_Get_Glyph_Name(face, gindex, buf, 50);
-		tmp2 += "/"+QString(reinterpret_cast<char*>(buf))+" "+tmp3.setNum(gindex)+" def\n";
-		 charcode = FT_Get_Next_Char(face, charcode, &gindex );
+		tmp2 += "/"+QString(reinterpret_cast<char*>(buf)) + " " + tmp3.setNum(gindex) + " def\n";
+		charcode = FT_Get_Next_Char(face, charcode, &gindex );
 		counter++;
 	}
 	tmp4.setNum(counter);
-	str += "/CharStrings " + tmp4 + " dict dup begin\n"+tmp2;
+	str += "/CharStrings " + tmp4 + " dict dup begin\n" + tmp2;
 	str += "end readonly def\n";
 	str += "FontName currentdict end definefont pop\n";
 	return(true);
