@@ -243,14 +243,13 @@ QPixmap FontSample(const ScFace& fnt, int s, QVector<uint> ts, const QColor& bac
 	int encode = setBestEncoding(face);
 	qreal uniEM = static_cast<qreal>(face->units_per_EM);
 
-	qreal m_descent = face->descender / uniEM;
+//	qreal m_descent = face->descender / uniEM;
 	qreal m_height = qMax(face->height / uniEM, (face->bbox.yMax - face->bbox.yMin) / uniEM);
 //	if (m_height == 0)
 //		m_height = (face->bbox.yMax - face->bbox.yMin) / uniEM;
 
 	int h = qRound(m_height * s) + 1;
-	qreal a = m_descent * s + 1;
-	a = 0;
+	qreal a = 0;//m_descent * s + 1;
 	int w = qRound((face->bbox.xMax - face->bbox.xMin) / uniEM) * s * (ts.length()+1);
 	if (w < 1)
 		w = s * (ts.length()+1);
