@@ -21,8 +21,8 @@
 
 
 
-namespace sfnt {
-	
+namespace sfnt
+{
 	uchar byte(QByteArray const & bb, uint pos);
 	quint32  word(QByteArray const & bb, uint pos);
 	void  putWord(QByteArray & bb, uint pos, quint32 val);
@@ -31,8 +31,8 @@ namespace sfnt {
 	void  putWord16(QByteArray & bb, uint pos, quint16 val);
 	void  appendWord16(QByteArray& bb, quint16 val);
 	bool  copy(QByteArray & dst, uint to, const QByteArray & src, uint from, uint len);
-	const QByteArray tag(QByteArray const & bb, uint pos);
-	const QByteArray getTable(const QByteArray& ttf, const QByteArray& ttfTag);
+	QByteArray tag(QByteArray const & bb, uint pos);
+	QByteArray getTable(const QByteArray& ttf, const QByteArray& ttfTag);
 	
 
 	QByteArray subsetFace(const QByteArray& ttf, QList<uint>& glyphs);
@@ -41,16 +41,22 @@ namespace sfnt {
 /**
  This class checks the post table of a ttf font.
  */
-class SCRIBUS_API PostTable {
+class SCRIBUS_API PostTable
+{
 	public:
-		PostTable() {usable=false;}
-		bool usable;
-		QString errorMsg;
+		PostTable() = default;
 		uint numberOfGlyphs() const;
 		QString nameFor(uint glyphId) const;
 		void readFrom(FT_Face face);
+		bool usable() const;
+		void setUsable(bool usable);
+		QString errorMsg() const;
+		void setErrorMsg(const QString& errorMsg);
+
 	private:
 		QList<QString> m_names;
+		bool m_usable {false};
+		QString m_errorMsg;
 };
 
 } //namespace
