@@ -35,7 +35,6 @@ for which a new license (GPL+exception) is in place.
 #include "gtparagraphstyle.h"
 #include "gtframestyle.h"
 
-#include "color.h"
 #include "commonstrings.h"
 #include "hyphenator.h"
 #include "marks.h"
@@ -50,8 +49,7 @@ for which a new license (GPL+exception) is in place.
 #include "undomanager.h"
 #include "util.h"
 #include "util_text.h"
-#include "ui/textpalette.h"
-#include "ui/propertiespalette_text.h"
+#include "ui/contentpalette.h"
 #include "ui/missing.h"
 
 gtAction::gtAction(bool append, PageItem* pageitem) :
@@ -124,10 +122,10 @@ void gtAction::writeUnstyled(const QString& text, bool isNote)
 	QString textStr = text;
 	textStr.remove(ch0);
 	textStr.remove(ch13);
-	textStr.replace(ch10,ch13);
-	textStr.replace(ch5,ch13);
-	textStr.replace(QString(0x2028),SpecialChars::LINEBREAK);
-	textStr.replace(QString(0x2029),SpecialChars::PARSEP);
+	textStr.replace(ch10, ch13);
+	textStr.replace(ch5, ch13);
+	textStr.replace(QString(0x2028), SpecialChars::LINEBREAK);
+	textStr.replace(QString(0x2029), SpecialChars::PARSEP);
 	if (isNote)
 	{
 		if (m_note == nullptr)
@@ -140,14 +138,8 @@ void gtAction::writeUnstyled(const QString& text, bool isNote)
 		{
 			NotesStyle* nStyle = m_note->notesStyle();
 			QString label = "NoteMark_" + nStyle->name();
-			if (nStyle->range() == NSRsection)
-				label += " in section " + m_it->m_Doc->getSectionNameForPageIndex(m_it->OwnPage) + " page " + QString::number(m_it->OwnPage +1);
-			else if (nStyle->range() == NSRpage)
-				label += " on page " + QString::number(m_it->OwnPage +1);
-			else if (nStyle->range() == NSRstory)
+			if (nStyle->range() == NSRstory)
 				label += " in " + m_it->firstInChain()->itemName();
-			else if (nStyle->range() == NSRframe)
-				label += " in frame" + m_it->itemName();
 			if (m_it->m_Doc->getMark(label + "_1", MARKNoteMasterType) != nullptr)
 				getUniqueName(label,m_it->m_Doc->marksLabelsList(MARKNoteMasterType), "_"); //FIX ME here user should be warned that inserted mark`s label was changed
 			else
@@ -160,7 +152,7 @@ void gtAction::writeUnstyled(const QString& text, bool isNote)
 			if (m_noteStory->text(m_noteStory->length() -1) == SpecialChars::PARSEP)
 				m_noteStory->removeChars(m_noteStory->length() -1, 1);
 			m_note->setSaxedText(saxedText(m_noteStory));
-			mrk->setString("");
+			mrk->clearString();
 			mrk->OwnPage = m_it->OwnPage;
 			m_it->itemText.insertMark(mrk);
 			if (UndoManager::undoEnabled())
@@ -295,14 +287,8 @@ void gtAction::write(const QString& text, gtStyle *style, bool isNote)
 		{
 			NotesStyle* nStyle = m_note->notesStyle();
 			QString label = "NoteMark_" + nStyle->name();
-			if (nStyle->range() == NSRsection)
-				label += " in section " + m_it->m_Doc->getSectionNameForPageIndex(m_it->OwnPage) + " page " + QString::number(m_it->OwnPage +1);
-			else if (nStyle->range() == NSRpage)
-				label += " on page " + QString::number(m_it->OwnPage +1);
-			else if (nStyle->range() == NSRstory)
+			if (nStyle->range() == NSRstory)
 				label += " in " + m_it->firstInChain()->itemName();
-			else if (nStyle->range() == NSRframe)
-				label += " in frame" + m_it->itemName();
 			if (m_it->m_Doc->getMark(label + "_1", MARKNoteMasterType) != nullptr)
 				getUniqueName(label,m_it->m_Doc->marksLabelsList(MARKNoteMasterType), "_"); //FIX ME here user should be warned that inserted mark`s label was changed
 			else
@@ -312,7 +298,7 @@ void gtAction::write(const QString& text, gtStyle *style, bool isNote)
 			mrk->setType(MARKNoteMasterType);
 			mrk->setNotePtr(m_note);
 			m_note->setMasterMark(mrk);
-			mrk->setString("");
+			mrk->clearString();
 			mrk->OwnPage = m_it->OwnPage;
 			m_it->itemText.insertMark(mrk);
 			story->applyCharStyle(lastStyleStart, story->length()-lastStyleStart, lastStyle);
@@ -409,7 +395,7 @@ void gtAction::applyFrameStyle(gtFrameStyle* fstyle)
 	m_textFrame->setFillColor(parseColor(fstyle->getBgColor()));
 	m_textFrame->setFillShade(fstyle->getBgShade());
 	ParagraphStyle newTabs(m_textFrame->itemText.defaultStyle());
-	newTabs.setTabValues(QList<ParagraphStyle::TabRecord>(*(fstyle->getTabValues())));
+	newTabs.setTabValues(fstyle->getTabValues());
 	m_textFrame->itemText.setDefaultStyle(newTabs);
 
 // 	gtParagraphStyle* pstyle = new gtParagraphStyle(*fstyle);
@@ -537,7 +523,7 @@ void gtAction::createParagraphStyle(gtParagraphStyle* pstyle)
 	tmp.create(vg);
 	m_textFrame->doc()->redefineStyles(tmp, false);
 	
-	m_ScMW->textPalette->textPal->updateParagraphStyles();
+	m_ScMW->contentPalette->updateTextStyles();
 }
 
 void gtAction:: setCharStyleAttributes(gtFont *font, CharStyle& style)
@@ -590,7 +576,7 @@ void gtAction::setParaStyleAttributes(gtParagraphStyle *pstyle, ParagraphStyle&
 	if (flags & gtParagraphStyle::spaceBelowWasSet)
 		style.setGapAfter(pstyle->getSpaceBelow());
 	if (flags & gtParagraphStyle::tabValueWasSet)
-		style.setTabValues(*pstyle->getTabValues());
+		style.setTabValues(pstyle->getTabValues());
 	if (flags & gtParagraphStyle::dropCapWasSet)
 		style.setHasDropCap(pstyle->hasDropCap());
 	if (flags & gtParagraphStyle::dropCapHeightWasSet)
@@ -833,13 +819,7 @@ QString gtAction::parseColor(const QString &s)
 			c = QColor(r.toInt(), g.toInt(), b.toInt());
 		}
 		else
-		{
-			QString rgbColor = s.trimmed();
-			if( rgbColor.startsWith( "#" ) )
-				c.setNamedColor( rgbColor );
-			else
-				c = parseColorN( rgbColor );
-		}
+			c.setNamedColor(s.trimmed());
 		found = false;
 		for (it = m_textFrame->doc()->PageColors.begin(); it != m_textFrame->doc()->PageColors.end(); ++it)
 		{
@@ -854,20 +834,13 @@ QString gtAction::parseColor(const QString &s)
 			ScColor tmp;
 			tmp.fromQColor(c);
 			m_textFrame->doc()->PageColors.insert("FromGetText"+c.name(), tmp);
-			m_ScMW->textPalette->updateColorList();
+			m_ScMW->contentPalette->updateColorList();
 			ret = "FromGetText"+c.name();
 		}
 	}
 	return ret;
 }
 
-QColor gtAction::parseColorN(const QString &rgbColor)
-{
-	int r, g, b;
-	keywordToRGB( rgbColor, r, g, b );
-	return QColor( r, g, b );
-}
-
 void gtAction::finalize()
 {
 	if (m_textFrame->doc()->docHyphenator->AutoCheck)
