@@ -44,12 +44,14 @@ class SCRIBUS_API IconManager : public QObject
 		* @return A pointer to the IconManager instance
 		*/
 		static IconManager& instance();
-
+		
+		void clearCache();
 		bool setup();
-		QCursor loadCursor(const QString& nam, int hotX = -1, int hotY = -1, bool forceUseColor=false);
-		QIcon loadIcon(const QString& nam, bool forceUseColor=false);
-		QPixmap loadPixmap(const QString& nam, bool forceUseColor=false, bool rtlFlip=false);
-		QString pathForIcon(const QString& nam);
+
+		QCursor loadCursor(const QString& name, int hotX = -1, int hotY = -1, bool forceUseColor=false);
+		QIcon loadIcon(const QString& name, bool forceUseColor=false);
+		QPixmap loadPixmap(const QString& name, bool forceUseColor=false, bool rtlFlip=false);
+		QString pathForIcon(const QString& name);
 		QStringList pathList() const;
 		QStringList nameList(const QString& language) const;
 		void iconToGrayscale(QPixmap *pm);
