@@ -7,22 +7,24 @@ for which a new license (GPL+exception) is in place.
 #ifndef SCIMGDATALOADER_KRA_H
 #define SCIMGDATALOADER_KRA_H
 
+#include <QByteArray>
+
 #include "scimgdataloader.h"
 #include "scpainter.h"
 #include "third_party/zip/scribus_zip.h"
-#include <QDomDocument>
-#include <QDomElement>
 
 class ScImgDataLoader_KRA : public ScImgDataLoader
 {
 public:
-		ScImgDataLoader_KRA();
+	ScImgDataLoader_KRA();
 
 	virtual bool preloadAlphaChannel(const QString& fn, int page, int res, bool& hasAlpha);
 	virtual void loadEmbeddedProfile(const QString& fn, int page = 0);
 	virtual bool loadPicture(const QString& fn, int page, int res, bool thumbnail);
+
 protected:
 	void initSupportedFormatList();
+	QByteArray getICCProfileFromPNGData(QByteArray& pngData);
 };
 
 #endif
