@@ -47,49 +47,49 @@ void ScImgDataLoader_PSD::loadEmbeddedProfile(const QString& fn, int /*page*/)
 {
 	m_embeddedProfile.resize(0);
 	m_profileComponents = 0;
+
 	ScColorProfile prof;
 	ScColorMgmtEngine engine(ScCore->defaultEngine);
 	QFileInfo fi = QFileInfo(fn);
 	if (!fi.exists())
 		return;
+
 	QString ext = fi.suffix().toLower();
-	if (ext == "psd")
+	if (ext != "psd")
+		return;
+
+	QFile f(fn);
+	if (!f.open(QIODevice::ReadOnly))
+		return;
+
+	m_imageInfoRecord.xres = 72;
+	m_imageInfoRecord.yres = 72;
+	QDataStream s( &f );
+	s.setByteOrder( QDataStream::BigEndian );
+	PSDHeader header;
+	s >> header;
+	// Check image file format.
+	if (s.atEnd() || !IsValid(header))
+		return;
+	// Check if it's a supported format.
+	if (!IsSupported(header))
+		return;
+	if (!LoadPSDResources(s, header, s.device()->pos()))
+		return;
+	if (m_embeddedProfile.size() > 0)
 	{
-		QFile f(fn);
-		if (f.open(QIODevice::ReadOnly))
+		prof = engine.openProfileFromMem(m_embeddedProfile.data());
+		if (prof)
 		{
-			m_imageInfoRecord.xres = 72;
-			m_imageInfoRecord.yres = 72;
-			QDataStream s( &f );
-			s.setByteOrder( QDataStream::BigEndian );
-			PSDHeader header;
-			s >> header;
-			// Check image file format.
-			if (s.atEnd() || !IsValid(header))
-				return;
-			// Check if it's a supported format.
-			if (!IsSupported(header))
-				return;
-			if (!LoadPSDResources(s, header, s.device()->pos()))
-				return;
-			if (m_embeddedProfile.size() > 0)
-			{
-				prof = engine.openProfileFromMem(m_embeddedProfile.data());
-				if (prof)
-				{
-					if (prof.colorSpace() == ColorSpace_Rgb)
-						m_profileComponents = 3;
-					if (prof.colorSpace() == ColorSpace_Cmyk)
-						m_profileComponents = 4;
-					if (prof.colorSpace() == ColorSpace_Gray)
-						m_profileComponents = 1;
-				}
-			}
-			f.close();
+			if (prof.colorSpace() == ColorSpace_Rgb)
+				m_profileComponents = 3;
+			if (prof.colorSpace() == ColorSpace_Cmyk)
+				m_profileComponents = 4;
+			if (prof.colorSpace() == ColorSpace_Gray)
+				m_profileComponents = 1;
 		}
-		else
-			return;
 	}
+	f.close();
 }
 
 bool ScImgDataLoader_PSD::preloadAlphaChannel(const QString& fn, int /*page*/, int res, bool& hasAlpha)
@@ -170,6 +170,7 @@ bool ScImgDataLoader_PSD::loadPicture(const QString& fn, int /*page*/, int res,
 		{
 			ScColorProfile prof = engine.openProfileFromMem(m_embeddedProfile);
 			m_imageInfoRecord.profileName = prof.productDescription();
+			m_imageInfoRecord.embeddedProfileName = m_imageInfoRecord.profileName;
 			m_imageInfoRecord.isEmbedded = true;
 		}
 		isCMYK = (header.color_mode == CM_CMYK);
@@ -263,8 +264,8 @@ bool ScImgDataLoader_PSD::LoadPSD( QDataStream & s, const PSDHeader & header)
 	uint tmp;
 	uint cresStart;
 	uint cdataStart;
-	uint ressourceDataLen;
-	uint startRessource;
+	uint resourceDataLen;
+	uint startResource;
 
 	cresStart = s.device()->pos();
 	// Skip mode data. FIX: this is incorrect, it's the Colormap Data for indexed Images
@@ -274,12 +275,12 @@ bool ScImgDataLoader_PSD::LoadPSD( QDataStream & s, const PSDHeader & header)
 	LoadPSDResources(s, header, cresStart); 
 	
 	s.device()->seek( cdataStart + tmp );
-	s >> ressourceDataLen;
-	startRessource = s.device()->pos();
+	s >> resourceDataLen;
+	startResource = s.device()->pos();
 
 	if  ((!m_imageInfoRecord.exifInfo.thumbnail.isNull()) && (header.reserved[0] == 't'))
 		return true;
-	bool ret = LoadPSDImgData(s, header, startRessource + ressourceDataLen);
+	bool ret = LoadPSDImgData(s, header, startResource + resourceDataLen);
 	return ret;
 }
 
@@ -290,8 +291,8 @@ bool ScImgDataLoader_PSD::LoadPSDResources( QDataStream & s, const PSDHeader & h
 
 	uint tmp;
 	uint cdataStart;
-	uint ressourceDataLen;
-//	uint startRessource;
+	uint resourceDataLen;
+//	uint startResource;
 
 	s.device()->seek( dataOffset );
 
@@ -459,10 +460,11 @@ bool ScImgDataLoader_PSD::LoadPSDResources( QDataStream & s, const PSDHeader & h
 			QList<uchar> colorTableR;
 			QList<uchar> colorTableG;
 			QList<uchar> colorTableB;
-			colorTableR.clear();
-			colorTableG.clear();
-			colorTableB.clear();
+			colorTableR.reserve(256);
+			colorTableG.reserve(256);
+			colorTableB.reserve(256);
 			m_colorTable.clear();
+			m_colorTable.reserve(256);
 			uchar r;
 			for (uint cc = 0; cc < 256; cc++)
 			{
@@ -486,10 +488,10 @@ bool ScImgDataLoader_PSD::LoadPSDResources( QDataStream & s, const PSDHeader & h
 		}
 	}
 	s.device()->seek( cdataStart + tmp );
-	s >> ressourceDataLen;
-//	startRessource = s.device()->pos();
-	if (ressourceDataLen != 0)
-		parseRessourceData(s, header, ressourceDataLen);
+	s >> resourceDataLen;
+//	startResource = s.device()->pos();
+	if (resourceDataLen != 0)
+		parseResourceData(s, header, resourceDataLen);
 	return true;
 }
 
