@@ -118,7 +118,7 @@ int ScImgDataLoader_TIFF::getLayers(const QString& fn, int /*page*/)
 
 	do
 	{
-		char *layerName=nullptr;
+		char *layerName = nullptr;
 		TIFFGetField(tif, TIFFTAG_PAGENAME, &layerName);
 		QString name = QString(layerName);
 		if (name.isEmpty())
@@ -353,42 +353,44 @@ bool ScImgDataLoader_TIFF::getImageData(TIFF* tif, RawImage *image, uint widtht,
 
 bool ScImgDataLoader_TIFF::getImageData_RGBA(TIFF* tif, RawImage *image, uint widtht, uint heightt, uint size, uint16 bitspersample, uint16 samplesperpixel)
 {
-	bool gotData = false;
 	uint32* bits = (uint32 *) _TIFFmalloc(size * sizeof(uint32));
+	if (!bits)
+		return false;
+
 	uint16  extrasamples(0), *extratypes(nullptr);
 	if (!TIFFGetField (tif, TIFFTAG_EXTRASAMPLES, &extrasamples, &extratypes))
 		extrasamples = 0;
-	if (bits)
+	
+	bool gotData = false;
+	if (TIFFReadRGBAImage(tif, widtht, heightt, bits, 0))
 	{
-		if (TIFFReadRGBAImage(tif, widtht, heightt, bits, 0))
+		for (unsigned int y = 0; y < heightt; y++)
 		{
-			for (unsigned int y = 0; y < heightt; y++)
+			memcpy(image->scanLine(heightt - 1 - y), bits + y * widtht, widtht * image->channels());
+			if (QSysInfo::ByteOrder == QSysInfo::BigEndian)
 			{
-				memcpy(image->scanLine(heightt - 1 - y), bits + y * widtht, widtht * image->channels());
-				if (QSysInfo::ByteOrder==QSysInfo::BigEndian)
+				unsigned char *s = image->scanLine( heightt - 1 - y );
+				unsigned char r, g, b, a;
+				for (uint xi=0; xi < widtht; ++xi)
 				{
-					unsigned char *s = image->scanLine( heightt - 1 - y );
-					unsigned char r, g, b, a;
-					for (uint xi=0; xi < widtht; ++xi)
-					{
-						r = s[0];
-						g = s[1];
-						b = s[2];
-						a = s[3];
-						s[0] = a;
-						s[1] = b;
-						s[2] = g;
-						s[3] = r;
-						s += image->channels();
-					}
+					r = s[0];
+					g = s[1];
+					b = s[2];
+					a = s[3];
+					s[0] = a;
+					s[1] = b;
+					s[2] = g;
+					s[3] = r;
+					s += image->channels();
 				}
 			}
-			if (extrasamples > 0 && extratypes[0] == EXTRASAMPLE_ASSOCALPHA)
-				unmultiplyRGBA(image);
-			gotData = true;
 		}
-		_TIFFfree(bits);
+		if (extrasamples > 0 && extratypes[0] == EXTRASAMPLE_ASSOCALPHA)
+			unmultiplyRGBA(image);
+		gotData = true;
 	}
+	_TIFFfree(bits);
+
 	return gotData;
 }
 
@@ -650,7 +652,7 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 	bool bilevel = false;
 	bool failedPS = false;
 	bool foundPS = false;
-	short resolutionunit = 0;
+	short resolutionunit = RESUNIT_INCH; // Default unit is inch
 	float xres = 72.0, yres = 72.0;
 	if (!QFile::exists(fn))
 		return false;
@@ -729,12 +731,14 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 		ScColorProfile tiffProf = engine.openProfileFromMem(profArray);
 		m_embeddedProfile = profArray;
 		m_imageInfoRecord.profileName = tiffProf.productDescription();
+		m_imageInfoRecord.embeddedProfileName = m_imageInfoRecord.profileName;
 		m_imageInfoRecord.isEmbedded = true;
 	}
 	else
 	{
 		m_imageInfoRecord.isEmbedded = false;
-		m_imageInfoRecord.profileName = "";
+		m_imageInfoRecord.profileName.clear();
+		m_imageInfoRecord.embeddedProfileName.clear();
 	}
 	unsigned int PhotoshopLen = 0;
 	unsigned char* PhotoshopBuffer;
@@ -748,7 +752,7 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 			PSDHeader fakeHeader;
 			fakeHeader.width = widtht;
 			fakeHeader.height = heightt;
-			parseRessourceData(strPhot, fakeHeader, PhotoshopLen);
+			parseResourceData(strPhot, fakeHeader, PhotoshopLen);
 			m_imageInfoRecord.exifInfo.width = widtht;
 			m_imageInfoRecord.exifInfo.height = heightt;
 			if (!m_imageInfoRecord.valid)
@@ -1350,7 +1354,7 @@ bool ScImgDataLoader_TIFF::loadLayerChannels( QDataStream & s, const PSDHeader &
 		return false;
 	}
 	channel_num = qMin(channel_num, (uint) 39);
-	uint components[40];
+	uint components[40] = {0};
 	for (uint channel = 0; channel < channel_num; channel++)
 	{
 		switch (layerInfo[layer].channelType[channel])
