@@ -148,7 +148,7 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("eu",       "",         "Basque",                  QObject::tr("Basque")));
 	m_langTable.append(LangDef("bts",      "",         "Batak Simalungun",        QObject::tr("Batak Simalungun")));
 	m_langTable.append(LangDef("bbc",      "",         "Batak Toba",              QObject::tr("Batak Toba")));
-	m_langTable.append(LangDef("bci",      "",         "Baulé",                   QObject::trUtf8("Baul\303\251")));
+	m_langTable.append(LangDef("bci",      "",         "Baulé",                   QObject::tr("Baul\303\251")));
 	m_langTable.append(LangDef("bar",      "",         "Bavarian",                QObject::tr("Bavarian")));
 	m_langTable.append(LangDef("bcq",      "",         "Bench",                   QObject::tr("Bench")));
 	m_langTable.append(LangDef("bdy",      "",         "Bandjalang",              QObject::tr("Bandjalang")));
@@ -158,7 +158,7 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("bn_BD",    "",         "Bengali (Bangladesh)",    QObject::tr("Bengali (Bangladesh)")));
 	m_langTable.append(LangDef("ber",      "",         "Berber",                  QObject::tr("Berber")));
 	m_langTable.append(LangDef("btb",      "",         "Beti (Cameroon)",         QObject::tr("Beti (Cameroon)")));
-	m_langTable.append(LangDef("eot",      "",         "Beti (Côte d'Ivoire)",    QObject::trUtf8("Beti (C\303\264te d'Ivoire)")));
+	m_langTable.append(LangDef("eot",      "",         "Beti (Côte d'Ivoire)",    QObject::tr("Beti (C\303\264te d'Ivoire)")));
 	m_langTable.append(LangDef("bhb",      "",         "Bhili",                   QObject::tr("Bhili")));
 	m_langTable.append(LangDef("bho",      "",         "Bhojpuri",                QObject::tr("Bhojpuri")));
 	m_langTable.append(LangDef("bik",      "",         "Bikol",                   QObject::tr("Bikol")));
@@ -246,7 +246,7 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("fi",       "",         "Finnish",                 QObject::tr("Finnish")));
 	m_langTable.append(LangDef("fon",      "",         "Fon",                     QObject::tr("Fon")));
 	m_langTable.append(LangDef("myq",      "",         "Forest Maninka",          QObject::tr("Forest Maninka")));
-	m_langTable.append(LangDef("frp",      "",         "Franco-Provençal",        QObject::trUtf8("Franco-Proven\303\247al")));
+	m_langTable.append(LangDef("frp",      "",         "Franco-Provençal",        QObject::tr("Franco-Proven\303\247al")));
 	m_langTable.append(LangDef("fr",       "fr_FR",    "French",                  QObject::tr("French")));
 	m_langTable.append(LangDef("fy",       "",         "Frisian",                 QObject::tr("Frisian")));
 	m_langTable.append(LangDef("fur",      "",         "Friulian",                QObject::tr("Friulian")));
@@ -345,7 +345,7 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("mwk",      "",         "Kita Maninkakan",         QObject::tr("Kita Maninkakan")));
 	m_langTable.append(LangDef("kex",      "",         "Kituba (Congo)",          QObject::tr("Kituba (Congo)")));
 	m_langTable.append(LangDef("kex",      "",         "Kokni",                   QObject::tr("Kokni")));
-	m_langTable.append(LangDef("ksh",      "",         "Kölsch",                  QObject::trUtf8("K\303\266lsch")));
+	m_langTable.append(LangDef("ksh",      "",         "Kölsch",                  QObject::tr("K\303\266lsch")));
 	m_langTable.append(LangDef("kv",       "",         "Komi",                    QObject::tr("Komi")));
 	m_langTable.append(LangDef("koi",      "",         "Komi-Permyak",            QObject::tr("Komi-Permyak")));
 	m_langTable.append(LangDef("kpv",      "",         "Komi-Zyrian",             QObject::tr("Komi-Zyrian")));
@@ -396,7 +396,7 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("mhr",      "",         "Low Mari",                QObject::tr("Low Mari")));
 	m_langTable.append(LangDef("dsb",      "",         "Lower Sorbian",           QObject::tr("Lower Sorbian")));
 	m_langTable.append(LangDef("lb",       "",         "Luxembourgish",           QObject::tr("Luxembourgish")));
-	m_langTable.append(LangDef("khb",      "",         "Lü",                      QObject::trUtf8("L\303\274")));
+	m_langTable.append(LangDef("khb",      "",         "Lü",                      QObject::tr("L\303\274")));
 	m_langTable.append(LangDef("lua",      "",         "Luba-Kasai",              QObject::tr("Luba-Kasai")));
 	m_langTable.append(LangDef("lu",       "",         "Luba-Katanga",            QObject::tr("Luba-Katanga")));
 	m_langTable.append(LangDef("luo",      "",         "Luo (Kenya and Tanzania)",QObject::tr("Luo (Kenya and Tanzania)")));
@@ -411,7 +411,7 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("mak",      "",         "Makasar",                 QObject::tr("Makasar")));
 	m_langTable.append(LangDef("vmw",      "",         "Makhuwa",                 QObject::tr("Makhuwa")));
 	m_langTable.append(LangDef("kde",      "",         "Makonde",                 QObject::tr("Makonde")));
-	m_langTable.append(LangDef("ms",       "",         "Malay",                   QObject::tr("Malay")));
+	m_langTable.append(LangDef("ms",       "ms_MY",    "Malay",                   QObject::tr("Malay")));
 	m_langTable.append(LangDef("mg",       "",         "Malagasy",                QObject::tr("Malagasy")));
 	m_langTable.append(LangDef("ml",       "ml_IN",    "Malayalam",               QObject::tr("Malayalam")));
 	m_langTable.append(LangDef("dv",       "",         "Maldivian",               QObject::tr("Maldivian")));
@@ -472,8 +472,8 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("niu",      "",         "Niuean",                  QObject::tr("Niuean")));
 	m_langTable.append(LangDef("nog",      "",         "Nogai",                   QObject::tr("Nogai")));
 	m_langTable.append(LangDef("no",       "no_NO",    "Norwegian",               QObject::tr("Norwegian")));
-	m_langTable.append(LangDef("nb",       "nb_NO",    "Norwegian (Bokmål)",      QObject::trUtf8("Norwegian (Bokm\303\245l)")));
-	m_langTable.append(LangDef("nn",       "nn_NO",    "Norwegian (Nnyorsk)",     QObject::tr("Norwegian (Nnyorsk)")));
+	m_langTable.append(LangDef("nb",       "nb_NO",    "Norwegian (Bokmål)",      QObject::tr("Norwegian (Bokm\303\245l)")));
+	m_langTable.append(LangDef("nn",       "nn_NO",    "Norwegian (Nynorsk)",     QObject::tr("Norwegian (Nynorsk)")));
 	m_langTable.append(LangDef("nov",      "",         "Novial",                  QObject::tr("Novial")));
 	m_langTable.append(LangDef("nym",      "",         "Nyamwezi",                QObject::tr("Nyamwezi")));
 	m_langTable.append(LangDef("nyn",      "",         "Nyankole",                QObject::tr("Nyankole")));
@@ -567,7 +567,7 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("nso",      "",         "Sotho Northern",          QObject::tr("Sotho Northern")));
 	m_langTable.append(LangDef("st",       "",         "Sotho Southern",          QObject::tr("Sotho Southern")));
 	m_langTable.append(LangDef("es",       "es_ES",    "Spanish",                 QObject::tr("Spanish")));
-	m_langTable.append(LangDef("es",       "es_ANY",   "Spanish",                 QObject::tr("Spanish")));
+	m_langTable.append(LangDef("es",       "es_ANY",   "Spanish (Generic)",       QObject::tr("Spanish (Generic)")));
 	m_langTable.append(LangDef("es_AR",    "",         "Spanish (Argentina)",     QObject::tr("Spanish (Argentina)")));
 	m_langTable.append(LangDef("es_LA",    "",         "Spanish (Latin)",         QObject::tr("Spanish (Latin)")));
 	m_langTable.append(LangDef("aii",      "",         "Swadaya Aramaic",         QObject::tr("Swadaya Aramaic")));
@@ -581,11 +581,11 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("ss",       "",         "Swati",                   QObject::tr("Swati")));
 	m_langTable.append(LangDef("syl",      "",         "Sylheti",                 QObject::tr("Sylheti")));
 	m_langTable.append(LangDef("syr",      "",         "Syriac",                  QObject::tr("Syriac")));
-	m_langTable.append(LangDef("tyz",      "",         "Tày",                     QObject::trUtf8("T\303\240y")));
+	m_langTable.append(LangDef("tyz",      "",         "Tày",                     QObject::tr("T\303\240y")));
 	m_langTable.append(LangDef("tab",      "",         "Tabasaran",               QObject::tr("Tabasaran")));
 	m_langTable.append(LangDef("tl",       "",         "Tagalog",                 QObject::tr("Tagalog")));
 	m_langTable.append(LangDef("ty",       "",         "Tahitian",                QObject::tr("Tahitian")));
-	m_langTable.append(LangDef("tdd",      "",         "Tai Nüa",                 QObject::trUtf8("Tai N\303\274a")));
+	m_langTable.append(LangDef("tdd",      "",         "Tai Nüa",                 QObject::tr("Tai N\303\274a")));
 	m_langTable.append(LangDef("tg",       "",         "Tajik",                   QObject::tr("Tajik")));
 	m_langTable.append(LangDef("tmh",      "",         "Tamashek",                QObject::tr("Tamashek")));
 	m_langTable.append(LangDef("ta",       "ta_IN",    "Tamil",                   QObject::tr("Tamil")));
@@ -626,8 +626,8 @@ void LanguageManager::generateLangList()
 	m_langTable.append(LangDef("vi",       "",         "Vietnamese",              QObject::tr("Vietnamese")));
 	m_langTable.append(LangDef("vls",      "",         "Vlaams",                  QObject::tr("Vlaams")));
 	m_langTable.append(LangDef("rmy",      "",         "Vlax Romani",             QObject::tr("Vlax Romani")));
-	m_langTable.append(LangDef("vo",       "",         "Volapük",                 QObject::trUtf8("Volap\303\274k")));
-	m_langTable.append(LangDef("vro",      "",         "Võro",                    QObject::trUtf8("V\303\265ro")));
+	m_langTable.append(LangDef("vo",       "",         "Volapük",                 QObject::tr("Volap\303\274k")));
+	m_langTable.append(LangDef("vro",      "",         "Võro",                    QObject::tr("V\303\265ro")));
 	m_langTable.append(LangDef("wbm",      "",         "Wa",                      QObject::tr("Wa")));
 	m_langTable.append(LangDef("wbr",      "",         "Wagdi",                   QObject::tr("Wagdi")));
 	m_langTable.append(LangDef("wa",       "",         "Walloon",                 QObject::tr("Walloon")));
@@ -655,23 +655,21 @@ void LanguageManager::generateInstalledGUILangList()
 	QString langAbbrev;
 	QMap<QString, langPair>::Iterator it;
 	QDir dir(path , "*.*", QDir::Name, QDir::Files | QDir::NoSymLinks);
-	if (dir.exists() && (dir.count() != 0))
+	if (!dir.exists() || (dir.count() == 0))
+		return;
+
+	for (uint i = 0; i < dir.count(); ++i)
 	{
-		for (uint i = 0; i < dir.count(); ++i)
-		{
-			QFileInfo file(path + dir[i]);
-			if (file.suffix().toLower() == "qm")
-			{
-				langAbbrev = file.completeSuffix().remove(".qm");
-				int j=langTableIndex(langAbbrev);
-				if (j!=-1)
-				{
-					m_langTable[j].m_transAvailable=true;
-					m_langTable[j].m_transFile=file.absoluteFilePath();
-					//qDebug()<<"Found installed GUI translation file:"<<langAbbrev<<" : "<<langTable[j].m_transFile<<langTable[j].m_transName;
-				}
-			}
-		}
+		QFileInfo file(path + dir[i]);
+		if (file.suffix().toLower() != "qm")
+			continue;
+		langAbbrev = file.completeSuffix().remove(".qm");
+		int j = langTableIndex(langAbbrev);
+		if (j < 0)
+			continue;
+		m_langTable[j].m_transAvailable = true;
+		m_langTable[j].m_transFile = file.absoluteFilePath();
+		//qDebug()<<"Found installed GUI translation file:"<<langAbbrev<<" : "<<langTable[j].m_transFile<<langTable[j].m_transName;
 	}
 }
 
@@ -686,18 +684,18 @@ void LanguageManager::generateInstalledHyphLangList()
 	}
 	QMap<QString, QString> dictionaryMap;
 	findHyphDictionarySets(dictionaryPaths, dictionaryMap);
-	if (dictionaryMap.count()==0)
+	if (dictionaryMap.count() == 0)
 		return;
 
 	QMap<QString, QString>::iterator it = dictionaryMap.begin();
 //	qDebug()<<"Installed Hyphenation Dictonaries:";
 	while (it != dictionaryMap.end())
 	{
-		int j=langTableIndex(it.key());
-		if (j!=-1)
+		int j = langTableIndex(it.key());
+		if (j != -1)
 		{
-			m_langTable[j].m_hyphAvailable=true;
-			m_langTable[j].m_hyphFile=it.value();
+			m_langTable[j].m_hyphAvailable = true;
+			m_langTable[j].m_hyphFile = it.value();
 			//qDebug()<<"Found installed hyphenation dictionary:"<<it.key()<<" : "<<it.value();
 		}
 		++it;
@@ -715,18 +713,18 @@ void LanguageManager::generateInstalledSpellLangList()
 	}
 	QMap<QString, QString> dictionaryMap;
 	findSpellingDictionarySets(dictionaryPaths, dictionaryMap);
-	if (dictionaryMap.count()==0)
+	if (dictionaryMap.count() == 0)
 		return;
 
 	QMap<QString, QString>::iterator it = dictionaryMap.begin();
 //	qDebug()<<"Installed Spelling Dictonaries:";
 	while (it != dictionaryMap.end())
 	{
-		int j=langTableIndex(it.key());
-		if (j!=-1)
+		int j = langTableIndex(it.key());
+		if (j != -1)
 		{
-			m_langTable[j].m_spellAvailable=true;
-			m_langTable[j].m_spellFile=it.value();
+			m_langTable[j].m_spellAvailable = true;
+			m_langTable[j].m_spellFile = it.value();
 //			qDebug()<<"Found installed spelling dictionary:"<<it.key()<<" : "<<it.value();
 		}
 		++it;
@@ -743,26 +741,26 @@ int LanguageManager::langTableIndex(const QString &abbrev)
 	for (int i = 0; i < m_langTable.size(); ++i)
 	{
 //		qDebug()<<abbrev<<langTable[i].m_priAbbrev<<langTable[i].m_altAbbrev;
-		if (m_langTable[i].m_priAbbrev==abbrev || m_langTable[i].m_altAbbrev==abbrev)
+		if (m_langTable[i].m_priAbbrev == abbrev || m_langTable[i].m_altAbbrev == abbrev)
 			return i;
 	}
 	return -1;
 }
 
-const QString LanguageManager::getLangFromAbbrev(QString langAbbrev, bool getTranslated)
+QString LanguageManager::getLangFromAbbrev(QString langAbbrev, bool getTranslated)
 {
 //	qDebug()<<"Trying to find:"<<langAbbrev;
 	int i=langTableIndex(langAbbrev);
 //	qDebug()<<"Index of"<<langAbbrev<<":"<<i;
 	if (i==-1)
 	{
-		if (langAbbrev.length()>5)
+		if (langAbbrev.length() > 5)
 		{
 			langAbbrev.truncate(5);
-			i=langTableIndex(langAbbrev);
+			i = langTableIndex(langAbbrev);
 		}
 	}
-	if (i!=-1)
+	if (i != -1)
 	{
 		if (getTranslated)
 			return m_langTable[i].m_transName;
@@ -772,53 +770,53 @@ const QString LanguageManager::getLangFromAbbrev(QString langAbbrev, bool getTra
 	return "";
 }
 
-const QString LanguageManager::getAbbrevFromLang(const QString& lang, bool useInstalled)
+QString LanguageManager::getAbbrevFromLang(const QString& lang, bool useInstalled)
 {
 	for (int i = 0; i < m_langTable.size(); ++i)
 	{
 		if (useInstalled)
 		{
-			if (m_langTable[i].m_transAvailable && (m_langTable[i].m_name==lang || m_langTable[i].m_transName==lang))
+			if (m_langTable[i].m_transAvailable && (m_langTable[i].m_name == lang || m_langTable[i].m_transName == lang))
 				return m_langTable[i].m_priAbbrev;
 		}
 		else
 		{
 			//qDebug()<<lang<<langTable[i].m_priAbbrev<<langTable[i].m_name<<langTable[i].m_transName;
-			if (m_langTable[i].m_name==lang || m_langTable[i].m_transName==lang)
+			if (m_langTable[i].m_name == lang || m_langTable[i].m_transName == lang)
 				return m_langTable[i].m_priAbbrev;
 		}
 	}
 	return "";
 }
 
-const QString LanguageManager::getLangFromTransLang(const QString& transLang)
+QString LanguageManager::getLangFromTransLang(const QString& transLang)
 {
 	for (int i = 0; i < m_langTable.size(); ++i)
 	{
-		if (m_langTable[i].m_transName==transLang)
+		if (m_langTable[i].m_transName == transLang)
 			return m_langTable[i].m_name;
 	}
 	return "";
 }
 
-const QString LanguageManager::getTransLangFromLang(const QString& lang)
+QString LanguageManager::getTransLangFromLang(const QString& lang)
 {
 	for (int i = 0; i < m_langTable.size(); ++i)
 	{
-		if (m_langTable[i].m_name==lang)
+		if (m_langTable[i].m_name == lang)
 			return m_langTable[i].m_transName;
 	}
 	return "";
 }
 
-const QString LanguageManager::getShortAbbrevFromAbbrev(QString langAbbrev)
+QString LanguageManager::getShortAbbrevFromAbbrev(QString langAbbrev)
 {
 	//	qDebug()<<"Trying to find:"<<langAbbrev;
 	int i = langTableIndex(langAbbrev);
 	//	qDebug()<<"Index of"<<langAbbrev<<":"<<i;
 	if (i == -1)
 	{
-		if (langAbbrev.length()>5)
+		if (langAbbrev.length() > 5)
 		{
 			langAbbrev.truncate(5);
 			i=langTableIndex(langAbbrev);
@@ -830,7 +828,7 @@ const QString LanguageManager::getShortAbbrevFromAbbrev(QString langAbbrev)
 	return "";
 }
 
-const QString LanguageManager::getShortAbbrevFromAbbrevDecomposition(const QString& langAbbrev)
+QString LanguageManager::getShortAbbrevFromAbbrevDecomposition(const QString& langAbbrev)
 {
 	int tIndex = langTableIndex(langAbbrev);
 	if (tIndex >= 0)
@@ -847,10 +845,10 @@ const QString LanguageManager::getShortAbbrevFromAbbrevDecomposition(const QStri
 	return "";
 }
 
-const QString LanguageManager::getAlternativeAbbrevfromAbbrev(const QString& langAbbrev)
+QString LanguageManager::getAlternativeAbbrevfromAbbrev(const QString& langAbbrev)
 {
 	int i=langTableIndex(langAbbrev);
-	if (i!=-1)
+	if (i != -1)
 		return m_langTable[i].m_altAbbrev;
 	return "";
 }
@@ -979,37 +977,37 @@ QString LanguageManager::numericSequence(const QString& seq)
 	switch (1)
 	{
 		case nsBengali:
-			retSeq+="";
+			retSeq += "";
 			break;
 		case nsDevanagari:
-			retSeq+="०१२३४५६७८९";
+			retSeq += "०१२३४५६७८९";
 			break;
 		case nsGujarati:
-			retSeq+="૦૧૨૩૪૫૬૭૮૯";
+			retSeq += "૦૧૨૩૪૫૬૭૮૯";
 			break;
 		case nsGurumukhi:
-			retSeq+="੦੧੨੩੪੫੬੭੮੯";
+			retSeq += "੦੧੨੩੪੫੬੭੮੯";
 			break;
 		case nsKannada:
-			retSeq+="";
+			retSeq += "";
 			break;
 		case nsMalayalam:
-			retSeq+="";
+			retSeq += "";
 			break;
 		case nsOriya:
-			retSeq+="";
+			retSeq += "";
 			break;
 		case nsTamil:
-			retSeq+="";
+			retSeq += "";
 			break;
 		case nsTelugu:
-			retSeq+="";
+			retSeq += "";
 			break;
 		case nsTibetan:
-			retSeq+="";
+			retSeq += "";
 			break;
 		case nsLepcha:
-			retSeq+="";
+			retSeq += "";
 			break;
 		default:
 			retSeq="0123456789";
@@ -1026,7 +1024,7 @@ bool LanguageManager::findSpellingDictionaries(QStringList &sl)
 
 void LanguageManager::findSpellingDictionarySets(QStringList &dictionaryPaths, QMap<QString, QString> &dictionaryMap)
 {
-	for (int i=0; i<dictionaryPaths.count(); ++i)
+	for (int i = 0; i<dictionaryPaths.count(); ++i)
 	{
 		// Find the dic and aff files in the location
 		QDir dictLocation(dictionaryPaths.at(i));
@@ -1046,7 +1044,7 @@ void LanguageManager::findSpellingDictionarySets(QStringList &dictionaryPaths, Q
 			if (dictionaryMap.contains(dictName))
 				continue;
 
-			if (dictName.length()<=5)
+			if (dictName.length() <= 5)
 			{
 				//QString shortAbbrev(LanguageManager::getShortAbbrevFromAbbrev(dictName));
 				//qDebug()<<"findSpellingDictionarySets"<<dictName<<shortAbbrev;
@@ -1054,7 +1052,7 @@ void LanguageManager::findSpellingDictionarySets(QStringList &dictionaryPaths, Q
 				//dictionaryMap.insert(shortAbbrev, dictionaryPaths.at(i)+dictName);
 			}
 			//qDebug()<<"Spell Finder:"<<dictName<<dictionaryPaths.at(i)+dictName;
-			if (dictName.length()>5)
+			if (dictName.length() > 5)
 			{
 				QString shortAbbrev(LanguageManager::getShortAbbrevFromAbbrev(dictName));
 				//qDebug()<<shortAbbrev;
@@ -1068,7 +1066,7 @@ void LanguageManager::findSpellingDictionarySets(QStringList &dictionaryPaths, Q
 	while (it != dictionaryMap.end())
 	{
 		QString lang(it.key());
-		if (lang.length()==5)
+		if (lang.length() == 5)
 		{
 			QString shortAbbrev(LanguageManager::getShortAbbrevFromAbbrev(lang));
 			if (!dictionaryMap.contains(shortAbbrev))
@@ -1079,7 +1077,7 @@ void LanguageManager::findSpellingDictionarySets(QStringList &dictionaryPaths, Q
 			//else
 				//qDebug()<<"Short abbreviation:"<<shortAbbrev<<"already exists for:"<<lang;
 		}
-		if (lang.length()==2)
+		if (lang.length() == 2)
 		{
 			QString altAbbrev(LanguageManager::getAlternativeAbbrevfromAbbrev(lang));
 			if (!dictionaryMap.contains(altAbbrev))
@@ -1102,7 +1100,7 @@ bool LanguageManager::findHyphDictionaries(QStringList& sl)
 
 void LanguageManager::findHyphDictionarySets(QStringList& dictionaryPaths, QMap<QString, QString>& dictionaryMap)
 {
-	for (int i=0; i<dictionaryPaths.count(); ++i)
+	for (int i = 0; i<dictionaryPaths.count(); ++i)
 	{
 		// Find the dic and aff files in the location
 		QDir dictLocation(dictionaryPaths.at(i));
@@ -1122,11 +1120,11 @@ void LanguageManager::findHyphDictionarySets(QStringList& dictionaryPaths, QMap<
 				dictName = dn;
 			if (dictionaryMap.contains(dictName))
 				continue;
-			if (dictName.length()<=2)
+			if (dictName.length() <= 2)
 			{
 				dictionaryMap.insert(dictName, dictionaryPaths.at(i)+dn+".dic");
 			}
-			if (dictName.length()>2)
+			if (dictName.length() > 2)
 			{
 				QString shortAbbrev(LanguageManager::getShortAbbrevFromAbbrev(dictName));
 				dictionaryMap.insert(shortAbbrev, dictionaryPaths.at(i)+dn+".dic");
@@ -1140,10 +1138,10 @@ LanguageManager::~LanguageManager()
 	m_langTable.clear();
 }
 
-const QString LanguageManager::getHyphFilename(const QString & langAbbrev)
+QString LanguageManager::getHyphFilename(const QString & langAbbrev)
 {
 	int j = langTableIndex(langAbbrev);
-	if (j!=-1 && m_langTable[j].m_hyphAvailable)
+	if (j != -1 && m_langTable[j].m_hyphAvailable)
 	{
 //		qDebug()<<"Found requested hyphenation dictionary:"<<langAbbrev<<" : "<<langTable[j].m_hyphFile;
 		return m_langTable[j].m_hyphFile;
