@@ -83,7 +83,7 @@ void PageItem_Line::DrawObj_Item(ScPainter *p, QRectF /*e*/)
 			else if (GrTypeStroke > 0)
 			{
 				if ((!gradientStrokeVal.isEmpty()) && (!m_Doc->docGradients.contains(gradientStrokeVal)))
-					gradientStrokeVal = "";
+					gradientStrokeVal.clear();
 				if (!(gradientStrokeVal.isEmpty()) && (m_Doc->docGradients.contains(gradientStrokeVal)))
 					stroke_gradient = m_Doc->docGradients[gradientStrokeVal];
 				if (stroke_gradient.stops() < 2) // fall back to solid stroking if there are not enough colorstops in the gradient.
@@ -103,7 +103,7 @@ void PageItem_Line::DrawObj_Item(ScPainter *p, QRectF /*e*/)
 				{
 					p->setStrokeMode(ScPainter::Gradient);
 					p->stroke_gradient = stroke_gradient;
-					if (GrTypeStroke == 6)
+					if (GrTypeStroke == Gradient_Linear)
 						p->setGradient(VGradient::linear, FPoint(GrStrokeStartX, GrStrokeStartY), FPoint(GrStrokeEndX, GrStrokeEndY), FPoint(GrStrokeStartX, GrStrokeStartY), GrStrokeScale, GrStrokeSkew);
 					else
 						p->setGradient(VGradient::radial, FPoint(GrStrokeStartX, GrStrokeStartY), FPoint(GrStrokeEndX, GrStrokeEndY), FPoint(GrStrokeFocalX, GrStrokeFocalY), GrStrokeScale, GrStrokeSkew);
@@ -121,7 +121,7 @@ void PageItem_Line::DrawObj_Item(ScPainter *p, QRectF /*e*/)
 		else
 		{
 			p->setStrokeMode(ScPainter::Solid);
-			multiLine ml = m_Doc->MLineStyles[NamedLStyle];
+			multiLine ml = m_Doc->docLineStyles[NamedLStyle];
 			QColor tmp;
 			for (int it = ml.size()-1; it > -1; it--)
 			{
@@ -161,12 +161,12 @@ QString PageItem_Line::infoDescription() const
 	return QString();
 }
 
-QPointF PageItem_Line::startPoint()
+QPointF PageItem_Line::startPoint() const
 {
 	return QPointF(m_xPos, m_yPos);
 }
 
-QPointF PageItem_Line::endPoint()
+QPointF PageItem_Line::endPoint() const
 {
 	double rot = this->rotation();
 	double x = m_xPos + m_width * cos(rot * M_PI / 180.0);
@@ -174,6 +174,17 @@ QPointF PageItem_Line::endPoint()
 	return QPointF(x, y);
 }
 
+void PageItem_Line::setLineClip()
+{
+	// Big fat warning : QPolygon::setPoints is a variadic function,
+	// only pass ints as arguments, or expect strange results
+	int ph = static_cast<int>(qMax(1.0, this->visualLineWidth() / 2.0));
+	Clip.setPoints(4, -1, -ph,
+	                  static_cast<int>(width() + 1.0), -ph,
+	                  static_cast<int>(width() + 1.0), ph,
+	                  -1, ph);
+}
+
 void PageItem_Line::getBoundingRect(double *x1, double *y1, double *x2, double *y2) const
 {
 	double minx =  std::numeric_limits<double>::max();
@@ -276,37 +287,7 @@ void PageItem_Line::getVisualBoundingRect(double * x1, double * y1, double * x2,
 	double miny =  std::numeric_limits<double>::max();
 	double maxx = -std::numeric_limits<double>::max();
 	double maxy = -std::numeric_limits<double>::max();
-	double extraSpace = 0.0;
-	if (NamedLStyle.isEmpty())
-	{
-		if ((lineColor() != CommonStrings::None) || (!patternStrokeVal.isEmpty()) || (GrTypeStroke > 0))
-		{
-			extraSpace = m_lineWidth / 2.0;
-			if ((extraSpace == 0) && m_Doc->view()) // Hairline case
-				extraSpace = 0.5 / m_Doc->view()->scale();
-		}
-		if ((!patternStrokeVal.isEmpty()) && (m_Doc->docPatterns.contains(patternStrokeVal)) && (patternStrokePath))
-		{
-			ScPattern *pat = &m_Doc->docPatterns[patternStrokeVal];
-			QTransform mat;
-			mat.rotate(patternStrokeRotation);
-			mat.scale(patternStrokeScaleX / 100.0, patternStrokeScaleY / 100.0);
-			QRectF p1R = QRectF(0, 0, pat->width / 2.0, pat->height / 2.0);
-			QRectF p2R = mat.map(p1R).boundingRect();
-			extraSpace = p2R.height();
-		}
-	}
-	else
-	{
-		multiLine ml = m_Doc->MLineStyles[NamedLStyle];
-		const SingleLine& sl = ml.last();
-		if (sl.Color != CommonStrings::None)
-		{
-			extraSpace = sl.Width / 2.0;
-			if ((extraSpace == 0) && m_Doc->view()) // Hairline case
-				extraSpace = 0.5 / m_Doc->view()->scale();
-		}
-	}
+	double extraSpace = visualLineWidth() / 2.0;
 	if (m_rotation != 0)
 	{
 		FPointArray pb;
@@ -367,7 +348,7 @@ QRectF PageItem_Line::getStartArrowBoundingRect() const
 		}
 		else
 		{
-			const multiLine ml = m_Doc->MLineStyles[NamedLStyle];
+			const multiLine ml = m_Doc->docLineStyles[NamedLStyle];
 			const SingleLine& sl = ml.last();
 			if (sl.Width != 0.0)
 				arrowTrans.scale(sl.Width, sl.Width);
@@ -400,7 +381,7 @@ QRectF PageItem_Line::getStartArrowOldBoundingRect() const
 		}
 		else
 		{
-			const multiLine ml = m_Doc->MLineStyles[NamedLStyle];
+			const multiLine ml = m_Doc->docLineStyles[NamedLStyle];
 			const SingleLine& sl = ml.last();
 			if (sl.Width != 0.0)
 				arrowTrans.scale(sl.Width, sl.Width);
@@ -433,7 +414,7 @@ QRectF PageItem_Line::getEndArrowBoundingRect() const
 		}
 		else
 		{
-			const multiLine ml = m_Doc->MLineStyles[NamedLStyle];
+			const multiLine ml = m_Doc->docLineStyles[NamedLStyle];
 			const SingleLine& sl = ml.last();
 			if (sl.Width != 0.0)
 				arrowTrans.scale(sl.Width, sl.Width);
@@ -465,7 +446,7 @@ QRectF PageItem_Line::getEndArrowOldBoundingRect() const
 		}
 		else
 		{
-			const multiLine ml = m_Doc->MLineStyles[NamedLStyle];
+			const multiLine ml = m_Doc->docLineStyles[NamedLStyle];
 			const SingleLine& sl = ml.last();
 			if (sl.Width != 0.0)
 				arrowTrans.scale(sl.Width, sl.Width);
@@ -478,3 +459,25 @@ QRectF PageItem_Line::getEndArrowOldBoundingRect() const
 
 	return arrowRect;
 }
+
+double PageItem_Line::visualXPos() const
+{
+	return m_xPos;
+}
+
+double PageItem_Line::visualYPos() const
+{
+	double extraSpace = visualLineWidth() / 2.0;
+	return m_yPos - extraSpace;
+}
+
+double PageItem_Line::visualWidth() const
+{
+	return m_width;
+}
+
+double PageItem_Line::visualHeight() const
+{
+	double extraSpace = visualLineWidth();
+	return extraSpace;
+}
