@@ -106,7 +106,7 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 				else if (GrTypeStroke > 0)
 				{
 					if ((!gradientStrokeVal.isEmpty()) && (!m_Doc->docGradients.contains(gradientStrokeVal)))
-						gradientStrokeVal = "";
+						gradientStrokeVal.clear();
 					if (!(gradientStrokeVal.isEmpty()) && (m_Doc->docGradients.contains(gradientStrokeVal)))
 						stroke_gradient = m_Doc->docGradients[gradientStrokeVal];
 					if (stroke_gradient.stops() < 2) // fall back to solid stroking if there are not enough colorstops in the gradient.
@@ -123,7 +123,7 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 					{
 						p->setStrokeMode(ScPainter::Gradient);
 						p->stroke_gradient = stroke_gradient;
-						if (GrTypeStroke == 6)
+						if (GrTypeStroke == Gradient_Linear)
 							p->setGradient(VGradient::linear, FPoint(GrStrokeStartX, GrStrokeStartY), FPoint(GrStrokeEndX, GrStrokeEndY), FPoint(GrStrokeStartX, GrStrokeStartY), GrStrokeScale, GrStrokeSkew);
 						else
 							p->setGradient(VGradient::radial, FPoint(GrStrokeStartX, GrStrokeStartY), FPoint(GrStrokeEndX, GrStrokeEndY), FPoint(GrStrokeFocalX, GrStrokeFocalY), GrStrokeScale, GrStrokeSkew);
@@ -139,7 +139,7 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 			else
 			{
 				p->setStrokeMode(ScPainter::Solid);
-				multiLine ml = m_Doc->MLineStyles[NamedLStyle];
+				multiLine ml = m_Doc->docLineStyles[NamedLStyle];
 				QColor tmp;
 				for (int it = ml.size()-1; it > -1; it--)
 				{
@@ -153,15 +153,13 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 			}
 		}
 	}
+
 	double totalTextLen = 0.0;
 	double totalCurveLen = 0.0;
 	double extraOffset = 0.0;
-	if (itemText.length() != 0)
-	{
-		CurX += itemText.charStyle(0).fontSize() * itemText.charStyle(0).tracking() / 10000.0;
-	}
-	else
+	if (itemText.length() <= 0)
 		return;
+	CurX += itemText.charStyle(0).fontSize() * itemText.charStyle(0).tracking() / 10000.0;
 
 	textLayout.setStory(&itemText);
 	int spaceCount = 0;
@@ -172,6 +170,10 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 	if (glyphRuns.isEmpty())
 		return;
 
+	// enable seamless crossing past the endpoint for closed curve
+	bool curveClosed = PoLine.isBezierClosed();
+	bool canWrapAround = curveClosed;
+
 	for (const GlyphCluster& run : glyphRuns)
 	{
 		totalTextLen += run.width();
@@ -183,9 +185,9 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 	{
 		totalCurveLen += PoLine.lenPathSeg(segs);
 	}
-	if ((itemText.paragraphStyle(0).alignment() != ParagraphStyle::Leftaligned) && (totalCurveLen >= totalTextLen + m_textDistanceMargins.left()))
+	if ((itemText.paragraphStyle(0).alignment() != ParagraphStyle::LeftAligned) && (totalCurveLen >= totalTextLen + m_textDistanceMargins.left()))
 	{
-		if (itemText.paragraphStyle(0).alignment() == ParagraphStyle::Rightaligned)
+		if (itemText.paragraphStyle(0).alignment() == ParagraphStyle::RightAligned)
 		{
 			CurX = totalCurveLen - totalTextLen;
 			CurX -= m_textDistanceMargins.left();
@@ -209,7 +211,7 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 			extraOffset = (totalCurveLen - m_textDistanceMargins.left() - totalTextLen) / static_cast<double>(itemText.length());
 	}
 	int firstRun = 0;
-	if (totalTextLen + m_textDistanceMargins.left() > totalCurveLen && itemText.paragraphStyle(0).direction() == ParagraphStyle::RTL)
+	if (!curveClosed && (totalTextLen + m_textDistanceMargins.left() > totalCurveLen) && (itemText.paragraphStyle(0).direction() == ParagraphStyle::RTL))
 	{
 		double totalLenDiff = totalTextLen + m_textDistanceMargins.left() - totalCurveLen;
 		while (firstRun < glyphRuns.count())
@@ -221,11 +223,16 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 				break;
 		}
 	}
+
+	int currPathIndex = 0;
 	QPainterPath guidePath = PoLine.toQPainterPath(false);
 	QList<QPainterPath> pathList = decomposePath(guidePath);
 	QPainterPath currPath = pathList[0];
-	int currPathIndex = 0;
 	PathLineBox* linebox = new PathLineBox();
+
+	double lastPathPerc = currPath.percentAtLength(CurX);
+	double totalPathPerc = 0.0;
+
 	for (int i = firstRun; i < glyphRuns.length(); i++)
 	{
 		const GlyphCluster &run = glyphRuns.at(i);
@@ -235,16 +242,35 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, QRectF cullingArea)
 		double currPerc = currPath.percentAtLength(CurX);
 		if (currPerc >= 0.9999999)
 		{
+			// sticks out to the next segment
 			currPathIndex++;
 			if (currPathIndex == pathList.count())
 			{
-				m_maxChars = run.firstChar();
-				break;
+				if (!curveClosed || !canWrapAround)
+				{
+					m_maxChars = run.firstChar();
+					break;
+				}
+				canWrapAround = false;
+				currPathIndex = 0;
 			}
+			CurX -= currPath.length();
 			currPath = pathList[currPathIndex];
-			CurX = dx;
 			currPerc = currPath.percentAtLength(CurX);
+			lastPathPerc = 0.0;
 		}
+
+		// Prevent total text length to exceed the length of path
+		totalPathPerc += (currPerc - lastPathPerc);
+		if (lastPathPerc > currPerc)
+			totalPathPerc -= 1.0;
+		if (totalPathPerc >= pathList.count() - 1e-7)
+		{
+			m_maxChars = run.firstChar();
+			break;
+		}
+		lastPathPerc = currPerc;
+
 		double currAngle = currPath.angleAtPercent(currPerc);
 		if (currAngle <= 180.0)
 			currAngle *= -1.0;
@@ -395,3 +421,27 @@ void PageItem_PathText::getVisualBoundingRect(double * x1, double * y1, double *
 	totalRect = totalRect.united(QRectF(clipTrans.mapRect(Clip.boundingRect())));
 	totalRect.getCoords(x1, y1, x2, y2);
 }
+
+double PageItem_PathText::visualXPos() const
+{
+	double extraSpace = visualLineWidth() / 2.0;
+	return qMin(m_xPos + QRectF(Clip.boundingRect()).x(), m_xPos - extraSpace);
+}
+
+double PageItem_PathText::visualYPos() const
+{
+	double extraSpace = visualLineWidth() / 2.0;
+	return qMin(m_yPos + QRectF(Clip.boundingRect()).y(), m_yPos - extraSpace);
+}
+
+double PageItem_PathText::visualWidth() const
+{
+	double extraSpace = visualLineWidth();
+	return qMax(QRectF(Clip.boundingRect()).width(), m_width + extraSpace);
+}
+
+double PageItem_PathText::visualHeight() const
+{
+	double extraSpace = visualLineWidth();
+	return qMax(QRectF(Clip.boundingRect()).height(), m_height + extraSpace);
+}
