@@ -521,6 +521,9 @@ public:
 	/// Collect named resource of table and its cells
 	void getNamedResources(ResourceCollection& lists) const override;
 
+	/// Replace named resource of table and its cells
+	void replaceNamedResources(ResourceCollection& newNames) override;
+
 	/// creates valid layout information
 	void layout() override;
 
@@ -664,10 +667,10 @@ private:
 	 */
 
 	/// The logical active row.
-	int m_activeRow;
+	int m_activeRow {0};
 
 	/// The logical active column.
-	int m_activeColumn;
+	int m_activeColumn {0};
 	//>>End of live working variables/data
 };
 
