@@ -275,8 +275,8 @@ namespace Pdf
 	QByteArray toUTF16(QString s)
 	{
 		QByteArray result;
-		result.append(0xfe);
-		result.append(0xff);
+		result.append('\xfe');
+		result.append('\xff');
 		for (int i = 0; i < s.length(); ++i)
 		{
 			result.append(s[i].row());
@@ -426,12 +426,10 @@ namespace Pdf
 		return result;
 	}
 	
-	
 	QByteArray toName(const QString& s)
 	{
 		return toName(toPdfDocEncoding(s));
 	}
-	
 
 	QByteArray toName(QByteArray s)
 	{
@@ -459,7 +457,6 @@ namespace Pdf
 		tmp = tmp.replace(":", "");
 		return "D:" + tmp.toLatin1() + "Z";
 	}
-
 	
 	QByteArray toRectangleArray(QRect r)
 	{
@@ -470,9 +467,6 @@ namespace Pdf
 	{
 		return "[" + toPdf(r.left()) + " " + toPdf(r.bottom()) + " " + toPdf(r.right()) + " " + toPdf(r.top()) + "]";
 	}
- 
- 
-
 
 	Writer::Writer()
 	{
@@ -509,7 +503,6 @@ namespace Pdf
 		    0x2f, 0x0c, 0xa9, 0xfe, 0x64, 0x53, 0x69, 0x7a };
 		for (int a = 0; a < 32; ++a)
 			m_KeyGen[a] = kg_array[a];
-
 	}
 	
 	
@@ -523,7 +516,6 @@ namespace Pdf
 		return true;
 	}
 	
-	
 	ScStreamFilter* Writer::openStreamFilter(bool encrypted, PdfId objId)
 	{
 		if (encrypted)
@@ -534,7 +526,6 @@ namespace Pdf
 		return new ScNullEncodeFilter(&m_outStream);
 	}
 	
-	
 	bool Writer::close(bool abortExport)
 	{
 		bool result = (m_Spool.error() == QFile::NoError);
@@ -548,13 +539,11 @@ namespace Pdf
 		return result;
 	}
 	
-	
 	void Writer::setFileId(const QByteArray& id)
 	{
 		m_FileID = QCryptographicHash::hash(id, QCryptographicHash::Md5);
 	}
 	
-	
 	void Writer::setEncryption(bool keyLen16, const QByteArray& PassOwner, const QByteArray& PassUser, int Permissions)
 	{
 		QByteArray ok = "";
@@ -589,10 +578,8 @@ namespace Pdf
 		write("/U "+Pdf::toHexString(uk)+"\n");
 		write("/P "+Pdf::toPdf(Permissions)+"\n>>");
 		endObj(EncryptObj);
-
 	}
 	
-	
 	QByteArray Writer::encryptBytes(const QByteArray& in, PdfId ObjNum)
 	{
 		rc4_context_t rc4;
@@ -627,7 +614,6 @@ namespace Pdf
 		rc4Key.resize(qMin(m_KeyLen+5, 16));
 		return rc4Key;
 	}
-	
 
 	QByteArray Writer::FitKey(const QByteArray & pass)
 	{
@@ -741,23 +727,25 @@ namespace Pdf
 //		return QCryptographicHash::hash(TBytes, QCryptographicHash::Md5);
 //	}
 	
-	
-	void Writer::writeHeader(PDFOptions::PDFVersion Version)
+	void Writer::writeHeader(const PDFVersion& Version)
 	{
 		switch (Version)
 		{
-			case PDFOptions::PDFVersion_X1a:
-			case PDFOptions::PDFVersion_X3:
-			case PDFOptions::PDFVersion_13:
+			case PDFVersion::PDF_X1a:
+			case PDFVersion::PDF_X3:
+			case PDFVersion::PDF_13:
 				write("%PDF-1.3\n");
 				break;
-			case PDFOptions::PDFVersion_14:
+			case PDFVersion::PDF_14:
 				write("%PDF-1.4\n");
 				break;
-			case PDFOptions::PDFVersion_X4:
-			case PDFOptions::PDFVersion_15:
+			case PDFVersion::PDF_X4:
+			case PDFVersion::PDF_15:
 				write("%PDF-1.5\n");
 				break;
+			case PDFVersion::PDF_16:
+				write("%PDF-1.6\n");
+				break;
 		}
 		write("%\xc7\xec\x8f\xa2\n");
 	}
@@ -799,7 +787,6 @@ namespace Pdf
 		write(Pdf::toPdf(StX)+"\n%%EOF\n");
 	}
 	
-	
 	void Writer::write(const QByteArray& bytes)
 	{
 		m_outStream.writeRawData(bytes, bytes.size());
@@ -868,7 +855,6 @@ namespace Pdf
 		write(">>\n");
 	}
 	
-	
 	PdfId Writer::reserveObjects(unsigned int n)
 	{
 		assert( n < (1<<30) ); // should only be triggered by reserveObjects(-1) or similar
