@@ -255,7 +255,7 @@ void PluginManager::enablePlugin(PluginData & pda)
 	}
 	else if (pda.plugin->inherits("ScPersistentPlugin"))
 	{
-		ScPersistentPlugin* plugin = dynamic_cast<ScPersistentPlugin*>(pda.plugin);
+		ScPersistentPlugin* plugin = qobject_cast<ScPersistentPlugin*>(pda.plugin);
 		assert(plugin);
 		pda.enabled = plugin->initPlugin();
 		if (!pda.enabled)
@@ -284,10 +284,10 @@ bool PluginManager::setupPluginActions(ScribusMainWindow *mw)
 		{
 			//Add in ScrAction based plugin linkage
 			//Insert DLL Action into Dictionary with values from plugin interface
-			plugin = dynamic_cast<ScActionPlugin*>(it.value().plugin);
+			plugin = qobject_cast<ScActionPlugin*>(it.value().plugin);
 			assert(plugin);
 			ScActionPlugin::ActionInfo ai(plugin->actionInfo());
-			ScrAction* action = new ScrAction(ScrAction::ActionDLL, ai.icon1, ai.icon2, ai.text, ai.keySequence, mw);
+			ScrAction* action = new ScrAction(ScrAction::ActionDLL, ai.iconPath1, ai.iconPath2, ai.text, ai.keySequence, mw);
 			Q_CHECK_PTR(action);
 			action->setStatusTip(ai.helpText);
 			action->setToolTip(ai.helpText);
@@ -385,12 +385,12 @@ bool PluginManager::setupPluginActions(StoryEditor *sew)
 		{
 			//Add in ScrAction based plugin linkage
 			//Insert DLL Action into Dictionary with values from plugin interface
-			plugin = dynamic_cast<ScActionPlugin*>(it.value().plugin);
+			plugin = qobject_cast<ScActionPlugin*>(it.value().plugin);
 			assert(plugin);
 			ScActionPlugin::ActionInfo ai(plugin->actionInfo());
 			if (ai.enabledForStoryEditor)
 			{
-				ScrAction* action = new ScrAction(ScrAction::ActionDLLSE, ai.icon1, ai.icon2, ai.text, ai.keySequence, sew);
+				ScrAction* action = new ScrAction(ScrAction::ActionDLLSE, ai.iconPath1, ai.iconPath2, ai.text, ai.keySequence, sew);
 				Q_CHECK_PTR(action);
 				sew->seActions.insert(ai.name, action);
 
@@ -443,7 +443,7 @@ void PluginManager::enableOnlyStartupPluginActions(ScribusMainWindow* mw)
 	{
 		if (it.value().plugin->inherits("ScActionPlugin"))
 		{
-			plugin = dynamic_cast<ScActionPlugin*>(it.value().plugin);
+			plugin = qobject_cast<ScActionPlugin*>(it.value().plugin);
 			assert(plugin);
 			ScActionPlugin::ActionInfo ai(plugin->actionInfo());
 			if (mw->scrActions.contains(ai.name))
@@ -455,31 +455,36 @@ void PluginManager::enableOnlyStartupPluginActions(ScribusMainWindow* mw)
 void PluginManager::enablePluginActionsForSelection(ScribusMainWindow* mw)
 {
 	Q_CHECK_PTR(mw);
-	ScribusDoc* doc=mw->doc;
+	ScribusDoc* doc = mw->doc;
 	if (!doc)
 		return;
 
-	ScActionPlugin* ixplug = nullptr;
+	int selectedType = -1;
+	if ( doc->m_Selection->count() > 0)
+	{
+		PageItem *currItem = doc->m_Selection->itemAt(0);
+		selectedType = currItem->itemType();
+	}
+	bool isLayerLocked = doc->layerLocked(doc->activeLayer());
+
+	ScActionPlugin* actionPlug = nullptr;
 	ScrAction* pluginAction = nullptr;
 	for (PluginMap::Iterator it = pluginMap.begin(); it != pluginMap.end(); ++it)
 	{
-		if (it.value().plugin->inherits("ScActionPlugin"))
-		{
-			ixplug = dynamic_cast<ScActionPlugin*>(it.value().plugin);
-			Q_ASSERT(ixplug);
-			if (ixplug)
-			{
-				ScActionPlugin::ActionInfo ai(ixplug->actionInfo());
-				pluginAction = mw->scrActions[ai.name];
-				if (pluginAction != nullptr)
-				{
-					if (doc->m_Selection->count() != 0)
-						pluginAction->setEnabled(ixplug->handleSelection(doc, doc->m_Selection->itemAt(0)->itemType()));
-					else
-						pluginAction->setEnabled(ixplug->handleSelection(doc));
-				}
-			}
-		}
+		if (!it.value().plugin->inherits("ScActionPlugin"))
+			continue;
+		actionPlug = qobject_cast<ScActionPlugin*>(it.value().plugin);
+		if (!actionPlug)
+			continue;
+
+		ScActionPlugin::ActionInfo actionInfo(actionPlug->actionInfo());
+		pluginAction = mw->scrActions[actionInfo.name];
+		if (pluginAction == nullptr)
+			continue;
+		if (isLayerLocked && !actionInfo.enabledOnStartup)
+			pluginAction->setEnabled(false);
+		else
+			pluginAction->setEnabled(actionPlug->handleSelection(doc, selectedType));
 	}
 }
 
@@ -500,52 +505,52 @@ bool PluginManager::DLLexists(const QString& name, bool includeDisabled) const
 	return false;
 }
 
-bool PluginManager::loadPlugin(PluginData & pda)
+bool PluginManager::loadPlugin(PluginData& pluginData)
 {
 	typedef int (*getPluginAPIVersionPtr)();
 	typedef ScPlugin* (*getPluginPtr)();
 	getPluginAPIVersionPtr getPluginAPIVersion;
 	getPluginPtr getPlugin;
 
-	Q_ASSERT(pda.plugin == nullptr);
-	Q_ASSERT(pda.pluginDLL == nullptr);
-	Q_ASSERT(!pda.enabled);
-	pda.plugin = nullptr;
+	Q_ASSERT(pluginData.plugin == nullptr);
+	Q_ASSERT(pluginData.pluginDLL == nullptr);
+	Q_ASSERT(!pluginData.enabled);
+	pluginData.plugin = nullptr;
 
-	pda.pluginDLL = loadDLL(pda.pluginFile);
-	if (!pda.pluginDLL)
+	pluginData.pluginDLL = loadDLL(pluginData.pluginFile);
+	if (!pluginData.pluginDLL)
 		return false;
 
 	getPluginAPIVersion = (getPluginAPIVersionPtr)
-		resolveSym(pda.pluginDLL, QString(pda.pluginName + "_getPluginAPIVersion").toLocal8Bit().data());
+		resolveSym(pluginData.pluginDLL, QString(pluginData.pluginName + "_getPluginAPIVersion").toLocal8Bit().data());
 	if (getPluginAPIVersion)
 	{
 		int gotVersion = (*getPluginAPIVersion)();
 		if ( gotVersion != PLUGIN_API_VERSION )
 		{
 			qDebug("API version mismatch when loading %s: Got %i, expected %i",
-					pda.pluginFile.toLocal8Bit().data(), gotVersion, PLUGIN_API_VERSION);
+					pluginData.pluginFile.toLocal8Bit().data(), gotVersion, PLUGIN_API_VERSION);
 		}
 		else
 		{
 			getPlugin = (getPluginPtr)
-				resolveSym(pda.pluginDLL, QString(pda.pluginName + "_getPlugin").toLocal8Bit().data());
+				resolveSym(pluginData.pluginDLL, QString(pluginData.pluginName + "_getPlugin").toLocal8Bit().data());
 			if (getPlugin)
 			{
-				pda.plugin = (*getPlugin)();
-				if (!pda.plugin)
+				pluginData.plugin = (*getPlugin)();
+				if (!pluginData.plugin)
 				{
 					qDebug("Unable to get ScPlugin when loading %s",
-							pda.pluginFile.toLocal8Bit().data());
+							pluginData.pluginFile.toLocal8Bit().data());
 				}
 				else
 					return true;
 			}
 		}
 	}
-	unloadDLL(pda.pluginDLL);
-	pda.pluginDLL = nullptr;
-	Q_ASSERT(!pda.plugin);
+	unloadDLL(pluginData.pluginDLL);
+	pluginData.pluginDLL = nullptr;
+	Q_ASSERT(!pluginData.plugin);
 	return false;
 }
 
@@ -584,7 +589,7 @@ void PluginManager::disablePlugin(PluginData & pda)
 	Q_ASSERT(pda.plugin);
 	if (pda.plugin->inherits("ScActionPlugin"))
 	{
-		ScActionPlugin* plugin = dynamic_cast<ScActionPlugin*>(pda.plugin);
+		ScActionPlugin* plugin = qobject_cast<ScActionPlugin*>(pda.plugin);
 		assert(plugin);
 		plugin->cleanupPlugin();
 		// FIXME: Correct way to delete action?
@@ -592,7 +597,7 @@ void PluginManager::disablePlugin(PluginData & pda)
 	}
 	else if (pda.plugin->inherits("ScPersistentPlugin"))
 	{
-		ScPersistentPlugin* plugin = dynamic_cast<ScPersistentPlugin*>(pda.plugin);
+		ScPersistentPlugin* plugin = qobject_cast<ScPersistentPlugin*>(pda.plugin);
 		assert(plugin);
 		plugin->cleanupPlugin();
 	}
@@ -655,7 +660,7 @@ void PluginManager::languageChange()
 		if (plugin)
 		{
 			plugin->languageChange();
-			ixplug = dynamic_cast<ScActionPlugin*>(plugin);
+			ixplug = qobject_cast<ScActionPlugin*>(plugin);
 			if (ixplug)
 			{
 				ScActionPlugin::ActionInfo ai(ixplug->actionInfo());
@@ -681,7 +686,7 @@ PluginManager & PluginManager::instance()
 	return (*ScCore->pluginManager);
 }
 
-const QString PluginManager::getPluginPath(const QString & pluginName) const
+QString PluginManager::getPluginPath(const QString & pluginName) const
 {
 	// It is not legal to call this function without a valid
 	// plug in name.
