@@ -24,12 +24,12 @@ class PLUGIN_API Barcode : public ScActionPlugin
 		virtual ~Barcode();
 		/*! \brief run the plug
 		\param target none usage here */
-		virtual bool run(ScribusDoc* doc, const QString& target = QString());
-		virtual const QString fullTrName() const;
-		virtual const AboutData* getAboutData() const;
-		virtual void deleteAboutData(const AboutData* about) const;
-		virtual void languageChange();
-		virtual void addToMainWindowMenu(ScribusMainWindow *) {};
+		bool run(ScribusDoc* doc, const QString& target = QString()) override;
+		QString fullTrName() const override;
+		const AboutData* getAboutData() const override;
+		void deleteAboutData(const AboutData* about) const override;
+		void languageChange() override;
+		void addToMainWindowMenu(ScribusMainWindow *) override {};
 };
 
 extern "C" PLUGIN_API int barcodegenerator_getPluginAPIVersion();
