@@ -18,8 +18,8 @@ for which a new license (GPL+exception) is in place.
 #include "scribus.h"
 #include "ui/cmykfw.h"
 #include "ui/colorlistbox.h"
+#include "ui/contentpalette.h"
 #include "ui/propertiespalette.h"
-#include "ui/textpalette.h"
 #include "util_color.h"
 
 
@@ -31,7 +31,6 @@ CWDialog::CWDialog(QWidget* parent, ScribusDoc* doc, const char* name, bool moda
 	setupUi(this);
 	setObjectName(name);
 	setModal(modal);
-	int h, s, v;
 	ScColor color;
 	QString colorName;
 	connectSlots(false);
@@ -72,6 +71,7 @@ CWDialog::CWDialog(QWidget* parent, ScribusDoc* doc, const char* name, bool moda
 	}
 	// Handle achromatic colors
 	QColor rgb = ScColorEngine::getRGBColor(color, m_Doc);
+	int h, s, v;
 	rgb.getHsv(&h, &s, &v);
 	if (h == -1)
 	{   // Reset to defaults
@@ -343,7 +343,7 @@ void CWDialog::addButton_clicked()
 		return;
 	}
 	m_Doc->scMW()->propertiesPalette->updateColorList();
-	m_Doc->scMW()->textPalette->updateColorList();
+	m_Doc->scMW()->contentPalette->updateColorList();
 	accept();
 }
 
@@ -354,7 +354,7 @@ void CWDialog::replaceButton_clicked()
 		m_Doc->PageColors[it.key()] = it.value();
 	}
 	m_Doc->scMW()->propertiesPalette->updateColorList();
-	m_Doc->scMW()->textPalette->updateColorList();
+	m_Doc->scMW()->contentPalette->updateColorList();
 	accept();
 }
 
