@@ -46,11 +46,7 @@ DocXIm::DocXIm(const QString& fileName, PageItem *textItem, bool textOnly, bool
 	m_item = textItem;
 	m_prefixName = prefix;
 	m_append = append;
-	themePart = "";
-	docPart = "";
-	stylePart = "";
-	themeFont1 = "";
-	themeFont2 = "";
+
 	uz = new ScZipHandler();
 	if (!uz->open(fileName))
 	{
@@ -297,7 +293,7 @@ void DocXIm::parseStyledText(PageItem *textItem)
 				{
 					currentParagraphStyle = defaultParagraphStyle;
 					bool hasStyle = false;
-					QString currStyleName = "";
+					QString currStyleName;
 					for (QDomElement spr = spf.firstChildElement(); !spr.isNull(); spr = spr.nextSiblingElement())
 					{
 						if (spr.tagName() == "w:pPr")
@@ -378,11 +374,11 @@ void DocXIm::parseParaProps(QDomElement &props, ParagraphStyle &pStyle)
 		{
 			QString align = spt.attribute("w:val");
 			if (align == "start")
-				pStyle.setAlignment(ParagraphStyle::Leftaligned);
+				pStyle.setAlignment(ParagraphStyle::LeftAligned);
 			else if (align == "center")
 				pStyle.setAlignment(ParagraphStyle::Centered);
 			else if (align == "end")
-				pStyle.setAlignment(ParagraphStyle::Rightaligned);
+				pStyle.setAlignment(ParagraphStyle::RightAligned);
 			else if (align == "both")
 				pStyle.setAlignment(ParagraphStyle::Justified);
 			else if (align == "distribute")
