@@ -17,7 +17,7 @@ for which a new license (GPL+exception) is in place.
 #include <QScopedPointer>
 #include <QXmlInputSource>
 #include <QXmlSimpleReader>
-#include "color.h"
+
 #include "scribusdoc.h"
 #include "styles/charstyle.h"
 #include "styles/paragraphstyle.h"
@@ -30,7 +30,7 @@ for which a new license (GPL+exception) is in place.
 
 QString FileFormatName()
 {
-    return QObject::tr("ODT Document");
+	return QObject::tr("ODT Document");
 }
 
 QStringList FileExtensions()
@@ -49,7 +49,6 @@ void GetText2(const QString& filename, const QString& encoding, bool textOnly, b
 
 ODTIm::ODTIm(const QString& fileName, PageItem *textItem, bool textOnly, bool prefix, bool append)
 {
-	uz=nullptr;
 	m_Doc = textItem->doc();
 	m_item = textItem;
 	m_prefixName = prefix;
@@ -1157,11 +1156,11 @@ void ODTIm::resolveStyle(ObjStyleODT &tmpOStyle, const QString& pAttrs)
 		{
 			QString attValue = actStyle.textAlign.value;
 			if ((attValue == "left") || (attValue == "start"))
-				tmpOStyle.textAlign = ParagraphStyle::Leftaligned;
+				tmpOStyle.textAlign = ParagraphStyle::LeftAligned;
 			else if (attValue == "center")
 				tmpOStyle.textAlign = ParagraphStyle::Centered;
 			else if ((attValue == "right") || (attValue == "end"))
-				tmpOStyle.textAlign = ParagraphStyle::Rightaligned;
+				tmpOStyle.textAlign = ParagraphStyle::RightAligned;
 			else if (attValue == "justify")
 				tmpOStyle.textAlign = ParagraphStyle::Justified;
 		}
@@ -1271,13 +1270,6 @@ double ODTIm::parseUnit(const QString &unit)
 	return value;
 }
 
-QColor ODTIm::parseColorN( const QString &rgbColor )
-{
-	int r, g, b;
-	keywordToRGB( rgbColor, r, g, b );
-	return QColor( r, g, b );
-}
-
 QString ODTIm::parseColor( const QString &s )
 {
 	QColor c;
@@ -1309,13 +1301,7 @@ QString ODTIm::parseColor( const QString &s )
 		c = QColor(r.toInt(), g.toInt(), b.toInt());
 	}
 	else
-	{
-		QString rgbColor = s.trimmed();
-		if (rgbColor.startsWith( "#" ))
-			c.setNamedColor( rgbColor );
-		else
-			c = parseColorN( rgbColor );
-	}
+		c.setNamedColor( s.trimmed() );
 	ScColor tmp;
 	tmp.fromQColor(c);
 	tmp.setSpotColor(false);
