@@ -41,16 +41,10 @@ StyleReader::StyleReader(const QString& documentName, gtWriter *w, bool textOnly
 {
 	sreader      = this;
 	docname      = documentName;
-	readProperties = false;
 	writer       = w;
 	importTextOnly = textOnly;
 	usePrefix    = prefix;
 	packStyles   = combineStyles;
-	currentStyle = nullptr;
-	parentStyle  = nullptr;
-	inList       = false;
-	currentList  = "";
-	defaultStyleCreated = false;
 }
 
 bool StyleReader::startElement(const QString&, const QString&, const QString &name, const QXmlAttributes &attrs)
@@ -63,7 +57,7 @@ bool StyleReader::startElement(const QString&, const QString&, const QString &na
 	{
 		/*if (!defaultStyleCreated)
 		{
-			gtParagraphStyle* pstyle = new gtParagraphStyle(*(writer->getDefaultStyle()));
+			gtParagraphStyle* pstyle = new gtParagraphStyle(writer->getDefaultStyle()->asGtParagraphStyle());
 			pstyle->setDefaultStyle(true);
 			currentStyle = dynamic_cast<gtStyle*>(pstyle);
 			currentStyle->setName("default-style");
@@ -170,16 +164,17 @@ void StyleReader::defaultStyle(const QXmlAttributes& attrs)
 {
 	currentStyle = nullptr;
 	for (int i = 0; i < attrs.count(); ++i)
-		if (attrs.localName(i) == "style:family")
-			if (attrs.value(i) == "paragraph")
-			{
-				gtParagraphStyle* pstyle = new gtParagraphStyle(*(writer->getDefaultStyle()));
-				pstyle->setDefaultStyle(true);
-				currentStyle = dynamic_cast<gtStyle*>(pstyle);
-				currentStyle->setName("default-style");
-				readProperties = true;
-				defaultStyleCreated = true;
-			}
+	{
+		if (attrs.localName(i) == "style:family" && attrs.value(i) == "paragraph")
+		{
+			gtParagraphStyle* pstyle = new gtParagraphStyle(writer->getDefaultStyle()->asGtParagraphStyle());
+			pstyle->setDefaultStyle(true);
+			currentStyle = dynamic_cast<gtStyle*>(pstyle);
+			currentStyle->setName("default-style");
+			readProperties = true;
+			defaultStyleCreated = true;
+		}
+	}
 }
 
 void StyleReader::styleProperties(const QXmlAttributes& attrs)
@@ -256,11 +251,11 @@ void StyleReader::styleProperties(const QXmlAttributes& attrs)
 			currentStyle->getFont()->setHscale(static_cast<int>(getSize(attrs.value(i), -1.0)));
 		else if ((attrs.localName(i) == "style:text-position") &&
 				 (((attrs.value(i)).indexOf("sub") != -1) ||
-				  (((attrs.value(i)).left(1) == "-") && ((attrs.value(i)).left(1) != "0"))))
+				  (((attrs.value(i)).at(0) == "-") && ((attrs.value(i)).at(0) != "0"))))
 			currentStyle->getFont()->toggleEffect(SUBSCRIPT);
 		else if ((attrs.localName(i) == "style:text-position") &&
 				 (((attrs.value(i)).indexOf("super") != -1) ||
-				  (((attrs.value(i)).left(1) != "-") && ((attrs.value(i)).left(1) != "0"))))
+				  (((attrs.value(i)).at(0) != "-") && ((attrs.value(i)).at(0) != "0"))))
 			currentStyle->getFont()->toggleEffect(SUPERSCRIPT);
 		else if ((attrs.localName(i) == "fo:margin-top") && (pstyle != nullptr))
 			pstyle->setSpaceAbove(getSize(attrs.value(i)));
@@ -315,7 +310,7 @@ void StyleReader::styleStyle(const QXmlAttributes& attrs)
 
 	if (!defaultStyleCreated)
 	{
-		gtParagraphStyle* pstyle = new gtParagraphStyle(*(writer->getDefaultStyle()));
+		gtParagraphStyle* pstyle = new gtParagraphStyle(writer->getDefaultStyle()->asGtParagraphStyle());
 		pstyle->setDefaultStyle(true);
 		currentStyle = dynamic_cast<gtStyle*>(pstyle);
 		currentStyle->setName("default-style");
@@ -574,9 +569,9 @@ void StyleReader::setupFrameStyle()
 			fstyleName = it.key();
 		}
 	}
-	gtFrameStyle* fstyle;
+
 	gtParagraphStyle* pstyle = dynamic_cast<gtParagraphStyle*>(attrsStyles[fstyleName]);
-	fstyle = new gtFrameStyle(*pstyle);
+	gtFrameStyle* fstyle = new gtFrameStyle(*pstyle);
 
 	if (!importTextOnly)
 		writer->setFrameStyle(fstyle);
@@ -645,12 +640,12 @@ bool StyleReader::updateStyle(gtStyle* style, gtStyle* parent2Style, const QStri
 	else if (key == "style:text-scale")
 		style->getFont()->setHscale(static_cast<int>(getSize(value, -1.0)));
 	else if ((key == "style:text-position") &&
-			 (((value).indexOf("sub") != -1) ||
-			  (((value).left(1) == "-") && ((value).left(1) != "0"))))
+			 ((value.indexOf("sub") != -1) ||
+			  ((value.at(0) == "-") && (value.at(0) != "0"))))
 		style->getFont()->toggleEffect(SUBSCRIPT);
 	else if ((key == "style:text-position") &&
-			 (((value).indexOf("super") != -1) ||
-			  (((value).left(1) != "-") && ((value).left(1) != "0"))))
+			 ((value.indexOf("super") != -1) ||
+			  ((value.at(0) != "-") && (value.at(0) != "0"))))
 		style->getFont()->toggleEffect(SUPERSCRIPT);
 	else if ((key == "fo:margin-top") && (pstyle != nullptr))
 		pstyle->setSpaceAbove(getSize(value));
