@@ -45,16 +45,7 @@ XtgScanner::XtgScanner(PageItem *item, bool textOnly, bool prefix, bool append)
     : m_item(item),
     m_importTextOnly(textOnly),
     m_prefixName(prefix),
-    m_append(append),
-    m_newlineFlag(false),
-    m_xflag(false),
-    m_inDef(false),
-	m_bufferIndex(0),
-    m_textIndex(0),
-    m_define(0),
-    m_isBold(false),
-    m_isItalic(false),
-	m_decoder(nullptr)
+    m_append(append)
 {
 	m_doc = item->doc();
 	initTagMode();
@@ -292,31 +283,19 @@ void XtgScanner::setBold()
 	m_item->itemText.insertChars(posC, "B");
 	m_item->itemText.applyStyle(posC, m_currentParagraphStyle);
 	m_item->itemText.applyCharStyle(posC, 1, m_currentCharStyle);
-	QString fam = m_item->itemText.charStyle(posC).font().family();
+	QString family = m_item->itemText.charStyle(posC).font().family();
 	m_item->itemText.removeChars(posC, 1);
-	if (fam.isEmpty())
+	if (family.isEmpty())
 		return;
-	QStringList slist = PrefsManager::instance().appPrefs.fontPrefs.AvailFonts.fontMap[fam];
-	if (m_isBold)
-	{
-		if (m_isItalic)
-		{
-			if (slist.contains("Bold Italic"))
-				m_currentCharStyle.setFont(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts[fam + " Bold Italic"]);
-		}
-		else if (slist.contains("Bold"))
-			m_currentCharStyle.setFont(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts[fam + " Bold"]);
-	}
-	else
-	{
-		if (m_isItalic)
-		{
-			if (slist.contains("Italic"))
-				m_currentCharStyle.setFont(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts[fam + " Italic"]);
-		}
-		else if (slist.contains("Regular"))
-			m_currentCharStyle.setFont(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts[fam + " Regular"]);
-	}
+	QStringList slist = PrefsManager::instance().appPrefs.fontPrefs.AvailFonts.fontMap[family];
+	if (m_isBold && m_isItalic && slist.contains("Bold Italic"))
+		m_currentCharStyle.setFont(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts[family + " Bold Italic"]);
+	if (m_isBold && !m_isItalic && slist.contains("Bold"))
+		m_currentCharStyle.setFont(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts[family + " Bold"]);
+	if (!m_isBold && m_isItalic && slist.contains("Italic"))
+		m_currentCharStyle.setFont(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts[family + " Italic"]);
+	if (!m_isBold && !m_isItalic && slist.contains("Regular"))
+		m_currentCharStyle.setFont(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts[family + " Regular"]);
 }
 
 void XtgScanner::setItalics()
@@ -637,7 +616,7 @@ void XtgScanner::setXPresOwn()
 void XtgScanner::setAlignLeft()
 {
 	flushText();
-	m_currentParagraphStyle.setAlignment(ParagraphStyle::Leftaligned);
+	m_currentParagraphStyle.setAlignment(ParagraphStyle::LeftAligned);
 }
 
 void XtgScanner::setAlignCenter()
@@ -649,7 +628,7 @@ void XtgScanner::setAlignCenter()
 void XtgScanner::setAlignRight()
 {
 	flushText();
-	m_currentParagraphStyle.setAlignment(ParagraphStyle::Rightaligned);
+	m_currentParagraphStyle.setAlignment(ParagraphStyle::RightAligned);
 }
 
 void XtgScanner::setAlignJustify()
