@@ -27,15 +27,15 @@ class PLUGIN_API ImportAIPlugin : public LoadSavePlugin
 		\brief Returns name of plugin
 		\retval QString containing name of plugin: Import EPS/PDF/PS...
 		*/
-		virtual const QString fullTrName() const;
-		virtual const AboutData* getAboutData() const;
-		virtual void deleteAboutData(const AboutData* about) const;
-		virtual void languageChange();
-		virtual bool fileSupported(QIODevice* file, const QString & fileName=QString()) const;
-		virtual bool loadFile(const QString & fileName, const FileFormat & fmt, int flags, int index = 0);
-		virtual QImage readThumbnail(const QString& fileName);
-		virtual bool readColors(const QString& fileName, ColorList & colors);
-		virtual void addToMainWindowMenu(ScribusMainWindow *) {};
+		QString fullTrName() const override;
+		const AboutData* getAboutData() const override;
+		void deleteAboutData(const AboutData* about) const override;
+		void languageChange() override;
+		bool fileSupported(QIODevice* file, const QString & fileName=QString()) const override;
+		bool loadFile(const QString & fileName, const FileFormat & fmt, int flags, int index = 0) override;
+		QImage readThumbnail(const QString& fileName) override;
+		bool readColors(const QString& fileName, ColorList & colors) override;
+		void addToMainWindowMenu(ScribusMainWindow *) override {};
 
 	public slots:
 		/*!
