@@ -247,7 +247,7 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->setPageSize("Custom");
 	}
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
-		m_Doc->view()->Deselect();
+		m_Doc->view()->deselectItems();
 	Elements.clear();
 	m_Doc->setLoading(true);
 	m_Doc->DoDrawing = false;
@@ -3403,7 +3403,7 @@ PageItem* CgmPlug::itemAdd(PageItem::ItemType itemType, PageItem::ItemFrameType
 				if (patternScaleY > -1)
 					patSY = patternScaleY / pat.height * 100;
 				ite->setPatternTransform(patSX, patSY, 0, 0, 0, 0.0, 0.0);
-				ite->GrType = 8;
+				ite->GrType = Gradient_Pattern;
 			}
 		}
 		else if (fillType == 4)
@@ -3432,7 +3432,7 @@ PageItem* CgmPlug::itemAdd(PageItem::ItemType itemType, PageItem::ItemFrameType
 				if (patternScaleY > -1)
 					patSY = patternScaleY / pat.height * 100;
 				ite->setPatternTransform(patSX, patSY, 0, 0, 0, 0.0, 0.0);
-				ite->GrType = 8;
+				ite->GrType = Gradient_Pattern;
 			}
 		}
 		else
