@@ -219,7 +219,7 @@ bool DrwPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->setPageSize("Custom");
 	}
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
-		m_Doc->view()->Deselect();
+		m_Doc->view()->deselectItems();
 	Elements.clear();
 	m_Doc->setLoading(true);
 	m_Doc->DoDrawing = false;
@@ -928,7 +928,7 @@ void DrwPlug::decodeCmd(quint8 cmd, int pos)
 					DRWParagraph para = paragraphList.at(paragraphCounter);
 					paragraphCounter++;
 					ParagraphStyle newStyle;
-					newStyle.setLineSpacingMode(static_cast<ParagraphStyle::LineSpacingMode>(1));
+					newStyle.setLineSpacingMode(ParagraphStyle::AutomaticLineSpacing);
 					newStyle.setAlignment(static_cast<ParagraphStyle::AlignmentType>(para.paragraphAlignment));
 					newStyle.charStyle().setFontSize(fontSize * scaleFactor * 10.0 * 0.8);
 					QString fontN(m_Doc->itemToolPrefs().textFont);
@@ -959,7 +959,7 @@ void DrwPlug::decodeCmd(quint8 cmd, int pos)
 			cmdText += "DRW Colortable";
 			if (currentItem != nullptr)
 			{
-				if (currentItem->asImageFrame())
+				if (currentItem->isImageFrame())
 				{
 					QString fileName = currentItem->Pfile;
 					if (!fileName.isEmpty())
@@ -1804,14 +1804,14 @@ void DrwPlug::handleGradient(PageItem* currentItem, quint8 patternIndex, const Q
 			{
 				FillGradient.addStop( ScColorEngine::getRGBColor(gradC2, m_Doc), qMin(grad.yOffset, 0.99), 0.5, 1.0, backColor, 100 );
 				FillGradient.addStop( ScColorEngine::getRGBColor(gradC1, m_Doc), 1.0, 0.5, 1.0, fillColor, 100 );
-				currentItem->GrType = 6;
+				currentItem->GrType = Gradient_Linear;
 				currentItem->fill_gradient = FillGradient;
 				currentItem->setGradientVector(bBox.width() / 2.0, 0, bBox.width() / 2.0, bBox.height(), 0, 0, 1, 0);
 			}
 			else
 			{
 				FillGradient.addStop( ScColorEngine::getRGBColor(gradC2, m_Doc), 1.0, 0.5, 1.0, backColor, 100 );
-				currentItem->GrType = 7;
+				currentItem->GrType = Gradient_Radial;
 				currentItem->fill_gradient = FillGradient;
 				currentItem->setGradientVector(xoff, yoff, qMax(bBox.width(), bBox.height()), qMax(bBox.width(), bBox.height()), xoff, yoff, 1, 0);
 			}
@@ -1828,7 +1828,7 @@ void DrwPlug::handleGradient(PageItem* currentItem, quint8 patternIndex, const Q
 		{
 			QColor back = ScColorEngine::getRGBColor(m_Doc->PageColors[fillColor], m_Doc);
 			QColor fore = ScColorEngine::getRGBColor(m_Doc->PageColors[backColor], m_Doc);
-			QString patNa = QString("%1%2%3").arg(back.name()).arg(fore.name()).arg(ind);
+			QString patNa = QString("%1%2%3").arg(back.name(), fore.name()).arg(ind);
 			QString patternName;
 			if (!patternMap.contains(patNa))
 			{
@@ -1907,7 +1907,7 @@ void DrwPlug::handleGradient(PageItem* currentItem, quint8 patternIndex, const Q
 			importedPatterns.append(patternName);
 			currentItem->setPattern(patternName);
 			currentItem->setPatternTransform(16.6666, 16.6666, 0, 0, 0, 0, 0);
-			currentItem->GrType = 8;
+			currentItem->GrType = Gradient_Pattern;
 		}
 	}
 }
@@ -1950,7 +1950,10 @@ void DrwPlug::getCommonData(QDataStream &ds)
 
 QString DrwPlug::getColor(QDataStream &ds)
 {
-	quint8 r, g, b, a;
+	quint8 r;
+	quint8 g;
+	quint8 b;
+	quint8 a;
 	ds >> r >> g >> b >> a;
 	ScColor color = ScColor(r, g, b);
 	return handleColor(color, "FromDRW"+color.name());
