@@ -34,7 +34,7 @@ ScPlugin* importpct_getPlugin()
 
 void importpct_freePlugin(ScPlugin* plugin)
 {
-	ImportPctPlugin* plug = dynamic_cast<ImportPctPlugin*>(plugin);
+	ImportPctPlugin* plug = qobject_cast<ImportPctPlugin*>(plugin);
 	Q_ASSERT(plug);
 	delete plug;
 }
@@ -61,7 +61,7 @@ ImportPctPlugin::~ImportPctPlugin()
 	unregisterAll();
 }
 
-const QString ImportPctPlugin::fullTrName() const
+QString ImportPctPlugin::fullTrName() const
 {
 	return QObject::tr("Pict Importer");
 }
@@ -136,7 +136,7 @@ bool ImportPctPlugin::import(QString fileName, int flags)
 	TransactionSettings trSettings;
 	trSettings.targetName   = hasCurrentPage ? m_Doc->currentPage()->getUName() : "";
 	trSettings.targetPixmap = Um::IImageFrame;
-	trSettings.actionName   = Um::ImportXfig;
+	trSettings.actionName   = Um::ImportPict;
 	trSettings.description  = fileName;
 	trSettings.actionPixmap = Um::IXFIG;
 	if (emptyDoc || !(flags & lfInteractive) || !(flags & lfScripted))
