@@ -68,14 +68,17 @@ PdfPlug::PdfPlug(ScribusDoc* doc, int flags)
 	m_Doc = doc;
 	importerFlags = flags;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
-	progressDialog = nullptr;
-	m_pdfDoc = nullptr;
+
 }
 
 QImage PdfPlug::readThumbnail(const QString& fName)
 {
 	QString pdfFile = QDir::toNativeSeparators(fName);
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 83, 0)
+	globalParams.reset(new GlobalParams());
+#else
 	globalParams = new GlobalParams();
+#endif
 	if (globalParams)
 	{
 #if defined(Q_OS_WIN32) && POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 62, 0)
@@ -90,7 +93,9 @@ QImage PdfPlug::readThumbnail(const QString& fName)
 			if (pdfDoc->getErrorCode() == errEncrypted)
 			{
 				delete pdfDoc;
+#if POPPLER_ENCODED_VERSION < POPPLER_VERSION_ENCODE(0, 83, 0)
 				delete globalParams;
+#endif
 				return QImage();
 			}
 			if (pdfDoc->isOk())
@@ -134,50 +139,29 @@ QImage PdfPlug::readThumbnail(const QString& fName)
 				image.setText("YSize", QString("%1").arg(h));
 				delete dev;
 				delete pdfDoc;
+#if POPPLER_ENCODED_VERSION < POPPLER_VERSION_ENCODE(0, 83, 0)
 				delete globalParams;
+#endif
 				return image;
 			}
 			delete pdfDoc;
+#if POPPLER_ENCODED_VERSION < POPPLER_VERSION_ENCODE(0, 83, 0)
 			delete globalParams;
+#endif
 		}
 	}
 	return QImage();
 }
-/*	Old Code to be backed up
-	QString tmp, cmd1, cmd2;
-	QString pdfFile = QDir::toNativeSeparators(fName);
-	QString tmpFile = QDir::toNativeSeparators(ScPaths::tempFileDir() + "sc.png");
-	int ret = -1;
-	tmp.setNum(1);
-	QStringList args;
-	args.append("-r72");
-	args.append("-sOutputFile="+tmpFile);
-	args.append("-dFirstPage="+tmp);
-	args.append("-dLastPage="+tmp);
-	args.append(pdfFile);
-	ret = callGS(args);
-	if (ret == 0)
-	{
-		QImage image;
-		image.load(tmpFile);
-		QFile::remove(tmpFile);
-		image.setText("XSize", QString("%1").arg(image.width()));
-		image.setText("YSize", QString("%1").arg(image.height()));
-		return image;
-	}
-	return QImage();
-*/
 
 bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
-#ifdef Q_OS_OSX
+#ifdef Q_OS_MACOS
 	showProgress = false;
 #endif
 	bool success = false;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	importerFlags = flags;
 	cancel = false;
-	double b, h;
 	bool ret = false;
 	QFileInfo fi = QFileInfo(fNameIn);
 	if ( !ScCore->usingGUI() )
@@ -190,9 +174,8 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	{
 		ScribusMainWindow* mw = (m_Doc==nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
-		QStringList barNames, barTexts;
-		barNames << "GI";
-		barTexts << tr("Analyzing File:");
+		QStringList barNames("GI");
+		QStringList barTexts(tr("Analyzing File:"));
 		QList<bool> barsNumeric;
 		barsNumeric << false;
 		progressDialog->addExtraProgressBars(barNames, barTexts, barsNumeric);
@@ -206,28 +189,18 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	else
 		progressDialog = nullptr;
 /* Set default Page to size defined in Preferences */
-	b = 0.0;
-	h = 0.0;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
 		qApp->processEvents();
 	}
-	if (b == 0.0)
-		b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
-	if (h == 0.0)
-		h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
-	docWidth = b;
-	docHeight = h;
-	baseX = 0;
-	baseY = 0;
+	double docWidth = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
+	double docHeight = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 	if (!interactive || (flags & LoadSavePlugin::lfInsertPage))
 	{
 		m_Doc->setPage(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false);
 		m_Doc->addPage(0);
 		m_Doc->view()->addPage(0, true);
-		baseX = 0;
-		baseY = 0;
 	}
 	else
 	{
@@ -236,17 +209,9 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 			m_Doc=ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, 0, 0, 0, 0, 1, "Custom", true);
 			ScCore->primaryMainWindow()->HaveNewDoc();
 			ret = true;
-			baseX = 0;
-			baseY = 0;
-			baseX = m_Doc->currentPage()->xOffset();
-			baseY = m_Doc->currentPage()->yOffset();
 		}
 	}
-	if ((!ret) && (interactive))
-	{
-		baseX = m_Doc->currentPage()->xOffset();
-		baseY = m_Doc->currentPage()->yOffset();
-	}
+
 	if ((ret) || (!interactive))
 	{
 		if (docWidth > docHeight)
@@ -256,7 +221,7 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->setPageSize("Custom");
 	}
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
-		m_Doc->view()->Deselect();
+		m_Doc->view()->deselectItems();
 	Elements.clear();
 	m_Doc->setLoading(true);
 	m_Doc->DoDrawing = false;
@@ -387,7 +352,11 @@ bool PdfPlug::convert(const QString& fn)
 		qApp->processEvents();
 	}
 
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 83, 0)
+	globalParams.reset(new GlobalParams());
+#else
 	globalParams = new GlobalParams();
+#endif
 	GooString *userPW = nullptr;
 	if (globalParams)
 	{
@@ -429,7 +398,9 @@ bool PdfPlug::convert(const QString& fn)
 					if (progressDialog)
 						progressDialog->close();
 					delete pdfDoc;
+#if POPPLER_ENCODED_VERSION < POPPLER_VERSION_ENCODE(0, 83, 0)
 					delete globalParams;
+#endif
 					return false;
 				}
 				if (progressDialog)
@@ -474,7 +445,9 @@ bool PdfPlug::convert(const QString& fn)
 							progressDialog->close();
 						delete optImp;
 						delete pdfDoc;
+#if POPPLER_ENCODED_VERSION < POPPLER_VERSION_ENCODE(0, 83, 0)
 						delete globalParams;
+#endif
 						return false;
 					}
 					pageString = optImp->getPagesString();
@@ -488,11 +461,6 @@ bool PdfPlug::convert(const QString& fn)
 						useMediaBox = gFalse;
 					if (cropped)
 						useMediaBox = gTrue;
-				/*	if (cb > Media_Box)
-					{
-						cropped = true;
-						contentRect = cb;
-					} */
 					delete optImp;
 					qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
 					if (progressDialog)
@@ -590,21 +558,20 @@ bool PdfPlug::convert(const QString& fn)
 							}
 						}
 					}
-					bool rotated = false;
+
+					const int zeroRotate = 0;
 					dev->startDoc(pdfDoc, pdfDoc->getXRef(), pdfDoc->getCatalog());
-					int rotate = pdfDoc->getPageRotate(firstPage);
-					if ((rotate == 90) || (rotate == 270))
-						rotated = true;
-					dev->rotate = rotate;
-					rotate = 0;
+					dev->rotate = pdfDoc->getPageRotate(firstPage);
+					bool rotated = dev->rotate == 90 || dev->rotate == 270;
+
 					if (importerFlags & LoadSavePlugin::lfCreateDoc)
 					{
 						if (hasOcg)
 						{
-							QString actL = m_Doc->activeLayerName();
-							for (int a = 0; a < ocgGroups.count(); a++)
+							QString actL(m_Doc->activeLayerName());
+							for (int i = 0; i < ocgGroups.count(); i++)
 							{
-								OptionalContentGroup *oc = ocgGroups[a];
+								OptionalContentGroup *oc = ocgGroups[i];
 								if (actL != UnicodeParsedString(oc->getName()))
 									currentLayer = m_Doc->addLayer(UnicodeParsedString(oc->getName()), false);
 								else
@@ -682,14 +649,14 @@ bool PdfPlug::convert(const QString& fn)
 						}
 						m_Doc->setPageSize("Custom");
 					//	m_Doc->pdfOptions().PresentVals.clear();
-						for (uint ap = 0; ap < pageNs.size(); ++ap)
+						for (size_t i = 0; i < pageNs.size(); ++i)
 						{
-							int pp = pageNs[ap];
+							int pp = pageNs[i];
 							m_Doc->setActiveLayer(baseLayer);
 							if (firstPg)
 								firstPg = false;
 							else
-								m_Doc->addPage(ap);
+								m_Doc->addPage(i);
 							QRectF mdBox = getCBox(0, pp);
 							QRectF crBox = getCBox(contentRect, pp);
 							if (cropped)
@@ -730,43 +697,28 @@ bool PdfPlug::convert(const QString& fn)
 									m_Doc->currentPage()->setWidth(pdfDoc->getPageMediaWidth(pp));
 								}
 							}
-							m_Doc->currentPage()->MPageNam = CommonStrings::trMasterPageNormal;
-							m_Doc->currentPage()->m_pageSize = "Custom";
+							m_Doc->currentPage()->setMasterPageNameNormal();
+							m_Doc->currentPage()->setSize("Custom");
 							m_Doc->reformPages(true);
 							if (hasOcg)
 							{
-							//	int numObj = m_Doc->Items->count();
-							//	if (cropped)
-							//		pdfDoc->displayPageSlice(dev, pp, hDPI, vDPI, rotate, useMediaBox, crop, printing, crBox.x(), crBox.y(), crBox.width(), crBox.height(), nullptr, nullptr, dev->annotations_callback, dev);
-							//	else
-							//		pdfDoc->displayPage(dev, pp, hDPI, vDPI, rotate, useMediaBox, crop, printing, nullptr, nullptr, dev->annotations_callback, dev);
-							//	int numObj2 = m_Doc->Items->count();
-							//	int countObj = numObj2 - numObj;
-								for (int a = 0; a < ocgGroups.count(); a++)
+								for (int j = 0; j < ocgGroups.count(); j++)
 								{
-									OptionalContentGroup *oc = ocgGroups[a];
-							//		m_Doc->setActiveLayer(UnicodeParsedString(oc->getName()));
-							//		currentLayer = m_Doc->activeLayer();
+									OptionalContentGroup *oc = ocgGroups[j];
 									oc->setState(OptionalContentGroup::On);
 									if (cropped)
-										pdfDoc->displayPageSlice(dev, pp, hDPI, vDPI, rotate, useMediaBox, crop, printing, crBox.x() - mdBox.x(), mdBox.bottom() - crBox.bottom(), crBox.width(), crBox.height(), nullptr, nullptr, dev->annotations_callback, dev);
+										pdfDoc->displayPageSlice(dev, pp, hDPI, vDPI, zeroRotate, useMediaBox, crop, printing, crBox.x() - mdBox.x(), mdBox.bottom() - crBox.bottom(), crBox.width(), crBox.height(), nullptr, nullptr, dev->annotations_callback, dev);
 									else
-										pdfDoc->displayPage(dev, pp, hDPI, vDPI, rotate, useMediaBox, crop, printing, nullptr, nullptr, dev->annotations_callback, dev);
+										pdfDoc->displayPage(dev, pp, hDPI, vDPI, zeroRotate, useMediaBox, crop, printing, nullptr, nullptr, dev->annotations_callback, dev);
 									oc->setState(OptionalContentGroup::Off);
-							//		for (int dd = 0; dd < countObj; dd++)
-							//		{
-							//			PageItem *iteD = m_Doc->Items->takeAt(numObj2);
-							//			delete iteD;
-							//		}
-							//		numObj2 = m_Doc->Items->count();
 								}
 							}
 							else
 							{
 								if (cropped)
-									pdfDoc->displayPageSlice(dev, pp, hDPI, vDPI, rotate, useMediaBox, crop, printing, crBox.x() - mdBox.x(), mdBox.bottom() - crBox.bottom(), crBox.width(), crBox.height(), nullptr, nullptr, dev->annotations_callback, dev);
+									pdfDoc->displayPageSlice(dev, pp, hDPI, vDPI, zeroRotate, useMediaBox, crop, printing, crBox.x() - mdBox.x(), mdBox.bottom() - crBox.bottom(), crBox.width(), crBox.height(), nullptr, nullptr, dev->annotations_callback, dev);
 								else
-									pdfDoc->displayPage(dev, pp, hDPI, vDPI, rotate, useMediaBox, crop, printing, nullptr, nullptr, dev->annotations_callback, dev);
+									pdfDoc->displayPage(dev, pp, hDPI, vDPI, zeroRotate, useMediaBox, crop, printing, nullptr, nullptr, dev->annotations_callback, dev);
 							}
 
 							PDFPresentationData ef;
@@ -838,11 +790,20 @@ bool PdfPlug::convert(const QString& fn)
 								names = catDict.dictLookup("OpenAction");
 								if (names.isDict())
 								{
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 86, 0)
+									std::unique_ptr<LinkAction> linkAction;
+									linkAction = LinkAction::parseAction(&names, pdfDoc->getCatalog()->getBaseURI());
+#else
 									LinkAction *linkAction = nullptr;
 									linkAction = LinkAction::parseAction(&names, pdfDoc->getCatalog()->getBaseURI());
+#endif
 									if (linkAction)
 									{
-										LinkJavaScript *jsa = (LinkJavaScript*)linkAction;
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 86, 0)
+										LinkJavaScript *jsa = (LinkJavaScript*) linkAction.get();
+#else
+										LinkJavaScript *jsa = (LinkJavaScript*) linkAction;
+#endif
 										if (jsa->isOk())
 										{
 											QString script = UnicodeParsedString(jsa->getScript());
@@ -859,7 +820,7 @@ bool PdfPlug::convert(const QString& fn)
 							}
 							delete jsNameTreeP;
 						}
-						m_Doc->pdfOptions().Version = (PDFOptions::PDFVersion)qMin(15, qMax(13, pdfDoc->getPDFMajorVersion() * 10 + pdfDoc->getPDFMinorVersion()));
+						m_Doc->pdfOptions().Version = (PDFVersion::Version) qMin(16, qMax(13, pdfDoc->getPDFMajorVersion() * 10 + pdfDoc->getPDFMinorVersion()));
 						ViewerPreferences *viewPrefs = pdfDoc->getCatalog()->getViewerPreferences();
 						if (viewPrefs)
 						{
@@ -880,13 +841,13 @@ bool PdfPlug::convert(const QString& fn)
 							m_Doc->pdfOptions().PageLayout = PDFOptions::OneColumn;
 						else if ((pgl == Catalog::pageLayoutTwoColumnLeft) || (pgl == Catalog::pageLayoutTwoPageLeft))
 						{
-							m_Doc->resetPage(1);
+							m_Doc->setPagePositioning(1);
 							m_Doc->setPageSetFirstPage(1, 0);
 							m_Doc->pdfOptions().PageLayout = PDFOptions::TwoColumnLeft;
 						}
 						else if ((pgl == Catalog::pageLayoutTwoColumnRight) || (pgl == Catalog::pageLayoutTwoPageRight))
 						{
-							m_Doc->resetPage(1);
+							m_Doc->setPagePositioning(1);
 							m_Doc->setPageSetFirstPage(1, 1);
 							m_Doc->pdfOptions().PageLayout = PDFOptions::TwoColumnRight;
 						}
@@ -900,7 +861,7 @@ bool PdfPlug::convert(const QString& fn)
 								ocgGroups[a]->setState(OptionalContentGroup::On);
 							}
 						}
-						pdfDoc->displayPage(dev, firstPage, hDPI, vDPI, rotate, useMediaBox, crop, printing, nullptr, nullptr, dev->annotations_callback, dev);
+						pdfDoc->displayPage(dev, firstPage, hDPI, vDPI, zeroRotate, useMediaBox, crop, printing, nullptr, nullptr, dev->annotations_callback, dev);
 					}
 				}
 				delete dev;
@@ -908,8 +869,12 @@ bool PdfPlug::convert(const QString& fn)
 		}
 		delete pdfDoc;
 	}
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 83, 0)
+	globalParams.release();
+#else
 	delete globalParams;
 	globalParams = nullptr;
+#endif
 
 //	qDebug() << "converting finished";
 //	qDebug() << "Imported" << Elements.count() << "Elements";
@@ -918,9 +883,9 @@ bool PdfPlug::convert(const QString& fn)
 	{
 		if (importedColors.count() != 0)
 		{
-			for (int cd = 0; cd < importedColors.count(); cd++)
+			for (int i = 0; i < importedColors.count(); i++)
 			{
-				m_Doc->PageColors.remove(importedColors[cd]);
+				m_Doc->PageColors.remove(importedColors[i]);
 			}
 		}
 	}
@@ -1046,3 +1011,43 @@ QString PdfPlug::UnicodeParsedString(POPPLER_CONST GooString *s1)
 	}
 	return result;
 }
+
+QString PdfPlug::UnicodeParsedString(const std::string& s1)
+{
+	if (s1.length() == 0)
+		return QString();
+	GBool isUnicode;
+	size_t i;
+	Unicode u;
+	QString result;
+	if ((s1.at(0) & 0xff) == 0xfe && (s1.length() > 1 && (s1.at(1) & 0xff) == 0xff))
+	{
+		isUnicode = gTrue;
+		i = 2;
+		result.reserve((s1.length() - 2) / 2);
+	}
+	else
+	{
+		isUnicode = gFalse;
+		i = 0;
+		result.reserve(s1.length());
+	}
+	while (i < s1.length())
+	{
+		if (isUnicode)
+		{
+			u = ((s1.at(i) & 0xff) << 8) | (s1.at(i+1) & 0xff);
+			i += 2;
+		}
+		else
+		{
+			u = s1.at(i) & 0xff;
+			++i;
+		}
+		// #15616: imagemagick may write unicode strings incorrectly in PDF
+		if (u == 0)
+			continue;
+		result += QChar( u );
+	}
+	return result;
+}
