@@ -602,7 +602,7 @@ bool WMFImport::importWMF(const TransactionSettings& trSettings, int flags)
 		m_Doc->setPageSize("Custom");
 	}
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
-		m_Doc->view()->Deselect();
+		m_Doc->view()->deselectItems();
 	m_Doc->setLoading(true);
 	m_Doc->DoDrawing = false;
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
@@ -757,7 +757,7 @@ void WMFImport::finishCmdParsing( PageItem* item )
 	QTransform gcm  = m_context.worldMatrix();
 	double coeff1 = sqrt(gcm.m11() * gcm.m11() + gcm.m12() * gcm.m12());
 	double coeff2 = sqrt(gcm.m21() * gcm.m21() + gcm.m22() * gcm.m22());
-	if (item->asImageFrame())
+	if (item->isImageFrame())
 	{
 		item->moveBy(gcm.dx(), gcm.dy());
 		item->setWidthHeight(item->width() * gcm.m11(), item->height() * gcm.m22());
@@ -765,7 +765,7 @@ void WMFImport::finishCmdParsing( PageItem* item )
 		if (item->imageIsAvailable)
 			item->setImageXYScale(item->width() / item->pixm.width(), item->height() / item->pixm.height());
 	}
-	else if (item->asTextFrame())
+	else if (item->isTextFrame())
 	{
 		item->setLineWidth(qMax(item->lineWidth() * (coeff1 + coeff2) / 2.0, 0.25));
 	}
@@ -1194,14 +1194,17 @@ void WMFImport::extTextOut( QList<PageItem*>& items, long num, short* params )
 		textString = QString::fromLocal8Bit(textArray.data());
 
 	QFontMetrics fm( m_context.font() );
-	int width  = fm.width(textString) + fm.descent();  // because fm.width(text) isn't rigth with Italic text
+	int width  = fm.horizontalAdvance(textString) + fm.descent();  // because fm.width(text) isn't rigth with Italic text
 	/*int height = fm.height();
 	int ascent = fm.ascent();*/
 
-	double startX = params[1], startY = params[0];
+	double startX = params[1];
+	double startY = params[0];
 	int    textAlign    = m_context.textAlign();
 	double textRotation = m_context.textRotation();
-	if ( textAlign & 0x01 ) {       // (left, top) position = current logical position
+	if ( textAlign & 0x01 )
+	{
+		// (left, top) position = current logical position
 		QPoint pos = m_context.position();
 		startX = pos.x();
 		startY = pos.y();
