@@ -359,7 +359,7 @@ void ScrPainter::finishItem(PageItem* ite)
 	if (isGradient)
 	{
 		ite->fill_gradient = currentGradient;
-		ite->GrType = 6;
+		ite->GrType = Gradient_Linear;
 		QTransform m1;
 		m1.rotate(-gradientAngle);
 		ite->GrStartX = 0;
@@ -572,7 +572,7 @@ bool WpgPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->setPageSize("Custom");
 	}
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
-		m_Doc->view()->Deselect();
+		m_Doc->view()->deselectItems();
 	Elements.clear();
 	m_Doc->setLoading(true);
 	m_Doc->DoDrawing = false;
