@@ -5,6 +5,8 @@ a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
 
+#include <algorithm>
+
 #include <QByteArray>
 #include <QCursor>
 #include <QDrag>
@@ -342,7 +344,7 @@ bool XfigPlug::import(const QString& fNameIn, const TransactionSettings& trSetti
 		m_Doc->setPageSize("Custom");
 	}
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
-		m_Doc->view()->Deselect();
+		m_Doc->view()->deselectItems();
 	Elements.clear();
 	m_Doc->setLoading(true);
 	m_Doc->DoDrawing = false;
@@ -1551,6 +1553,7 @@ void XfigPlug::resortItems()
 {
 	int ac = m_Doc->Items->count();
 	QList<PageItem*> itemList;
+	itemList.reserve(ac);
 	for (int as = oldDocItemCount; as < ac; ++as)
 	{
 		itemList.append(m_Doc->Items->takeAt(oldDocItemCount));
@@ -1563,7 +1566,7 @@ void XfigPlug::resortItems()
 		if ((importerFlags & LoadSavePlugin::lfCreateDoc) && (it > 0))
 			currentLayer = m_Doc->addLayer(QString("Layer %1").arg(it), true);
 		QList<int> elems = depthMap.values(keylist.at(it));
-		qSort(elems);
+		std::sort(elems.begin(), elems.end());
 		int itemsCount = elems.count();
 		for (int i = 0; i < itemsCount; ++i)
 		{
