@@ -141,6 +141,14 @@ If the save fails, there is currently no way to tell.\n\
 "));
 PyObject *scribus_savedoc(PyObject * /*self*/);
 
+/*! docstring */
+PyDoc_STRVAR(scribus_revertdoc__doc__,
+QT_TR_NOOP("revertDoc()\n\
+\n\
+Revert the current document to its last saved state.\n\
+"));
+PyObject *scribus_revertdoc(PyObject * /*self*/);
+
 /*! docstring */
 PyDoc_STRVAR(scribus_getdocname__doc__,
 QT_TR_NOOP("getDocName() -> string\n\
@@ -173,6 +181,17 @@ strings.\n\
 /** Sets document infos - author, title and description */
 PyObject *scribus_setinfo(PyObject * /*self*/, PyObject* args);
 
+/*! docstring */
+PyDoc_STRVAR(scribus_setbleeds__doc__,
+QT_TR_NOOP("setBleeds(lr, rr, tr, br)\n\
+\n\
+Sets the bleeds of the document. Left(lr), Right(rr), Top(tr) and Bottom(br)\n\
+bleeds are given in the measurement units of the document - see UNIT_<type>\n\
+constants.\n\
+"));
+/** Sets document bleeds - left, right, top and bottom. */
+PyObject *scribus_setbleeds(PyObject * /*self*/, PyObject* args);
+
 /*! docstring */
 PyDoc_STRVAR(scribus_setmargins__doc__,
 QT_TR_NOOP("setMargins(lr, rr, tr, br)\n\
@@ -278,9 +297,9 @@ Delete the named master page.\n\
 PyObject* scribus_deletemasterpage(PyObject* self, PyObject* args);
 
 PyDoc_STRVAR(scribus_getmasterpage__doc__,
-QT_TR_NOOP("getMasterPage(nr)\n\
+QT_TR_NOOP("getMasterPage(pageNr)\n\
 \n\
-Get Master Page of the page \"nr\".\n\
+Returns the name of master page applied to page \"nr\".\n\
 \n\
 May raise IndexError if the page number is out of range.\n\
 "));
