@@ -4,6 +4,9 @@ to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
+
+#include <algorithm>
+
 #include "cmdgetprop.h"
 #include "cmdutil.h"
 #include "scribuscore.h"
@@ -40,11 +43,27 @@ PyObject *scribus_getobjecttype(PyObject* /* self */, PyObject* args)
 		result = "Polyline";
 	} else if (item->itemType() == PageItem::LatexFrame) {
 		result = "LatexFrame";
+	} else if (item->itemType() == PageItem::OSGFrame) {
+		result = "OSGFrame";
+	} else if (item->itemType() == PageItem::Symbol) {
+		result = "Symbol";
+	} else if (item->itemType() == PageItem::Group) {
+		result = "Group";
+	} else if (item->itemType() == PageItem::RegularPolygon) {
+		result = "RegularPolygon";
+	} else if (item->itemType() == PageItem::Arc) {
+		result = "Arc";
+	} else if (item->itemType() == PageItem::Spiral) {
+		result = "Spiral";
+	} else if (item->itemType() == PageItem::Table) {
+		result = "Table";
+	} else if (item->itemType() == PageItem::NoteFrame) {
+		result = "NoteFrame";
 	} else if (item->itemType() == PageItem::Multiple) {
 		result = "Multiple";
 	}
 
-	return PyString_FromString(result.toUtf8());
+	return PyUnicode_FromString(result.toUtf8());
 }
 
 PyObject *scribus_getfillcolor(PyObject* /* self */, PyObject* args)
@@ -57,10 +76,10 @@ PyObject *scribus_getfillcolor(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyString_FromString(item->fillColor().toUtf8());
+	return PyUnicode_FromString(item->fillColor().toUtf8());
 }
 
-PyObject *scribus_getfilltrans(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getfilltransparency(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -73,7 +92,7 @@ PyObject *scribus_getfilltrans(PyObject* /* self */, PyObject* args)
 	return PyFloat_FromDouble(static_cast<double>(1.0 - item->fillTransparency()));
 }
 
-PyObject *scribus_getfillblend(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getfillblendmode(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -83,7 +102,7 @@ PyObject *scribus_getfillblend(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(item->fillBlendmode()));
+	return PyLong_FromLong(static_cast<long>(item->fillBlendmode()));
 }
 
 PyObject *scribus_getcustomlinestyle(PyObject* /* self */, PyObject* args)
@@ -96,7 +115,7 @@ PyObject *scribus_getcustomlinestyle(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyString_FromString(item->customLineStyle().toUtf8());
+	return PyUnicode_FromString(item->customLineStyle().toUtf8());
 }
 
 PyObject *scribus_getlinecolor(PyObject* /* self */, PyObject* args)
@@ -109,10 +128,10 @@ PyObject *scribus_getlinecolor(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyString_FromString(item->lineColor().toUtf8());
+	return PyUnicode_FromString(item->lineColor().toUtf8());
 }
 
-PyObject *scribus_getlinetrans(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getlinetransparency(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -125,7 +144,7 @@ PyObject *scribus_getlinetrans(PyObject* /* self */, PyObject* args)
 	return PyFloat_FromDouble(static_cast<double>(1.0 - item->lineTransparency()));
 }
 
-PyObject *scribus_getlineblend(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getlineblendmode(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -135,7 +154,7 @@ PyObject *scribus_getlineblend(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(item->lineBlendmode()));
+	return PyLong_FromLong(static_cast<long>(item->lineBlendmode()));
 }
 
 PyObject *scribus_getlinewidth(PyObject* /* self */, PyObject* args)
@@ -161,7 +180,7 @@ PyObject *scribus_getlineshade(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(item->lineShade()));
+	return PyLong_FromLong(static_cast<long>(item->lineShade()));
 }
 
 PyObject *scribus_getlinejoin(PyObject* /* self */, PyObject* args)
@@ -174,7 +193,7 @@ PyObject *scribus_getlinejoin(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(item->PLineJoin));
+	return PyLong_FromLong(static_cast<long>(item->PLineJoin));
 }
 
 PyObject *scribus_getlinecap(PyObject* /* self */, PyObject* args)
@@ -187,7 +206,7 @@ PyObject *scribus_getlinecap(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(item->PLineEnd));
+	return PyLong_FromLong(static_cast<long>(item->PLineEnd));
 }
 
 PyObject *scribus_getlinestyle(PyObject* /* self */, PyObject* args)
@@ -200,7 +219,7 @@ PyObject *scribus_getlinestyle(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(item->PLineArt));
+	return PyLong_FromLong(static_cast<long>(item->PLineArt));
 }
 
 PyObject *scribus_getfillshade(PyObject* /* self */, PyObject* args)
@@ -213,10 +232,10 @@ PyObject *scribus_getfillshade(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(item->fillShade()));
+	return PyLong_FromLong(static_cast<long>(item->fillShade()));
 }
 
-PyObject *scribus_getcornerrad(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getcornerradius(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -226,10 +245,10 @@ PyObject *scribus_getcornerrad(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(item->cornerRadius()));
+	return PyLong_FromLong(static_cast<long>(item->cornerRadius()));
 }
 
-PyObject *scribus_getimgoffset(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getimageoffset(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -242,7 +261,7 @@ PyObject *scribus_getimgoffset(PyObject* /* self */, PyObject* args)
 	return Py_BuildValue("(ff)", item->imageXOffset() * item->imageXScale(), item->imageYOffset() * item->imageYScale());
 }
 
-PyObject *scribus_getimgscale(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getimagescale(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -265,10 +284,10 @@ PyObject *scribus_getimagefile(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	return PyString_FromString(item->Pfile.toUtf8());
+	return PyUnicode_FromString(item->Pfile.toUtf8());
 }
 
-PyObject *scribus_getposi(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getposition(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -308,68 +327,66 @@ PyObject *scribus_getrotation(PyObject* /* self */, PyObject* args)
 	return PyFloat_FromDouble(static_cast<double>(item->rotation() * -1));
 }
 
-PyObject *scribus_getallobj(PyObject* /* self */, PyObject* args, PyObject *keywds)
+PyObject *scribus_getallobjects(PyObject* /* self */, PyObject* args, PyObject *keywds)
 {
-	PyObject *l;
-	int typ = -1;
+	int itemType = -1;
+	int layerId = -1;
 	uint counter = 0;
-	uint counter2 = 0;
+
+	if (!checkHaveDocument())
+		return nullptr;
 
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	int pageNr = currentDoc->currentPageNumber();
-	char *kwlist[] = {const_cast<char*>(""), const_cast<char*>("page"), nullptr};
+	char *kwlist[] = { const_cast<char*>("type"), const_cast<char*>("page"), const_cast<char*>("layer"), nullptr};
+	char* szLayerName = const_cast<char*>("");
 
-	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|ii", kwlist, &typ, &pageNr))
+	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|iies", kwlist, &itemType, &pageNr, "utf-8", &szLayerName))
 		return nullptr;
 
 	int numPages = currentDoc->Pages->count();
-	if (pageNr < 0 || pageNr >= numPages) {
-		PyErr_SetString(PyExc_RuntimeError, QObject::tr("page number is invalid.","python error").toLocal8Bit().constData());
-		return nullptr;
-	}
-	//if (!PyArg_ParseTuple(args, "|i", &typ))
-	//	return nullptr;
-	if (!checkHaveDocument())
-		return nullptr;
-	// have doc already
-	if (typ != -1)
+	if (pageNr < 0 || pageNr >= numPages)
 	{
-		for (int lam2 = 0; lam2 < currentDoc->Items->count(); ++lam2)
-		{
-			if ((currentDoc->Items->at(lam2)->itemType() == typ) && (pageNr == currentDoc->Items->at(lam2)->OwnPage))
-				counter++;
-		}
-	}
-	else
-	{
-		for (int lam2 = 0; lam2 < currentDoc->Items->count(); ++lam2)
-		{
-			if (pageNr == currentDoc->Items->at(lam2)->OwnPage)
-				counter++;
-		}
+		PyErr_SetString(PyExc_ValueError, QObject::tr("page number is invalid.", "python error").toLocal8Bit().constData());
+		return nullptr;
 	}
 
-	l = PyList_New(counter);
-	for (int lam=0; lam < currentDoc->Items->count(); ++lam)
+	const ScLayer *layer = nullptr;
+	QString layerName = QString::fromUtf8(szLayerName);
+	if (!layerName.isEmpty())
 	{
-		if  (pageNr == currentDoc->Items->at(lam)->OwnPage)
+		const ScLayer *layer = currentDoc->Layers.layerByName(layerName);
+		if (!layer)
 		{
-			if (typ != -1)
-			{
-				if (currentDoc->Items->at(lam)->itemType() == typ)
-				{
-					PyList_SetItem(l, counter2, PyString_FromString(currentDoc->Items->at(lam)->itemName().toUtf8()));
-					counter2++;
-				}
-			}
-			else
-			{
-				PyList_SetItem(l, counter2, PyString_FromString(currentDoc->Items->at(lam)->itemName().toUtf8()));
-				counter2++;
-			}
+			PyErr_SetString(PyExc_ValueError, QObject::tr("layer name is invalid.", "python error").toLocal8Bit().constData());
+			return nullptr;
 		}
+		layerId = layer->ID;
 	}
-	return l;
+
+	auto isReturnedItem = [pageNr, layerId, itemType](PageItem* item)
+	{
+		if  (pageNr != item->OwnPage)
+			return false;
+		if ((itemType != -1) && (item->itemType() != itemType))
+			return false;
+		if ((layerId != -1) && (item->m_layerID) != layerId)
+			return false;
+		return true;
+	};
+
+	int returnedItemCount = std::count_if(currentDoc->DocItems.begin(), currentDoc->DocItems.end(), isReturnedItem);
+
+	PyObject* pyItemList = PyList_New(returnedItemCount);
+	for (int i = 0; i < currentDoc->Items->count(); ++i)
+	{
+		PageItem* item = currentDoc->Items->at(i);
+		if (!isReturnedItem(item))
+			continue;
+		PyList_SetItem(pyItemList, counter, PyUnicode_FromString(item->itemName().toUtf8()));
+		counter++;
+	}
+	return pyItemList;
 }
 
 PyObject *scribus_getobjectattributes(PyObject* /* self */, PyObject* args)
@@ -431,7 +448,7 @@ PyObject *scribus_getimagecolorspace(PyObject* /* self */, PyObject* args)
 
 	const ScImage& pixm = item->pixm;
 	if (pixm.width() == 0 || pixm.height() == 0)
-		return PyInt_FromLong(static_cast<long>(-1));
+		return PyLong_FromLong(static_cast<long>(-1));
 
 	const ImageInfoRecord& iir = pixm.imgInfo;
 	int cspace = iir.colorspace;
@@ -442,7 +459,7 @@ PyObject *scribus_getimagecolorspace(PyObject* /* self */, PyObject* args)
 	Duotone = 3,
 	Monochrome = 4
 	*/
-	return PyInt_FromLong(static_cast<long>(cspace));
+	return PyLong_FromLong(static_cast<long>(cspace));
 }
 
 
@@ -452,16 +469,28 @@ PV */
 void cmdgetpropdocwarnings()
 {
 	QStringList s;
-	s << scribus_getobjecttype__doc__ << scribus_getfillcolor__doc__
+	s << scribus_getallobjects__doc__
+	  << scribus_getcornerradius__doc__ 
 	  << scribus_getcustomlinestyle__doc__
-	  << scribus_getfilltrans__doc__ << scribus_getfillblend__doc__ 
-	  << scribus_getlinecolor__doc__ << scribus_getlinetrans__doc__ 
-	  << scribus_getlineblend__doc__ << scribus_getlinewidth__doc__ 
-	  << scribus_getlineshade__doc__ << scribus_getlinejoin__doc__ 
-	  << scribus_getlinecap__doc__ << scribus_getlinestyle__doc__ 
-	  << scribus_getfillshade__doc__ << scribus_getcornerrad__doc__ 
-	  << scribus_getimgscale__doc__ << scribus_getimagefile__doc__ 
-	  << scribus_getposi__doc__ << scribus_getsize__doc__ 
-	  << scribus_getrotation__doc__ <<  scribus_getallobj__doc__
-	  << scribus_getobjectattributes__doc__ << scribus_getimagecolorspace__doc__;
+	  << scribus_getfillcolor__doc__
+	  << scribus_getfillblendmode__doc__
+	  << scribus_getfillshade__doc__ 
+	  << scribus_getfilltransparency__doc__
+	  << scribus_getimagecolorspace__doc__
+	  << scribus_getimagefile__doc__
+	  << scribus_getimageoffset__doc__
+	  << scribus_getimagescale__doc__
+	  << scribus_getlinecolor__doc__ 
+	  << scribus_getlineblendmode__doc__ 
+	  << scribus_getlinecap__doc__
+	  << scribus_getlinejoin__doc__ 
+	  << scribus_getlineshade__doc__
+	  << scribus_getlinetransparency__doc__
+	  << scribus_getlinewidth__doc__
+	  << scribus_getlinestyle__doc__ 
+	  << scribus_getobjectattributes__doc__ 
+	  << scribus_getobjecttype__doc__
+	  << scribus_getposition__doc__
+	  << scribus_getrotation__doc__
+	  << scribus_getsize__doc__;
 }
