@@ -11,11 +11,8 @@ for which a new license (GPL+exception) is in place.
 #include "scribusview.h"
 #include "sctextstream.h"
 #include "selection.h"
-#include "ui/propertiespalette.h" //CB argh.. noooooooooooooooooooooooooooooooooooo FIXME see other FIXME
-#include "ui/propertiespalette_image.h"
 #include "undomanager.h"
 
-
 PyObject *scribus_loadimage(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
@@ -27,7 +24,7 @@ PyObject *scribus_loadimage(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (!item->asImageFrame())
+	if (!item->isImageFrame())
 	{
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Target is not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -47,7 +44,7 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (! item->asImageFrame())
+	if (!item->isImageFrame())
 	{
 		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -61,17 +58,17 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
-	currentView->Deselect();
+	currentView->deselectItems();
 	// Select the item, which will also select its group if
 	// there is one.
-	currentView->SelectItem(item);
+	currentView->selectItem(item);
 
 	// scale
 	currentDoc->itemSelection_SetImageScale(x, y); //CB why when this is done above?
 	currentDoc->updatePic();
 
 	// Now restore the selection.
-	currentView->Deselect();
+	currentView->deselectItems();
 	if (hadOrigSelection)
 		*currentDoc->m_Selection=tempSelection;
 
@@ -89,7 +86,7 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (!item->asImageFrame())
+	if (!item->isImageFrame())
 	{
 		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -103,10 +100,10 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
-	currentView->Deselect();
+	currentView->deselectItems();
 	// Select the item, which will also select its group if
 	// there is one.
-	currentView->SelectItem(item);
+	currentView->selectItem(item);
 
 	// scale
 	double newScaleX = x / item->pixm.imgInfo.xres * 72.0;
@@ -115,7 +112,7 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 	currentDoc->updatePic();
 
 	// Now restore the selection.
-	currentView->Deselect();
+	currentView->deselectItems();
 	if (hadOrigSelection)
 		*currentDoc->m_Selection=tempSelection;
 
@@ -132,7 +129,7 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (!item->asImageFrame())
+	if (!item->isImageFrame())
 	{
 		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -146,10 +143,10 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
-	currentView->Deselect();
+	currentView->deselectItems();
 	// Select the item, which will also select its group if
 	// there is one.
-	currentView->SelectItem(item);
+	currentView->selectItem(item);
 
 	// offset
 	double newOffsetX = x / ((item->imageXScale() != 0.0) ? item->imageXScale() : 1);
@@ -158,7 +155,7 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 	currentDoc->updatePic();
 
 	// Now restore the selection.
-	currentView->Deselect();
+	currentView->deselectItems();
 	if (hadOrigSelection)
 		*currentDoc->m_Selection=tempSelection;
 
@@ -176,14 +173,14 @@ PyObject *scribus_setimagebrightness(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (! item->asImageFrame())
+	if (!item->isImageFrame())
 	{
 		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
 	ImageEffect ef;
-	ef.effectCode = ScImage::EF_BRIGHTNESS;
+	ef.effectCode = ImageEffect::EF_BRIGHTNESS;
 	ScTextStream fp(&ef.effectParameters, QIODevice::WriteOnly);
 	fp << n;
 
@@ -204,14 +201,14 @@ PyObject *scribus_setimagegrayscale(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (! item->asImageFrame())
+	if (!item->isImageFrame())
 	{
 		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
 	ImageEffect ef;
-	ef.effectCode = ScImage::EF_GRAYSCALE;
+	ef.effectCode = ImageEffect::EF_GRAYSCALE;
 
 	item->effectsInUse.append(ef);
 	item->pixm.applyEffect(item->effectsInUse, ScCore->primaryMainWindow()->doc->PageColors, false);
@@ -220,7 +217,7 @@ PyObject *scribus_setimagegrayscale(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_moveobjrel(PyObject* /* self */, PyObject* args)
+PyObject *scribus_moveobjectrel(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x, y;
@@ -240,10 +237,10 @@ PyObject *scribus_moveobjrel(PyObject* /* self */, PyObject* args)
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
-	currentView->Deselect();
+	currentView->deselectItems();
 	// Select the item, which will also select its group if
 	// there is one.
-	currentView->SelectItem(item);
+	currentView->selectItem(item);
 	// Move the item, or items
 	if (currentDoc->m_Selection->count() > 1)
 	{
@@ -255,13 +252,13 @@ PyObject *scribus_moveobjrel(PyObject* /* self */, PyObject* args)
 		currentDoc->moveItem(ValueToPoint(x), ValueToPoint(y), item);
 		}
 	// Now restore the selection.
-	currentView->Deselect();
+	currentView->deselectItems();
 	if (hadOrigSelection)
 		*currentDoc->m_Selection=tempSelection;
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_moveobjabs(PyObject* /* self */, PyObject* args)
+PyObject *scribus_moveobjectabs(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x, y;
@@ -280,10 +277,10 @@ PyObject *scribus_moveobjabs(PyObject* /* self */, PyObject* args)
 	bool hadOrigSelection = (tempSelection.count() != 0);
 
 	// Clear the selection
-	currentView->Deselect();
+	currentView->deselectItems();
 	// Select the item, which will also select its group if
 	// there is one.
-	currentView->SelectItem(item);
+	currentView->selectItem(item);
 	// Move the item, or items
 	if (currentDoc->m_Selection->count() > 1)
 	{
@@ -296,14 +293,14 @@ PyObject *scribus_moveobjabs(PyObject* /* self */, PyObject* args)
 	else
 		currentDoc->moveItem(pageUnitXToDocX(x) - item->xPos(), pageUnitYToDocY(y) - item->yPos(), item);
 	// Now restore the selection.
-	currentView->Deselect();
+	currentView->deselectItems();
 	if (hadOrigSelection)
 		*currentDoc->m_Selection=tempSelection;
 
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_rotobjrel(PyObject* /* self */, PyObject* args)
+PyObject *scribus_rotateobjectrel(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x;
@@ -318,7 +315,7 @@ PyObject *scribus_rotobjrel(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_rotobjabs(PyObject* /* self */, PyObject* args)
+PyObject *scribus_rotateobjectabs(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x;
@@ -333,7 +330,7 @@ PyObject *scribus_rotobjabs(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_sizeobjabs(PyObject* /* self */, PyObject* args)
+PyObject *scribus_sizeobject(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x, y;
@@ -348,9 +345,9 @@ PyObject *scribus_sizeobjabs(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_groupobj(PyObject* /* self */, PyObject* args)
+PyObject *scribus_groupobjects(PyObject* /* self */, PyObject* args)
 {
-	char *Name = const_cast<char*>("");
+	const char *Name = const_cast<char*>("");
 	PyObject *il = nullptr;
 	if (!PyArg_ParseTuple(args, "|O", &il))
 		return nullptr;
@@ -361,8 +358,8 @@ PyObject *scribus_groupobj(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(PyExc_TypeError, QObject::tr("Need selection or argument list of items to group", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	Selection *tempSelection=nullptr;
-	Selection *finalSelection=nullptr;
+	Selection *tempSelection = nullptr;
+	Selection *finalSelection = nullptr;
 	//uint ap = ScCore->primaryMainWindow()->doc->currentPage()->pageNr();
 	// If we were passed a list of items to group...
 	if (il != nullptr)
@@ -374,7 +371,7 @@ PyObject *scribus_groupobj(PyObject* /* self */, PyObject* args)
 			// FIXME: We might need to explicitly get this string as utf8
 			// but as sysdefaultencoding is utf8 it should be a no-op to do
 			// so anyway.
-			Name = PyString_AsString(PyList_GetItem(il, i));
+			Name = PyUnicode_AsUTF8(PyList_GetItem(il, i));
 			PageItem *ic = GetUniqueItem(QString::fromUtf8(Name));
 			if (ic == nullptr)
 			{
@@ -383,10 +380,10 @@ PyObject *scribus_groupobj(PyObject* /* self */, PyObject* args)
 			}
 			tempSelection->addItem (ic, true);
 		}
-		finalSelection=tempSelection;
+		finalSelection = tempSelection;
 	}
 	else
-		finalSelection=ScCore->primaryMainWindow()->doc->m_Selection;
+		finalSelection = ScCore->primaryMainWindow()->doc->m_Selection;
 	if (finalSelection->count() < 2)
 	{
 		// We can't very well group only one item
@@ -400,10 +397,10 @@ PyObject *scribus_groupobj(PyObject* /* self */, PyObject* args)
 	finalSelection=nullptr;
 	delete tempSelection;
 	
-	return (group ? PyString_FromString(group->itemName().toUtf8()) : nullptr);
+	return (group ? PyUnicode_FromString(group->itemName().toUtf8()) : nullptr);
 }
 
-PyObject *scribus_ungroupobj(PyObject* /* self */, PyObject* args)
+PyObject *scribus_ungroupobjects(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -415,8 +412,8 @@ PyObject *scribus_ungroupobj(PyObject* /* self */, PyObject* args)
 		return nullptr;
 
 	ScribusMainWindow* currentWin = ScCore->primaryMainWindow();
-	currentWin->view->Deselect();
-	currentWin->view->SelectItem(i);
+	currentWin->view->deselectItems();
+	currentWin->view->selectItem(i);
 	currentWin->UnGroupObj();
 
 	Py_RETURN_NONE;
@@ -442,8 +439,8 @@ PyObject *scribus_scalegroup(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 
-	currentView->Deselect();
-	currentView->SelectItem(i);
+	currentView->deselectItems();
+	currentView->selectItem(i);
 //	int h = currentView->frameResizeHandle;
 //	currentView->frameResizeHandle = 1;
 	currentView->startGroupTransaction(Um::Resize, "", Um::IResize);
@@ -453,27 +450,28 @@ PyObject *scribus_scalegroup(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_getselobjnam(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getselectedobject(PyObject* /* self */, PyObject* args)
 {
 	int i = 0;
 	if (!PyArg_ParseTuple(args, "|i", &i))
 		return nullptr;
 	if (!checkHaveDocument())
 		return nullptr;
-	if ((i < static_cast<int>(ScCore->primaryMainWindow()->doc->m_Selection->count())) && (i > -1))
-		return PyString_FromString(ScCore->primaryMainWindow()->doc->m_Selection->itemAt(i)->itemName().toUtf8());
+	Selection * selection = ScCore->primaryMainWindow()->doc->m_Selection;
+	if ((i < selection->count()) && (i > -1))
+		return PyUnicode_FromString(selection->itemAt(i)->itemName().toUtf8());
 	// FIXME: Should probably return None if no selection?
-	return PyString_FromString("");
+	return PyUnicode_FromString("");
 }
 
-PyObject *scribus_selcount(PyObject* /* self */)
+PyObject *scribus_selectioncount(PyObject* /* self */)
 {
 	if (!checkHaveDocument())
 		return nullptr;
-	return PyInt_FromLong(static_cast<long>(ScCore->primaryMainWindow()->doc->m_Selection->count()));
+	return PyLong_FromLong(static_cast<long>(ScCore->primaryMainWindow()->doc->m_Selection->count()));
 }
 
-PyObject *scribus_selectobj(PyObject* /* self */, PyObject* args)
+PyObject *scribus_selectobject(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "es", "utf-8", &Name))
@@ -483,15 +481,15 @@ PyObject *scribus_selectobj(PyObject* /* self */, PyObject* args)
 	PageItem *i = GetUniqueItem(QString::fromUtf8(Name));
 	if (i == nullptr)
 		return nullptr;
-	ScCore->primaryMainWindow()->view->SelectItem(i);
+	ScCore->primaryMainWindow()->view->selectItem(i);
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_deselect(PyObject* /* self */)
+PyObject *scribus_deselectall(PyObject* /* self */)
 {
 	if (!checkHaveDocument())
 		return nullptr;
-	ScCore->primaryMainWindow()->view->Deselect();
+	ScCore->primaryMainWindow()->view->deselectItems();
 	Py_RETURN_NONE;
 }
 
@@ -505,10 +503,12 @@ PyObject *scribus_lockobject(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
 	if (item == nullptr)
 		return nullptr;
+	// FIXME: Rather than toggling the lock, we should probably let the user set the lock state
+	// and instead provide a different function like toggleLock()
 	item->toggleLock();
 	if (item->locked())
-		return PyInt_FromLong(1);
-	return PyInt_FromLong(0);
+		return PyLong_FromLong(1);
+	return PyLong_FromLong(0);
 }
 
 PyObject *scribus_islocked(PyObject* /* self */, PyObject* args)
@@ -516,8 +516,6 @@ PyObject *scribus_islocked(PyObject* /* self */, PyObject* args)
 	char *name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
 		return nullptr;
-	// FIXME: Rather than toggling the lock, we should probably let the user set the lock state
-	// and instead provide a different function like toggleLock()
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
@@ -538,7 +536,7 @@ PyObject *scribus_setscaleframetoimage(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (!item->asImageFrame())
+	if (!item->isImageFrame())
 	{
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -565,7 +563,7 @@ PyObject *scribus_setscaleimagetoframe(PyObject* /* self */, PyObject* args, PyO
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
 	if (item == nullptr)
 		return nullptr;
-	if (! item->asImageFrame())
+	if (!item->isImageFrame())
 	{
 		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -603,10 +601,10 @@ PyObject *scribus_flipobject(PyObject* /* self */, PyObject* args)
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
-	currentView->Deselect();
+	currentView->deselectItems();
 	// Select the item, which will also select its group if
 	// there is one.
-	currentView->SelectItem(item);
+	currentView->selectItem(item);
 
 	// flip
 	if (h == 1)
@@ -614,7 +612,7 @@ PyObject *scribus_flipobject(PyObject* /* self */, PyObject* args)
 	if (v == 1)
 		currentDoc->itemSelection_FlipV();
 	// Now restore the selection.
-	currentView->Deselect();
+	currentView->deselectItems();
 	if (hadOrigSelection)
 		*currentDoc->m_Selection = tempSelection;
 
@@ -635,7 +633,7 @@ PyObject *scribus_combinepolygons(PyObject * /* self */)
 	for (int i = 0; i < curSelection->count(); ++i)
 	{
 		PageItem* it = currentDoc->m_Selection->itemAt(i);
-		if ((!it->asPolygon()) || (!it->asPolyLine()))
+		if ((!it->isPolygon()) || (!it->isPolyLine()))
 			canUniteItems = false;
 	}
 
@@ -655,15 +653,28 @@ PV */
 void cmdmanidocwarnings()
 {
 	QStringList s;
-	s << scribus_moveobjrel__doc__ << scribus_moveobjabs__doc__
-	  << scribus_rotobjrel__doc__ << scribus_rotobjabs__doc__
-	  << scribus_sizeobjabs__doc__ << scribus_getselobjnam__doc__
-	  << scribus_selcount__doc__ << scribus_selectobj__doc__
-	  << scribus_deselect__doc__ << scribus_groupobj__doc__
-	  << scribus_ungroupobj__doc__ << scribus_scalegroup__doc__
-	  << scribus_loadimage__doc__ << scribus_scaleimage__doc__
-	  << scribus_setimagescale__doc__ << scribus_lockobject__doc__
-	  << scribus_islocked__doc__ << scribus_setscaleimagetoframe__doc__ << scribus_setimagebrightness__doc__ << scribus_setimagegrayscale__doc__ << scribus_setimageoffset__doc__
+	s << scribus_combinepolygons__doc__
+	  << scribus_deselectall__doc__
+	  << scribus_flipobject__doc__
+	  << scribus_getselectedobject__doc__
+	  << scribus_groupobjects__doc__
+	  << scribus_islocked__doc__
+	  << scribus_loadimage__doc__
+	  << scribus_lockobject__doc__
+      << scribus_moveobjectabs__doc__
+	  << scribus_moveobjectrel__doc__
+	  << scribus_rotateobjectabs__doc__
+	  << scribus_rotateobjectrel__doc__
+	  << scribus_scalegroup__doc__
+	  << scribus_scaleimage__doc__
+	  << scribus_selectioncount__doc__
+	  << scribus_selectobject__doc__
+	  << scribus_setimagebrightness__doc__
+	  << scribus_setimagegrayscale__doc__
+	  << scribus_setimageoffset__doc__
+	  << scribus_setimagescale__doc__
 	  << scribus_setscaleframetoimage__doc__
-	  << scribus_flipobject__doc__;
+	  << scribus_setscaleimagetoframe__doc__
+	  << scribus_sizeobject__doc__ 
+	  << scribus_ungroupobjects__doc__;
 }
