@@ -17,7 +17,7 @@ for which a new license (GPL+exception) is in place.
 #include "util_math.h"
 
 
-PyObject *scribus_newrect(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createrect(PyObject* /* self */, PyObject* args)
 {
 	double x, y, w, h;
 	char *Name = const_cast<char*>("");
@@ -31,23 +31,24 @@ PyObject *scribus_newrect(PyObject* /* self */, PyObject* args)
 //		PyErr_SetString(NameExistsError, QObject::tr("An object with the requested name already exists.","python error"));
 //		return nullptr;
 //	}
-	int i = ScCore->primaryMainWindow()->doc->itemAdd(PageItem::Polygon, PageItem::Rectangle,
-								pageUnitXToDocX(x), pageUnitYToDocY(y),
-								ValueToPoint(w), ValueToPoint(h),
-								ScCore->primaryMainWindow()->doc->itemToolPrefs().shapeLineWidth,
-								ScCore->primaryMainWindow()->doc->itemToolPrefs().shapeFillColor, ScCore->primaryMainWindow()->doc->itemToolPrefs().shapeLineColor);
+	ScribusDoc* doc = ScCore->primaryMainWindow()->doc;
+	int i = doc->itemAdd(PageItem::Polygon, PageItem::Rectangle,
+						pageUnitXToDocX(x), pageUnitYToDocY(y),
+						ValueToPoint(w), ValueToPoint(h),
+						doc->itemToolPrefs().shapeLineWidth,
+						doc->itemToolPrefs().shapeFillColor, doc->itemToolPrefs().shapeLineColor);
 //	ScCore->primaryMainWindow()->doc->setRedrawBounding(ScCore->primaryMainWindow()->doc->Items->at(i));
 	if (strlen(Name) > 0)
 	{
 		QString objName = QString::fromUtf8(Name);
 		if (!ItemExists(objName))
-			ScCore->primaryMainWindow()->doc->Items->at(i)->setItemName(objName);
+			doc->Items->at(i)->setItemName(objName);
 	}
-	return PyString_FromString(ScCore->primaryMainWindow()->doc->Items->at(i)->itemName().toUtf8());
+	return PyUnicode_FromString(doc->Items->at(i)->itemName().toUtf8());
 }
 
 
-PyObject *scribus_newellipse(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createellipse(PyObject* /* self */, PyObject* args)
 {
 	double x, y, w, h;
 	char *Name = const_cast<char*>("");
@@ -69,11 +70,11 @@ PyObject *scribus_newellipse(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			ScCore->primaryMainWindow()->doc->Items->at(i)->setItemName(objName);
 	}
-	return PyString_FromString(ScCore->primaryMainWindow()->doc->Items->at(i)->itemName().toUtf8());
+	return PyUnicode_FromString(ScCore->primaryMainWindow()->doc->Items->at(i)->itemName().toUtf8());
 }
 
 
-PyObject *scribus_newimage(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createimage(PyObject* /* self */, PyObject* args)
 {
 	double x, y, w, h;
 	char *Name = const_cast<char*>("");
@@ -94,11 +95,11 @@ PyObject *scribus_newimage(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			ScCore->primaryMainWindow()->doc->Items->at(i)->setItemName(objName);
 	}
-	return PyString_FromString(ScCore->primaryMainWindow()->doc->Items->at(i)->itemName().toUtf8());
+	return PyUnicode_FromString(ScCore->primaryMainWindow()->doc->Items->at(i)->itemName().toUtf8());
 }
 
 
-PyObject *scribus_newtext(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createtext(PyObject* /* self */, PyObject* args)
 {
 	double x, y, w, h;
 	char *Name = const_cast<char*>("");
@@ -119,10 +120,10 @@ PyObject *scribus_newtext(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			ScCore->primaryMainWindow()->doc->Items->at(i)->setItemName(objName);
 	}
-	return PyString_FromString(ScCore->primaryMainWindow()->doc->Items->at(i)->itemName().toUtf8());
+	return PyUnicode_FromString(ScCore->primaryMainWindow()->doc->Items->at(i)->itemName().toUtf8());
 }
 
-PyObject *scribus_newtable(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createtable(PyObject* /* self */, PyObject* args)
 {
 	double x, y, w, h;
 	int numRows, numColumns;
@@ -155,10 +156,10 @@ PyObject *scribus_newtable(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			ScCore->primaryMainWindow()->doc->Items->at(i)->setItemName(objName);
 	}
-	return PyString_FromString(table->itemName().toUtf8());
+	return PyUnicode_FromString(table->itemName().toUtf8());
 }
 
-PyObject *scribus_newline(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createline(PyObject* /* self */, PyObject* args)
 {
 	double x, y, w, h;
 	char *Name = const_cast<char*>("");
@@ -215,11 +216,11 @@ PyObject *scribus_newline(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			ScCore->primaryMainWindow()->doc->Items->at(i)->setItemName(objName);
 	}
-	return PyString_FromString(it->itemName().toUtf8());
+	return PyUnicode_FromString(it->itemName().toUtf8());
 }
 
 
-PyObject *scribus_polyline(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createpolyline(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	PyObject *il;
@@ -292,11 +293,11 @@ PyObject *scribus_polyline(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			ScCore->primaryMainWindow()->doc->Items->at(ic)->setItemName(objName);
 	}
-	return PyString_FromString(it->itemName().toUtf8());
+	return PyUnicode_FromString(it->itemName().toUtf8());
 }
 
 
-PyObject *scribus_polygon(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createpolygon(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	PyObject *il;
@@ -374,10 +375,10 @@ PyObject *scribus_polygon(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			ScCore->primaryMainWindow()->doc->Items->at(ic)->setItemName(objName);
 	}
-	return PyString_FromString(it->itemName().toUtf8());
+	return PyUnicode_FromString(it->itemName().toUtf8());
 }
 
-PyObject *scribus_bezierline(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createbezierline(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	PyObject *il;
@@ -465,13 +466,13 @@ PyObject *scribus_bezierline(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			ScCore->primaryMainWindow()->doc->Items->at(ic)->setItemName(objName);
 	}
-	return PyString_FromString(it->itemName().toUtf8());
+	return PyUnicode_FromString(it->itemName().toUtf8());
 }
 
 
 /* 03/31/2004 - xception handling
  */
-PyObject *scribus_pathtext(PyObject* /* self */, PyObject* args)
+PyObject *scribus_createpathtext(PyObject* /* self */, PyObject* args)
 {
 	double x, y;
 	char *Name = const_cast<char*>("");
@@ -506,13 +507,13 @@ PyObject *scribus_pathtext(PyObject* /* self */, PyObject* args)
 		if (!ItemExists(objName))
 			i->setItemName(objName);
 	}
-	return PyString_FromString(i->itemName().toUtf8());
+	return PyUnicode_FromString(i->itemName().toUtf8());
 }
 
 
 /* 03/21/2004 - exception raised when Name doesn't exists. Doesn't crash then. (subik)
  */
-PyObject *scribus_deleteobj(PyObject* /* self */, PyObject* args)
+PyObject *scribus_deleteobject(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -529,10 +530,23 @@ PyObject *scribus_deleteobj(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
+PyObject *scribus_gettextflowmode(PyObject* /* self */, PyObject* args)
+{
+	char *name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
+		return NULL;
+	if (!checkHaveDocument())
+		return NULL;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
+	if (item == NULL)
+		return NULL;
+
+	return PyLong_FromLong(static_cast<int>(item->textFlowMode()));
+};
 
 /* 03/21/2004 - exception raises by non existent name (subik)
  */
-PyObject *scribus_textflow(PyObject* /* self */, PyObject* args)
+PyObject *scribus_settextflowmode(PyObject* /* self */, PyObject* args)
 {
 	char *name = const_cast<char*>("");
 	int state = -1;
@@ -578,12 +592,47 @@ PyObject *scribus_objectexists(PyObject* /* self */, PyObject* args)
 	return PyBool_FromLong(static_cast<long>(false));
 }
 
+PyObject *scribus_getcharacterstyle(PyObject* /* self */, PyObject* args)
+{
+	char *name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
+		return NULL;
+	if (!checkHaveDocument())
+		return NULL;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
+	if (item == NULL)
+		return NULL;
+	if ((item->itemType() != PageItem::TextFrame) && (item->itemType() != PageItem::PathText))
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get character style of a non-text frame.", "python error").toLocal8Bit().constData());
+		return NULL;
+	}
+
+	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
+	StoryText&  itemText = item->itemText;
+
+	int selectionLength = itemText.selectionLength();	
+	if ((selectionLength > 0) || (currentDoc->appMode == modeEdit))
+	{
+		int cursorPos = (selectionLength > 0) ? itemText.startOfSelection() : itemText.cursorPosition();
+		const CharStyle& currentStyle = itemText.charStyle(cursorPos);
+		if (currentStyle.hasParent())
+			return PyUnicode_FromString(currentStyle.parentStyle()->name().toUtf8());
+	}
+	else
+	{
+		const CharStyle& itemDefaultStyle = itemText.defaultStyle().charStyle();
+		if (itemDefaultStyle.hasParent())
+			return PyUnicode_FromString(itemDefaultStyle.parentStyle()->name().toUtf8());
+	}
+	Py_RETURN_NONE;
+};
 
 /*
  * Vaclav Smilauer, 2017-21-21
  * Return style name of the object (or currently selected object)
  */
-PyObject *scribus_getstyle(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getparagraphstyle(PyObject* /* self */, PyObject* args)
 {
 	char *name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
@@ -599,19 +648,22 @@ PyObject *scribus_getstyle(PyObject* /* self */, PyObject* args)
 		return NULL;
 	}
 
-	int selectionLength = item->itemText.selectionLength();	
-	if (selectionLength > 0)
+	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
+	StoryText&  itemText = item->itemText;
+
+	int selectionLength = itemText.selectionLength();	
+	if ((selectionLength > 0) || (currentDoc->appMode == modeEdit))
 	{
-		int selectionStart = item->itemText.startOfSelection();
-		const ParagraphStyle& currentStyle = item->itemText.paragraphStyle(selectionStart);
+		int cursorPos = (selectionLength > 0) ? itemText.startOfSelection() : itemText.cursorPosition();
+		const ParagraphStyle& currentStyle = itemText.paragraphStyle(cursorPos);
 		if (currentStyle.hasParent())
-			return PyString_FromString(currentStyle.parentStyle()->name().toUtf8());
+			return PyUnicode_FromString(currentStyle.parentStyle()->name().toUtf8());
 	}
 	else
 	{
 		const ParagraphStyle& itemDefaultStyle = item->itemText.defaultStyle();
 		if (itemDefaultStyle.hasParent())
-			return PyString_FromString(itemDefaultStyle.parentStyle()->name().toUtf8());
+			return PyUnicode_FromString(itemDefaultStyle.parentStyle()->name().toUtf8());
 	}
 	Py_RETURN_NONE;
 };
@@ -623,7 +675,7 @@ PyObject *scribus_getstyle(PyObject* /* self */, PyObject* args)
  * Apply the named style to the currently selected object.
  * pv, 2004-09-13, optionaly param objectName + "check the page" stuff
  */
-PyObject *scribus_setstyle(PyObject* /* self */, PyObject* args)
+PyObject *scribus_setparagraphstyle(PyObject* /* self */, PyObject* args)
 {
 	char *style = const_cast<char*>("");
 	char *name = const_cast<char*>("");
@@ -639,65 +691,58 @@ PyObject *scribus_setstyle(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set style on a non-text frame.", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-
-	// First, find the style number associated with the requested style
-	// by scanning through the styles looking for the name. If
-	// we can't find it, raise PyExc_Exception.
-	// FIXME: Should use a more specific exception.
-	bool found = false;
-	QString paraStyleName = QString::fromUtf8(style);
-	// We start at zero here because it's OK to match an internal name
+	
 	ScribusDoc*  currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	ScribusMainWindow* currentWin = ScCore->primaryMainWindow();
-	const StyleSet<ParagraphStyle> &docParagraphStyles = currentDoc->paragraphStyles();
-	int docParagraphStylesCount = docParagraphStyles.count();
-	for (int i=0; i < docParagraphStylesCount; ++i)
+
+	// First, check if style name provided by user is available in document
+	QString paraStyleName = QString::fromUtf8(style);
+	if (!currentDoc->paragraphStyles().contains(paraStyleName))
 	{
-		if (docParagraphStyles[i].name() == paraStyleName) {
-			found = true;
-			break;
-		}
-	}
-	if (!found) {
 		// whoops, the user specified an invalid style, complain loudly.
+		// FIXME: Should use a more specific exception.
 		PyErr_SetString(NotFoundError, QObject::tr("Style not found.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	// for current item only
-	if (currentDoc->m_Selection->count() == 0 || (strlen(name) > 0))
+
+	// For multiple selections or if current item has no text selected, we apply style in normal mode
+	if (currentDoc->m_Selection->isMultipleSelection() || (item->itemText.selectionLength() <= 0))
 	{
-		// Store text selection as clearing object selection
-		// will also clear text selection
-		int selectionStart = -1;
-		int selectionLength = item->itemText.selectionLength();
-		if (selectionLength > 0)
-			selectionStart = item->itemText.startOfSelection();
-		// quick hack to always apply on the right frame - pv
-		currentView->Deselect(true);
-		//CB I dont think we need to draw here. Its faster if we dont.
-		currentView->SelectItem(item, false);
-		// Restore text selection if necessary
-		if (selectionStart >= 0)
+		if (currentDoc->m_Selection->count() <= 1)
 		{
-			item->itemText.deselectAll();
-			item->itemText.select(selectionStart, selectionLength);
-			item->HasSel = true;
+			currentView->deselectItems(true);
+			currentView->selectItem(item, false);
 		}
-		// Now apply the style.
-		int mode = currentDoc->appMode;
-		currentDoc->appMode = modeEdit;
-		currentWin->setNewParStyle(paraStyleName);
-		currentDoc->appMode = mode;
-	}
-	else // for multiple selection
-	{
 		int mode = currentDoc->appMode;
 		currentDoc->appMode = modeNormal;
 		currentDoc->itemSelection_SetNamedParagraphStyle(paraStyleName);
 		currentDoc->appMode = mode;
+		Py_RETURN_NONE;
 	}
 
+	// For single items which have a text selection, we apply style in edit mode
+	// Store text selection as clearing object selection
+	// will also clear text selection
+	int selectionStart =  item->itemText.startOfSelection();
+	int selectionLength = item->itemText.selectionLength();
+	// Quick hack to always apply on the right frame - pv
+	currentView->deselectItems(true);
+	//CB I dont think we need to draw here. Its faster if we dont.
+	currentView->selectItem(item, false);
+	// Restore text selection if necessary
+	if (selectionStart >= 0)
+	{
+		item->itemText.deselectAll();
+		item->itemText.select(selectionStart, selectionLength);
+		item->HasSel = true;
+	}
+	// Now apply the style.
+	int mode = currentDoc->appMode;
+	currentDoc->appMode = modeEdit;
+	currentWin->setNewParStyle(paraStyleName);
+	currentDoc->appMode = mode;
+
 	Py_RETURN_NONE;
 }
 
@@ -722,110 +767,62 @@ PyObject *scribus_setcharstyle(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set character style on a non-text frame.", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-
-	// First, find the style number associated with the requested style
-	// by scanning through the styles looking for the name. If
-	// we can't find it, raise PyExc_Exception.
-	// FIXME: Should use a more specific exception.
-	bool found = false;
-	QString charStyleName = QString::fromUtf8(style);
-	// We start at zero here because it's OK to match an internal name
+	
 	ScribusDoc*  currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	ScribusMainWindow* currentWin = ScCore->primaryMainWindow();
-	const StyleSet<CharStyle> &docCharStyles = currentDoc->charStyles();
-	int docCharacterStylesCount = docCharStyles.count();
-	for (int i = 0; i < docCharacterStylesCount; ++i)
+
+	// First, check if style name provided by user is available in document
+	QString charStyleName = QString::fromUtf8(style);
+	if (!currentDoc->charStyles().contains(charStyleName))
 	{
-		if (docCharStyles[i].name() == charStyleName) {
-			found = true;
-			break;
-		}
-	}
-	if (!found) {
 		// whoops, the user specified an invalid style, complain loudly.
+		// FIXME: Should use a more specific exception.
 		PyErr_SetString(NotFoundError, QObject::tr("Character style not found.", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	// for current item only
-	if (currentDoc->m_Selection->count() == 0 || (strlen(name) > 0))
+
+	// For multiple selections or if current item has no text selected, we apply style in normal mode
+	if (currentDoc->m_Selection->isMultipleSelection() || (item->itemText.selectionLength() <= 0))
 	{
-		// Store text selection as clearing object selection
-		// will also clear text selection
-		int selectionStart = -1;
-		int selectionLength = item->itemText.selectionLength();
-		if (selectionLength > 0)
-			selectionStart = item->itemText.startOfSelection();
-		// quick hack to always apply on the right frame - pv
-		currentView->Deselect(true);
-		//CB I dont think we need to draw here. Its faster if we dont.
-		currentView->SelectItem(item, false);
-		// Restore text selection if necessary
-		if (selectionStart >= 0)
+		if (currentDoc->m_Selection->count() <= 1)
 		{
-			item->itemText.deselectAll();
-			item->itemText.select(selectionStart, selectionLength);
-			item->HasSel = true;
-		}	
-		// Now apply the style.
-		int mode = ScCore->primaryMainWindow()->doc->appMode;
-		currentDoc->appMode = modeEdit;
-		currentWin->setNewCharStyle(charStyleName);
-		currentDoc->appMode = mode;
-	}
-	else // for multiple selection
-	{
+			currentView->deselectItems(true);
+			currentView->selectItem(item, false);
+		}
 		int mode = currentDoc->appMode;
 		currentDoc->appMode = modeNormal;
 		currentDoc->itemSelection_SetNamedCharStyle(charStyleName);
 		currentDoc->appMode = mode;
+		Py_RETURN_NONE;
 	}
 
+	// For single items which have a text selection, we apply style in edit mode
+	// Store text selection as clearing object selection
+	// will also clear text selection
+	int selectionStart =  item->itemText.startOfSelection();
+	int selectionLength = item->itemText.selectionLength();
+
+	// Quick hack to always apply on the right frame - pv
+	currentView->deselectItems(true);
+	//CB I dont think we need to draw here. Its faster if we dont.
+	currentView->selectItem(item, false);
+	// Restore text selection if necessary
+	if (selectionStart >= 0)
+	{
+		item->itemText.deselectAll();
+		item->itemText.select(selectionStart, selectionLength);
+		item->HasSel = true;
+	}	
+	// Now apply the style.
+	int mode = ScCore->primaryMainWindow()->doc->appMode;
+	currentDoc->appMode = modeEdit;
+	currentWin->setNewCharStyle(charStyleName);
+	currentDoc->appMode = mode;
+
 	Py_RETURN_NONE;
 }
 
-/*
- * Craig Ringer, 2004-09-09
- * Enumerate all known paragraph styles
- */
-PyObject *scribus_getstylenames(PyObject* /* self */)
-{
-	PyObject *styleList;
-	if (!checkHaveDocument())
-		return nullptr;
-	const auto& paragraphStyles = ScCore->primaryMainWindow()->doc->paragraphStyles();
-
-	styleList = PyList_New(0);
-	for (int i = 0; i < paragraphStyles.count(); ++i)
-	{
-		if (PyList_Append(styleList, PyString_FromString(paragraphStyles[i].name().toUtf8())))
-		{
-			// An exception will have already been set by PyList_Append apparently.
-			return nullptr;
-		}
-	}
-	return styleList;
-}
-
-PyObject *scribus_getcharstylenames(PyObject* /* self */)
-{
-	PyObject *charStyleList;
-	if (!checkHaveDocument())
-		return nullptr;
-	const auto& charStyles = ScCore->primaryMainWindow()->doc->charStyles();
-
-	charStyleList = PyList_New(0);
-	for (int i = 0; i < charStyles.count(); ++i)
-	{
-		if (PyList_Append(charStyleList, PyString_FromString(charStyles[i].name().toUtf8())))
-		{
-			// An exception will have already been set by PyList_Append apparently.
-			return nullptr;
-		}
-	}
-	return charStyleList;
-}
-
 PyObject *scribus_duplicateobject(PyObject * /* self */, PyObject *args)
 {
 	char* name = const_cast<char*>("");
@@ -848,7 +845,92 @@ PyObject *scribus_duplicateobject(PyObject * /* self */, PyObject *args)
 	currentWin->slotEditCopy();
 	currentWin->slotEditPaste();
 
-	Py_RETURN_NONE;
+	return PyUnicode_FromString(currentDoc->m_Selection->itemAt(0)->itemName().toUtf8());
+}
+
+PyObject *scribus_duplicateobjects(PyObject * /* self */, PyObject *args)
+{
+	PyObject* pyObject = nullptr;
+	if (!PyArg_ParseTuple(args, "|O", &pyObject))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+
+	// Is there a special name given? Yes -> add this to selection
+	ScribusMainWindow* currentWin = ScCore->primaryMainWindow();
+	ScribusDoc* currentDoc = currentWin->doc;
+
+	if ((pyObject != nullptr) && !PyUnicode_Check(pyObject) && !PyList_Check(pyObject))
+	{
+		PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a string or a list of strings", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	QStringList itemNames;
+	if ((pyObject != nullptr) && PyUnicode_Check(pyObject))
+	{
+		char* name = const_cast<char*>("");
+		if (!PyArg_Parse(pyObject, "es", "utf-8", &name))
+			return nullptr;
+		QString itemName = QString::fromUtf8(name);
+		if (!itemName.isEmpty())
+			itemNames.append(itemName);
+	}
+	else if ((pyObject != nullptr) && PyList_Check(pyObject))
+	{
+		int len = PyList_Size(pyObject);
+		for (int i = 0; i < len; ++i)
+		{
+			PyObject* pyItem = PyList_GetItem(pyObject, i);
+			if (!PyUnicode_Check(pyItem))
+			{
+				PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a list of strings", "python error").toLocal8Bit().constData());
+				return nullptr;
+			}
+			const char* name = PyUnicode_AsUTF8(pyItem);
+			QString itemName = QString::fromUtf8(name);
+			if (itemName.isEmpty())
+				continue;
+			itemNames.append(itemName);
+		}
+	}
+
+	if (!itemNames.isEmpty())
+	{
+		QList<PageItem*> pageItems;
+		pageItems.reserve(itemNames.count());
+
+		currentDoc->m_Selection->delaySignalsOn();
+		currentDoc->m_Selection->clear();
+		for (int i = 0; i < itemNames.count(); ++i)
+		{
+			QString itemName = itemNames.at(i);
+			PageItem *item = GetUniqueItem(itemName);
+			if (item == nullptr)
+				return nullptr;
+			pageItems.append(item);
+		}
+		currentDoc->m_Selection->addItems(pageItems);
+		currentDoc->m_Selection->delaySignalsOff();
+	}
+
+	if (currentDoc->m_Selection->isEmpty())
+	{
+		PyObject* pyList = PyList_New(0);
+		return pyList;
+	}
+
+	// do the duplicate
+	currentWin->slotEditCopy();
+	currentWin->slotEditPaste();
+
+	PyObject* pyList = PyList_New(currentDoc->m_Selection->count());
+	for (int i = 0; i < currentDoc->m_Selection->count(); ++i)
+	{
+		PageItem* item = currentDoc->m_Selection->itemAt(i);
+		PyList_SetItem(pyList, i, PyUnicode_FromString(item->itemName().toUtf8()));
+	}
+	return pyList;
 }
 
 PyObject *scribus_copyobject(PyObject * /* self */, PyObject *args)
@@ -872,28 +954,154 @@ PyObject *scribus_copyobject(PyObject * /* self */, PyObject *args)
 	// do the copy
 	currentWin->slotEditCopy();
 
-	Py_RETURN_NONE;
+	return PyUnicode_FromString(currentDoc->m_Selection->itemAt(0)->itemName().toUtf8());
 }
 
-PyObject *scribus_pasteobject(PyObject * /* self */, PyObject *args)
+PyObject *scribus_copyobjects(PyObject * /* self */, PyObject *args)
 {
-	char* name = const_cast<char*>("");
-	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
+	PyObject* pyObject = nullptr;
+	if (!PyArg_ParseTuple(args, "|O", &pyObject))
 		return nullptr;
 	if (!checkHaveDocument())
 		return nullptr;
 
-	// do the paste
-	ScCore->primaryMainWindow()->slotEditPaste();
+	// Is there a special name given? Yes -> add this to selection
+	ScribusMainWindow* currentWin = ScCore->primaryMainWindow();
+	ScribusDoc* currentDoc = currentWin->doc;
+
+	if ((pyObject != nullptr) && !PyUnicode_Check(pyObject) && !PyList_Check(pyObject))
+	{
+		PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a string or a list of strings", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	QStringList itemNames;
+	if ((pyObject != nullptr) && PyUnicode_Check(pyObject))
+	{
+		char* name = const_cast<char*>("");
+		if (!PyArg_Parse(pyObject, "es", "utf-8", &name))
+			return nullptr;
+		QString itemName = QString::fromUtf8(name);
+		if (!itemName.isEmpty())
+			itemNames.append(itemName);
+	}
+	else if ((pyObject != nullptr) && PyList_Check(pyObject))
+	{
+		int len = PyList_Size(pyObject);
+		for (int i = 0; i < len; i++)
+		{
+			PyObject* pyItem = PyList_GetItem(pyObject, i);
+			if (!PyUnicode_Check(pyItem))
+			{
+				PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a list of strings", "python error").toLocal8Bit().constData());
+				return nullptr;
+			}
+			const char* name = PyUnicode_AsUTF8(pyItem);
+			QString itemName = QString::fromUtf8(name);
+			if (itemName.isEmpty())
+				continue;
+			itemNames.append(itemName);
+		}
+	}
+
+	if (!itemNames.isEmpty())
+	{
+		QList<PageItem*> pageItems;
+		pageItems.reserve(itemNames.count());
+
+		currentDoc->m_Selection->delaySignalsOn();
+		currentDoc->m_Selection->clear();
+		for (int i = 0; i < itemNames.count(); ++i)
+		{
+			QString itemName = itemNames.at(i);
+			PageItem *item = GetUniqueItem(itemName);
+			if (item == nullptr)
+				return nullptr;
+			pageItems.append(item);
+		}
+		currentDoc->m_Selection->addItems(pageItems);
+		currentDoc->m_Selection->delaySignalsOff();
+	}
+
+	// do the copy
+	currentWin->slotEditCopy();
 
 	Py_RETURN_NONE;
 }
 
+PyObject *scribus_pasteobject(PyObject * /* self */, PyObject * /*args*/)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	// do the paste
+	ScribusMainWindow* currentWin = ScCore->primaryMainWindow();
+	ScribusDoc* currentDoc = currentWin->doc;
+	currentWin->slotEditPaste();
+	if (!currentDoc->m_Selection->isMultipleSelection())
+		return PyUnicode_FromString(currentDoc->m_Selection->itemAt(0)->itemName().toUtf8());
+
+	QString nameList;
+	int docSelectionCount = currentDoc->m_Selection->count();
+	for (int i = 0; i < docSelectionCount; ++i)
+	{
+		nameList.append(currentDoc->m_Selection->itemAt(i)->itemName());
+		if (i < docSelectionCount - 1)
+			nameList.append(",");
+	}
+	return PyUnicode_FromString(nameList.toUtf8());
+}
+
+PyObject *scribus_pasteobjects(PyObject * /* self */, PyObject * /*args*/)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	// do the paste
+	ScribusMainWindow* currentWin = ScCore->primaryMainWindow();
+	ScribusDoc* currentDoc = currentWin->doc;
+	currentWin->slotEditPaste();
+
+	PyObject* pyList = PyList_New(currentDoc->m_Selection->count());
+	for (int i = 0; i < currentDoc->m_Selection->count(); ++i)
+	{
+		PageItem* item = currentDoc->m_Selection->itemAt(i);
+		PyList_SetItem(pyList, i, PyUnicode_FromString(item->itemName().toUtf8()));
+	}
+	return pyList;
+}
+
 /*! HACK: this removes "warning: 'blah' defined but not used" compiler warnings
 with header files structure untouched (docstrings are kept near declarations)
 PV */
 void cmdobjdocwarnings()
 {
 	QStringList s;
-	s << scribus_newrect__doc__ <<scribus_newellipse__doc__ << scribus_newimage__doc__ << scribus_newtext__doc__ << scribus_newtable__doc__ << scribus_newline__doc__ <<scribus_polyline__doc__ << scribus_polygon__doc__ << scribus_bezierline__doc__ <<scribus_pathtext__doc__ <<scribus_deleteobj__doc__ <<scribus_textflow__doc__ <<scribus_objectexists__doc__ <<scribus_getstyle__doc__ <<scribus_setstyle__doc__ <<scribus_getstylenames__doc__ <<scribus_getcharstylenames__doc__ <<scribus_duplicateobject__doc__ <<scribus_copyobject__doc__ <<scribus_pasteobject__doc__;
+	s << scribus_copyobject__doc__
+	  << scribus_copyobjects__doc__
+	  << scribus_createbezierline__doc__
+	  << scribus_createellipse__doc__
+	  << scribus_createimage__doc__
+	  << scribus_createline__doc__
+	  << scribus_createpathtext__doc__
+	  << scribus_createpolygon__doc__
+	  << scribus_createpolyline__doc__
+	  << scribus_createrect__doc__
+	  << scribus_createtable__doc__
+	  << scribus_createtext__doc__
+	  << scribus_deleteobject__doc__
+	  << scribus_duplicateobject__doc__
+	  << scribus_duplicateobjects__doc__
+	  << scribus_getcharacterstyle__doc__
+	  << scribus_getparagraphstyle__doc__
+	  << scribus_getstyle__doc__
+	  << scribus_gettextflowmode__doc__
+	  << scribus_objectexists__doc__
+	  << scribus_pasteobject__doc__
+	  << scribus_pasteobjects__doc__
+	  << scribus_setcharstyle__doc__
+	  << scribus_setparagraphstyle__doc__
+	  << scribus_setstyle__doc__
+	  << scribus_settextflowmode__doc__
+	  << scribus_textflowmode__doc__;
 }
