@@ -92,10 +92,10 @@ PyObject *scribus_getfont(PyObject* /* self */, PyObject* args)
 	{
 		for (int i = 0; i < item->itemText.length(); i++)
 			if (item->itemText.selected(i))
-				return PyString_FromString(item->itemText.charStyle(i).font().scName().toUtf8());
+				return PyUnicode_FromString(item->itemText.charStyle(i).font().scName().toUtf8());
 		return nullptr;
 	}
-	return PyString_FromString(item->currentCharStyle().font().scName().toUtf8());
+	return PyUnicode_FromString(item->currentCharStyle().font().scName().toUtf8());
 }
 
 PyObject *scribus_gettextcolor(PyObject* /* self */, PyObject* args)
@@ -118,11 +118,11 @@ PyObject *scribus_gettextcolor(PyObject* /* self */, PyObject* args)
 		for (int i = 0; i < item->itemText.length(); ++i)
 		{
 			if (item->itemText.selected(i))
-				return PyString_FromString(item->itemText.charStyle(i).fillColor().toUtf8());
+				return PyUnicode_FromString(item->itemText.charStyle(i).fillColor().toUtf8());
 		}
         return nullptr;
 	}
-    return PyString_FromString(item->currentCharStyle().fillColor().toUtf8());
+    return PyUnicode_FromString(item->currentCharStyle().fillColor().toUtf8());
 }
 
 PyObject *scribus_gettextshade(PyObject* /* self */, PyObject* args)
@@ -145,14 +145,14 @@ PyObject *scribus_gettextshade(PyObject* /* self */, PyObject* args)
 		for (int i = 0; i < item->itemText.length(); ++i)
 		{
 			if (item->itemText.selected(i))
-				return PyInt_FromLong(item->itemText.charStyle(i).fillShade());
+				return PyLong_FromLong(item->itemText.charStyle(i).fillShade());
 		}
 		return nullptr;
 	}
-	return PyInt_FromLong(item->currentCharStyle().fillShade());
+	return PyLong_FromLong(item->currentCharStyle().fillShade());
 }
 
-PyObject *scribus_gettextsize(PyObject* /* self */, PyObject* args)
+PyObject *scribus_gettextlength(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -167,7 +167,7 @@ PyObject *scribus_gettextsize(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get text size of non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	return PyInt_FromLong(static_cast<long>(item->itemText.length()));
+	return PyLong_FromLong(static_cast<long>(item->itemText.length()));
 }
 
 PyObject *scribus_gettextlines(PyObject* /* self */, PyObject* args)
@@ -185,7 +185,7 @@ PyObject *scribus_gettextlines(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get number of lines of non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	return PyInt_FromLong(static_cast<long>(item->textLayout.lines()));
+	return PyLong_FromLong(static_cast<long>(item->textLayout.lines()));
 }
 
 PyObject *scribus_gettextverticalalignment(PyObject* /* self */, PyObject* args)
@@ -203,7 +203,7 @@ PyObject *scribus_gettextverticalalignment(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get vertical alignment of non-text frame.", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	return PyInt_FromLong(static_cast<long>(item->verticalAlignment()));
+	return PyLong_FromLong(static_cast<long>(item->verticalAlignment()));
 }
 
 PyObject *scribus_getcolumns(PyObject* /* self */, PyObject* args)
@@ -221,7 +221,7 @@ PyObject *scribus_getcolumns(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get column count of non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	return PyInt_FromLong(static_cast<long>(item->m_columns));
+	return PyLong_FromLong(static_cast<long>(item->m_columns));
 }
 
 PyObject *scribus_getcolumngap(PyObject* /* self */, PyObject* args)
@@ -261,13 +261,13 @@ PyObject *scribus_getfontfeatures(PyObject* /* self */, PyObject* args)
 	{
 		for (int i = 0; i < item->itemText.length(); i++)
 			if (item->itemText.selected(i))
-				return PyString_FromString(item->itemText.charStyle(i).fontFeatures().toUtf8());
+				return PyUnicode_FromString(item->itemText.charStyle(i).fontFeatures().toUtf8());
 		return nullptr;
 	}
-	return PyString_FromString(item->currentCharStyle().fontFeatures().toUtf8());
+	return PyUnicode_FromString(item->currentCharStyle().fontFeatures().toUtf8());
 }
 
-PyObject *scribus_getlinespace(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getfirstlinkedframe(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -277,7 +277,107 @@ PyObject *scribus_getlinespace(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (!item->asTextFrame())
+	if (!item->isTextFrame())
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get linked frames of non-text frame.","python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	return PyUnicode_FromString(item->firstInChain()->itemName().toUtf8());
+}
+
+PyObject *scribus_getlastlinkedframe(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+	if (!item->isTextFrame())
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get linked frames of non-text frame.","python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	return PyUnicode_FromString(item->lastInChain()->itemName().toUtf8());
+}
+
+PyObject *scribus_getnextlinkedframe(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+	if (!item->isTextFrame())
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get linked frames of non-text frame.","python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	if (item->nextInChain() != nullptr)
+		return PyUnicode_FromString(item->nextInChain()->itemName().toUtf8());
+
+	Py_RETURN_NONE;
+}
+
+PyObject *scribus_getprevlinkedframe(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+	if (!item->isTextFrame())
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get linked frames of non-text frame.","python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	if (item->prevInChain() != nullptr)
+		return PyUnicode_FromString(item->prevInChain()->itemName().toUtf8());
+
+	Py_RETURN_NONE;
+}
+
+PyObject *scribus_getfirstlineoffset(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+	if (!item->isTextFrame())
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get first line offset of non-text frame.", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+	return PyLong_FromLong(static_cast<long>(item->firstLineOffset()));
+}
+
+PyObject *scribus_getlinespacing(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+	if (!item->isTextFrame())
 	{
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get line space of non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -314,7 +414,6 @@ PyObject *scribus_getframetext(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!checkHaveDocument())
 		return nullptr;
-	QString text = "";
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
@@ -323,29 +422,32 @@ PyObject *scribus_getframetext(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get text of non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
+	
+	const StoryText& story = item->itemText;
+	QString text;
+	text.reserve(story.hasSelection() ? story.selectionLength() : story.length());
 	for (int i = item->firstInFrame(); i <= item->lastInFrame(); ++i)
 	{
 		if (item->HasSel)
 		{
-			if (item->itemText.selected(i))
-				text += item->itemText.text(i);
+			if (story.selected(i))
+				text += story.text(i);
 		}
 		else
 		{
-			text += item->itemText.text(i);
+			text += story.text(i);
 		}
 	}
-	return PyString_FromString(text.toUtf8());
+	return PyUnicode_FromString(text.toUtf8());
 }
 
-PyObject *scribus_gettext(PyObject* /* self */, PyObject* args)
+PyObject *scribus_getalltext(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
 		return nullptr;
 	if (!checkHaveDocument())
 		return nullptr;
-	QString text = "";
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
@@ -356,22 +458,25 @@ PyObject *scribus_gettext(PyObject* /* self */, PyObject* args)
 	}
 
 	// collect all chars from a storytext
-	for (int i = 0; i < item->itemText.length(); i++)
+	const StoryText& story = item->itemText;
+	QString text;
+	text.reserve(story.hasSelection() ? story.selectionLength() : story.length());
+	for (int i = 0; i < story.length(); i++)
 	{
 		if (item->HasSel)
 		{
-			if (item->itemText.selected(i))
-				text += item->itemText.text(i);
+			if (story.selected(i))
+				text += story.text(i);
 		}
 		else
 		{
-			text += item->itemText.text(i);
+			text += story.text(i);
 		}
-	} // for
-	return PyString_FromString(text.toUtf8());
+	}
+	return PyUnicode_FromString(text.toUtf8());
 }
 
-PyObject *scribus_setboxtext(PyObject* /* self */, PyObject* args)
+PyObject *scribus_settext(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	char *Text;
@@ -387,14 +492,13 @@ PyObject *scribus_setboxtext(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set text of non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	QString Daten = QString::fromUtf8(Text);
-	Daten.replace("\r\n", SpecialChars::PARSEP);
-	Daten.replace(QChar('\n') , SpecialChars::PARSEP);
+	QString userText = QString::fromUtf8(Text);
+	userText.replace("\r\n", SpecialChars::PARSEP);
+	userText.replace(QChar('\n') , SpecialChars::PARSEP);
 	PyMem_Free(Text);
 	currItem->itemText.clear();
-	currItem->itemText.insertChars(0, Daten);
+	currItem->itemText.insertChars(0, userText);
 	currItem->invalidateLayout();
-	currItem->Dirty = false;
 
 	Py_RETURN_NONE;
 }
@@ -428,12 +532,8 @@ PyObject *scribus_inserttext(PyObject* /* self */, PyObject* args)
 	if (pos == -1)
 		pos = item->itemText.length();
 	item->itemText.insertChars(pos, textData, true);
-	item->Dirty = true;
-	if (ScCore->primaryMainWindow()->doc->DoDrawing)
-	{
-		// FIXME adapt to Qt-4 painting style
-		item->Dirty = false;
-	}
+	item->invalidateLayout();
+
 	Py_RETURN_NONE;
 }
 
@@ -471,7 +571,60 @@ PyObject *scribus_inserthtmltext(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_setalignment(PyObject* /* self */, PyObject* args)
+PyObject *scribus_layouttext(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+	if (!item->isTextFrame() && !item->isPathText())
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot layout text of a non-text frame.", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+	item->layout();
+
+	Py_RETURN_NONE;
+}
+
+PyObject *scribus_layouttextchain(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+	if (!item->isTextFrame() && !item->isPathText())
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot layout text chain for a non-text frame.", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	if (item->isPathText())
+	{
+		item->layout();
+		Py_RETURN_NONE;
+	}
+	
+	PageItem* firstFrame = item->firstInChain();
+	PageItem* nextFrame = firstFrame;
+	while (nextFrame)
+	{
+		nextFrame->layout();
+		nextFrame = nextFrame->nextInChain();
+	}
+
+	Py_RETURN_NONE;
+}
+
+PyObject *scribus_settextalignment(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	int alignment;
@@ -487,7 +640,7 @@ PyObject *scribus_setalignment(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (!item->asTextFrame())
+	if (!item->isTextFrame())
 	{
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set text alignment on a non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -522,7 +675,7 @@ PyObject *scribus_setdirection(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == nullptr)
 		return nullptr;
-	if (!item->asTextFrame())
+	if (!item->isTextFrame())
 	{
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set text direction on a non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -644,7 +797,34 @@ PyObject *scribus_setfont(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_setlinespace(PyObject* /* self */, PyObject* args)
+PyObject *scribus_setfirstlineoffset(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	int offset;
+	if (!PyArg_ParseTuple(args, "i|es", &offset, "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	if (offset < 0 || offset > (int) FLOPBaselineGrid)
+	{
+		PyErr_SetString(PyExc_ValueError, QObject::tr("First line offset out of bounds, Use one of the scribus.FLOP_* constants.", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+	if (!item->isTextFrame())
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set first line offset on a non-text frame.", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+	item->setFirstLineOffset((FirstLineOffsetPolicy) offset);
+	item->update();
+
+	Py_RETURN_NONE;
+}
+
+PyObject *scribus_setlinespacing(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double w;
@@ -679,7 +859,7 @@ PyObject *scribus_setlinespace(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_setlinespacemode(PyObject* /* self */, PyObject* args)
+PyObject *scribus_setlinespacingmode(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	int w;
@@ -819,6 +999,49 @@ PyObject *scribus_settextverticalalignment(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
+PyObject *scribus_selectframetext(PyObject* /* self */, PyObject* args)
+{
+	char *Name = const_cast<char*>("");
+	int start, selcount;
+	if (!PyArg_ParseTuple(args, "ii|es", &start, &selcount, "utf-8", &Name))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	if (item == nullptr)
+		return nullptr;
+
+	if (!(item->isTextFrame()) && !(item->isPathText()))
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot select text in a non-text frame", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+	if (selcount < -1)
+	{
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Count must be positive, 0 or -1", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	if (start < 0 || (selcount > 0 && ((item->lastInFrame() == -1) || (selcount + start > item->lastInFrame() - item->firstInFrame() + 1))))
+	{
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Selection index out of bounds", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+	start += item->firstInFrame();
+	if (selcount == -1)
+		selcount = item->lastInFrame() + 1 - start;
+	item->itemText.deselectAll();
+	if (selcount == 0)
+	{
+		item->HasSel = false;
+		Py_RETURN_NONE;
+	}
+	item->itemText.select(start, selcount, true);
+	item->HasSel = true;
+
+	Py_RETURN_NONE;
+}
+
 PyObject *scribus_selecttext(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
@@ -860,8 +1083,6 @@ PyObject *scribus_selecttext(PyObject* /* self */, PyObject* args)
 	if (selcount == 0)
 	{
 		item->HasSel = false;
-//		Py_INCREF(Py_None);
-//		return Py_None;
 		Py_RETURN_NONE;
 	}
 	item->itemText.select(start, selcount, true);
@@ -919,18 +1140,6 @@ PyObject *scribus_settextfill(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	ApplyCharstyleHelper<QString>(item, QString::fromUtf8(Color)).apply(&CharStyle::setFillColor, 0, item->itemText.length());
-//	for (int b = 0; b < item->itemText.length(); b++)
-//	{
-//		//FIXME: doc method
-//		if (item->HasSel)
-//		{
-//			if (item->itemText.selected(b))
-//				item->itemText.item(b)->setFillColor(QString::fromUtf8(Color));
-//		}
-//		else
-//			item->itemText.item(b)->setFillColor(QString::fromUtf8(Color));
-//	}
-//	item->TxtFill = QString::fromUtf8(Color);
 	Py_RETURN_NONE;
 }
 
@@ -951,18 +1160,6 @@ PyObject *scribus_settextstroke(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	ApplyCharstyleHelper<QString>(item, QString::fromUtf8(Color)).apply(&CharStyle::setStrokeColor, 0, item->itemText.length());
-//	for (int b = 0; b < item->itemText.length(); b++)
-//	{
-//		//FIXME:NLS use document method for this
-//		if (item->HasSel)
-//		{
-//			if (item->itemText.selected(b))
-//				item->itemText.item(b)->setStrokeColor(QString::fromUtf8(Color));
-//		}
-//		else
-//			item->itemText.item(b)->setStrokeColor(QString::fromUtf8(Color));
-//	}
-//	item->TxtStroke = QString::fromUtf8(Color);
 	Py_RETURN_NONE;
 }
 
@@ -1059,18 +1256,6 @@ PyObject *scribus_settextshade(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	}
 	ApplyCharstyleHelper<double>(item, w).apply(&CharStyle::setFillShade, 0, item->itemText.length());
-//	//FIXME:NLS use document method for that
-//	for (int b = 0; b < item->itemText.length(); ++b)
-//	{
-//		if (item->HasSel)
-//		{
-//			if (item->itemText.selected(b))
-//				item->itemText.item(b)->setFillShade(w);
-//		}
-//		else
-//			item->itemText.item(b)->setFillShade(w);
-//	}
-//	item->ShTxtFill = w;
 	Py_RETURN_NONE;
 }
 
@@ -1133,7 +1318,7 @@ PyObject *scribus_unlinktextframes(PyObject* /* self */, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
 	if (item == nullptr)
 		return nullptr;
-	if (!item->asTextFrame())
+	if (!item->isTextFrame())
 	{
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot unlink a non-text frame.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -1177,7 +1362,7 @@ PyObject *scribus_unlinktextframes(PyObject* /* self */, PyObject* args)
  * 2004-09-07 (Craig Ringer)
  * 2004-09-14 pv frame type, optional frame name param
  */
-PyObject *scribus_tracetext(PyObject* /* self */, PyObject* args)
+PyObject *scribus_outlinetext(PyObject* /* self */, PyObject* args)
 {
 	char *name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
@@ -1194,8 +1379,8 @@ PyObject *scribus_tracetext(PyObject* /* self */, PyObject* args)
 	}
 	if (item->invalid)
 		item->layout();
-	ScCore->primaryMainWindow()->view->Deselect(true);
-	ScCore->primaryMainWindow()->view->SelectItem(item);
+	ScCore->primaryMainWindow()->view->deselectItems(true);
+	ScCore->primaryMainWindow()->view->selectItem(item);
 	ScCore->primaryMainWindow()->view->TextToPath();
 
 	Py_RETURN_NONE;
@@ -1235,17 +1420,17 @@ PyObject *scribus_istextoverflowing(PyObject * self, PyObject* args, PyObject* k
 	}
 	// no overrun
 	if (nolinks)
-		return PyInt_FromLong(maxchars - firstFrame);
+		return PyLong_FromLong(maxchars - firstFrame);
 
 	if (maxchars > chars)
-		return PyInt_FromLong(0);
+		return PyLong_FromLong(0);
 	// number of overrunning letters
-	return PyInt_FromLong(static_cast<long>(chars - maxchars));
+	return PyLong_FromLong(static_cast<long>(chars - maxchars));
 	 */
 	// refresh overflow information
 	item->invalidateLayout();
 	item->layout();
-	return PyInt_FromLong(static_cast<long>(item->frameOverflows()));
+	return PyLong_FromLong(static_cast<long>(item->frameOverflows()));
 }
 
 /*
@@ -1350,25 +1535,58 @@ PV */
 void cmdtextdocwarnings()
 {
 	QStringList s;
-	s << scribus_getfontsize__doc__    << scribus_getfont__doc__
-	  << scribus_gettextlines__doc__   << scribus_gettextsize__doc__
-	  << scribus_getframetext__doc__   << scribus_gettext__doc__
-	  << scribus_getlinespace__doc__   << scribus_getcolumngap__doc__
-	  << scribus_getcolumns__doc__     << scribus_setboxtext__doc__
+	s << scribus_dehyphenatetext__doc__
+	  << scribus_deletetext__doc__
+	  << scribus_getalltext__doc__
+	  << scribus_getcolumngap__doc__
+	  << scribus_getcolumns__doc__
+	  << scribus_getfirstlineoffset__doc__
+	  << scribus_getfirstlinkedframe__doc__
+	  << scribus_getfont__doc__
+	  << scribus_getfontfeatures__doc__
+	  << scribus_getfontsize__doc__
+	  << scribus_getframetext__doc__
+	  << scribus_getlastlinkedframe__doc__
+	  << scribus_getlinespacing__doc__
+	  << scribus_getnextlinkedframe__doc__
+	  << scribus_getprevlinkedframe__doc__
+	  << scribus_gettext__doc__ // Deprecated
+	  << scribus_gettextcolor__doc__
+	  << scribus_gettextdistances__doc__
+	  << scribus_gettextlength__doc__
+	  << scribus_gettextlines__doc__
+	  << scribus_gettextshade__doc__
 	  << scribus_gettextverticalalignment__doc__
-	  << scribus_inserttext__doc__     << scribus_inserthtmltext__doc__<< scribus_setfont__doc__
-	  << scribus_setfontsize__doc__    << scribus_setlinespace__doc__
-	  << scribus_setcolumngap__doc__   << scribus_setcolumns__doc__
+	  << scribus_hyphenatetext__doc__
+	  << scribus_inserthtmltext__doc__
+	  << scribus_inserttext__doc__
+	  << scribus_ispdfbookmark__doc__
+	  << scribus_istextoverflowing__doc__
+	  << scribus_layouttext__doc__
+	  << scribus_layouttextchain__doc__
+	  << scribus_linktextframes__doc__
+	  << scribus_outlinetext__doc__
+	  << scribus_selectframetext__doc__
+	  << scribus_selecttext__doc__
+	  << scribus_setcolumngap__doc__
+	  << scribus_setcolumns__doc__
+	  << scribus_setdirection__doc__
+	  << scribus_setfirstlineoffset__doc__
+	  << scribus_setfont__doc__
+	  << scribus_setfontfeatures__doc__
+	  << scribus_setfontsize__doc__
+	  << scribus_setlinespacing__doc__
+	  << scribus_setlinespacingmode__doc__
+	  << scribus_setpdfbookmark__doc__
+	  << scribus_settextdistances__doc__
+	  << scribus_settext__doc__
+	  << scribus_settextalignment__doc__
+	  << scribus_settextfill__doc__
+	  << scribus_settextscalingh__doc__
+	  << scribus_settextscalingv__doc__
+	  << scribus_settextshade__doc__
+	  << scribus_settextstroke__doc__
 	  << scribus_settextverticalalignment__doc__
-	  << scribus_setalign__doc__       << scribus_selecttext__doc__
-	  << scribus_deletetext__doc__     << scribus_settextfill__doc__
-	  << scribus_settextstroke__doc__  << scribus_settextshade__doc__
-	  << scribus_linktextframes__doc__ << scribus_unlinktextframes__doc__
-	  << scribus_tracetext__doc__      << scribus_istextoverflowing__doc__
-	  << scribus_setpdfbookmark__doc__ << scribus_ispdfbookmark__doc__
-	  << scribus_hyphenatetext__doc__ << scribus_dehyphenatetext__doc__
-	  << scribus_gettextdistances__doc__ << scribus_settextdistances__doc__
-	  << scribus_settextscalingh__doc__ << scribus_settextscalingv__doc__
-	  << scribus_setlinespacemode__doc__ << scribus_setdirection__doc__
-	  << scribus_setfontfeatures__doc__ << scribus_getfontfeatures__doc__;
+	  << scribus_tracetext__doc__
+	  << scribus_unlinktextframes__doc__;
 }
