@@ -64,10 +64,10 @@ PageItem *GetItem(const QString& Name)
 {
 	if (!Name.isEmpty())
 	{
-		for (int a = 0; a < ScCore->primaryMainWindow()->doc->Items->count(); a++)
+		for (int i = 0; i < ScCore->primaryMainWindow()->doc->Items->count(); i++)
 		{
-			if (ScCore->primaryMainWindow()->doc->Items->at(a)->itemName() == Name)
-				return ScCore->primaryMainWindow()->doc->Items->at(a);
+			if (ScCore->primaryMainWindow()->doc->Items->at(i)->itemName() == Name)
+				return ScCore->primaryMainWindow()->doc->Items->at(i);
 		}
 	}
 	else
@@ -118,9 +118,9 @@ PageItem* getPageItemByName(const QString& name)
 		PyErr_SetString(PyExc_ValueError, QString("Cannot accept empty name for pageitem").toLocal8Bit().constData());
 		return nullptr;
 	}
-	for (int i = 0; i<ScCore->primaryMainWindow()->doc->Items->count(); i++)
+	for (int i = 0; i < ScCore->primaryMainWindow()->doc->Items->count(); i++)
 	{
-		if (name==ScCore->primaryMainWindow()->doc->Items->at(i)->itemName())
+		if (name == ScCore->primaryMainWindow()->doc->Items->at(i)->itemName())
 			return ScCore->primaryMainWindow()->doc->Items->at(i);
 	} // for items
 	PyErr_SetString(NoValidObjectError, QString("Object not found").toLocal8Bit().constData());
@@ -137,9 +137,9 @@ bool ItemExists(const QString& name)
 {
 	if (name.length() == 0)
 		return false;
-	for (int i = 0; i<ScCore->primaryMainWindow()->doc->Items->count(); i++)
+	for (int i = 0; i < ScCore->primaryMainWindow()->doc->Items->count(); i++)
 	{
-		if (name==ScCore->primaryMainWindow()->doc->Items->at(i)->itemName())
+		if (name == ScCore->primaryMainWindow()->doc->Items->at(i)->itemName())
 			return true;
 	} // for items
 	return false;
@@ -176,7 +176,7 @@ QStringList getSelectedItemsByName()
 
 bool setSelectedItemsByName(QStringList& itemNames)
 {
-	ScCore->primaryMainWindow()->view->Deselect();
+	ScCore->primaryMainWindow()->view->deselectItems();
 	// For each named item
 	for (QStringList::Iterator it = itemNames.begin() ; it != itemNames.end() ; it++)
 	{
@@ -188,7 +188,7 @@ bool setSelectedItemsByName(QStringList& itemNames)
 		if (!item)
 			return false;
 		// and select it
-		ScCore->primaryMainWindow()->view->SelectItem(item);
+		ScCore->primaryMainWindow()->view->selectItem(item);
 	}
 	return true;
 }
@@ -241,3 +241,11 @@ TableBorder parseBorder(PyObject* borderLines, bool* ok)
 	return border;
 }
 
+QString PyUnicode_asQString(PyObject* arg)
+{
+	const char* utf8Str = PyUnicode_AsUTF8(arg);
+	if (!utf8Str)
+		return QString();
+	return QString::fromUtf8(utf8Str);
+}
+
