@@ -8,30 +8,32 @@ for which a new license (GPL+exception) is in place.
 #include <iostream>
 
 #include "objprinter.h"
-#include "cmdutil.h"
-#include "prefsmanager.h"
 
 #include <structmember.h>
 #include <QFileInfo>
 #include <QDir>
+#include <QScopedPointer>
 
+#include "cmdutil.h"
+#include "prefsmanager.h"
 #include "pslib.h"
 #include "scpaths.h"
+#include "scprintengine_pdf.h"
+#include "scprintengine_ps.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "util_file.h"
 #include "util_ghostscript.h"
 #include "util_printer.h"
 
-// these functions are located at utils.cpp
-bool SCRIBUS_API loadText(QString nam, QString *Buffer);
-void SCRIBUS_API ReOrderText(ScribusDoc *doc, ScribusView *view);
-// end of utils.cpp
-
 #if defined(_WIN32)
 #include "scprintengine_gdi.h"
 #endif
 
+// these functions are located at utils.cpp
+void SCRIBUS_API ReOrderText(ScribusDoc *doc, ScribusView *view);
+// end of utils.cpp
+
 typedef struct
 {
 	PyObject_HEAD
@@ -44,7 +46,7 @@ typedef struct
 	PyObject *separation; // string - No; All; Cyan; Magenta; Yellow; Black
 	int color; // bool - do we print in color=1 or greyscale=0
 	int useICC; // bool - do we use ICC Profiles 0 = No 1 = Yes
-	int pslevel; // integer - 1, 2 or 3 level of used postscript
+	int prnLang; // integer - print language
 	int mph; // bool - mirror pages horizontally
 	int mpv; // bool - mirror pages vertically
 	int ucr; // bool - Under Color Removal
@@ -59,7 +61,7 @@ static void Printer_dealloc(Printer* self)
 	Py_XDECREF(self->cmd);
 	Py_XDECREF(self->pages);
 	Py_XDECREF(self->separation);
-	self->ob_type->tp_free((PyObject *)self);
+	Py_TYPE(self)->tp_free((PyObject *)self);
 }
 
 static PyObject * Printer_new(PyTypeObject *type, PyObject * /*args*/, PyObject * /*kwds*/)
@@ -73,37 +75,37 @@ static PyObject * Printer_new(PyTypeObject *type, PyObject * /*args*/, PyObject
 	if (self != nullptr) {
 // set allPrinters attribute
 		self->allPrinters = PyList_New(0);
-		if (self->allPrinters == nullptr){
+		if (self->allPrinters == nullptr) {
 			Py_DECREF(self);
 			return nullptr;
 		}
 // set printer attribute
-		self->printer = PyString_FromString("");
-		if (self->printer == nullptr){
+		self->printer = PyUnicode_FromString("");
+		if (self->printer == nullptr) {
 			Py_DECREF(self);
 			return nullptr;
 		}
 // set file attribute
-		self->file = PyString_FromString("");
-		if (self->file == nullptr){
+		self->file = PyUnicode_FromString("");
+		if (self->file == nullptr) {
 			Py_DECREF(self);
 			return nullptr;
 		}
 // set cmd attribute
-		self->cmd = PyString_FromString("");
-		if (self->cmd == nullptr){
+		self->cmd = PyUnicode_FromString("");
+		if (self->cmd == nullptr) {
 			Py_DECREF(self);
 			return nullptr;
 		}
 // set pages attribute
 		self->pages = PyList_New(0);
-		if (self->pages == nullptr){
+		if (self->pages == nullptr) {
 			Py_DECREF(self);
 			return nullptr;
 		}
 // set separation attribute
-		self->separation = PyString_FromString("No");
-		if (self->separation == nullptr){
+		self->separation = PyUnicode_FromString("No");
+		if (self->separation == nullptr) {
 			Py_DECREF(self);
 			return nullptr;
 		}
@@ -111,8 +113,8 @@ static PyObject * Printer_new(PyTypeObject *type, PyObject * /*args*/, PyObject
 		self->color = 1;
 // set useICC attribute
 		self->useICC = 0;
-// set pslevel attribute
-		self->pslevel = 3;
+// set prnLanguage attribute
+		self->prnLang = (int) PrintLanguage::PostScript3;
 // set mph attribute
 		self->mph = 0;
 // set mpv attribute
@@ -133,7 +135,7 @@ static int Printer_init(Printer *self, PyObject * /*args*/, PyObject * /*kwds*/)
 // pool system for installed printers
 // most code is stolen and little adopted from druck.cpp
 	PyObject *allPrinters = PyList_New(0);
-	if (allPrinters){
+	if (allPrinters) {
 		Py_DECREF(self->allPrinters);
 		self->allPrinters = allPrinters;
 	}
@@ -143,19 +145,19 @@ static int Printer_init(Printer *self, PyObject * /*args*/, PyObject * /*kwds*/)
 		QString prn = printers[i];
 		if (prn.isEmpty())
 			continue;
-		PyObject *tmppr = PyString_FromString(prn.toLocal8Bit().constData());
-		if (tmppr){
+		PyObject *tmppr = PyUnicode_FromString(prn.toUtf8().constData());
+		if (tmppr) {
 			PyList_Append(self->allPrinters, tmppr);
 			Py_DECREF(tmppr);
 		}
 	}
-	PyObject *tmp2 = PyString_FromString("File");
+	PyObject *tmp2 = PyUnicode_FromString("File");
 	PyList_Append(self->allPrinters, tmp2);
 	Py_DECREF(tmp2);
 // as defaut set to print into file
 	PyObject *printer = nullptr;
-	printer = PyString_FromString("File");
-	if (printer){
+	printer = PyUnicode_FromString("File");
+	if (printer) {
 		Py_DECREF(self->printer);
 		self->printer = printer;
 	}
@@ -163,11 +165,11 @@ static int Printer_init(Printer *self, PyObject * /*args*/, PyObject * /*kwds*/)
 	QString tf(ScCore->primaryMainWindow()->doc->pdfOptions().fileName);
 	if (tf.isEmpty()) {
 		QFileInfo fi = QFileInfo(ScCore->primaryMainWindow()->doc->documentFileName());
-		tf = fi.path()+"/"+fi.baseName()+".pdf";
+		tf = fi.path() + "/" + fi.baseName() + ".pdf";
 	}
 	PyObject *file = nullptr;
-	file = PyString_FromString(tf.toLatin1());
-	if (file){
+	file = PyUnicode_FromString(tf.toUtf8());
+	if (file) {
 		Py_DECREF(self->file);
 		self->file = file;
 	} else {
@@ -176,8 +178,8 @@ static int Printer_init(Printer *self, PyObject * /*args*/, PyObject * /*kwds*/)
 	}
 // alternative printer commands default to ""
 	PyObject *cmd = nullptr;
-	cmd = PyString_FromString("");
-	if (cmd){
+	cmd = PyUnicode_FromString("");
+	if (cmd) {
 		Py_DECREF(self->cmd);
 		self->cmd = cmd;
 	}
@@ -186,20 +188,20 @@ static int Printer_init(Printer *self, PyObject * /*args*/, PyObject * /*kwds*/)
 	PyObject *pages = nullptr;
 	int num = ScCore->primaryMainWindow()->doc->Pages->count();
 	pages = PyList_New(num);
-	if (pages){
+	if (pages) {
 		Py_DECREF(self->pages);
 		self->pages = pages;
 	}
-	for (int i = 0; i<num; i++) {
-		PyObject *tmp=nullptr;
-		tmp = PyInt_FromLong((long)i+1L); // instead of 1 put here first page number
+	for (int i = 0; i < num; i++) {
+		PyObject *tmp = nullptr;
+		tmp = PyLong_FromLong((long)i+1L); // instead of 1 put here first page number
 		if (tmp)
 			PyList_SetItem(self->pages, i, tmp);
 	}
 // do not print separation
 	PyObject *separation = nullptr;
-	separation = PyString_FromString("No");
-	if (separation){
+	separation = PyUnicode_FromString("No");
+	if (separation) {
 		Py_DECREF(self->separation);
 		self->separation = separation;
 	}
@@ -208,7 +210,7 @@ static int Printer_init(Printer *self, PyObject * /*args*/, PyObject * /*kwds*/)
 // do not use ICC Profile
 	self->useICC = 0;
 // use PostScrip level 3
-	self->pslevel = 3;
+	self->prnLang = (int) PrintLanguage::PostScript3;
 // do not mirror pages
 	self->mph = 0;
 // do not mirror pages
@@ -224,7 +226,8 @@ static PyMemberDef Printer_members[] = {
 	{const_cast<char*>("copies"), T_INT, offsetof(Printer, copies), 0, const_cast<char*>("Number of copies")},
 	{const_cast<char*>("color"), T_INT, offsetof(Printer, color), 0, const_cast<char*>("Print in color.\n\t True - color  --  Default\n\t False - greyscale")},
 	{const_cast<char*>("useICC"), T_INT, offsetof(Printer, useICC), 0, const_cast<char*>("Use ICC Profile\n\tTrue\n\tFalse  --  Default")},
-	{const_cast<char*>("pslevel"), T_INT, offsetof(Printer, pslevel), 0, const_cast<char*>("PostScript Level\nCan be 1 or 2 or 3    -- Default is 3.")},
+	{const_cast<char*>("pslevel"), T_INT, offsetof(Printer, prnLang), 0, const_cast<char*>("Deprecated, use prnLanguage instead.")}, // Deprecated
+	{const_cast<char*>("prnLanguage"), T_INT, offsetof(Printer, prnLang), 0, const_cast<char*>("Print Language\nOne of PRNLANG_* constants  -- Default is PRNLANG_POSTSCRIPT3.")},
 	{const_cast<char*>("mph"), T_INT, offsetof(Printer, mph), 0, const_cast<char*>("Mirror Pages Horizontal\n\tTrue\n\tFalse  --  Default")},
 	{const_cast<char*>("mpv"), T_INT, offsetof(Printer, mpv), 0, const_cast<char*>("Mirror Pages Vertical\n\t True\n\tFalse  --  Default")},
 	{const_cast<char*>("ucr"), T_INT, offsetof(Printer, ucr), 0, const_cast<char*>("Apply Under Color Removal\n\tTrue  --  Default\n\tFalse")},
@@ -257,19 +260,24 @@ static int Printer_setprinter(Printer *self, PyObject *value, void * /*closure*/
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'printer' attribute.");
 		return -1;
 	}
-	if (!PyString_Check(value)) {
+	if (!PyUnicode_Check(value)) {
 		PyErr_SetString(PyExc_TypeError, "The 'printer' attribute value must be string.");
 		return -1;
 	}
+
 	int n = PyList_Size(self->allPrinters);
 	bool same = 0;
-	for (int i = 0; i<n; i++)
-		if (PyObject_RichCompareBool(value, PyList_GetItem(self->allPrinters, i), Py_EQ) == 1)
+	for (int i = 0; i < n; i++) {
+		if (PyObject_RichCompareBool(value, PyList_GetItem(self->allPrinters, i), Py_EQ) == 1) {
 			same = true;
+			break;
+		}
+	}
 	if (!same) {
 		PyErr_SetString(PyExc_ValueError, "'printer' value can be only one of string in 'allPrinters' attribute ");
 		return -1;
 	}
+
 	Py_DECREF(self->printer);
 	Py_INCREF(value);
 	self->printer = value;
@@ -288,7 +296,7 @@ static int Printer_setfile(Printer *self, PyObject *value, void * /*closure*/)
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'file' attribute.");
 		return -1;
 	}
-	if (!PyString_Check(value)) {
+	if (!PyUnicode_Check(value)) {
 		PyErr_SetString(PyExc_TypeError, "The 'file' attribute value must be string.");
 		return -1;
 	}
@@ -310,7 +318,7 @@ static int Printer_setcmd(Printer *self, PyObject *value, void * /*closure*/)
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'cmd' attribute.");
 		return -1;
 	}
-	if (!PyString_Check(value)) {
+	if (!PyUnicode_Check(value)) {
 		PyErr_SetString(PyExc_TypeError, "The 'cmd' attribute value must be string.");
 		return -1;
 	}
@@ -337,13 +345,13 @@ static int Printer_setpages(Printer *self, PyObject *value, void * /*closure*/)
 		return -1;
 	}
 	int len = PyList_Size(value);
-	for (int i = 0; i<len; i++){
+	for (int i = 0; i < len; i++) {
 		PyObject *tmp = PyList_GetItem(value, i);
-		if (!PyInt_Check(tmp)){
+		if (!PyLong_Check(tmp)) {
 			PyErr_SetString(PyExc_TypeError, "'pages' attribute must be list containing only integers.");
 			return -1;
 		}
-		if (PyInt_AsLong(tmp) > static_cast<int>(ScCore->primaryMainWindow()->doc->Pages->count()) || PyInt_AsLong(tmp) < 1) {
+		if (PyLong_AsLong(tmp) > static_cast<int>(ScCore->primaryMainWindow()->doc->Pages->count()) || PyLong_AsLong(tmp) < 1) {
 			PyErr_SetString(PyExc_ValueError, "'pages' value out of range.");
 			return -1;
 		}
@@ -366,7 +374,7 @@ static int Printer_setseparation(Printer *self, PyObject *value, void * /*closur
 		PyErr_SetString(PyExc_TypeError, "Cannot delete 'separation' attribute.");
 		return -1;
 	}
-	if (!PyString_Check(value)) {
+	if (!PyUnicode_Check(value)) {
 		PyErr_SetString(PyExc_TypeError, "The 'separation' attribute value must be string.");
 		return -1;
 	}
@@ -393,54 +401,58 @@ static PyObject *Printer_print(Printer *self)
 	if (!checkHaveDocument()) {
 		return nullptr;
 	}
-// copied from void ScribusMainWindow::slotFilePrint() in file scribus.cpp
-	QString fna, prn, cmd, cc, SepName;
-	QString printcomm;
-	bool fil, PSfile;
-	PSfile = false;
 
-//    ReOrderText(ScCore->primaryMainWindow()->doc, ScCore->primaryMainWindow()->view);
-	prn = QString(PyString_AsString(self->printer));
-	fna = QString(PyString_AsString(self->file));
-	fil = QString(PyString_AsString(self->printer)) == QString("File");
-	std::vector<int> pageNs;
+//	ReOrderText(ScCore->primaryMainWindow()->doc, ScCore->primaryMainWindow()->view);
+	QString prn = PyUnicode_asQString(self->printer);
+	QString fna = PyUnicode_asQString(self->file);
+	bool    fil = PyUnicode_asQString(self->printer) == QString("File");
+	QString sepName = PyUnicode_asQString(self->separation);
+	
 	PrintOptions options;
 	for (int i = 0; i < PyList_Size(self->pages); ++i) {
-		options.pageNumbers.push_back((int)PyInt_AsLong(PyList_GetItem(self->pages, i)));
+		options.pageNumbers.push_back((int) PyLong_AsLong(PyList_GetItem(self->pages, i)));
 	}
-	int copyCount = (self->copies < 1) ? 1 : self->copies;
-	SepName = QString(PyString_AsString(self->separation));
 	options.printer   = prn;
-	options.prnEngine = (PrintEngine) self->pslevel;
+	options.prnLanguage = (PrintLanguage) self->prnLang;
+	options.copies    = (self->copies < 1) ? 1 : self->copies;
 	options.toFile    = fil;
-	options.separationName = SepName;
-	options.outputSeparations = SepName != QString("No");
+	options.filename  = fil ? fna : QString();
+	options.separationName = sepName;
+	options.outputSeparations = sepName != QString("No");
+	options.useSpotColors = true;
 	options.useColor = self->color;
 	options.mirrorH  = self->mph;
 	options.mirrorV  = self->mpv;
 	options.doGCR    = self->ucr;
+	options.doClip = false;
+	options.setDevParam = false;
 	options.cropMarks  = false;
 	options.bleedMarks = false;
 	options.registrationMarks = false;
 	options.colorMarks = false;
+	options.includePDFMarks = false;
 	options.markOffset = 0.0;
 	options.bleeds.set(0, 0, 0, 0);
-	if (!PrinterUtil::checkPrintEngineSupport(options.printer, options.prnEngine, options.toFile))
-		options.prnEngine = PrinterUtil::getDefaultPrintEngine(options.printer, options.toFile);
-	printcomm = QString(PyString_AsString(self->cmd));
-	QMap<QString, QMap<uint, FPointArray> > ReallyUsed;
-	ReallyUsed.clear();
-	ScCore->primaryMainWindow()->doc->getUsedFonts(ReallyUsed);
+	if (!PrinterUtil::checkPrintLanguageSupport(options.printer, options.prnLanguage, options.toFile))
+		options.prnLanguage = PrinterUtil::getDefaultPrintLanguage(options.printer, options.toFile);
+	if (options.prnLanguage == PrintLanguage::PDF || options.prnLanguage == PrintLanguage::WindowsGDI)
+	{
+		options.separationName = "All";
+		options.outputSeparations = false;
+	}
+	options.printerCommand = PyUnicode_asQString(self->cmd);
+
+	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 
 #if defined(_WIN32)
 	if (!options.toFile)
 	{
 		QByteArray devMode;
 		bool printDone = false;
-		if ( PrinterUtil::getDefaultSettings(prn, options.devMode) )
+		if (PrinterUtil::getDefaultSettings(prn, options.devMode))
 		{
-			ScPrintEngine_GDI winPrint;
-			printDone = winPrint.print( *ScCore->primaryMainWindow()->doc, options );
+			ScPrintEngine_GDI winPrint(*currentDoc);
+			printDone = winPrint.print(options);
 		}
 		if (!printDone)
 			PyErr_SetString(PyExc_SystemError, "Printing failed");
@@ -448,69 +460,38 @@ static PyObject *Printer_print(Printer *self)
 	}
 #endif
 
-	PSLib *dd = new PSLib(options, true, PrefsManager::instance().appPrefs.fontPrefs.AvailFonts, ReallyUsed, ScCore->primaryMainWindow()->doc->PageColors, false, true);
-	if (dd != nullptr)
+	if (options.prnLanguage == PrintLanguage::PostScript1 || options.prnLanguage == PrintLanguage::PostScript2)
 	{
-		if (!fil)
-			fna = QDir::toNativeSeparators(ScPaths::tempFileDir()+"/tmp.ps");
-		PSfile = dd->PS_set_file(fna);
-		fna = QDir::toNativeSeparators(fna);
-		if (PSfile)
+		if (!ScCore->haveGS())
 		{
-			options.setDevParam = false;
-			options.doClip = false;
-			dd->CreatePS(ScCore->primaryMainWindow()->doc, options);
-			if (options.prnEngine == PostScript1 || options.prnEngine == PostScript2)
-			{
-				if (ScCore->haveGS())
-				{
-					QString tmp;
-					QStringList opts;
-					opts.append( QString("-dDEVICEWIDTHPOINTS=%1").arg(tmp.setNum(ScCore->primaryMainWindow()->doc->pageWidth())) );
-					opts.append( QString("-dDEVICEHEIGHTPOINTS=%1").arg(tmp.setNum(ScCore->primaryMainWindow()->doc->pageHeight())) );
-					convertPS2PS(fna, fna+".tmp", opts, options.prnEngine);
-					moveFile( fna + ".tmp", fna );
-				}
-				else
-				{
-					PyErr_SetString(PyExc_SystemError, "Printing failed : GhostScript is needed to print to PostScript Level 1 or Level 2");
-					Py_RETURN_NONE;
-				}
-			}
-
-			if (!fil)
-			{
-				if (!printcomm.isEmpty())
-					cmd = printcomm + " "+fna;
-				else
-				{
-					cmd = "lpr -P" + prn;
-					if (copyCount > 1)
-						cmd += " -#" + cc.setNum(copyCount);
-					cmd += " "+fna;
-				}
-				system(cmd.toLocal8Bit().constData());
-				unlink(fna.toLocal8Bit().constData());
-			}
+			PyErr_SetString(PyExc_SystemError, "Printing failed : GhostScript is needed to print to PostScript Level 1 or Level 2");
+			Py_RETURN_NONE;
 		}
-		else {
-			delete dd;
-			PyErr_SetString(PyExc_SystemError, "Printing failed");
-			return nullptr;
-		}
-		delete dd;
 	}
+
+	QScopedPointer<ScPrintEngine> printEngine;
+	if (options.prnLanguage == PrintLanguage::PDF)
+		printEngine.reset(new ScPrintEngine_PDF(*currentDoc));
+	else
+		printEngine.reset(new ScPrintEngine_PS(*currentDoc));
+
+	bool printDone = printEngine->print(options);
+	if (!printDone)
+	{
+		QString error = printEngine->errorMessage();
+		PyErr_SetString(PyExc_SystemError, error.toLocal8Bit().constData());
+	}
+
 	Py_RETURN_NONE;
 }
 
 static PyMethodDef Printer_methods[] = {
-	{const_cast<char*>("printNow"), (PyCFunction)Printer_print, METH_NOARGS, const_cast<char*>("Prints selected pages.")},
+	{const_cast<char*>("printNow"), (PyCFunction)Printer_print, METH_NOARGS, printer_printnow__doc__},
 	{nullptr, (PyCFunction)(nullptr), 0, nullptr} // sentinel
 };
 
 PyTypeObject Printer_Type = {
-	PyObject_HEAD_INIT(nullptr)   // PyObject_VAR_HEAD
-	0,			 //
+	PyVarObject_HEAD_INIT(nullptr, 0)   // PyObject_VAR_HEAD	 //
 	const_cast<char*>("scribus.Printer"), // char *tp_name; /* For printing, in format "<module>.<name>" */
 	sizeof(Printer),   // int tp_basicsize, /* For allocation */
 	0,		       // int tp_itemsize; /* For allocation */
@@ -518,10 +499,14 @@ PyTypeObject Printer_Type = {
 	/* Methods to implement standard operations */
 
 	(destructor) Printer_dealloc, //     destructor tp_dealloc;
+#if PY_VERSION_HEX >= 0x03080000
+	0,       //     Py_ssize_t tp_vectorcall_offset
+#else
 	nullptr, //     printfunc tp_print;
+#endif
 	nullptr, //     getattrfunc tp_getattr;
 	nullptr, //     setattrfunc tp_setattr;
-	nullptr, //     cmpfunc tp_compare;
+	nullptr, //     cmpfunc tp_as_async;
 	nullptr, //     reprfunc tp_repr;
 
 	/* Method suites for standard classes */
@@ -585,12 +570,21 @@ PyTypeObject Printer_Type = {
 	nullptr, //     PyObject *tp_subclasses;
 	nullptr, //     PyObject *tp_weaklist;
 	nullptr, //     destructor tp_del;
+	0, //	 unsigned int tp_version_tag;
+	0, //	 destructor tp_finalize;
+#if PY_VERSION_HEX >= 0x03080000
+	nullptr, // tp_vectorcall
+#endif
+#if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
+	nullptr, //deprecated tp_print
+#endif
 
 #ifdef COUNT_ALLOCS
 	/* these must be last and never explicitly initialized */
 	//    int tp_allocs;
 	//    int tp_frees;
 	//    int tp_maxalloc;
+	//    struct _typeobject *tp_prev;
 	//    struct _typeobject *tp_next;
 #endif
 };
