@@ -17,17 +17,18 @@ for which a new license (GPL+exception) is in place.
 #include <QPixmap>
 #include <cstdlib>
 
+#include "cmdutil.h"
 #include "runscriptdialog.h"
 #include "ui/helpbrowser.h"
 #include "ui/marksmanager.h"
 #include "ui/notesstyleseditor.h"
 #include "ui/propertiespalette.h" //TODO Move the calls to this to a signal
+#include "ui/contentpalette.h" //TODO Move the calls to this to a signal
 #include "ui/pagepalette.h" //TODO Move the calls to this to a signal
 #include "ui/layers.h" //TODO Move the calls to this to a signal
 #include "ui/outlinepalette.h" //TODO Move the calls to this to a signal
 #include "ui/scmessagebox.h"
 #include "ui/scmwmenumanager.h"
-#include "ui/textpalette.h"
 #include "pconsole.h"
 #include "scraction.h"
 #include "scribuscore.h"
@@ -43,8 +44,6 @@ for which a new license (GPL+exception) is in place.
 
 ScripterCore::ScripterCore(QWidget* parent)
 {
-	m_menuMgr = nullptr;
-
 	m_pyConsole = new PythonConsole(parent);
 	m_scripterActions.clear();
 	m_recentScriptActions.clear();
@@ -97,7 +96,7 @@ void ScripterCore::addToMainWindowMenu(ScribusMainWindow *mw)
 
 	buildScribusScriptsMenu();
 
-	m_menuMgr->addMenuStringToMenuBarBefore("Scripter","Windows");
+	m_menuMgr->addMenuStringToMenuBarBefore("Scripter", "Windows");
 	m_menuMgr->addMenuItemStringsToMenuBar("Scripter", m_scripterActions);
 	m_recentScripts = m_savedRecentScripts;
 	rebuildRecentScriptsMenu();
@@ -124,19 +123,18 @@ void ScripterCore::disableMainWindowMenu()
 void ScripterCore::buildScribusScriptsMenu()
 {
 	QString pfad = ScPaths::instance().scriptDir();
-	QString pfad2;
-	pfad2 = QDir::toNativeSeparators(pfad);
+	QString pfad2 = QDir::toNativeSeparators(pfad);
 	QDir ds(pfad2, "*.py", QDir::Name | QDir::IgnoreCase, QDir::Files | QDir::NoSymLinks);
-	if ((ds.exists()) && (ds.count() != 0))
+	if ((!ds.exists()) || (ds.count() == 0))
+		return;
+
+	for (uint dc = 0; dc < ds.count(); ++dc)
 	{
-		for (uint dc = 0; dc < ds.count(); ++dc)
-		{
-			QFileInfo fs(ds[dc]);
-			QString strippedName=fs.baseName();
-			m_scripterActions.insert(strippedName, new ScrAction( ScrAction::RecentScript, strippedName, QKeySequence(), this, strippedName));
-			connect( m_scripterActions[strippedName], SIGNAL(triggeredData(QString)), this, SLOT(StdScript(QString)) );
-			m_menuMgr->addMenuItemString(strippedName, "ScribusScripts");
-		}
+		QFileInfo fs(ds[dc]);
+		QString strippedName=fs.baseName();
+		m_scripterActions.insert(strippedName, new ScrAction( ScrAction::RecentScript, strippedName, QKeySequence(), this, strippedName));
+		connect( m_scripterActions[strippedName], SIGNAL(triggeredData(QString)), this, SLOT(StdScript(QString)) );
+		m_menuMgr->addMenuItemString(strippedName, "ScribusScripts");
 	}
 }
 
@@ -163,14 +161,14 @@ void ScripterCore::finishScriptRun()
 		return;
 
 	mainWin->propertiesPalette->setDoc(mainWin->doc);
-	mainWin->textPalette->setDoc(mainWin->doc);
+	mainWin->contentPalette->setDoc(mainWin->doc);
 	mainWin->marksManager->setDoc(mainWin->doc);
 	mainWin->nsEditor->setDoc(mainWin->doc);
 	mainWin->layerPalette->setDoc(mainWin->doc);
 	mainWin->outlinePalette->setDoc(mainWin->doc);
 	mainWin->outlinePalette->BuildTree();
 	mainWin->pagePalette->setView(mainWin->view);
-	mainWin->pagePalette->Rebuild();
+	mainWin->pagePalette->rebuild();
 	mainWin->doc->RePos = false;
 	if (mainWin->doc->m_Selection->count() != 0)
 		mainWin->doc->m_Selection->itemAt(0)->emitAllToGUI();
@@ -202,12 +200,12 @@ void ScripterCore::runScriptDialog()
 	finishScriptRun();
 }
 
-void ScripterCore::StdScript(const QString& basefilename)
+void ScripterCore::StdScript(const QString& baseFilename)
 {
 	QString pfad = ScPaths::instance().scriptDir();
 	QString pfad2;
 	pfad2 = QDir::toNativeSeparators(pfad);
-	QString fn = pfad2+basefilename+".py";
+	QString fn = pfad2+baseFilename+".py";
 	QFileInfo fd(fn);
 	if (!fd.exists())
 		return;
@@ -249,7 +247,7 @@ void ScripterCore::slotRunScriptFile(const QString& fileName, QStringList argume
 	if (!inMainInterpreter)
 	{
 		ScCore->primaryMainWindow()->propertiesPalette->unsetDoc();
-		ScCore->primaryMainWindow()->textPalette->unsetDoc();
+		ScCore->primaryMainWindow()->contentPalette->unsetDoc();
 		ScCore->primaryMainWindow()->pagePalette->setView(nullptr);
 		ScCore->primaryMainWindow()->setScriptRunning(true);
 		qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -259,20 +257,20 @@ void ScripterCore::slotRunScriptFile(const QString& fileName, QStringList argume
 		global_state = PyThreadState_Get();
 		state = Py_NewInterpreter();
 		// Init the scripter module in the sub-interpreter
-		initscribus(ScCore->primaryMainWindow());
+		//initscribus(ScCore->primaryMainWindow());
 	}
 
 	// Make sure sys.argv[0] is the path to the script
 	arguments.prepend(na.data());
 	//convert arguments (QListString) to char** for Python bridge
 	/* typically arguments == ['path/to/script.py','--argument1','valueforarg1','--flag']*/
-	char **comm = new char*[arguments.size()];
+	wchar_t **comm = new wchar_t*[arguments.size()];
 	for (int i = 0; i < arguments.size(); i++)
 	{
-		QByteArray localStr = arguments.at(i).toLocal8Bit();
-		comm[i] = new char[localStr.size() + 1]; //+1 to allow adding '\0'. may be useless, don't know how to check.
-		comm[i][localStr.size()] = 0;
-		strncpy(comm[i], localStr.data(), localStr.size());
+		const QString& argStr = arguments.at(i);
+		comm[i] = new wchar_t[argStr.size() + 1]; //+1 to allow adding '\0'. may be useless, don't know how to check.
+		comm[i][argStr.size()] = 0;
+		argStr.toWCharArray(comm[i]);
 	}
 	PySys_SetArgv(arguments.size(), comm);
 
@@ -288,13 +286,14 @@ void ScripterCore::slotRunScriptFile(const QString& fileName, QStringList argume
 	{
 		// Path separators need to be escaped on Windows
 		QString escapedAbsPath  = QDir::toNativeSeparators(fi.absolutePath()).replace("\\", "\\\\");
+		QString escapedAbsFilePath  = QDir::toNativeSeparators(fi.absoluteFilePath()).replace("\\", "\\\\");
 		QString escapedFileName = QDir::toNativeSeparators(fileName).replace("\\", "\\\\");
 		// FIXME: If filename contains chars outside 7bit ascii, might be problems
 		PyObject* globals = PyModule_GetDict(m);
 		// Build the Python code to run the script
 		//QString cm = QString("from __future__ import division\n"); removed due #5252 PV
 		QString cm = QString("import sys\n");
-		cm        += QString("import cStringIO\n");
+		cm        += QString("import io\n");
 		/* Implementation of the help() in pydoc.py reads some OS variables
 		 * for output settings. I use ugly hack to stop freezing calling help()
 		 * in script. pv. */
@@ -302,7 +301,9 @@ void ScripterCore::slotRunScriptFile(const QString& fileName, QStringList argume
 		cm        += QString("sys.path[0] = \"%1\"\n").arg(escapedAbsPath);
 		// Replace sys.stdin with a dummy StringIO that always returns
 		// "" for read
-		cm        += QString("sys.stdin = cStringIO.StringIO()\n");
+		cm        += QString("sys.stdin = io.StringIO()\n");
+		// Provide script path to the interpreter
+		cm        += QString("__file__ = \"%1\"\n").arg(escapedAbsFilePath);
 		// tell the script if it's running in the main intepreter or a subinterpreter
 		cm        += QString("import scribus\n");
 		if (inMainInterpreter)
@@ -310,7 +311,7 @@ void ScripterCore::slotRunScriptFile(const QString& fileName, QStringList argume
 		else
 			cm+= QString("scribus.mainInterpreter = False\n");
 		cm        += QString("try:\n");
-		cm        += QString("    execfile(\"%1\")\n").arg(escapedFileName);
+		cm        += QString("    exec(open(\"%1\", \"rb\").read())\n").arg(escapedFileName);
 		cm        += QString("except SystemExit:\n");
 		cm        += QString("    pass\n");
 		// Capture the text of any other exception that's raised by the interpreter
@@ -344,7 +345,7 @@ void ScripterCore::slotRunScriptFile(const QString& fileName, QStringList argume
 			}
 			else if (ScCore->usingGUI())
 			{
-				QString errorMsg = PyString_AsString(errorMsgPyStr);
+				QString errorMsg = PyUnicode_asQString(errorMsgPyStr);
 				// Display a dialog to the user with the exception
 				QClipboard *cp = QApplication::clipboard();
 				cp->setText(errorMsg);
@@ -394,7 +395,7 @@ void ScripterCore::slotRunScript(const QString& Script)
 	disableMainWindowMenu();
 
 	ScCore->primaryMainWindow()->propertiesPalette->unsetDoc();
-	ScCore->primaryMainWindow()->textPalette->unsetDoc();
+	ScCore->primaryMainWindow()->contentPalette->unsetDoc();
 	ScCore->primaryMainWindow()->pagePalette->setView(nullptr);
 	ScCore->primaryMainWindow()->setScriptRunning(true);
 	inValue = Script;
@@ -402,7 +403,7 @@ void ScripterCore::slotRunScript(const QString& Script)
 	cm = "# -*- coding: utf8 -*- \n";
 	if (PyThreadState_Get() != nullptr)
 	{
-		initscribus(ScCore->primaryMainWindow());
+		//initscribus(ScCore->primaryMainWindow());
 		/* HACK: following loop handles all input line by line.
 		It *should* use I.C. because of docstrings etc. I.I. cannot
 		handle docstrings right.
@@ -411,21 +412,21 @@ void ScripterCore::slotRunScript(const QString& Script)
 		works fine in plain Python. Not here. WTF? */
 		cm += (
 				"try:\n"
-				"    import cStringIO\n"
-				"    scribus._bu = cStringIO.StringIO()\n"
+				"    import io\n"
+				"    scribus._bu = io.StringIO()\n"
 				"    sys.stdout = scribus._bu\n"
 				"    sys.stderr = scribus._bu\n"
 				"    sys.argv = ['scribus']\n" // this is the PySys_SetArgv replacement
 				"    scribus.mainInterpreter = True\n" // the scripter console runs everything in the main interpreter
-				"    for i in scribus.getval().splitlines():\n"
-				"        scribus._ia.push(i)\n"
+				"    for scribus._i_str in scribus.getval().splitlines():\n"
+				"        scribus._ia.push(scribus._i_str)\n"
 				"    scribus.retval(scribus._bu.getvalue())\n"
 				"    sys.stdout = sys.__stdout__\n"
 				"    sys.stderr = sys.__stderr__\n"
 				"except SystemExit:\n"
-				"    print 'Catched SystemExit - it is not good for Scribus'\n"
+				"    print ('Catched SystemExit - it is not good for Scribus')\n"
 				"except KeyboardInterrupt:\n"
-				"    print 'Catched KeyboardInterrupt - it is not good for Scribus'\n"
+				"    print ('Catched KeyboardInterrupt - it is not good for Scribus')\n"
 			  );
 	}
 	// Set up sys.argv
@@ -544,7 +545,7 @@ void ScripterCore::aboutScript()
 		return;
 	QTextStream intputstream(&input);
 	QString content = intputstream.readAll();
-	QString docstring = content.section("\"\"\"", 1, 1);
+	QString docstring = content.section(R"(""")", 1, 1);
 	if (!docstring.isEmpty())
 	{
 		html += QString("<h1>%1 %2</h1>").arg( tr("Documentation for:"), fi.fileName());
@@ -552,7 +553,7 @@ void ScripterCore::aboutScript()
 	}
 	else
 	{
-		html += QString("<p><b>%1 %2 %3</b></p>").arg( tr("Script")).arg(fi.fileName(), tr(" doesn't contain any docstring!"));
+		html += QString("<p><b>%1 %2 %3</b></p>").arg( tr("Script"), fi.fileName(), tr(" doesn't contain any docstring!"));
 		html += QString("<pre>%4</pre>").arg(content);
 	}
 	html += "</body></html>";
@@ -602,8 +603,8 @@ bool ScripterCore::setupMainInterpreter()
 		"import sys\n"
 		"import code\n"
 		"sys.path.insert(0, \"%1\")\n"
-		"import cStringIO\n"
-		"sys.stdin = cStringIO.StringIO()\n"
+		"import io\n"
+		"sys.stdin = io.StringIO()\n"
 		"scribus._ia = code.InteractiveConsole(globals())\n"
 		).arg(ScPaths::instance().scriptDir());
 	if (m_importAllNames)
