@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """ This is a simple 'Calendar creation wizard' for Scribus. It's a fully
-rewritten Calender.py from Scribus examples. Enjoy.
+rewritten Calendar.py from Scribus examples. Enjoy.
 
 DESCRIPTION & USAGE:
 This script needs Tkinter. It will create a GUI with available options
@@ -54,16 +54,16 @@ import datetime
 try:
     from scribus import *
 except ImportError:
-    print "This Python script is written for the Scribus scripting interface."
-    print "It can only be run from within Scribus."
+    print ("This Python script is written for the Scribus scripting interface.")
+    print ("It can only be run from within Scribus.")
     sys.exit(1)
 
 try:
     # I wish PyQt installed everywhere :-/
-    from Tkinter import *
-    from tkFont import Font
+    from tkinter import *
+    from tkinter import font
 except ImportError:
-    print "This script requires Python's Tkinter properly installed."
+    print ("This script requires Python's Tkinter properly installed.")
     messageBox('Script failed',
                'This script requires Python\'s Tkinter properly installed.',
                ICON_CRITICAL)
@@ -261,7 +261,8 @@ class ScCalendar:
         if not newDocDialog():
             return 'Create a new document first, please'
         createParagraphStyle(name=self.pStyleDate, alignment=ALIGN_RIGHT)
-        createParagraphStyle(name=self.pStyleWeekday, alignment=ALIGN_RIGHT)
+        createParagraphStyle(name=self.pStyleWeekday, alignment=ALIGN_CENTERED)
+#        createParagraphStyle(name=self.pStyleWeekday, alignment=ALIGN_RIGHT) # original alignment
         createParagraphStyle(name=self.pStyleMonth)
         createParagraphStyle(name=self.pStyleWeekNo, alignment=ALIGN_RIGHT)
         originalUnit = getUnit()
@@ -306,14 +307,14 @@ class ScEventCalendar(ScCalendar):
         ScCalendar.__init__(self, year, months, firstDay, drawSauce, sepMonths, lang)
 
     def printMonth(self, cal, month, week):
-	    """ Print the month name(s) """
-	    if week[6].day < 7:
-		    if (week == cal[len(cal)-1]):
-			    self.createHeader(localization[self.lang][0][month] + self.sepMonths + localization[self.lang][0][(month+1)%12])
-		    elif ((month-1) not in self.months):
-			    self.createHeader(localization[self.lang][0][(month-1)%12] + self.sepMonths + localization[self.lang][0][month])
-	    else:
-		    self.createHeader(localization[self.lang][0][month])
+        """ Print the month name(s) """
+        if week[6].day < 7:
+            if (week == cal[len(cal)-1]):
+                self.createHeader(localization[self.lang][0][month] + self.sepMonths + localization[self.lang][0][(month+1)%12])
+            elif ((month-1) not in self.months):
+                self.createHeader(localization[self.lang][0][(month-1)%12] + self.sepMonths + localization[self.lang][0][month])
+        else:
+            self.createHeader(localization[self.lang][0][month])
 
     def createMonthCalendar(self, month, cal):
         """ Draw one week calendar per page """
@@ -324,12 +325,12 @@ class ScEventCalendar(ScCalendar):
             # * If it starts on the first weekday
             # * If the month before it isn't included
             if (week != cal[0]) or (week[0].day == 1) or ((month-1) not in self.months):
-				self.createLayout()
-				self.printMonth(cal, month, week)
-				self.printWeekNo(week)
+                self.createLayout()
+                self.printMonth(cal, month, week)
+                self.printWeekNo(week)
 
-				for day in week:
-				    self.printDay(day)
+                for day in week:
+                    self.printDay(day)
 
 class ScHorizontalEventCalendar(ScEventCalendar):
     """ One day = one row calendar. I suggest LANDSCAPE orientation.\
@@ -390,7 +391,7 @@ class ScVerticalCalendar(ScCalendar):
         """ Compute base metrics here. Page layout is bordered by margins and
         virtually divided by golden mean 'cut' in the bottom. The calendar is
         in the bottom part - top is occupied with empty image frame. """
-        # golden mean
+        # gloden mean
         ScCalendar.setupDocVariables(self)
         self.gmean = self.height - self.goldenMean(self.height) + self.margint
         # calendar size
@@ -444,10 +445,11 @@ class ScClassicCalendar(ScVerticalCalendar):
                 cel = createText(self.marginl + colCnt * self.colSize,
                                  self.calHeight + rowCnt * self.rowSize,
                                  self.colSize, self.rowSize)
+                setLineColor("Black", cel)  # comment this out if you do not want border to cells
                 colCnt += 1
                 if day.month == month + 1:
-					setText(str(day.day), cel)
-					setStyle(self.pStyleDate, cel)
+                    setText(str(day.day), cel)
+                    setStyle(self.pStyleDate, cel)
             rowCnt += 1
 
 class ScVerticalEventCalendar(ScVerticalCalendar, ScEventCalendar):
@@ -505,7 +507,7 @@ class TkCalendar(Frame):
         self.langScrollbar.config(command=self.langListbox.yview)
 
         keys = localization.keys()
-        keys.sort()
+        sorted(keys)
         for i in keys:
             self.langListbox.insert(END, i)
         self.langButton = Button(self, text='Change language', command=self.languageChange)
