@@ -52,7 +52,7 @@ ScPlugin* scribusshortwords_getPlugin()
 
 void scribusshortwords_freePlugin(ScPlugin* plugin)
 {
-	ShortWordsPlugin* plug = dynamic_cast<ShortWordsPlugin*>(plugin);
+	ShortWordsPlugin* plug = qobject_cast<ShortWordsPlugin*>(plugin);
 	Q_ASSERT(plug);
 	delete plug;
 }
@@ -64,7 +64,7 @@ ShortWordsPlugin::ShortWordsPlugin()
 	languageChange();
 }
 
-ShortWordsPlugin::~ShortWordsPlugin() {};
+ShortWordsPlugin::~ShortWordsPlugin() = default;
 
 void ShortWordsPlugin::languageChange()
 {
@@ -81,7 +81,7 @@ void ShortWordsPlugin::languageChange()
 	m_actionInfo.needsNumObjects = -1;
 }
 
-const QString ShortWordsPlugin::fullTrName() const
+QString ShortWordsPlugin::fullTrName() const
 {
 	return QObject::tr("Short Words");
 }
@@ -114,7 +114,7 @@ void ShortWordsPlugin::deleteAboutData(const AboutData* about) const
 
 bool ShortWordsPlugin::run(ScribusDoc* doc, const QString& target)
 {
-	if (doc==nullptr)
+	if (doc == nullptr)
 		return false;
 	Q_ASSERT(target.isEmpty());
 
@@ -126,7 +126,7 @@ bool ShortWordsPlugin::run(ScribusDoc* doc, const QString& target)
 		if (!dlg->useStyleLang())
 			parse->lang = dlg->lang();
 		else
-			parse->lang = ""; // get it from style
+			parse->lang.clear(); // get it from style
 
 		doc->scMW()->setStatusBarInfoText(QObject::tr("Short Words processing. Wait please...", "short words plugin"));
 		switch (dlg->actionSelected())
@@ -157,11 +157,9 @@ bool ShortWordsPlugin::run(ScribusDoc* doc, const QString& target)
 	return true;
 }
 
-bool ShortWordsPlugin::newPrefsPanelWidget(QWidget* parent, Prefs_Pane*& panel, QString& caption, QPixmap& icon)
+bool ShortWordsPlugin::newPrefsPanelWidget(QWidget* parent, Prefs_Pane*& panel)
 {
 	panel = new Prefs_ShortWords(parent);
 	Q_CHECK_PTR(panel);
-	caption = tr("Short Words");
-	icon = IconManager::instance().loadPixmap("shortwords_16.png");
 	return true;
 }
