@@ -27,15 +27,14 @@ class PLUGIN_API ShortWordsPlugin : public ScActionPlugin
 		// Standard plugin implementation
 		ShortWordsPlugin();
 		virtual ~ShortWordsPlugin();
-		virtual bool run(ScribusDoc* doc, const QString& target = QString());
-		virtual const QString fullTrName() const;
-		virtual const AboutData* getAboutData() const;
-		virtual void deleteAboutData(const AboutData* about) const;
-		virtual void languageChange();
-		virtual void addToMainWindowMenu(ScribusMainWindow *) {};
+		bool run(ScribusDoc* doc, const QString& target = QString()) override;
+		QString fullTrName() const override;
+		const AboutData* getAboutData() const override;
+		void deleteAboutData(const AboutData* about) const override;
+		void languageChange() override;
+		void addToMainWindowMenu(ScribusMainWindow *) override {};
 		/*! \brief Preference widget */
-		virtual bool newPrefsPanelWidget(QWidget* parent, Prefs_Pane*& panel,
-										 QString& caption, QPixmap& icon);
+		bool newPrefsPanelWidget(QWidget* parent, Prefs_Pane*& panel) override;
 		// Special features (none)
 };
 
