@@ -22,11 +22,11 @@ class PLUGIN_API PathFinderDialog : public QDialog, Ui::PathFinderBase
 
 public:
 	PathFinderDialog(QWidget* parent, ScribusDoc* doc, PageItem *shape1, PageItem *shape2);
-	~PathFinderDialog() {};
+	~PathFinderDialog() = default;
 	void updatePreview(QLabel *label, QPainterPath &path, const QColor& color, double scale);
 	void updatePartPreview(const QColor& color, double scale);
-	const QString getOtherFillColor();
-	const QString getOtherLineColor();
+	QString getOtherFillColor();
+	QString getOtherLineColor();
 
 	bool keepItem1;
 	bool keepItem2;
