@@ -120,8 +120,6 @@ public:
 	\param ho a file name to write
 	\retval bool true on success, false on write error */
 	bool ReadPref(const QString& ho);
-	//! \brief Set up the main window with prefs values, recent files list, main window size etc
-	void setupMainWindow(ScribusMainWindow* mw);
 	void setGhostscriptExecutable(const QString&);
 	void setImageEditorExecutable(const QString&);
 	void setExtBrowserExecutable(const QString&);
@@ -139,7 +137,7 @@ public:
 	QString latexEditorExecutable() const {return appPrefs.extToolPrefs.latexEditorExecutable;}
 	bool latexStartWithEmptyFrames() const {return appPrefs.extToolPrefs.latexStartWithEmptyFrames;}
 	//! \brief Get the users preferred preview resolution
-	int gsResolution();
+	int gsResolution() const {return appPrefs.extToolPrefs.gs_Resolution;}
 	int latexResolution() const {return appPrefs.extToolPrefs.latexResolution;}
 	bool latexForceDpi() const {return appPrefs.extToolPrefs.latexForceDpi;}
 	//! \brief Get the users preferred document directory
@@ -153,6 +151,8 @@ public:
 	//! \brief Get the GUI style from preferences
 	const QString& guiStyle() const;
 	const QString& guiSystemStyle() const;
+	//! \brief Get the GUI icon set from preferences
+	const QString& guiIconSet() const;
 	//! \brief Get the GUI style from preferences
 	const int& guiFontSize() const;
 	const int& paletteFontSize() const;
@@ -201,7 +201,8 @@ public:
 
 	//! \brief Temporarily public while this class takes shape so progress can happen and cvs can build
 	struct ApplicationPrefs appPrefs;
-	PrefsFile* prefsFile;
+	PrefsFile* prefsFile {nullptr};
+	bool firstTimeIgnoreOldPrefs() const;
 
 public slots:
 	void languageChange();
@@ -211,8 +212,8 @@ private:
 	~PrefsManager();
 
 	QString m_prefsLocation;
-	bool m_importingFrom12;
-	bool m_firstTimeIgnoreOldPrefs;
+	bool m_importingFrom12 {false};
+	bool m_firstTimeIgnoreOldPrefs {false};
 
 	/*! \brief The last error message generated by a method of this class.
 	Do not write "success" messages to this. */
