@@ -92,23 +92,14 @@ struct TypoPrefs
 
 struct WindowPrefs
 {
-	WindowPrefs() {
-		xPosition = 0;
-		yPosition = 0;
-		width   = 640;
-		height  = 480;
-		visible = true;
-		docked  = false;
-		maximized = false;
-	}
-
-	int xPosition;
-	int yPosition;
-	int width;
-	int height;
-	bool visible;
-	bool docked;
-	bool maximized;
+	int xPosition {0};
+	int yPosition {0};
+	int width {640};
+	int height {480};
+	bool visible {true};
+	bool docked {false};
+	bool maximized {false};
+	int screenNumber {0};
 };
 
 struct tabPrefs
@@ -120,34 +111,21 @@ struct tabPrefs
 //User Interface
 struct UIPrefs
 {
-	UIPrefs() {
-		mouseMoveTimeout = 150;
-		wheelJump = 40;
-		applicationFontSize = 12;
-		paletteFontSize = 10;
-		recentDocCount = 5;
-		useSmallWidgets = false;
-		useTabs = false;
-		showStartupDialog = true;
-		showSplashOnStartup = true;
-		stickyTools = false;
-		grayscaleIcons = false;
-	}
-
-	int mouseMoveTimeout; //! Mouse move timeout for move/resize operations
-	int wheelJump; //! Distance to jump with mouse wheel scrolling
-	int applicationFontSize; //! Font size to use in the application, apart from pßalettes
-	int paletteFontSize; //! Font size to use in the palettes
+	int mouseMoveTimeout {150}; //! Mouse move timeout for move/resize operations
+	int wheelJump {40}; //! Distance to jump with mouse wheel scrolling
+	int applicationFontSize {12}; //! Font size to use in the application, apart from pßalettes
+	int paletteFontSize {10}; //! Font size to use in the palettes
 	QString style; 	//! Currently used QStyle name
-	int recentDocCount; //! Number of recent documents to remember
+	int recentDocCount {5}; //! Number of recent documents to remember
 	QStringList RecentDocs; //! List of recent documents
 	QString language; //! Language of the user interface
-	bool useSmallWidgets; //! Use small widgets in the palettes
-	bool useTabs;		 //! Use a tabbed MainWidget a la FireFox 
-	bool showStartupDialog; //! Whether to show the startup dialog or not
-	bool showSplashOnStartup; //! Whether to show the splashscreen or not
-	bool stickyTools; //! Whether a user's tool section remains after use or the normal tool is reselected
-	bool grayscaleIcons; //! Show icons in toolbars as grayscale
+	QString userPreferredLocale; //! System or interface language number formats
+	bool useSmallWidgets {false}; //! Use small widgets in the palettes
+	bool useTabs {false}; //! Use a tabbed MainWidget a la FireFox
+	bool showStartupDialog {true}; //! Whether to show the startup dialog or not
+	bool showSplashOnStartup {true}; //! Whether to show the splashscreen or not
+	bool stickyTools {false}; //! Whether a user's tool section remains after use or the normal tool is reselected
+	bool grayscaleIcons {false}; //! Show icons in toolbars as grayscale
 	QString iconSet; //! Icon set name
 	WindowPrefs mainWinSettings;
 	QByteArray mainWinState;
@@ -428,15 +406,42 @@ struct StoryEditorPrefs
 
 struct PrintPreviewPrefs
 {
-	bool PrPr_Mode;
-	bool PrPr_AntiAliasing;
-	bool PrPr_Transparency;
-	bool PrPr_C;
-	bool PrPr_M;
-	bool PrPr_Y;
-	bool PrPr_K;
-	bool PrPr_InkCoverage;
-	int PrPr_InkThreshold;
+	bool PrPr_Mode { false };
+	bool PrPr_AntiAliasing { true };
+	bool PrPr_Transparency { false };
+	bool PrPr_C { true };
+	bool PrPr_M { true };
+	bool PrPr_Y { true };
+	bool PrPr_K { true };
+	bool PrPr_InkCoverage { false };
+	int PrPr_InkThreshold { 250 };
+};
+
+struct PDFOutputPreviewPrefs
+{
+	bool enableAntiAliasing { true };
+	bool showTransparency { false };
+	bool cmykPreviewMode { false };
+	bool isCyanVisible { true };
+	bool isMagentaVisible { true };
+	bool isYellowVisible { true };
+	bool isBlackVisible { true };
+	bool displayInkCoverage { false };
+	int  inkCoverageThreshold { 250 };
+};
+
+struct PSOutputPreviewPrefs
+{
+	int  psLevel { 3 };
+	bool enableAntiAliasing { true };
+	bool showTransparency { false };
+	bool cmykPreviewMode { false };
+	bool isCyanVisible { true };
+	bool isMagentaVisible { true };
+	bool isYellowVisible { true };
+	bool isBlackVisible { true };
+	bool displayInkCoverage { false };
+	int  inkCoverageThreshold { 250 };
 };
 
 struct PluginPrefs
@@ -478,8 +483,10 @@ struct ApplicationPrefs
 	PDFOptions pdfPrefs;
 	PathPrefs pathPrefs;
 	PluginPrefs pluginPrefs;
-	PrintPreviewPrefs printPreviewPrefs;
 	PrinterPrefs printerPrefs;
+	PrintPreviewPrefs printPreviewPrefs;
+	PDFOutputPreviewPrefs pdfOutputPreviewPrefs;
+	PSOutputPreviewPrefs  psOutputPreviewPrefs;
 	ScrapbookPrefs scrapbookPrefs;
 	ScripterPrefs scripterPrefs;
 	ShortWordPrefs shortwordPrefs;
@@ -495,12 +502,9 @@ struct ApplicationPrefs
 	QList<PageSet> pageSets;
 	QStringList activePageSizes;
 
-
-
 	//TODO : Remove these no longer used items
 	//! System default QStyle name for current instance, seemingly unused
 	QString ui_SystemTheme;
-	//	bool Gcr_Mode;
 
 	//Added for Doc Only
 	DocumentInformation docInfo;
