@@ -26,6 +26,11 @@ for which a new license (GPL+exception) is in place.
 #include <QMap>
 #include <QRegExp>
 #include <QRawFont>
+#ifdef Q_OS_WIN32
+#include <QSet>
+#include <QSettings>
+#include <QStandardPaths>
+#endif
 #include <QString>
 #include <QTextCodec>
 
@@ -77,7 +82,7 @@ for which a new license (GPL+exception) is in place.
 SCFonts::SCFonts()
 {
 //	insert("", ScFace::none()); // Wtf why inserting an empty entry here ????
-	m_showFontInfo=false;
+	m_showFontInfo = false;
 	m_checkedFonts.clear();
 }
 
@@ -120,7 +125,7 @@ void SCFonts::addPath(QString p)
 	if (p.right(1) != "/")
 		p += "/";
 	if (!m_fontPaths.contains(p))
-		m_fontPaths.insert(m_fontPaths.count(),p);
+		m_fontPaths.insert(m_fontPaths.count(), p);
 }
 
 void SCFonts::addScalableFonts(const QString &path, const QString& DocName)
@@ -137,17 +142,17 @@ void SCFonts::addScalableFonts(const QString &path, const QString& DocName)
 	QString pathname(path);
 	if ( !pathname.endsWith("/") )
 		pathname += "/";
-	pathname=QDir::toNativeSeparators(pathname);
+	pathname = QDir::toNativeSeparators(pathname);
 	QDir d(pathname, "*", QDir::Name, QDir::Dirs | QDir::Files | QDir::Readable);
 	if ((d.exists()) && (d.count() != 0))
 	{
-		for (uint dc = 0; dc < d.count(); ++dc)
+		for (uint i = 0; i < d.count(); ++i)
 		{
 			// readdir may return . or .., which we don't want to recurse
 			// over. Skip 'em.
-			if (d[dc] == "." || d[dc] == "..")
+			if (d[i] == "." || d[i] == "..")
 				continue;
-			fullpath = pathname+d[dc];
+			fullpath = pathname + d[i];
 			QFileInfo fi(fullpath);
 			if (!fi.exists())      // Sanity check for broken Symlinks
 				continue;
@@ -157,9 +162,9 @@ void SCFonts::addScalableFonts(const QString &path, const QString& DocName)
 			bool symlink = fi.isSymLink();
 			if (symlink)
 			{
-				QFileInfo fi3(fi.readLink());
+				QFileInfo fi3(fi.symLinkTarget());
 				if (fi3.isRelative())
-					pathfile = pathname+fi.readLink();
+					pathfile = pathname + fi.symLinkTarget();
 				else
 					pathfile = fi3.absoluteFilePath();
 			}
@@ -580,11 +585,11 @@ ScFace SCFonts::loadScalableFont(const QString &filename)
 		switch (format)
 		{
 			case ScFace::PFA:
-				t = ScFace(new ScFace_pfa(fam, sty, "", ts, qpsName, filename, faceIndex, features));
+				t = ScFace(new ScFace_PFA(fam, sty, "", ts, qpsName, filename, faceIndex, features));
 				t.subset(Subset);
 				break;
 			case ScFace::PFB:
-				t = ScFace(new ScFace_pfb(fam, sty, "", ts, qpsName, filename, faceIndex, features));
+				t = ScFace(new ScFace_PFB(fam, sty, "", ts, qpsName, filename, faceIndex, features));
 				t.subset(Subset);
 				break;
 			case ScFace::SFNT:
@@ -592,10 +597,7 @@ ScFace SCFonts::loadScalableFont(const QString &filename)
 			case ScFace::TYPE42:
 				t = ScFace(new ScFace_ttf(fam, sty, "", ts, qpsName, filename, faceIndex, features));
 				getSFontType(face, t.m_m->typeCode);
-				if (t.type() == ScFace::OTF)
-					t.subset(true);
-				else
-					t.subset(Subset);
+				t.subset(Subset);
 				break;
 			default:
 				/* catching any types not handled above to silence compiler */
@@ -825,44 +827,29 @@ bool SCFonts::addScalableFont(const QString& filename, FT_Library &library, cons
 			switch (format) 
 			{
 				case ScFace::PFA:
-					t = ScFace(new ScFace_pfa(fam, sty, "", ts, qpsName, filename, faceIndex, features));
+					t = ScFace(new ScFace_PFA(fam, sty, "", ts, qpsName, filename, faceIndex, features));
 					t.subset(Subset);
 					break;
 				case ScFace::PFB:
-					t = ScFace(new ScFace_pfb(fam, sty, "", ts, qpsName, filename, faceIndex, features));
+					t = ScFace(new ScFace_PFB(fam, sty, "", ts, qpsName, filename, faceIndex, features));
 					t.subset(Subset);
 					break;
 				case ScFace::SFNT:
 					t = ScFace(new ScFace_ttf(fam, sty, "", ts, qpsName, filename, faceIndex, features));
 					getSFontType(face, t.m_m->typeCode);
-					if (t.type() == ScFace::OTF) 
-					{
-						t.subset(true);
-					}
-					else
-						t.subset(Subset);
+					t.subset(Subset);
 					break;
 				case ScFace::TTCF:
 					t = ScFace(new ScFace_ttf(fam, sty, "", ts, qpsName, filename, faceIndex, features));
 					t.m_m->formatCode = ScFace::TTCF;
 					t.m_m->typeCode = ScFace::TTF;
 					getSFontType(face, t.m_m->typeCode);
-					if (t.type() == ScFace::OTF) 
-					{
-						t.subset(true);
-					}
-					else
-						t.subset(Subset);
+					t.subset(Subset);
 					break;
 				case ScFace::TYPE42:
 					t = ScFace(new ScFace_ttf(fam, sty, "", ts, qpsName, filename, faceIndex, features));
 					getSFontType(face, t.m_m->typeCode);
-					if (t.type() == ScFace::OTF) 
-					{
-						t.subset(true);
-					}
-					else
-						t.subset(Subset);
+					t.subset(Subset);
 					break;
 				default:
 				/* catching any types not handled above to silence compiler */
@@ -878,7 +865,7 @@ bool SCFonts::addScalableFont(const QString& filename, FT_Library &library, cons
 			t.m_m->forDocument = DocName;
 			//setBestEncoding(face); //AV
 			if (m_showFontInfo)
-				sDebug(QObject::tr("Font %1 loaded from %2(%3)").arg(t.psName()).arg(filename).arg(faceIndex+1));
+				sDebug(QObject::tr("Font %1 loaded from %2(%3)").arg(t.psName(), filename).arg(faceIndex+1));
 
 /*
 //debug
@@ -1039,71 +1026,152 @@ void SCFonts::addFontconfigFonts()
 	FcFontSetDestroy(fs);
 }
 
-#elif defined(Q_OS_LINUX)
+#elif defined(Q_OS_WIN32)
 
-void SCFonts::addXFontPath()
+void SCFonts::addRegistryFonts()
 {
-	int pathcount,i;
-	Display *display=XOpenDisplay(nullptr);
-	char **fontpath=XGetFontPath(display,&pathcount);
-	for (i=0; i<pathcount; ++i)
-		addPath(fontpath[i]);
-	XFreeFontPath(fontpath);
-}
+	const QStringList keys = { QStringLiteral("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Fonts"),
+		                       QStringLiteral("HKEY_CURRENT_USER\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Fonts"),
+#if defined(Q_OS_WIN64)
+	                           QStringLiteral("HKEY_CURRENT_USER\\SOFTWARE\\WOW6432Node\\Microsoft\\Windows NT\\CurrentVersion\\Fonts"),
+		                       QStringLiteral("HKEY_LOCAL_MACHINE\\SOFTWARE\\WOW6432Node\\Microsoft\\Windows NT\\CurrentVersion\\Fonts"),
+#endif
+	                         };
+	QSet<QString> foundFonts;
 
-/* replacement for addXFontServerPath() for correctly parsing
- * RedHad-Style /etc/X11/fs/config files */
+	FT_Library library = nullptr;
+	FT_Init_FreeType( &library );
 
-void SCFonts::addXFontServerPath()
-{
-	QFile fs("/etc/X11/fs/config");
-	if (!(fs.exists()))
+	for (const auto key : keys)
 	{
-		fs.setName("/usr/X11R6/lib/X11/fs/config");
-		if (!(fs.exists()))
+		const QSettings fontRegistry(key, QSettings::NativeFormat);
+		const QStringList allKeys = fontRegistry.allKeys();
+
+		int size = allKeys.size();
+		for (int i = 0; i < size; ++i)
 		{
-			fs.setName("/usr/X11/lib/X11/fs/config");
-			if (!(fs.exists()))
-				return;
+			const QString &fontKey = allKeys.at(i);
+			const QString fileName = fontRegistry.value(fontKey).toString();
+
+			QFileInfo fontInfo(fileName);
+			if (fontInfo.isRelative())
+				continue; // Font located in system font directory, nothing to do
+			if (!fontInfo.exists())
+				continue; // Sanity check for broken Symlinks
+			QString fontPath = fontInfo.absoluteFilePath();
+			QString pathName = fontInfo.absolutePath();
+
+			qApp->processEvents();
+			
+			bool isSymlink = fontInfo.isSymLink();
+			if (isSymlink)
+			{
+				QFileInfo symlinkInfo(fontInfo.symLinkTarget());
+				if (symlinkInfo.isRelative())
+					fontPath = pathName + fontInfo.symLinkTarget();
+				else
+					fontPath = symlinkInfo.absoluteFilePath();
+			}
+
+			fontPath = QDir::toNativeSeparators(fontPath);
+			if (foundFonts.contains(fontPath))
+				continue;
+
+			QFileInfo fontInfo2(fontPath);
+			QString ext = fontInfo.suffix().toLower();
+			QString ext2 = fontInfo2.suffix().toLower();
+			if ((ext != ext2) && (ext.isEmpty())) 
+				ext = ext2;
+			if ((ext == "ttc") || (ext == "dfont") || (ext == "pfa") || (ext == "pfb") || (ext == "ttf") || (ext == "otf"))
+			{
+				foundFonts.insert(fontPath);
+				addScalableFont(fontPath, library, QString());
+			}
 		}
 	}
 
-	if (fs.open(QIODevice::ReadOnly))
-	{
-		QString fsconfig,paths,tmp;
-		QTextStream tsx(&fs);
-		fsconfig = tsx.readAll();
-		fs.close();
-
-		int pos = fsconfig.find("catalogue");
-		paths = fsconfig.mid(pos);
-		paths = paths.mid(paths.find("=")+1);
-
-		pos=0;
-		do {
-			pos = paths.find("\n",pos+1);
-		} while (pos > -1 && paths.mid(pos-1, 1) == ",");
-
-		if (pos<0) pos=paths.length();
-		paths = paths.left(pos);
-		paths = paths.simplified();
-		paths.replace(QRegExp(" "), "");
-		paths.replace(QRegExp(","), "\n");
-		paths += "\n";
-		paths = paths.trimmed();
-
-		pos=-1;
-		do {
-			int pos2;
-			pos2 = paths.find("\n",pos+1);
-			tmp = paths.mid(pos+1,(pos2-pos)-1);
-			pos=pos2;
-
-			addPath(tmp);
-
-		} while (pos > -1);
-	}
+	FT_Done_FreeType(library);
 }
+
+void SCFonts::addType1RegistryFonts()
+{
+	const QStringList keys = { QStringLiteral("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Type 1 Installer\\Type 1 Fonts"),
+		                       QStringLiteral("HKEY_CURRENT_USER\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Type 1 Installer\\Type 1 Fonts"),
+#if defined(Q_OS_WIN64)
+	                           QStringLiteral("HKEY_CURRENT_USER\\SOFTWARE\\WOW6432Node\\Microsoft\\Windows NT\\CurrentVersion\\Type 1 Installer\\Type 1 Fonts"),
+		                       QStringLiteral("HKEY_LOCAL_MACHINE\\SOFTWARE\\WOW6432Node\\Microsoft\\Windows NT\\CurrentVersion\\Type 1 Installer\\Type 1 Fonts"),
+#endif
+	                         };
+	QSet<QString> foundFonts;
+
+	FT_Library library = nullptr;
+	FT_Init_FreeType( &library );
+
+	for (const auto key : keys)
+	{
+		const QSettings fontRegistry(key, QSettings::NativeFormat);
+		const QStringList allKeys = fontRegistry.allKeys();
+
+		int size = allKeys.size();
+		for (int i = 0; i < size; ++i)
+		{
+			const QString &fontKey = allKeys.at(i);
+			const QStringList fileNames = fontRegistry.value(fontKey).toStringList();
+			if (fileNames.size() <= 0)
+				continue;
+			if (fileNames.at(0) != "T")
+				continue;
+
+			for (int j = 1; j < fileNames.count(); ++j)
+			{
+				QString fileName = fileNames.at(j);
+
+				QFileInfo fontInfo(fileName);
+				if (fontInfo.isRelative())
+					continue; // Font located in system font directory, nothing to do
+				if (!fontInfo.exists())
+					continue; // Sanity check for broken Symlinks
+
+				QString ext = fontInfo.suffix().toLower();
+				if ((ext != "pfa") && (ext != "pfb"))
+					continue;
+
+				QString fontPath = fontInfo.absoluteFilePath();
+				QString pathName = fontInfo.absolutePath();
+
+				qApp->processEvents();
+			
+				bool isSymlink = fontInfo.isSymLink();
+				if (isSymlink)
+				{
+					QFileInfo symlinkInfo(fontInfo.symLinkTarget());
+					if (symlinkInfo.isRelative())
+						fontPath = pathName + fontInfo.symLinkTarget();
+					else
+						fontPath = symlinkInfo.absoluteFilePath();
+				}
+
+				fontPath = QDir::toNativeSeparators(fontPath);
+				if (foundFonts.contains(fontPath))
+					continue;
+
+				QFileInfo fontInfo2(fontPath);
+				QString ext2 = fontInfo2.suffix().toLower();
+				if ((ext != ext2) && (ext.isEmpty())) 
+					ext = ext2;
+				if ((ext == "pfa") || (ext == "pfb"))
+				{
+					foundFonts.insert(fontPath);
+					addScalableFont(fontPath, library, QString());
+					break;
+				}
+			}
+		}
+	}
+
+	FT_Done_FreeType(library);
+}
+
 #endif
 
 /* Add an extra path to our font search path,
@@ -1207,17 +1275,27 @@ void SCFonts::getFonts(const QString& pf, bool showFontInfo)
 	readFontCache(pf);
 	ScCore->setSplashStatus( QObject::tr("Searching for Fonts") );
 	addUserPath(pf);
+
 	// Search the system paths
 	QStringList ftDirs = ScPaths::systemFontDirs();
 	for (int i = 0; i < ftDirs.count(); i++)
 		addScalableFonts( ftDirs[i] );
+
+#ifdef Q_OS_WIN32
+	// Search fonts outside system paths using Windows Registry
+	addRegistryFonts();
+	addType1RegistryFonts();
+#endif
+
 	// Search Scribus font path
 	if (!ScPaths::instance().fontDir().isEmpty() && QDir(ScPaths::instance().fontDir()).exists())
 		addScalableFonts( ScPaths::instance().fontDir() );
+
 	//Add downloaded user fonts
 	QString userFontDir(ScPaths::instance().userFontDir(false));
 	if (QDir(userFontDir).exists())
 		addScalableFonts( userFontDir );
+
 // if fontconfig is there, it does all the work
 #if HAVE_FONTCONFIG
 	// Search fontconfig paths
@@ -1226,12 +1304,7 @@ void SCFonts::getFonts(const QString& pf, bool showFontInfo)
 		addScalableFonts(*fpi);
 	addFontconfigFonts();
 #else
-// on X11 look there:
-#ifdef Q_OS_LINUX
-	addXFontPath();
-	addXFontServerPath();
-#endif
-// add user and X11 fonts:
+	// add user and X11 fonts:
 	QStringList::iterator fpi, fpend = m_fontPaths.end();
 	for (fpi = m_fontPaths.begin() ; fpi != fpend; ++fpi) 
 		addScalableFonts(*fpi);
@@ -1240,7 +1313,7 @@ void SCFonts::getFonts(const QString& pf, bool showFontInfo)
 	writeFontCache(pf);
 }
 
-void SCFonts::addRejectedFont(QString fontPath, QString message)
+void SCFonts::addRejectedFont(const QString& fontPath, const QString& message)
 {
 	rejectedFonts.insert(fontPath, message);
 }
