@@ -44,10 +44,11 @@ for which a new license (GPL+exception) is in place.
 #include "imagedataloaders/scimgdataloader_ora.h"
 #include "imagedataloaders/scimgdataloader_kra.h"
 #include "imagedataloaders/scimgdataloader_pict.h"
-#include "imagedataloaders/scimgdataloader_ps.h"
-#include "imagedataloaders/scimgdataloader_psd.h"
 #include "imagedataloaders/scimgdataloader_pdf.h"
 #include "imagedataloaders/scimgdataloader_pgf.h"
+#include "imagedataloaders/scimgdataloader_png.h"
+#include "imagedataloaders/scimgdataloader_ps.h"
+#include "imagedataloaders/scimgdataloader_psd.h"
 #include "imagedataloaders/scimgdataloader_qt.h"
 #include "imagedataloaders/scimgdataloader_tiff.h"
 #include "imagedataloaders/scimgdataloader_wpg.h"
@@ -108,12 +109,14 @@ void ScImage::initialize()
 	imgInfo.lowResScale = 1.0;
 	imgInfo.PDSpathData.clear();
 	imgInfo.RequestProps.clear();
-	imgInfo.clipPath = "";
-	imgInfo.usedPath = "";
+	imgInfo.clipPath.clear();
+	imgInfo.usedPath.clear();
+	imgInfo.profileName.clear();
+	imgInfo.embeddedProfileName.clear();
 	imgInfo.layerInfo.clear();
 	imgInfo.duotoneColors.clear();
-	imgInfo.exifInfo.cameraName = "";
-	imgInfo.exifInfo.cameraVendor = "";
+	imgInfo.exifInfo.cameraName.clear();
+	imgInfo.exifInfo.cameraVendor.clear();
 	imgInfo.exifInfo.thumbnail = QImage();
 	imgInfo.BBoxX = 0;
 	imgInfo.BBoxH = 0;
@@ -129,15 +132,16 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		return;
 	ScribusDoc* doc = colors.document();
 
-	for (int a = 0; a < effectsList.count(); ++a)
+	for (int i = 0; i < effectsList.count(); ++i)
 	{
-		if (effectsList.at(a).effectCode == EF_INVERT)
+		const ImageEffect& effect = effectsList.at(i);
+		if (effect.effectCode == ImageEffect::EF_INVERT)
 			invert(cmyk);
-		if (effectsList.at(a).effectCode == EF_GRAYSCALE)
+		if (effect.effectCode == ImageEffect::EF_GRAYSCALE)
 			toGrayscale(cmyk);
-		if (effectsList.at(a).effectCode == EF_COLORIZE)
+		if (effect.effectCode == ImageEffect::EF_COLORIZE)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			QString col = CommonStrings::None;
 			int shading = 100;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
@@ -146,51 +150,51 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 			fp >> shading;
 			colorize(doc, colors[col], shading, cmyk);
 		}
-		if (effectsList.at(a).effectCode == EF_BRIGHTNESS)
+		if (effect.effectCode == ImageEffect::EF_BRIGHTNESS)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			int brightnessValue = 0;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> brightnessValue;
 			brightness(brightnessValue, cmyk);
 		}
-		if (effectsList.at(a).effectCode == EF_CONTRAST)
+		if (effect.effectCode == ImageEffect::EF_CONTRAST)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			int contrastValue = 0;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> contrastValue;
 			contrast(contrastValue, cmyk);
 		}
-		if (effectsList.at(a).effectCode == EF_SHARPEN)
+		if (effect.effectCode == ImageEffect::EF_SHARPEN)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			double radius, sigma;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> radius;
 			fp >> sigma;
 			sharpen(radius, sigma);
 		}
-		if (effectsList.at(a).effectCode == EF_BLUR)
+		if (effect.effectCode == ImageEffect::EF_BLUR)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			double radius, sigma;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> radius;
 			fp >> sigma;
 			blur(static_cast<int>(radius));
 		}
-		if (effectsList.at(a).effectCode == EF_SOLARIZE)
+		if (effect.effectCode == ImageEffect::EF_SOLARIZE)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			double sigma;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> sigma;
 			solarize(sigma, cmyk);
 		}
-		if (effectsList.at(a).effectCode == EF_DUOTONE)
+		if (effect.effectCode == ImageEffect::EF_DUOTONE)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			QString col1 = CommonStrings::None;
 			int shading1 = 100;
 			QString col2 = CommonStrings::None;
@@ -226,9 +230,9 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 			fp >> lin2;
 			duotone(doc, colors[col1], shading1, curve1, lin1, colors[col2], shading2, curve2, lin2, cmyk);
 		}
-		if (effectsList.at(a).effectCode == EF_TRITONE)
+		if (effect.effectCode == ImageEffect::EF_TRITONE)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			QString col1 = CommonStrings::None;
 			QString col2 = CommonStrings::None;
 			QString col3 = CommonStrings::None;
@@ -279,9 +283,9 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 			fp >> lin3;
 			tritone(doc, colors[col1], shading1, curve1, lin1, colors[col2], shading2, curve2, lin2, colors[col3], shading3, curve3, lin3, cmyk);
 		}
-		if (effectsList.at(a).effectCode == EF_QUADTONE)
+		if (effect.effectCode == ImageEffect::EF_QUADTONE)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			QString col1 = CommonStrings::None;
 			QString col2 = CommonStrings::None;
 			QString col3 = CommonStrings::None;
@@ -347,9 +351,9 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 			fp >> lin4;
 			quadtone(doc, colors[col1], shading1, curve1, lin1, colors[col2], shading2, curve2, lin2, colors[col3], shading3, curve3, lin3, colors[col4], shading4, curve4, lin4, cmyk);
 		}
-		if (effectsList.at(a).effectCode == EF_GRADUATE)
+		if (effect.effectCode == ImageEffect::EF_GRADUATE)
 		{
-			QString tmpstr = effectsList.at(a).effectParameters;
+			QString tmpstr = effect.effectParameters;
 			int numVals;
 			double xval, yval;
 			FPointArray curve;
@@ -368,16 +372,7 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 	}
 }
-/*
-void ScImage::liberateMemory(void **memory)
-{
-	assert(memory != (void **)nullptr);
-	if (*memory == (void *)nullptr)
-		return;
-	free(*memory);
-	*memory=(void *) nullptr;
-}
-*/
+
 void ScImage::solarize(double factor, bool cmyk)
 {
 	QVector<int> curveTable(256);
@@ -396,13 +391,13 @@ void ScImage::blur(int radius)
 		return;
 	}
 
-	QRgb *pix = (QRgb*)bits();
+	QRgb *pix = (QRgb*) bits();
 	int w   = width();
 	int h   = height();
-	int wm  = w-1;
-	int hm  = h-1;
-	int wh  = w*h;
-	int div = radius+radius+1;
+	int wm  = w - 1;
+	int hm  = h - 1;
+	int wh  = w * h;
+	int div = radius + radius + 1;
 
 	int *r = new int[wh];
 	int *g = new int[wh];
@@ -410,13 +405,13 @@ void ScImage::blur(int radius)
 	int *a = new int[wh];
 	int rsum, gsum, bsum, asum, x, y, i, yp, yi, yw;
 	QRgb p;
-	int *vmin = new int[qMax(w,h)];
+	int *vmin = new int[qMax(w, h)];
 
-	int divsum = (div+1)>>1;
+	int divsum = (div + 1) >> 1;
 	divsum *= divsum;
 	int *dv = new int[256*divsum];
-	for (i=0; i < 256*divsum; ++i) {
-		dv[i] = (i/divsum);
+	for (i = 0; i < 256 * divsum; ++i) {
+		dv[i] = (i / divsum);
 	}
 
 	yw = yi = 0;
@@ -426,12 +421,11 @@ void ScImage::blur(int radius)
 		stack[i] = new int[4];
 	}
 
-
 	int stackpointer;
 	int stackstart;
 	int *sir;
 	int rbs;
-	int r1 = radius+1;
+	int r1 = radius + 1;
 	int routsum, goutsum, boutsum, aoutsum;
 	int rinsum, ginsum, binsum, ainsum;
 
@@ -442,18 +436,18 @@ void ScImage::blur(int radius)
 			= rsum = gsum = bsum = asum = 0;
 		for (i = -radius; i <= radius; ++i)
 		{
-			p = pix[yi+qMin(wm,qMax(i,0))];
-			sir = stack[i+radius];
+			p = pix[yi + qMin(wm, qMax(i, 0))];
+			sir = stack[i + radius];
 			sir[0] = qRed(p);
 			sir[1] = qGreen(p);
 			sir[2] = qBlue(p);
 			sir[3] = qAlpha(p);
 
-			rbs = r1-abs(i);
-			rsum += sir[0]*rbs;
-			gsum += sir[1]*rbs;
-			bsum += sir[2]*rbs;
-			asum += sir[3]*rbs;
+			rbs = r1 - abs(i);
+			rsum += sir[0] * rbs;
+			gsum += sir[1] * rbs;
+			bsum += sir[2] * rbs;
+			asum += sir[3] * rbs;
 
 			if (i > 0)
 			{
@@ -474,7 +468,6 @@ void ScImage::blur(int radius)
 
 		for (x=0; x < w; ++x)
 		{
-
 			r[yi] = dv[rsum];
 			g[yi] = dv[gsum];
 			b[yi] = dv[bsum];
@@ -485,8 +478,8 @@ void ScImage::blur(int radius)
 			bsum -= boutsum;
 			asum -= aoutsum;
 
-			stackstart = stackpointer-radius+div;
-			sir = stack[stackstart%div];
+			stackstart = stackpointer - radius + div;
+			sir = stack[stackstart % div];
 
 			routsum -= sir[0];
 			goutsum -= sir[1];
@@ -495,9 +488,9 @@ void ScImage::blur(int radius)
 
 			if (y == 0)
 			{
-				vmin[x] = qMin(x+radius+1,wm);
+				vmin[x] = qMin(x + radius + 1, wm);
 			}
-			p = pix[yw+vmin[x]];
+			p = pix[yw + vmin[x]];
 
 			sir[0] = qRed(p);
 			sir[1] = qGreen(p);
@@ -541,16 +534,16 @@ void ScImage::blur(int radius)
 
 		for (i=-radius; i <= radius; ++i)
 		{
-			yi=qMax(0,yp)+x;
+			yi = qMax(0, yp) + x;
 
-			sir = stack[i+radius];
+			sir = stack[i + radius];
 
 			sir[0] = r[yi];
 			sir[1] = g[yi];
 			sir[2] = b[yi];
 			sir[3] = a[yi];
 
-			rbs = r1-abs(i);
+			rbs = r1 - abs(i);
 
 			rsum += r[yi]*rbs;
 			gsum += g[yi]*rbs;
@@ -600,9 +593,9 @@ void ScImage::blur(int radius)
 
 			if (x==0)
 			{
-				vmin[y] = qMin(y+r1,hm)*w;
+				vmin[y] = qMin(y + r1,hm)*w;
 			}
-			p = x+vmin[y];
+			p = x + vmin[y];
 
 			sir[0] = r[p];
 			sir[1] = g[p];
@@ -619,7 +612,7 @@ void ScImage::blur(int radius)
 			bsum += binsum;
 			asum += ainsum;
 
-			stackpointer = (stackpointer+1)%div;
+			stackpointer = (stackpointer + 1) % div;
 			sir = stack[stackpointer];
 
 			routsum += sir[0];
@@ -651,61 +644,59 @@ void ScImage::blur(int radius)
 
 bool ScImage::convolveImage(QImage *dest, const unsigned int order, const double *kernel)
 {
-	long widthk;
 	double red, green, blue, alpha;
-	double normalize, *normal_kernel;
 	const double *k;
 	unsigned int *q;
 	int x, y, mx, my, sx, sy;
 	long i;
 	int mcx, mcy;
-	widthk = order;
+	long widthk = order;
 	if ((widthk % 2) == 0)
-		return(false);
-	normal_kernel = (double *)malloc(widthk*widthk*sizeof(double));
+		return false;
+	double *normal_kernel = (double *)malloc(widthk*widthk*sizeof(double));
 	if (!normal_kernel)
-		return(false);
+		return false;
 	*dest = QImage(width(), height(), QImage::Format_ARGB32);
-	normalize=0.0;
-	for (i=0; i < (widthk*widthk); i++)
+	double normalize = 0.0;
+	for (i=0; i < (widthk * widthk); i++)
 		normalize += kernel[i];
 	if (fabs(normalize) <= 1.0e-12)
-		normalize=1.0;
-	normalize=1.0/normalize;
-	for (i=0; i < (widthk*widthk); i++)
+		normalize = 1.0;
+	normalize = 1.0 / normalize;
+	for (i = 0; i < (widthk * widthk); i++)
 		normal_kernel[i] = normalize*kernel[i];
-	for (y=0; y < dest->height(); ++y)
+	for (y = 0; y < dest->height(); ++y)
 	{
-		sy = y-(widthk/2);
-		q = (unsigned int *)dest->scanLine(y);
-		for (x=0; x < dest->width(); ++x)
+		sy = y - (widthk / 2);
+		q = (unsigned int *) dest->scanLine(y);
+		for (x = 0; x < dest->width(); ++x)
 		{
 			k = normal_kernel;
 			red = green = blue = alpha = 0;
-			sy = y-(widthk/2);
-			for (mcy=0; mcy < widthk; ++mcy, ++sy)
+			sy = y - (widthk / 2);
+			for (mcy = 0; mcy < widthk; ++mcy, ++sy)
 			{
-				my = sy < 0 ? 0 : sy > height()-1 ? height()-1 : sy;
-				sx = x+(-widthk/2);
+				my = sy < 0 ? 0 : sy > height() - 1 ? height() - 1 : sy;
+				sx = x + (-widthk / 2);
 				for (mcx=0; mcx < widthk; ++mcx, ++sx)
 				{
 					mx = sx < 0 ? 0 : sx > width()-1 ? width()-1 : sx;
 					int px = pixel(mx, my);
-					red += (*k)*(qRed(px)*257);
-					green += (*k)*(qGreen(px)*257);
-					blue += (*k)*(qBlue(px)*257);
-					alpha += (*k)*(qAlpha(px)*257);
+					red += (*k)*(qRed(px) * 257);
+					green += (*k)*(qGreen(px) * 257);
+					blue += (*k)*(qBlue(px) * 257);
+					alpha += (*k)*(qAlpha(px) * 257);
 					++k;
 				}
 			}
-			red = red < 0 ? 0 : red > 65535 ? 65535 : red+0.5;
-			green = green < 0 ? 0 : green > 65535 ? 65535 : green+0.5;
-			blue = blue < 0 ? 0 : blue > 65535 ? 65535 : blue+0.5;
-			alpha = alpha < 0 ? 0 : alpha > 65535 ? 65535 : alpha+0.5;
-			*q++ = qRgba((unsigned char)(red/257UL),
-			             (unsigned char)(green/257UL),
-			             (unsigned char)(blue/257UL),
-			             (unsigned char)(alpha/257UL));
+			red = red < 0 ? 0 : red > 65535 ? 65535 : red + 0.5;
+			green = green < 0 ? 0 : green > 65535 ? 65535 : green + 0.5;
+			blue = blue < 0 ? 0 : blue > 65535 ? 65535 : blue + 0.5;
+			alpha = alpha < 0 ? 0 : alpha > 65535 ? 65535 : alpha + 0.5;
+			*q++ = qRgba((unsigned char)(red / 257UL),
+			             (unsigned char)(green / 257UL),
+			             (unsigned char)(blue / 257UL),
+			             (unsigned char)(alpha / 257UL));
 		}
 	}
 	free(normal_kernel);
@@ -719,19 +710,19 @@ int ScImage::getOptimalKernelWidth(double radius, double sigma)
 	long u;
 	assert(sigma != 0.0);
 	if (radius > 0.0)
-		return((int)(2.0*ceil(radius)+1.0));
-	for (width=5; ;)
+		return((int)(2.0 * ceil(radius) + 1.0));
+	for (width = 5; ;)
 	{
-		normalize=0.0;
-		for (u=(-width/2); u <= (width/2); u++)
-			normalize+=exp(-((double) u*u)/(2.0*sigma*sigma))/(2.50662827463100024161235523934010416269302368164062*sigma);
-		u=width/2;
-		value=exp(-((double) u*u)/(2.0*sigma*sigma))/(2.50662827463100024161235523934010416269302368164062*sigma)/normalize;
-		if ((long)(65535*value) <= 0)
+		normalize = 0.0;
+		for (u= (-width / 2); u <= (width / 2); u++)
+			normalize += exp(-((double) u * u) / (2.0 * sigma * sigma)) / (2.50662827463100024161235523934010416269302368164062 * sigma);
+		u = width / 2;
+		value = exp(-((double) u*u) / (2.0 * sigma * sigma)) / (2.50662827463100024161235523934010416269302368164062 * sigma) / normalize;
+		if ((long)(65535 * value) <= 0)
 			break;
-		width+=2;
+		width += 2;
 	}
-	return((int)width-2);
+	return ((int) width - 2);
 }
 
 void ScImage::sharpen(double radius, double sigma)
@@ -743,32 +734,32 @@ void ScImage::sharpen(double radius, double sigma)
 	if (sigma == 0.0)
 		return;
 	widthk = getOptimalKernelWidth(radius, sigma);
-	if (width() < widthk)
+	if ((widthk <= 0) || (width() < widthk))
 		return;
-	kernel = (double *)malloc(widthk*widthk*sizeof(double));
+	kernel = (double *) malloc(widthk * widthk * sizeof(double));
 	if (!kernel)
 		return;
 	i = 0;
-	normalize=0.0;
-	for (v=(-widthk/2); v <= (widthk/2); v++)
+	normalize = 0.0;
+	for (v= (-widthk / 2); v <= (widthk / 2); v++)
 	{
-		for (u=(-widthk/2); u <= (widthk/2); u++)
+		for (u= (-widthk / 2); u <= (widthk / 2); u++)
 		{
-			alpha=exp(-((double) u*u+v*v)/(2.0*sigma*sigma));
-			kernel[i]=alpha/(2.0*3.14159265358979323846264338327950288419716939937510*sigma*sigma);
-			normalize+=kernel[i];
+			alpha = exp(-((double) u * u + v * v) / (2.0 * sigma * sigma));
+			kernel[i] = alpha / (2.0 * 3.14159265358979323846264338327950288419716939937510 * sigma * sigma);
+			normalize += kernel[i];
 			i++;
 		}
 	}
-	kernel[i/2]=(-2.0)*normalize;
+	kernel[i / 2] = (-2.0) * normalize;
 	convolveImage(&dest, widthk, kernel);
 	free(kernel);
-//	liberateMemory((void **) &kernel);
-	for (int yi=0; yi < dest.height(); ++yi)
+
+	for (int yi = 0; yi < dest.height(); ++yi)
 	{
-		QRgb *s = (QRgb*)(dest.scanLine( yi ));
-		QRgb *d = (QRgb*)(scanLine( yi ));
-		for (int xi=0; xi < dest.width(); ++xi)
+		QRgb *s = (QRgb*) dest.scanLine(yi);
+		QRgb *d = (QRgb*) scanLine(yi);
+		for (int xi = 0; xi < dest.width(); ++xi)
 		{
 			(*d) = (*s);
 			s++;
@@ -873,10 +864,10 @@ void ScImage::colorize(ScribusDoc* doc, ScColor color, int shade, bool cmyk)
 		ScColorEngine::getShadeColorRGB(color, doc, rgbCol, shade);
 		rgbCol.getValues(cc, cm, cy);
 	}
-	for (int yi=0; yi < h; ++yi)
+	for (int yi = 0; yi < h; ++yi)
 	{
 		s = (QRgb*)(scanLine( yi ));
-		for (int xi=0; xi < w; ++xi)
+		for (int xi = 0; xi < w; ++xi)
 		{
 			r = *s;
 			if (cmyk)
@@ -927,7 +918,7 @@ void ScImage::duotone(ScribusDoc* doc, ScColor color1, int shade1, FPointArray c
 		QRgb * s = (QRgb*)(scanLine( yi ));
 		for (int xi=0; xi < w; ++xi)
 		{
-			QRgb r=*s;
+			QRgb r = *s;
 			if (cmyk)
 				cb = qMin(qRound(0.3 * qRed(r) + 0.59 * qGreen(r) + 0.11 * qBlue(r) + qAlpha(r)), 255);
 			else
@@ -940,7 +931,7 @@ void ScImage::duotone(ScribusDoc* doc, ScColor color1, int shade1, FPointArray c
 			m1n = qMin((m1 * curveTable2[(int)cb]) >> 8, 255);
 			y1n = qMin((y1 * curveTable2[(int)cb]) >> 8, 255);
 			k1n = qMin((k1 * curveTable2[(int)cb]) >> 8, 255);
-			ScColor col = ScColor(qMin(cn+c1n, 255), qMin(mn+m1n, 255), qMin(yn+y1n, 255), qMin(kn+k1n, 255));
+			ScColor col = ScColor(qMin(cn + c1n, 255), qMin(mn + m1n, 255), qMin(yn + y1n, 255), qMin(kn + k1n, 255));
 			if (cmyk)
 				col.getCMYK(&cn, &mn, &yn, &kn);
 			else
@@ -986,12 +977,12 @@ void ScImage::tritone(ScribusDoc* doc, ScColor color1, int shade1, FPointArray c
 	{
 		curveTable3[x] = qMin(255, qMax(0, qRound(getCurveYValue(curve2, x / 255.0, lin3) * 255)));
 	}
-	for (int yi=0; yi < h; ++yi)
+	for (int yi = 0; yi < h; ++yi)
 	{
 		QRgb * s = (QRgb*)(scanLine( yi ));
-		for (int xi=0; xi < w; ++xi)
+		for (int xi = 0; xi < w; ++xi)
 		{
-			QRgb r=*s;
+			QRgb r = *s;
 			if (cmyk)
 				cb = qMin(qRound(0.3 * qRed(r) + 0.59 * qGreen(r) + 0.11 * qBlue(r) + qAlpha(r)), 255);
 			else
@@ -1065,9 +1056,9 @@ void ScImage::quadtone(ScribusDoc* doc, ScColor color1, int shade1, FPointArray
 	for (int yi=0; yi < h; ++yi)
 	{
 		QRgb * s = (QRgb*)(scanLine( yi ));
-		for (int xi=0; xi < w; ++xi)
+		for (int xi = 0; xi < w; ++xi)
 		{
-			QRgb r=*s;
+			QRgb r = *s;
 			if (cmyk)
 				cb = qMin(qRound(0.3 * qRed(r) + 0.59 * qGreen(r) + 0.11 * qBlue(r) + qAlpha(r)), 255);
 			else
@@ -1109,10 +1100,10 @@ void ScImage::invert(bool cmyk)
 	unsigned char *p;
 	QRgb * s;
 	unsigned char c, m, y, k;
-	for (int yi=0; yi < h; ++yi)
+	for (int yi = 0; yi < h; ++yi)
 	{
 		s = (QRgb*)(scanLine( yi ));
-		for (int xi=0; xi < w; ++xi)
+		for (int xi = 0; xi < w; ++xi)
 		{
 			if (cmyk)
 			{
@@ -1140,10 +1131,10 @@ void ScImage::toGrayscale(bool cmyk)
 	int k;
 	QRgb * s;
 	QRgb r;
-	for (int yi=0; yi < h; ++yi)
+	for (int yi = 0; yi < h; ++yi)
 	{
 		s = (QRgb*)(scanLine( yi ));
-		for (int xi=0; xi < w; ++xi)
+		for (int xi = 0; xi < w; ++xi)
 		{
 			r = *s;
 			if (cmyk)
@@ -1196,31 +1187,32 @@ bool ScImage::createLowRes(double scale)
 
 bool ScImage::convert2JPG(const QString& fn, int Quality, bool isCMYK, bool isGray)
 {
-	bool success = false;
 	QFile file(fn);
-	if (file.open(QIODevice::WriteOnly))
+	if (!file.open(QIODevice::WriteOnly))
+		return false;
+
+	bool success = false;
+	ScJpegEncodeFilter::Color imgColor = ScJpegEncodeFilter::GRAY;
+	if (isCMYK)
+		imgColor = ScJpegEncodeFilter::CMYK;
+	else if (!isGray)
+		imgColor = ScJpegEncodeFilter::RGB;
+	int qual[] = { 95, 85, 75, 50, 25 };  // These are the JPEG Quality settings 100 means best, 0 .. don't discuss
+	QDataStream dataStream(&file);
+	ScJpegEncodeFilter jpegFilter(&dataStream, width(), height(), imgColor);
+	jpegFilter.setQuality(qual[Quality]);
+	if (jpegFilter.openFilter())
 	{
-		ScJpegEncodeFilter::Color imgColor = ScJpegEncodeFilter::GRAY;
 		if (isCMYK)
-			imgColor = ScJpegEncodeFilter::CMYK;
-		else if (!isGray)
-			imgColor = ScJpegEncodeFilter::RGB;
-		int qual[] = { 95, 85, 75, 50, 25 };  // These are the JPEG Quality settings 100 means best, 0 .. don't discuss
-		QDataStream dataStream(&file);
-		ScJpegEncodeFilter jpegFilter(&dataStream, width(), height(), imgColor);
-		jpegFilter.setQuality(qual[Quality]);
-		if (jpegFilter.openFilter())
-		{
-			if (isCMYK)
-				success = writeCMYKDataToFilter(&jpegFilter);
-			else if (isGray)
-				success = writeGrayDataToFilter(&jpegFilter, true);
-			else
-				success = writeRGBDataToFilter(&jpegFilter);
-			success &= jpegFilter.closeFilter();
-		}
-		file.close();
+			success = writeCMYKDataToFilter(&jpegFilter);
+		else if (isGray)
+			success = writeGrayDataToFilter(&jpegFilter, true);
+		else
+			success = writeRGBDataToFilter(&jpegFilter);
+		success &= jpegFilter.closeFilter();
 	}
+	file.close();
+
 	return success;
 }
 
@@ -1257,10 +1249,10 @@ void ScImage::convertToGray()
 	int h = height();
 	int w = width();
 	QRgb *s, r;
-	for (int yi=0; yi < h; ++yi)
+	for (int yi = 0; yi < h; ++yi)
 	{
 		s = (QRgb*)(scanLine( yi ));
-		for (int xi=0; xi < w; ++xi)
+		for (int xi = 0; xi < w; ++xi)
 		{
 			r = *s;
 			k = qMin(qRound(0.3 * qRed(r) + 0.59 * qGreen(r) + 0.11 * qBlue(r)), 255);
@@ -1286,7 +1278,7 @@ bool ScImage::writeRGBDataToFilter(ScStreamFilter* filter) const
 	for (int yi = 0; yi < h; ++yi)
 	{
 		s = (const QRgb*) constScanLine(yi);
-		for (int xi=0; xi < w; ++xi)
+		for (int xi = 0; xi < w; ++xi)
 		{
 			r = *s++;
 			buffer[pending++] = static_cast<unsigned char>(qRed(r));
@@ -1411,10 +1403,10 @@ bool ScImage::writeCMYKDataToFilter(ScStreamFilter* filter) const
 	buffer.resize(bufferSize + 16);
 	if (buffer.isNull()) // Memory allocation failure
 		return false;
-	for (int yi=0; yi < h; ++yi)
+	for (int yi = 0; yi < h; ++yi)
 	{
 		s = (const QRgb*) constScanLine(yi);
-		for (int xi=0; xi < w; ++xi)
+		for (int xi = 0; xi < w; ++xi)
 		{
 			r = *s++;
 			buffer[pending++] = static_cast<unsigned char> (qRed(r));
@@ -1612,8 +1604,8 @@ void ScImage::scaleImage32bpp(int nwidth, int nheight)
 	}
 	xscale = (double) newcols / (double) cols;
 	yscale = (double) newrows / (double) rows;
-	sxscale = (long)(xscale * SCALE);
-	syscale = (long)(yscale * SCALE);
+	sxscale = (long) (xscale * SCALE);
+	syscale = (long) (yscale * SCALE);
 	if ( newrows != rows )	/* shortcut Y scaling if possible */
 		tempxelrow = new QRgb[cols];
 	as = new long[cols];
@@ -1623,19 +1615,19 @@ void ScImage::scaleImage32bpp(int nwidth, int nheight)
 	rowsread = 0;
 	fracrowleft = syscale;
 	needtoreadrow = 1;
-	for ( col = 0; col < cols; ++col )
+	for (col = 0; col < cols; ++col)
 		rs[col] = gs[col] =  as[col] = bs[col] = HALFSCALE;
 	fracrowtofill = SCALE;
-	for ( row = 0; row < newrows; ++row )
+	for (row = 0; row < newrows; ++row)
 	{
 		if ( newrows == rows )
-			tempxelrow = xelrow = (QRgb*)scanLine(rowsread++);
+			tempxelrow = xelrow = (QRgb*) scanLine(rowsread++);
 		else
 		{
 			while ( fracrowleft < fracrowtofill )
 			{
 				if ( needtoreadrow && rowsread < rows )
-					xelrow = (QRgb*)scanLine(rowsread++);
+					xelrow = (QRgb*) scanLine(rowsread++);
 				for ( col = 0, xP = xelrow; col < cols; ++col, ++xP )
 				{
 					as[col] += fracrowleft * qAlpha( *xP );
@@ -1647,13 +1639,13 @@ void ScImage::scaleImage32bpp(int nwidth, int nheight)
 				fracrowleft = syscale;
 				needtoreadrow = 1;
 			}
-			if ( needtoreadrow && rowsread < rows )
+			if (needtoreadrow && rowsread < rows)
 			{
-				xelrow = (QRgb*)scanLine(rowsread++);
+				xelrow = (QRgb*) scanLine(rowsread++);
 				needtoreadrow = 0;
 			}
-			long a=0;
-			for ( col = 0, xP = xelrow, nxP = tempxelrow; col < cols; ++col, ++xP, ++nxP )
+			long a = 0;
+			for (col = 0, xP = xelrow, nxP = tempxelrow; col < cols; ++col, ++xP, ++nxP)
 			{
 				long r, g, b;
 				a = as[col] + fracrowtofill * qAlpha( *xP );
@@ -1661,114 +1653,126 @@ void ScImage::scaleImage32bpp(int nwidth, int nheight)
 				g = gs[col] + fracrowtofill * qGreen( *xP );
 				b = bs[col] + fracrowtofill * qBlue( *xP );
 				r /= SCALE;
-				if ( r > maxval ) r = maxval;
+				if (r > maxval)
+					r = maxval;
 				g /= SCALE;
-				if ( g > maxval ) g = maxval;
+				if (g > maxval)
+					g = maxval;
 				b /= SCALE;
-				if ( b > maxval ) b = maxval;
+				if (b > maxval)
+					b = maxval;
 				a /= SCALE;
-				if ( a > maxval ) a = maxval;
-				*nxP = qRgba( (int)r, (int)g, (int)b , (int)a);
+				if (a > maxval)
+					a = maxval;
+				*nxP = qRgba((int) r, (int) g, (int) b , (int) a);
 				rs[col] = as[col] = gs[col] = bs[col] = HALFSCALE;
 			}
 			fracrowleft -= fracrowtofill;
-			if ( fracrowleft == 0 )
+			if (fracrowleft == 0)
 			{
 				fracrowleft = syscale;
 				needtoreadrow = 1;
 			}
 			fracrowtofill = SCALE;
 		}
-		if ( newcols == cols )
+		if (newcols == cols)
 			memcpy(dst.scanLine(rowswritten++), tempxelrow, newcols*4);
 		else
 		{
 			long a, r, g, b;
 			long fraccoltofill, fraccolleft = 0;
 			int needcol;
-			nxP = (QRgb*)dst.scanLine(rowswritten++);
+			nxP = (QRgb*) dst.scanLine(rowswritten++);
 			QRgb *nxPEnd = nxP + newcols;
 			fraccoltofill = SCALE;
 			a = r = g = b = HALFSCALE;
 			needcol = 0;
-			for ( col = 0, xP = tempxelrow; col < cols; ++col, ++xP )
+			for (col = 0, xP = tempxelrow; col < cols; ++col, ++xP)
 			{
 				fraccolleft = sxscale;
-				while ( fraccolleft >= fraccoltofill )
+				while (fraccolleft >= fraccoltofill)
 				{
-					if ( needcol )
+					if (needcol)
 					{
 						++nxP;
 						a = r = g = b = HALFSCALE;
 					}
-					a += fraccoltofill * qAlpha( *xP );
-					r += fraccoltofill * qRed( *xP );
-					g += fraccoltofill * qGreen( *xP );
-					b += fraccoltofill * qBlue( *xP );
+					a += fraccoltofill * qAlpha(*xP);
+					r += fraccoltofill * qRed(*xP);
+					g += fraccoltofill * qGreen(*xP);
+					b += fraccoltofill * qBlue(*xP);
 					r /= SCALE;
-					if ( r > maxval ) r = maxval;
+					if (r > maxval)
+						r = maxval;
 					g /= SCALE;
-					if ( g > maxval ) g = maxval;
+					if (g > maxval)
+						g = maxval;
 					b /= SCALE;
-					if ( b > maxval ) b = maxval;
+					if (b > maxval)
+						b = maxval;
 					a /= SCALE;
-					if ( a > maxval ) a = maxval;
-					*nxP = qRgba( (int)r, (int)g, (int)b, (int)a );
+					if (a > maxval)
+						a = maxval;
+					*nxP = qRgba((int) r, (int) g, (int) b, (int) a);
 					fraccolleft -= fraccoltofill;
 					fraccoltofill = SCALE;
 					needcol = 1;
 				}
-				if ( fraccolleft > 0 )
+				if (fraccolleft > 0)
 				{
-					if ( needcol )
+					if (needcol)
 					{
 						++nxP;
 						a = r = g = b = HALFSCALE;
 						needcol = 0;
 					}
-					a += fraccolleft * qAlpha( *xP );
-					r += fraccolleft * qRed( *xP );
-					g += fraccolleft * qGreen( *xP );
-					b += fraccolleft * qBlue( *xP );
+					a += fraccolleft * qAlpha(*xP);
+					r += fraccolleft * qRed(*xP);
+					g += fraccolleft * qGreen(*xP);
+					b += fraccolleft * qBlue(*xP);
 					fraccoltofill -= fraccolleft;
 				}
 			}
-			if ( fraccoltofill > 0 )
+			if (fraccoltofill > 0)
 			{
 				--xP;
-				a += fraccoltofill * qAlpha( *xP );
-				r += fraccoltofill * qRed( *xP );
-				g += fraccoltofill * qGreen( *xP );
-				b += fraccoltofill * qBlue( *xP );
+				a += fraccoltofill * qAlpha(*xP);
+				r += fraccoltofill * qRed(*xP);
+				g += fraccoltofill * qGreen(*xP);
+				b += fraccoltofill * qBlue(*xP);
 			}
 			if (nxP < nxPEnd)
 			{
 				r /= SCALE;
-				if ( r > maxval ) r = maxval;
+				if (r > maxval)
+					r = maxval;
 				g /= SCALE;
-				if ( g > maxval ) g = maxval;
+				if (g > maxval)
+					g = maxval;
 				b /= SCALE;
-				if ( b > maxval ) b = maxval;
+				if (b > maxval)
+					b = maxval;
 				a /= SCALE;
-				if ( a > maxval ) a = maxval;
-				*nxP = qRgba( (int)r, (int)g, (int)b, (int)a );
+				if (a > maxval)
+					a = maxval;
+				*nxP = qRgba((int) r, (int) g, (int) b, (int) a);
 				while (++nxP != nxPEnd)
 					nxP[0] = nxP[-1];
 			}
 		}
 	}
-	if ( newrows != rows && tempxelrow )// Robust, tempxelrow might be 0 1 day
+	if (newrows != rows && tempxelrow) // Robust, tempxelrow might be 0 1 day
 		delete [] tempxelrow;
 	delete [] as;
 	delete [] rs;
 	delete [] gs;
 	delete [] bs;
 	QImage::operator=(QImage(nwidth, nheight, QImage::Format_ARGB32));
-	for (int yi=0; yi < dst.height(); ++yi)
+	for (int yi = 0; yi < dst.height(); ++yi)
 	{
-		QRgb *s = (QRgb*)(dst.scanLine( yi ));
-		QRgb *d = (QRgb*)(scanLine( yi ));
-		for (int xi=0; xi < dst.width(); ++xi)
+		QRgb *s = (QRgb*) dst.scanLine(yi);
+		QRgb *d = (QRgb*) scanLine(yi);
+		for (int xi = 0; xi < dst.width(); ++xi)
 		{
 			(*d) = (*s);
 			s++;
@@ -1833,7 +1837,7 @@ void ScImage::scaleImageGeneric(int nwidth, int nheight)
 	yscale = (double) newrows / (double) rows;
 	sxscale = (long)(xscale * SCALE);
 	syscale = (long)(yscale * SCALE);
-	if ( newrows != rows )	/* shortcut Y scaling if possible */
+	if (newrows != rows)	/* shortcut Y scaling if possible */
 		tempxelrow = new unsigned char[cols * nChannels];
 	ps = new long[cols];
 
@@ -1874,12 +1878,13 @@ void ScImage::scaleImageGeneric(int nwidth, int nheight)
 				{
 					p = ps[col] + fracrowtofill * (*xP);
 					p /= SCALE;
-					if ( p > maxval ) p = maxval;
+					if (p > maxval)
+						p = maxval;
 					*nxP = (unsigned char) p;
 					ps[col] = HALFSCALE;
 				}
 				fracrowleft -= fracrowtofill;
-				if ( fracrowleft == 0 )
+				if (fracrowleft == 0)
 				{
 					fracrowleft = syscale;
 					needtoreadrow = 1;
@@ -1903,16 +1908,17 @@ void ScImage::scaleImageGeneric(int nwidth, int nheight)
 				for (col = 0, xP = tempxelrow + chIndex; col < cols; ++col, xP += nChannels)
 				{
 					fraccolleft = sxscale;
-					while ( fraccolleft >= fraccoltofill )
+					while (fraccolleft >= fraccoltofill)
 					{
-						if ( needcol )
+						if (needcol)
 						{
 							nxP += nChannels;
 							p = HALFSCALE;
 						}
-						p += fraccoltofill * ( *xP );
+						p += fraccoltofill * (*xP);
 						p /= SCALE;
-						if ( p > maxval ) p = maxval;
+						if (p > maxval)
+							p = maxval;
 						*nxP = (unsigned char) p;
 						fraccolleft -= fraccoltofill;
 						fraccoltofill = SCALE;
@@ -1938,7 +1944,8 @@ void ScImage::scaleImageGeneric(int nwidth, int nheight)
 				if (nxP < nxPEnd)
 				{
 					p /= SCALE;
-					if ( p > maxval ) p = maxval;
+					if (p > maxval)
+						p = maxval;
 					*nxP = (unsigned char) p;
 					while ((nxP += nChannels) != nxPEnd)
 						nxP[0] = nxP[-nChannels];
@@ -1952,10 +1959,10 @@ void ScImage::scaleImageGeneric(int nwidth, int nheight)
 
 	int scanWidth = dst.width() * nChannels;
 	QImage::operator=(QImage(nwidth, nheight, this->format()));
-	for (int yi=0; yi < dst.height(); ++yi)
+	for (int yi = 0; yi < dst.height(); ++yi)
 	{
-		uchar *s = (dst.scanLine( yi ));
-		uchar *d = (scanLine( yi ));
+		uchar *s = dst.scanLine(yi);
+		uchar *d = scanLine(yi);
 		memcpy(d, s, scanWidth);
 	}
 }
@@ -1965,7 +1972,7 @@ bool ScImage::getAlpha(const QString& fn, int page, QByteArray& alpha, bool PDF,
 	bool gotAlpha = false;
 	QScopedPointer<ScImgDataLoader> pDataLoader;
 	imgInfo.valid = false;
-	imgInfo.clipPath = "";
+	imgInfo.clipPath.clear();
 	imgInfo.PDSpathData.clear();
 	imgInfo.layerInfo.clear();
 	QFileInfo fi = QFileInfo(fn);
@@ -1992,9 +1999,9 @@ bool ScImage::getAlpha(const QString& fn, int page, QByteArray& alpha, bool PDF,
 	{
 		pDataLoader.reset( new ScImgDataLoader_PS() );
 	}
-	else if (extensionIndicatesTIFF(ext))
+	else if (extensionIndicatesPNG(ext))
 	{
-		pDataLoader.reset( new ScImgDataLoader_TIFF() );
+		pDataLoader.reset( new ScImgDataLoader_PNG() );
 		if	(pDataLoader.data())
 			pDataLoader->setRequest(imgInfo.isRequest, imgInfo.RequestProps);
 	}
@@ -2004,6 +2011,12 @@ bool ScImage::getAlpha(const QString& fn, int page, QByteArray& alpha, bool PDF,
 		if	(pDataLoader.data())
 			pDataLoader->setRequest(imgInfo.isRequest, imgInfo.RequestProps);
 	}
+	else if (extensionIndicatesTIFF(ext))
+	{
+		pDataLoader.reset( new ScImgDataLoader_TIFF() );
+		if	(pDataLoader.data())
+			pDataLoader->setRequest(imgInfo.isRequest, imgInfo.RequestProps);
+	}
 	else if (ext == "ora")
 	{
 		pDataLoader.reset( new ScImgDataLoader_ORA() );
@@ -2068,10 +2081,10 @@ bool ScImage::getAlpha(const QString& fn, int page, QByteArray& alpha, bool PDF,
 			alpha.resize(hm * wm);
 			if (alpha.size() > 0) // 
 			{
-				for (int yi=0; yi < hm; ++yi)
+				for (int yi = 0; yi < hm; ++yi)
 				{
-					s = (QRgb*)(rImage.scanLine( yi ));
-					for (int xi=0; xi < wm; ++xi)
+					s = (QRgb*) rImage.scanLine(yi);
+					for (int xi = 0; xi < wm; ++xi)
 					{
 						r = *s++;
 						u = qAlpha(r);
@@ -2094,12 +2107,12 @@ bool ScImage::getAlpha(const QString& fn, int page, QByteArray& alpha, bool PDF,
 			alpha.resize(hm * w2);
 			if (alpha.size() > 0)
 			{
-				for (int yi=0; yi < hm; ++yi)
+				for (int yi = 0; yi < hm; ++yi)
 				{
 					s = iMask.scanLine( yi );
-					for (int xi=0; xi < w2; ++xi)
+					for (int xi = 0; xi < w2; ++xi)
 					{
-						u = *(s+xi);
+						u = *(s + xi);
 						if (PDF) u = ~u;
 						alpha[i++] = u;
 					}
@@ -2120,6 +2133,7 @@ void ScImage::getEmbeddedProfile(const QString & fn, QByteArray *profile, int *c
 
 	profile->resize(0);
 	*components = 0;
+
 	QFileInfo fi = QFileInfo(fn);
 	if (!fi.exists())
 		return;
@@ -2128,24 +2142,36 @@ void ScImage::getEmbeddedProfile(const QString & fn, QByteArray *profile, int *c
 	if (ext.isEmpty() || (!ext2.isEmpty() && (ext2 != ext)))
 		ext = ext2;
 
+	QList<QByteArray> fmtList = QImageReader::supportedImageFormats();
+	QStringList fmtImg;
+	for (int i = 0; i < fmtList.count(); i++)
+		fmtImg.append( QString(fmtList[i].toLower()) );
+
 	if (extensionIndicatesPSD(ext))
 		pDataLoader = new ScImgDataLoader_PSD();
 	else if (extensionIndicatesEPSorPS(ext))
 		pDataLoader = new ScImgDataLoader_PS();
-	else if (extensionIndicatesTIFF(ext))
-		pDataLoader = new ScImgDataLoader_TIFF();
 	else if (extensionIndicatesJPEG(ext))
 		pDataLoader = new ScImgDataLoader_JPEG();
-	#ifdef FOUND_GMAGICK
+	else if (extensionIndicatesPNG(ext))
+		pDataLoader = new ScImgDataLoader_PNG();
+	else if (extensionIndicatesTIFF(ext))
+		pDataLoader = new ScImgDataLoader_TIFF();
+#ifdef GMAGICK_FOUND
+	else if (fmtImg.contains(ext))
+		pDataLoader = new ScImgDataLoader_QT();
 	else
 		pDataLoader = new ScImgDataLoader_GMagick();
-	#endif
+#else
+	else
+		pDataLoader = new ScImgDataLoader_QT();
+#endif
 
 	if (pDataLoader)
 	{
 		pDataLoader->loadEmbeddedProfile(fn, page);
 		QByteArray embeddedProfile = pDataLoader->embeddedProfile();
-		if	(embeddedProfile.size())
+		if	(!embeddedProfile.isEmpty())
 		{
 			prof = ScCore->defaultEngine.openProfileFromMem(embeddedProfile);
 			if (prof)
@@ -2168,13 +2194,9 @@ void ScImage::addProfileToCacheModifiers(ScImageCacheProxy & cache, const QStrin
 	if (profile)
 	{
 		cache.addModifier(prefix + "ProfileDescription", profile.productDescription());
-		const ScColorProfileData *pd = profile.data();
-		if (pd)
-		{
-			QString hash = pd->dataHash();
-			if (!hash.isEmpty())
-				cache.addModifier(prefix + "ProfileHash", hash);
-		}
+		QString hash = profile.dataHash();
+		if (!hash.isEmpty())
+			cache.addModifier(prefix + "ProfileHash", hash);
 	}
 }
 
@@ -2237,7 +2259,7 @@ bool ScImage::loadPicture(const QString & fn, int page, const CMSettings& cmSett
 	if (!fi.exists())
 		return ret;
 	QString ext = fi.suffix().toLower();
-	QString profileName = "";
+	QString profileName;
 	bool hasEmbeddedProfile = false;
 	QList<QByteArray> fmtList = QImageReader::supportedImageFormats();
 	QStringList fmtImg;
@@ -2268,15 +2290,17 @@ bool ScImage::loadPicture(const QString & fn, int page, const CMSettings& cmSett
 		pDataLoader.reset( new ScImgDataLoader_PDF() );
 	else if (extensionIndicatesEPSorPS(ext))
 		pDataLoader.reset( new ScImgDataLoader_PS() );
-	else if (extensionIndicatesTIFF(ext))
-		pDataLoader.reset( new ScImgDataLoader_TIFF() );
+	else if (extensionIndicatesJPEG(ext))
+		pDataLoader.reset( new ScImgDataLoader_JPEG() );
+	else if (extensionIndicatesPNG(ext))
+		pDataLoader.reset( new ScImgDataLoader_PNG() );
 	else if (extensionIndicatesPSD(ext))
 	{
 		pDataLoader.reset( new ScImgDataLoader_PSD() );
 		pDataLoader->setRequest(imgInfo.isRequest, imgInfo.RequestProps);
 	}
-	else if (extensionIndicatesJPEG(ext))
-		pDataLoader.reset( new ScImgDataLoader_JPEG() );
+	else if (extensionIndicatesTIFF(ext))
+		pDataLoader.reset( new ScImgDataLoader_TIFF() );
 	else if (ext == "pat")
 		pDataLoader.reset( new ScImgDataLoader_GIMP() );
 	else if (ext == "pgf")
@@ -2415,11 +2439,11 @@ bool ScImage::loadPicture(const QString & fn, int page, const CMSettings& cmSett
 		eColorFormat outputProfFormat = Format_YMCK_8;
 		eColorSpaceType inputProfColorSpace  = inputProf.colorSpace();
 		eColorSpaceType outputProfColorSpace = printerProf.colorSpace();
-		if ( inputProfColorSpace == ColorSpace_Gray)
+		if (inputProfColorSpace == ColorSpace_Gray)
 			inputProfFormat  = Format_GRAY_8; // Grayscale is still a bit tricky
-		if ( outputProfColorSpace == ColorSpace_Rgb )
+		if (outputProfColorSpace == ColorSpace_Rgb)
 			outputProfFormat = Format_BGRA_8;
-		else if ( outputProfColorSpace == ColorSpace_Cmyk )
+		else if (outputProfColorSpace == ColorSpace_Cmyk)
 			outputProfFormat = Format_YMCK_8;
 		ScColorSpace inputCSpace  = engine.createColorSpace(inputProf, inputProfFormat);
 		ScColorSpace screenCSpace = engine.createColorSpace(screenProf, Format_BGRA_8);
@@ -2525,7 +2549,7 @@ bool ScImage::loadPicture(const QString & fn, int page, const CMSettings& cmSett
 			{
 				uchar* ptr = scanLine(i);
 				ptr2 = pDataLoader->useRawImage() ? pDataLoader->r_image.scanLine(i) : nullptr;
-				if ( inputProfFormat == Format_GRAY_8 && (outputProfColorSpace != ColorSpace_Cmyk) )
+				if ((inputProfFormat == Format_GRAY_8) && (outputProfColorSpace != ColorSpace_Cmyk))
 				{
 					unsigned char* ucs = ptr2 ? (ptr2 + 1) : (ptr + 1);
 					unsigned char* uc = new unsigned char[width()];
@@ -2537,7 +2561,7 @@ bool ScImage::loadPicture(const QString & fn, int page, const CMSettings& cmSett
 					xform.apply(uc, ptr, width());
 					delete[] uc;
 				}
-				else if (inputProfFormat == Format_GRAY_8 && (outputProfColorSpace == ColorSpace_Cmyk))
+				else if ((inputProfFormat == Format_GRAY_8) && (outputProfColorSpace == ColorSpace_Cmyk))
 				{
 					unsigned char  value;
 					unsigned char* ucs = ptr2 ? ptr2 : ptr;
