@@ -16,18 +16,7 @@ for which a new license (GPL+exception) is in place.
 
 ScLayer::ScLayer()
 {
-	Name         = QObject::tr("New Layer");
-	ID           = 0;
-	Level        = 0;
-	isPrintable  = true;
-	isViewable   = true;
-	isEditable   = true;
-	isSelectable = false;
-	flowControl  = true;
-	outlineMode  = false;
-	transparency = 1.0;
-	blendMode    = 0;
-	markerColor  = QColor(0, 0, 0);
+	Name = QObject::tr("New Layer");
 }
 
 ScLayer::ScLayer(const QString& name, int level, int id)
@@ -35,15 +24,6 @@ ScLayer::ScLayer(const QString& name, int level, int id)
 	Name         = name;
 	ID           = id;
 	Level        = level;
-	isPrintable  = true;
-	isViewable   = true;
-	isEditable   = true;
-	isSelectable = false;
-	flowControl  = true;
-	outlineMode  = false;
-	transparency = 1.0;
-	blendMode    = 0;
-	markerColor  = QColor(0, 0, 0);
 	switch (ID % 7)
 	{
 		case 0:
@@ -79,18 +59,18 @@ bool ScLayer::operator== (const ScLayer& other) const
 {
 	// ignore markerColor?
 	return Name == other.Name && ID == other.ID && Level == other.Level &&
-		isPrintable  == other.isPrintable  && isViewable  == other.isViewable &&
-		flowControl  == other.flowControl  && outlineMode == other.outlineMode &&
-		transparency == other.transparency && isEditable == other.isEditable &&
-		blendMode   == other.blendMode;
+		   isPrintable == other.isPrintable && isViewable  == other.isViewable &&
+		   flowControl == other.flowControl && outlineMode == other.outlineMode &&
+		   transparency == other.transparency && isEditable == other.isEditable &&
+		   blendMode == other.blendMode;
 }
 
 int ScLayers::getMaxID()
 {
-	int nr, maxNr = -1;
+	int maxNr = -1;
 	for (int i = 0; i < this->count(); ++i)
 	{
-		nr = this->at(i).ID;
+		int nr = this->at(i).ID;
 		if (nr > maxNr)
 			maxNr = nr;
 	}
@@ -143,7 +123,7 @@ void ScLayers::levelToLayer (ScLayer& layer, int level) const
 	}
 }
 
-ScLayer* ScLayers::byLevel(const int level)
+ScLayer* ScLayers::byLevel(int level)
 {
 	ScLayers::Iterator itend = end();
 	for (ScLayers::Iterator it = nullptr; it != itend; ++it)
@@ -154,7 +134,7 @@ ScLayer* ScLayers::byLevel(const int level)
 	return nullptr;
 }
 
-ScLayer* ScLayers::byID(const int nr)
+ScLayer* ScLayers::byID(int nr)
 {
 	ScLayers::Iterator itend = end();
 	for (ScLayers::Iterator it = nullptr; it != itend; ++it)
@@ -192,45 +172,41 @@ ScLayer* ScLayers::top()
 ScLayer* ScLayers::above (int nr)
 {
 	ScLayer* lyr = byID(nr);
-	if (lyr)
+	if (!lyr)
+		return nullptr;
+	ScLayer *rlyr = top();
+	int level = lyr->Level;
+	int maxLevel = rlyr->Level;
+	ScLayers::Iterator it, itEnd = end();
+	for (it = begin(); it != itEnd; ++it)
 	{
-		ScLayer *rlyr = top();
-		int level     = lyr->Level;
-		int maxLevel  = rlyr->Level;
-		ScLayers::Iterator it, itEnd = end();
-		for (it = begin(); it != itEnd; ++it)
+		if (it->Level > level && it->Level < maxLevel)
 		{
-			if (it->Level > level && it->Level < maxLevel)
-			{
-				maxLevel = it->Level;
-				rlyr     = &(*it);
-			}
+			maxLevel = it->Level;
+			rlyr     = &(*it);
 		}
-		return rlyr;
 	}
-	return nullptr;
+	return rlyr;
 }
 
 ScLayer* ScLayers::below (int nr)
 {
 	ScLayer* lyr = byID(nr);
-	if (lyr)
+	if (!lyr)
+		return nullptr;
+	ScLayer *rlyr = bottom();
+	int level = lyr->Level;
+	int minLevel = lyr->Level;
+	ScLayers::Iterator it, itEnd = end();
+	for (it = begin(); it != itEnd; ++it)
 	{
-		ScLayer *rlyr = bottom();
-		int level     = lyr->Level;
-		int minLevel  = lyr->Level;
-		ScLayers::Iterator it, itEnd = end();
-		for (it = begin(); it != itEnd; ++it)
+		if (it->Level < level && it->Level > minLevel)
 		{
-			if (it->Level < level && it->Level > minLevel)
-			{
-				minLevel = it->Level;
-				rlyr     = &(*it);
-			}
+			minLevel = it->Level;
+			rlyr     = &(*it);
 		}
-		return rlyr;
 	}
-	return nullptr;
+	return rlyr;
 }
 
 const ScLayer* ScLayers::layerByLevel (int level) const
@@ -293,66 +269,61 @@ const ScLayer* ScLayers::layerAbove (int level) const
 const ScLayer* ScLayers::layerAbove (const ScLayer& layer) const
 {
 	const ScLayer* top = topLayer();
-	if (top)
+	if (!top)
+		return nullptr;
+	const ScLayer *curlay, *retlay = top;
+	int   level    = layer.Level;
+	int   maxLevel = top->Level;
+	for (int i = 0; i < this->count(); ++i)
 	{
-		const ScLayer *curlay, *retlay = top;
-		int   level    = layer.Level;
-		int   maxLevel = top->Level;
-		for (int i = 0; i < this->count(); ++i)
+		curlay = &this->at(i);
+		if (curlay->Level > level && curlay->Level < maxLevel)
 		{
-			curlay = &this->at(i);
-			if (curlay->Level > level && curlay->Level < maxLevel)
-			{
-				maxLevel = curlay->Level;
-				retlay   = curlay;
-			}
+			maxLevel = curlay->Level;
+			retlay   = curlay;
 		}
-		return retlay;
 	}
-	return nullptr;
+	return retlay;
 }
 
 const ScLayer* ScLayers::layerBelow (int level) const
 {
 	const ScLayer* bottom = bottomLayer();
-	if (bottom)
+	if (!bottom)
+		return nullptr;
+	const ScLayer *layer, *retlay = bottom;
+	int   minLevel = bottom->Level;
+	for (int i = 0; i < this->count(); ++i)
 	{
-		const ScLayer *layer, *retlay = bottom;
-		int   minLevel = bottom->Level;
-		for (int i = 0; i < this->count(); ++i)
+		layer = &this->at(i);
+		if (layer->Level < level && layer->Level > minLevel)
 		{
-			layer = &this->at(i);
-			if (layer->Level < level && layer->Level > minLevel)
-			{
-				minLevel = layer->Level;
-				retlay   = layer;
-			}
+			minLevel = layer->Level;
+			retlay   = layer;
 		}
-		return retlay;
 	}
-	return nullptr;
+	return retlay;
 }
 
 const ScLayer* ScLayers::layerBelow (const ScLayer& layer) const
 {
 	const ScLayer* bottom = bottomLayer();
-	if (bottom)
+	if (!bottom)
+		return nullptr;
+
+	const ScLayer *curlay, *retlay = bottom;
+	int   level    = layer.Level;
+	int   minLevel = bottom->Level;
+	for (int i = 0; i < this->count(); ++i)
 	{
-		const ScLayer *curlay, *retlay = bottom;
-		int   level    = layer.Level;
-		int   minLevel = bottom->Level;
-		for (int i = 0; i < this->count(); ++i)
+		curlay = &this->at(i);
+		if (curlay->Level < level && curlay->Level > minLevel)
 		{
-			curlay = &this->at(i);
-			if (curlay->Level < level && curlay->Level > minLevel)
-			{
-				minLevel = curlay->Level;
-				retlay   = curlay;
-			}
+			minLevel = curlay->Level;
+			retlay   = curlay;
 		}
-		return retlay;
 	}
-	return nullptr;
+	return retlay;
 }
 
 int ScLayers::addLayer(const QString& layerName)
@@ -365,7 +336,7 @@ int ScLayers::addLayer(const QString& layerName)
 
 int ScLayers::addLayer(const ScLayer& layer)
 {
-	int   newID = layer.ID;
+	int newID = layer.ID;
 	const ScLayer* lid = layerByID(newID);
 	if (lid)
 	{
@@ -382,8 +353,8 @@ int ScLayers::addLayer(const ScLayer& layer)
 ScLayer* ScLayers::newLayer(const QString& layerName)
 {
 	QString lname;
-	int     lId    = getMaxID() + 1;
-	int     llevel = count();
+	int lId = getMaxID() + 1;
+	int llevel = count();
 	if (layerName.isEmpty())
 	{
 		QString tmp;
@@ -478,181 +449,164 @@ bool ScLayers::lowerLayer(int nr)
 void ScLayers::sort()
 {
 	int level = 0;
-	ScLayers::Iterator it, itend = end();
-	qStableSort(begin(), end());
+	ScLayers::Iterator it;
+	ScLayers::Iterator itend = end();
+	std::stable_sort(begin(), end());
 	for (it = begin(); it != itend; ++it, ++level)
 		it->Level = level;
 }
 
-bool ScLayers::layerPrintable(const int layerID) const
+bool ScLayers::layerPrintable(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return layer->isPrintable;
-	return false;
+	if (!layer)
+		return false;
+	return layer->isPrintable;
 }
 
-bool ScLayers::setLayerPrintable(const int layerID, const bool isPrintable)
+bool ScLayers::setLayerPrintable(int layerID, bool isPrintable)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->isPrintable = isPrintable;
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->isPrintable = isPrintable;
+	return true;
 }
 
-bool ScLayers::layerVisible(const int layerID) const
+bool ScLayers::layerVisible(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return layer->isViewable;
-	return false;
+	if (!layer)
+		return false;
+	return layer->isViewable;
 }
 
-bool ScLayers::setLayerVisible(const int layerID, const bool isViewable)
+bool ScLayers::setLayerVisible(int layerID, bool isViewable)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->isViewable = isViewable;
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->isViewable = isViewable;
+	return true;
 }
 
-bool ScLayers::layerLocked(const int layerID) const
+bool ScLayers::layerLocked(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return !(layer->isEditable);
-	return false;
+	if (!layer)
+		return false;
+	return !(layer->isEditable);
 }
 
-bool ScLayers::setLayerLocked(const int layerID, const bool isLocked)
+bool ScLayers::setLayerLocked(int layerID, bool isLocked)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->isEditable = !isLocked;
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->isEditable = !isLocked;
+	return true;
 }
 
-bool ScLayers::layerFlow(const int layerID) const
+bool ScLayers::layerFlow(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return layer->flowControl;
-	return false;
+	if (!layer)
+		return false;
+	return layer->flowControl;
 }
 
-bool ScLayers::setLayerFlow(const int layerID, const bool flow)
+bool ScLayers::setLayerFlow(int layerID, bool flow)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->flowControl = flow;
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->flowControl = flow;
+	return true;
 }
 
-bool ScLayers::layerOutline(const int layerID) const
+bool ScLayers::layerOutline(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return layer->outlineMode;
-	return false;
+	if (!layer)
+		return false;
+	return layer->outlineMode;
 }
 
-bool ScLayers::setLayerOutline(const int layerID, const bool outline)
+bool ScLayers::setLayerOutline(int layerID, bool outline)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->outlineMode = outline;
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->outlineMode = outline;
+	return true;
 }
 
-double ScLayers::layerTransparency(const int layerID) const
+double ScLayers::layerTransparency(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return layer->transparency;
-	return 1.0;
+	if (!layer)
+		return 1.0;
+	return layer->transparency;
 }
 
-bool ScLayers::setLayerTransparency(const int layerID, double trans)
+bool ScLayers::setLayerTransparency(int layerID, double trans)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->transparency = trans;
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->transparency = trans;
+	return true;
 }
 
-int ScLayers::layerBlendMode(const int layerID) const
+int ScLayers::layerBlendMode(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return layer->blendMode;
-	return 0;
+	if (!layer)
+		return 0;
+	return layer->blendMode;
 }
 
-bool ScLayers::setLayerBlendMode(const int layerID, int blend)
+bool ScLayers::setLayerBlendMode(int layerID, int blend)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->blendMode = blend;
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->blendMode = blend;
+	return true;
 }
 
-QColor ScLayers::layerMarker(const int layerID) const
+QColor ScLayers::layerMarker(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return layer->markerColor;
-	return Qt::black;
+	if (!layer)
+		return Qt::black;
+	return layer->markerColor;
 }
 
-bool ScLayers::setLayerMarker(const int layerID, QColor color)
+bool ScLayers::setLayerMarker(int layerID, QColor color)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->markerColor = std::move(color);
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->markerColor = std::move(color);
+	return true;
 }
 
-bool ScLayers::layerSelectable(const int layerID) const
+bool ScLayers::layerSelectable(int layerID) const
 {
 	const ScLayer* layer = layerByID(layerID);
-	if (layer)
-		return layer->isSelectable;
-	return false;
+	if (!layer)
+		return false;
+	return layer->isSelectable;
 }
 
-bool ScLayers::setLayerSelectable(const int layerID, const bool isSelectable)
+bool ScLayers::setLayerSelectable(int layerID, bool isSelectable)
 {
 	ScLayer* layer = byID(layerID);
-	if (layer)
-	{
-		layer->isSelectable = isSelectable;
-		return true;
-	}
-	return false;
+	if (!layer)
+		return false;
+	layer->isSelectable = isSelectable;
+	return true;
 }
 
 uint qHash(const ScLayer& layer)
