@@ -30,8 +30,11 @@ public:
 	ScListBoxPixmap(void);
 
 	virtual QString text(const QVariant&) const = 0;
-	virtual QSize sizeHint (const QStyleOptionViewItem & option, const QModelIndex & index ) const;
-	virtual void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index ) const;
+
+	// Functions reimplemented from QAbstractItemDelegate
+	QSize sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const override;
+	void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const override;
+
 protected:
 	static QScopedPointer<QPixmap> pmap;
 	// The drawPixmap function must not modify pixmap size
@@ -41,16 +44,12 @@ protected:
 template<unsigned int pixWidth, unsigned int pixHeight> 
 QScopedPointer<QPixmap> ScListBoxPixmap<pixWidth, pixHeight>::pmap;
 
-
 template<unsigned int pixWidth, unsigned int pixHeight>
 ScListBoxPixmap<pixWidth, pixHeight>::ScListBoxPixmap(void) : QAbstractItemDelegate()
 {
 	if (pmap.isNull())
-	{
-		pmap.reset( new QPixmap(pixWidth, pixHeight) );
-	}
-};
-
+		pmap.reset(new QPixmap(pixWidth, pixHeight));
+}
 
 template<unsigned int pixWidth, unsigned int pixHeight>
 QSize ScListBoxPixmap<pixWidth, pixHeight>::sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const
@@ -58,29 +57,30 @@ QSize ScListBoxPixmap<pixWidth, pixHeight>::sizeHint(const QStyleOptionViewItem
 	int h,w;
 	QFontMetrics metrics(option.font);
 	const QVariant data(index.data(Qt::DisplayRole));
-	if ( text(data).isEmpty() )
+	
+	QString textData = text(data);
+	if (textData.isEmpty())
 	{
 		h = pmap->height();
 		w = pmap->width() + 6;
 	}
 	else
 	{
-		h = qMax( pmap->height(), metrics.lineSpacing() + 2 );
-		w = pmap->width() + metrics.width(text(data)) + 6;
+		h = qMax(pmap->height(), metrics.lineSpacing() + 2);
+		w = pmap->width() + metrics.horizontalAdvance(textData) + 6;
 	}
-	return QSize(qMax(w, QApplication::globalStrut().width()), qMax( h, QApplication::globalStrut().height()));
-};
 
+	QSize globalStrut = QApplication::globalStrut();
+	return QSize(qMax(w, globalStrut.width()), qMax(h, globalStrut.height()));
+}
 
 template<unsigned int pixWidth, unsigned int pixHeight>
 void ScListBoxPixmap<pixWidth, pixHeight>::paint(QPainter * qpainter, const QStyleOptionViewItem & option, const QModelIndex & index) const
 {
-	int yPos;
-	
 	const QVariant data(index.data(Qt::UserRole));
 	redraw(data);
 	
-	int itemHeight = sizeHint( option, index ).height();
+	int itemHeight = sizeHint(option, index).height();
 
 	if (option.state & QStyle::State_Selected)
 		qpainter->fillRect(option.rect, option.palette.highlight());
@@ -89,24 +89,25 @@ void ScListBoxPixmap<pixWidth, pixHeight>::paint(QPainter * qpainter, const QSty
 	qpainter->setRenderHint(QPainter::Antialiasing, true);
 	qpainter->setPen(Qt::NoPen);
 
-	if ( !pmap->isNull() ) {
-		yPos = ( itemHeight - pmap->height() ) / 2;
-		qpainter->drawPixmap( option.rect.x() + 3, option.rect.y() + yPos, *pmap);
+	if (!pmap->isNull())
+	{
+		int yPos = (itemHeight - pmap->height()) / 2;
+		qpainter->drawPixmap(option.rect.x() + 3, option.rect.y() + yPos, *pmap);
 	}
-	if (option.state & QStyle::State_Selected)
-		qpainter->setBrush(option.palette.highlightedText());
-	else
-		qpainter->setBrush(QBrush(Qt::black));
-	qpainter->setPen(Qt::black);
-	
-	QString txt = index.data(Qt::DisplayRole).toString();
 
-	if ( !txt.isEmpty() ) {
+	if (option.state & QStyle::State_Selected)
+		qpainter->setPen(QPen(option.palette.highlightedText(), 0));
+	else
+		qpainter->setPen(QPen(option.palette.text(), 0));
+	
+	QString txt(index.data(Qt::DisplayRole).toString());
+	if (!txt.isEmpty())
+	{
 		QFontMetrics fm = qpainter->fontMetrics();
-		yPos = ( ( itemHeight - fm.height() ) / 2 ) + fm.ascent();
-		qpainter->drawText( option.rect.x() + pmap->width() + 5, option.rect.y() + yPos, txt );
+		int yPos = (itemHeight - fm.height()) / 2 + fm.ascent();
+		qpainter->drawText(option.rect.x() + pmap->width() + 5, option.rect.y() + yPos, txt);
 	}
 	qpainter->restore();
-};
+}
 
 #endif
