@@ -143,7 +143,7 @@ class SCRIBUS_API ScPlugin : public QObject
 		 * The results of testing the value of this can not be guaranteed,
 		 * as its value may change depending on locale and change at runtime.
 		 */
-		virtual const QString fullTrName() const = 0;
+		virtual QString fullTrName() const = 0;
 
 		/**
 		 * \brief Create and return a prefs UI panel for the plugin.
@@ -170,8 +170,7 @@ class SCRIBUS_API ScPlugin : public QObject
 		 *
 		 * By default, returns 0 to indicate no prefs UI.
 		*/
-		virtual bool newPrefsPanelWidget(QWidget* parent, Prefs_Pane*& panel,
-								 QString& caption, QPixmap& icon);
+		virtual bool newPrefsPanelWidget(QWidget* parent, Prefs_Pane*& panel);
 
 		/*! @brief Return descriptive information about the plug-in
 		 *
@@ -269,8 +268,8 @@ class SCRIBUS_API ScActionPlugin : public ScPlugin
 			QString subMenuName;
 			QString toolbar;				// Name of the ToolBar the action is to be inserted, if that toolbar doesn't exits it will be created
 			QString toolBarName;			// translateable ToolBar title
-			QPixmap icon1;
-			QPixmap icon2;
+			QString iconPath1;
+			QString iconPath2;
 			QList<int> notSuitableFor;		// a list of PageItem type values which the plugin can *not* handle
 			QList<int> forAppMode;			// a list of AppMode values for which the plugin will be active, an empty list indicates that the plugin is always active
 			int needsNumObjects;			// plugin needs this number of selected Objects. -1 = needs no Object, num > 2 any number of Objects is allowed
@@ -278,8 +277,8 @@ class SCRIBUS_API ScActionPlugin : public ScPlugin
 			QList<int> secondObjectType;	// when needsNumObjects is 2 this list contains the Object Types of the second object on the selection
 											// -1 indicates that any kind of object is possible. Otherwise the selection must contain the 2 Object Types
 											// for the Plugin Action to be enabled
-			bool enabledOnStartup;
-			bool enabledForStoryEditor;
+			bool enabledOnStartup {false};
+			bool enabledForStoryEditor {false};
 			QString seMenu;
 			QString seParentMenu;
 			QString seKeySequence;
@@ -432,7 +431,7 @@ class SCRIBUS_API ScActionPlugin : public ScPlugin
 		ActionInfo m_actionInfo;
 		// Obsolete - see runResult()
 		QString m_runResult;
-		ScribusDoc* m_Doc;
+		ScribusDoc* m_Doc {nullptr};
 };
 
 /**
@@ -513,7 +512,7 @@ class SCRIBUS_API ScPersistentPlugin : public ScPlugin
 //
 // The API version is currently simply incremented with each incompatible
 // change. Future versions may introduce a minor/major scheme if necessary.
-#define PLUGIN_API_VERSION 0x00000106
+#define PLUGIN_API_VERSION 0x00000107
 
 
 #endif
