@@ -91,6 +91,7 @@ class PagePalette;
 class PageSelector;
 class PrefsContext;
 class PrefsManager;
+class ContentPalette;
 class PropertiesPalette;
 class ResourceManager;
 class ScMWMenuManager;
@@ -106,7 +107,6 @@ class SimpleState;
 class StoryEditor;
 class StyleManager;
 class SymbolPalette;
-class TextPalette;
 class TOCGenerator;
 class UndoManager;
 class UndoPalette;
@@ -133,7 +133,12 @@ public:
 	/*!
 	* \retval 0 - ok, 1 - no fonts, ...
 	*/
-	int initScMW(bool primaryMainwWindow);
+	int initScMW(bool primaryMainWindow);
+	void setupMainWindow();
+	int getScreenNumber() const;
+	QScreen* getScreen() const;
+	void getScreenPosition(int& xPos, int& yPos) const;
+	void getScreenDPI(int& dpiX, int& dpiY) const;
 	void addScToolBar(ScToolBar *tb, const QString& name);
 	bool warningVersion(QWidget *parent);
 	void SetShortCut();
@@ -147,19 +152,21 @@ public:
 	ScribusDoc *doFileNew(double width, double height, double topMargin, double leftMargin, double rightMargin, double bottomMargin, double columnDistance, double columnCount, bool autoTextFrames, int pageArrangement, int unitIndex, int firstPageLocation, int orientation, int firstPageNumber, const QString& defaultPageSize, bool requiresGUI, int pageCount=1, bool showView=true, int marginPreset=0);
 	ScribusDoc *newDoc(double width, double height, double topMargin, double leftMargin, double rightMargin, double bottomMargin, double columnDistance, double columnCount, bool autoTextFrames, int pageArrangement, int unitIndex, int firstPageLocation, int orientation, int firstPageNumber, const QString& defaultPageSize, bool requiresGUI, int pageCount=1, bool showView=true, int marginPreset=0);
 	bool DoFileSave(const QString& fileName, QString* savedFileName = nullptr);
-	void changeEvent(QEvent *e);
-	void closeEvent(QCloseEvent *ce);
-	void keyPressEvent(QKeyEvent *k);
-	void keyReleaseEvent(QKeyEvent *k);
-	void inputMethodEvent (QInputMethodEvent *event);
-	QVariant inputMethodQuery ( Qt::InputMethodQuery query ) const ;
+
+	void changeEvent(QEvent *e) override;
+	void closeEvent(QCloseEvent *ce) override;
+	void keyPressEvent(QKeyEvent *k) override;
+	void keyReleaseEvent(QKeyEvent *k) override;
+	void inputMethodEvent (QInputMethodEvent *event) override;
+	QVariant inputMethodQuery ( Qt::InputMethodQuery query ) const override;
+
 	void requestUpdate(int);
 	void setTBvals(PageItem *currItem);
 	int ShowSubs();
 	void applyNewMaster(const QString& name);
 	void updateRecent(const QString& fn);
 	void doPasteRecent(const QString& data);
-	bool getPDFDriver(const QString & filename, const QString & name, int components, const std::vector<int> & pageNumbers, const QMap<int, QImage> & thumbs, QString& error, bool* cancelled = nullptr);
+	bool getPDFDriver(const QString & filename, const std::vector<int> & pageNumbers, const QMap<int, QImage> & thumbs, QString& error, bool* cancelled = nullptr);
 	bool DoSaveAsEps(const QString& fn, QString& error);
 	QString CFileDialog(const QString& workingDirectory = ".", const QString& dialogCaption = "", const QString& fileFilter = "", const QString& defNa = "",
 						int optionFlags = fdExistingFiles, bool *useCompression = 0, bool *useFonts = 0, bool *useProfiles = 0);
@@ -179,13 +186,14 @@ public:
 	 * @brief Returns true if an arrow key is pressed down.
 	 * @return true if an arrow key is pressed down otherwise returns false
 	 */
-	bool arrowKeyDown();
+	//bool arrowKeyDown();
+
 	/**
 	 * @brief Returns true if application is in object specific undo mode, other wise returns false.
 	 * @return true if application is in object specific undo mode, other wise returns false
 	 */
 	bool isObjectSpecificUndo();
-	void restore(UndoState* state, bool isUndo);
+	void restore(UndoState* state, bool isUndo) override;
 	void restoreGrouping(SimpleState *state, bool isUndo);
 	void restoreUngrouping(SimpleState *state, bool isUndo);
 	void restoreAddPage(SimpleState *state, bool isUndo);
@@ -196,65 +204,65 @@ public:
 	bool internalCopy;
 	QString internalCopyBuffer;
 	int  HaveDoc;
-	PrefsContext* dirs;
+	PrefsContext* dirs {nullptr};
 	/** \brief view is the main widget which represents your working area. The View
 	 * class should handle all events of the view widget.  It is kept empty so
 	 * you can create your view according to your application's needs by
 	 * changing the view class.
 	 */
-	ScribusView *view;
+	ScribusView *view {nullptr};
 	/** \brief doc represents your actual document and is created only once. It keeps
 	 * information such as filename and does the serialization of your files.
 	 */
-	ScribusDoc *doc;
+	ScribusDoc *doc {nullptr};
 	/** \brief private doc for managing default patterns. */
-	ScribusDoc* m_doc;
+	ScribusDoc* m_doc {nullptr};
 
 
-	QProgressBar* mainWindowProgressBar;
+	QProgressBar* mainWindowProgressBar {nullptr};
 	ScrSpinBox* zoomSpinBox; //zoom spinbox at bottom of view
 	PageSelector* pageSelector; //Page selector at bottom of view
-	QPushButton *zoomDefaultToolbarButton;
-	QPushButton *zoomOutToolbarButton;
-	QPushButton *zoomInToolbarButton;
-	QComboBox *layerMenu; //Menu for layers at bottom of view
-	QComboBox *unitSwitcher; //Menu for units at bottom of view
-	EditToolBar *editToolBar;
-	FileToolBar *fileToolBar;
-	ModeToolBar* modeToolBar;
-	PDFToolBar* pdfToolBar;
-	ViewToolBar* viewToolBar;
-	QLabel* mainWindowXPosLabel;
-	QLabel* mainWindowXPosDataLabel;
-	QLabel* mainWindowYPosLabel;
-	QLabel* mainWindowYPosDataLabel;
-	GuideManager *guidePalette;
-	CharSelect *charPalette;
-	PropertiesPalette *propertiesPalette;
-	TextPalette *textPalette;
-	MarksManager *marksManager;
-	NotesStylesEditor *nsEditor;
-	NodePalette *nodePalette;
-	OutlinePalette *outlinePalette;
-	Biblio *scrapbookPalette;
-	LayerPalette* layerPalette;
-	PagePalette *pagePalette;
-	BookPalette *bookmarkPalette;
-	DownloadsPalette *downloadsPalette;
-	SymbolPalette *symbolPalette;
-	InlinePalette *inlinePalette;
-	Measurements* measurementPalette;
-	CheckDocument * docCheckerPalette;
-	UndoPalette* undoPalette;
-	AlignDistributePalette *alignDistributePalette;
-	ResourceManager *resourceManager;
-	StoryEditor* storyEditor;
-	StoryEditor* CurrStED;
-	QMdiArea *mdiArea;
-	ScribusWin* ActWin;
-	QClipboard *ClipB;
+	QPushButton *zoomDefaultToolbarButton {nullptr};
+	QPushButton *zoomOutToolbarButton {nullptr};
+	QPushButton *zoomInToolbarButton {nullptr};
+	QComboBox *layerMenu {nullptr}; //Menu for layers at bottom of view
+	QComboBox *unitSwitcher {nullptr}; //Menu for units at bottom of view
+	EditToolBar *editToolBar {nullptr};
+	FileToolBar *fileToolBar {nullptr};
+	ModeToolBar* modeToolBar {nullptr};
+	PDFToolBar* pdfToolBar {nullptr};
+	ViewToolBar* viewToolBar {nullptr};
+	QLabel* mainWindowXPosLabel {nullptr};
+	QLabel* mainWindowXPosDataLabel {nullptr};
+	QLabel* mainWindowYPosLabel {nullptr};
+	QLabel* mainWindowYPosDataLabel {nullptr};
+	GuideManager *guidePalette {nullptr};
+	CharSelect *charPalette {nullptr};
+	PropertiesPalette *propertiesPalette {nullptr};
+	ContentPalette *contentPalette {nullptr};
+	MarksManager *marksManager {nullptr};
+	NotesStylesEditor *nsEditor {nullptr};
+	NodePalette *nodePalette {nullptr};
+	OutlinePalette *outlinePalette {nullptr};
+	Biblio *scrapbookPalette {nullptr};
+	LayerPalette* layerPalette {nullptr};
+	PagePalette *pagePalette {nullptr};
+	BookPalette *bookmarkPalette {nullptr};
+	DownloadsPalette *downloadsPalette {nullptr};
+	SymbolPalette *symbolPalette {nullptr};
+	InlinePalette *inlinePalette {nullptr};
+	Measurements* measurementPalette {nullptr};
+	CheckDocument * docCheckerPalette {nullptr};
+	UndoPalette* undoPalette {nullptr};
+	AlignDistributePalette *alignDistributePalette {nullptr};
+	ResourceManager *resourceManager {nullptr};
+	StoryEditor* storyEditor {nullptr};
+	StoryEditor* CurrStED {nullptr};
+	QMdiArea *mdiArea {nullptr};
+	ScribusWin* ActWin {nullptr};
+	QClipboard *ClipB {nullptr};
 	QString LoadEnc;
-	AppModeHelper *appModeHelper;
+	AppModeHelper *appModeHelper {nullptr};
 
 	QMap<QString, QPointer<ScrAction> > scrActions;
 	QMap<QString, QPointer<ScrAction> > scrRecentFileActions;
@@ -264,13 +272,15 @@ public:
 	QMap<QString, QPointer<ScrAction> > scrRecentPasteActions;
 	QMap<QString, QPointer<ScToolBar> > scrToolBars;
 	QMultiHash<QString, QActionGroup*> scrActionGroups;
-	ScMWMenuManager* scrMenuMgr;
-	ActionManager* actionManager;
+	ScMWMenuManager* scrMenuMgr {nullptr};
+	ActionManager* actionManager {nullptr};
 	QStringList m_recentDocsList;
 	QStringList patternsDependingOnThis;
 
 public slots:
+	void iconSetChange();
 	void languageChange();
+	void localeChange();
 	void statusBarLanguageChange();
 	void specialActionKeyEvent(int unicodevalue);
 	void newView();
@@ -306,7 +316,7 @@ public slots:
 	void changeLayer(int);
 	void setLayerMenuText(const QString &);
 	void showLayer();
-	void slotSetCurrentPage(int Seite);
+	void slotSetCurrentPage(int pageIndex);
 	void setCurrentPage(int p);
 	void ManageJava();
 	void editSelectedSymbolStart();
@@ -321,7 +331,7 @@ public slots:
 	void newFileFromTemplate();
 	bool slotPageImport();
 	bool loadPage(const QString& fileName, int Nr, bool Mpa, const QString& renamedPageName=QString());
-	void GotoLa(int l);
+	void gotoLayer(int l);
 	void slotGetContent();
 	void slotGetContent2(); // kk2006
 	void slotGetClipboardImage();
@@ -380,12 +390,11 @@ public slots:
 	void slotEditPaste();
 	void slotEditCopyContents();
 	void slotEditPasteContents(int absolute=0);
-	void EnableTxEdit();
-	void DisableTxEdit();
 	void SelectAll(bool docWideSelect=false);
 	void SelectAllOnLayer();
 	void deselectAll();
 	void ClipChange();
+	void setCopyCutEnabled(bool b);
 	/** \brief shows an about dialog*/
 	void slotHelpAbout();
 	void slotHelpAboutPlugins();
@@ -490,6 +499,10 @@ public slots:
 	void selectPagesFromOutlines(int ScPage);
 	void doPrintPreview();
 	void printPreview();
+	void doOutputPreviewPDF();
+	void outputPreviewPDF();
+	void doOutputPreviewPS();
+	void outputPreviewPS();
 	void SaveAsEps();
 	void reallySaveAsEps();
 	void SaveAsPDF();
@@ -584,9 +597,9 @@ protected:
 	/*!
 	\brief Receive key events from palettes such as palette hiding events. Possibly easier way but this is cleaner than before. No need to modify all those palettes and each new one in future.
 	 */
-	bool eventFilter( QObject *o, QEvent *e );
-	virtual void dragEnterEvent( QDragEnterEvent* e);
-	virtual void dropEvent( QDropEvent* e);
+	bool eventFilter( QObject *o, QEvent *e ) override;
+	void dragEnterEvent( QDragEnterEvent* e) override;
+	void dropEvent( QDropEvent* e) override;
 
 private:
     /** init methods */
@@ -604,12 +617,11 @@ private:
 	void initKeyboardShortcuts();
 	void initPalettes();
 	void initScrapbook();
-
 	void updateColorMenu(QProgressBar* progressBar=nullptr);
 
-	int m_ScriptRunning;
+	int m_ScriptRunning {0};
 
-	QLabel* m_mainWindowStatusLabel;
+	QLabel* m_mainWindowStatusLabel {nullptr};
 	QString m_statusLabelText;
 	//QPixmap noIcon;
 
@@ -626,12 +638,12 @@ private:
 	int m_viewBopal;
 	int m_viewUndoPalette;
 
-	bool m_palettesStatus[12];
+	bool m_palettesStatus[13];
 	bool m_guidesStatus[13];
 
-	bool m_keyrep;
+	//bool m_keyrep;
 	/** @brief Tells if an arrow key is pressed down */
-	bool m__arrowKeyDown;
+	//bool m_arrowKeyDown;
 	/** @brief tells the undo mode */
 	bool m_objectSpecificUndo;
 
@@ -645,15 +657,12 @@ private:
 					QString Dname;
 					QString Command;
 				} PDef ;
-	TOCGenerator *m_tocGenerator;
-	int m_storedPageNum;
-	int m_storedViewXCoor;
-	int m_storedViewYCoor;
-	double m_storedViewScale;
-	StyleManager *m_styleManager;
-	UndoManager *m_undoManager;
+	TOCGenerator *m_tocGenerator {nullptr};
+
+	StyleManager *m_styleManager {nullptr};
+	UndoManager *m_undoManager {nullptr};
 	PrefsManager& m_prefsManager;
-	FormatsManager *m_formatsManager;
+	FormatsManager *m_formatsManager {nullptr};
 
 	QPointer<HelpBrowser> m_helpBrowser;
 	QString m_osgFilterString;
@@ -663,8 +672,6 @@ private:
 	int m_marksCount; //remember marks count from last call
 	bool m_WasAutoSave;
 	bool m_pagePalVisible;
-
-	//QQuickView *m_qqview;
 };
 
 #endif
