@@ -28,17 +28,16 @@ for which a new license (GPL+exception) is in place.
 #include "scribusapi.h"
 
 #include "annotation.h"
+#include "colormgmt/sccolormgmtstructs.h"
 #include "fpointarray.h"
-#include "pageitem.h"
 #include "margins.h"
+#include "pageitem.h"
 #include "sccolorstructs.h"
 #include "scfonts.h"
 #include "scimagestructs.h"
 #include "sctextstruct.h"
+#include "util_math.h"
 #include "vgradient.h"
-#include "colormgmt/sccolormgmtstructs.h"
-
-extern bool SCRIBUS_API compareDouble(double, double);
 
 struct CopyContentsBuffer
 {
@@ -59,17 +58,17 @@ struct CopyContentsBuffer
 
 struct DocPagesSetup
 {
-	DocPagesSetup() : pageArrangement(0), firstPageLocation(0), firstPageNumber(0), orientation(0), autoTextFrames(false), columnDistance(0), columnCount(1) {}
+	DocPagesSetup() = default;
 	DocPagesSetup(int pa, int fpl, int fpn, int o, bool atf, double cd, double cc) :
 		pageArrangement(pa), firstPageLocation(fpl), firstPageNumber(fpn), orientation(o), autoTextFrames(atf),
 		columnDistance(cd), columnCount(cc) {}
-	int pageArrangement;
-	int firstPageLocation;
-	int firstPageNumber;
-	int orientation;
-	bool autoTextFrames;
-	double columnDistance;
-	double columnCount;
+	int pageArrangement {0};
+	int firstPageLocation {0};
+	int firstPageNumber {0};
+	int orientation {0};
+	bool autoTextFrames {false};
+	double columnDistance {0.0};
+	double columnCount {1.0};
 };
 
 struct PageSet
@@ -100,7 +99,39 @@ struct CMSData
 	bool SoftProofFullOn;
 	bool GamutCheck;
 	bool BlackPoint;
-} ;
+};
+
+enum
+{
+	Gradient_None = 0,
+	Gradient_LinearLegacy1 = 1,
+	Gradient_LinearLegacy2 = 2,
+	Gradient_LinearLegacy3 = 3,
+	Gradient_LinearLegacy4 = 4,
+	Gradient_RadialLegacy5 = 5,
+	Gradient_Linear = 6,
+	Gradient_Radial = 7,
+	Gradient_Pattern = 8,
+	Gradient_4Colors = 9,
+	Gradient_Diamond = 10,
+	Gradient_Mesh = 11,
+	Gradient_PatchMesh = 12,
+	Gradient_Conical = 13,
+	Gradient_Hatch = 14
+};
+
+enum
+{
+	GradMask_None = 0,
+	GradMask_Linear = 1,
+	GradMask_Radial = 2,
+	GradMask_Pattern = 3,
+	GradMask_LinearLumAlpha = 4,
+	GradMask_RadialLumAlpha = 5,
+	GradMask_PatternLumAlpha = 6,
+	GradMask_PatternLumAlphaInverted = 7,
+	GradMask_PatternInverted = 8
+};
 
 struct SingleLine
 {
@@ -155,26 +186,20 @@ struct ArrowDesc
 
 struct PDFPresentationData
 {
-	PDFPresentationData()
-	{
-		pageEffectDuration = 1;
-		pageViewDuration = 1;
-		effectType = 0;
-		Dm = M = Di = 0;
-	}
-	int pageEffectDuration;
-	int pageViewDuration;
-	int effectType;
-	int Dm;
-	int M;
-	int Di;
+	PDFPresentationData() = default;
+	int pageEffectDuration {1};
+	int pageViewDuration {1};
+	int effectType {0};
+	int Dm {0};
+	int M {0};
+	int Di {0};
 };
 
 struct LPIData
 {
-	int Frequency;
-	int Angle;
-	int SpotFunc;
+	int Frequency {0};
+	int Angle {0};
+	int SpotFunc {0};
 };
 
 struct Keys
@@ -187,44 +212,45 @@ struct Keys
 	int menuPos;
 };
 
-enum PrintEngine
+enum class PrintLanguage
 {
 	PostScript1 = 1,
 	PostScript2 = 2,
 	PostScript3 = 3,
-	WindowsGDI  = 4
+	WindowsGDI  = 4,
+	PDF         = 5
 };
-typedef QMap<QString, PrintEngine> PrintEngineMap;
+typedef QMap<QString, PrintLanguage> PrintLanguageMap;
 
 struct PrintOptions
 {
-	bool firstUse;
-	bool toFile;
-	bool useAltPrintCommand;
-	bool outputSeparations;
-	bool useSpotColors;
-	bool useColor;
-	bool mirrorH;
-	bool mirrorV;
-	bool doGCR;
-	bool doClip;
-	bool setDevParam;
-	bool useDocBleeds;
-	bool cropMarks;
-	bool bleedMarks;
-	bool registrationMarks;
-	bool colorMarks;
-	bool includePDFMarks;
-	int  copies;
-	PrintEngine prnEngine;
-	double markLength;
-	double markOffset;
+	bool firstUse { true };
+	bool toFile { false };
+	bool useAltPrintCommand { false };
+	bool outputSeparations { false };
+	bool useSpotColors { true };
+	bool useColor { true };
+	bool mirrorH { false };
+	bool mirrorV { false };
+	bool doGCR { false };
+	bool doClip { false };
+	bool setDevParam { false };
+	bool useDocBleeds { true };
+	bool cropMarks { false };
+	bool bleedMarks { false };
+	bool registrationMarks { false };
+	bool colorMarks { false };
+	bool includePDFMarks { true };
+	int  copies { 1 };
+	PrintLanguage prnLanguage { PrintLanguage::PostScript3 };
+	double markLength { 20.0 };
+	double markOffset { 0.0 };
 	MarginStruct bleeds;
 	std::vector<int> pageNumbers;
 	QString printerOptions;
 	QString printer;
 	QString filename;
-	QString separationName;
+	QString separationName { "All" };
 	QStringList allSeparations;
 	QString printerCommand;
 	QByteArray devMode; // printer specific options on Windows
@@ -242,7 +268,8 @@ public:
 	}
 };
 
-typedef enum {
+enum PreflightError
+{
 	MissingGlyph = 1,
 	TextOverflow = 2,
 	ObjectNotOnPage = 3,
@@ -264,7 +291,7 @@ typedef enum {
 	MarksChanged = 19,
 	AppliedMasterDifferentSide = 20,
 	EmptyTextFrame = 21
-} PreflightError;
+};
 
 typedef QMap<PreflightError, int> errorCodes;
 
@@ -293,7 +320,8 @@ enum PageOrientation
 /**
 * Flags for ScribusView PageToPixmap()
 */
-enum PageToPixmapFlag {
+enum PageToPixmapFlag
+{
 	Pixmap_NoFlags = 0,
 	Pixmap_DrawFrame = 1 << 0,
 	Pixmap_DrawBackground = 1 << 1,
@@ -335,7 +363,8 @@ struct Linked
 };
 
 // this is a quick hack to combine runs until I've thought of something better -- AV
-class LastStyles {
+class LastStyles
+{
 public:
 	CharStyle Style;
 	int StyleStart;
@@ -348,12 +377,10 @@ public:
 class AttributeValue
 {
 	public:
-		AttributeValue() : valid(false)
-		{
-		}
+		AttributeValue() = default;
 		AttributeValue(const QString& val)
 		{
-			if (val.isEmpty() || (val == ""))
+			if (val.isEmpty())
 			{
 				valid = false;
 				value.clear();
@@ -364,7 +391,7 @@ class AttributeValue
 				value = val;
 			}
 		}
-		bool valid;
+		bool valid {false};
 		QString value;
 };
 
@@ -415,6 +442,7 @@ enum
 	GS_MAX
 };
 
+//Always add new at the end, leave existing and deprecated items in the list
 enum
 {
 	PAL_ALL,
@@ -429,6 +457,7 @@ enum
 	PAL_VERIFIER,
 	PAL_DOWNLOADS,
 	PAL_TEXT,
+	PAL_CONTENT,
 	PAL_MAX
 };
 
