@@ -6,6 +6,7 @@
  */
 
 #include <cmath>
+#include <unicode/brkiter.h>
 
 #include "pageitem.h"
 #include "boxes.h"
@@ -21,6 +22,8 @@
 #include "itextcontext.h"
 #include "itextsource.h"
 
+using namespace icu;
+
 int GroupBox::pointToPosition(QPointF coord, const StoryText &story) const
 {
 	QPointF rel = coord - QPointF(m_x, m_y);
@@ -126,7 +129,8 @@ void GroupBox::removeBox(int i)
 void GroupBox::update()
 {
 	m_naturalHeight = m_naturalWidth = 0;
-	for (const Box* box : boxes()) {
+	for (const Box* box : boxes())
+	{
 		m_firstChar = qMin(m_firstChar, box->firstChar());
 		m_lastChar = qMax(m_lastChar, box->lastChar());
 		if (m_direction == D_Horizontal)
@@ -140,8 +144,6 @@ void GroupBox::update()
 			m_naturalHeight = ceil(box->y() + box->ascent() - box->naturalDescent());
 		}
 	}
-
-//	emit boxChanged();
 }
 
 #if 0
@@ -242,8 +244,11 @@ void LineBox::render(ScreenPainter *p, ITextContext *ctx) const
 
 void LineBox::drawSelection(ScreenPainter *p, ITextContext *ctx) const
 {
+	p->save();
+	p->translate(0, ascent());
 	for (const Box *box : boxes())
 		box->drawSelection(p, ctx);
+	p->restore();
 }
 
 void LineBox::drawBackGround(TextLayoutPainter *p) const
@@ -338,8 +343,6 @@ void LineBox::update()
 		m_naturalAscent = qMax(m_naturalAscent, box->naturalAsc());
 		m_naturalDescent = qMin(m_naturalDescent, box->naturalDescent());
 	}
-
-//	emit boxChanged();
 }
 
 #if 0
@@ -463,12 +466,11 @@ void LineBox::justify(const ParagraphStyle& style)
 
 void PathLineBox::update()
 {
-	for (Box* box : boxes()) {
+	for (Box* box : boxes())
+	{
 		m_firstChar = qMin(m_firstChar, box->firstChar());
 		m_lastChar = qMax(m_lastChar, box->lastChar());
 	}
-
-//	emit boxChanged();
 }
 
 void PathLineBox::drawBackGround(TextLayoutPainter *p) const
@@ -562,7 +564,7 @@ void GlyphBox::drawSelection(ScreenPainter *p, ITextContext *ctx) const
 		}
 	}
 
-	QRectF rect(x(), 0, width(), height());
+	QRectF rect(x(), -ascent(), width(), height());
 	p->setSelected(true);
 	p->setStrokeWidth(0);
 
