@@ -22,6 +22,8 @@ pageitem.cpp  -  description
 ***************************************************************************/
 
 //#include <QDebug>
+#include <unicode/brkiter.h>
+
 //FIXME: this include must go to sctextstruct.h !
 #include <QList>
 #include <cassert>  //added to make Fedora-5 happy
@@ -40,6 +42,7 @@ pageitem.cpp  -  description
 #include "desaxe/simple_actions.h"
 #include "shapedtextcache.h"
 
+using namespace icu;
 
 StoryText::StoryText(ScribusDoc * doc_) : m_doc(doc_)
 {
@@ -52,8 +55,8 @@ StoryText::StoryText(ScribusDoc * doc_) : m_doc(doc_)
 	else
 		d = new ScText_Shared(nullptr);
 
-	m_selFirst = 0;
-	m_selLast = -1;
+	d->selFirst = 0;
+	d->selLast = -1;
 	
 	m_shapedTextCache = new ShapedTextCache();
 	
@@ -65,8 +68,8 @@ StoryText::StoryText() : m_doc(nullptr)
 {
 	d = new ScText_Shared(nullptr);
 
-	m_selFirst = 0;
-	m_selLast = -1;
+	d->selFirst = 0;
+	d->selLast = -1;
 	m_shapedTextCache = nullptr;
 }
 
@@ -81,8 +84,8 @@ StoryText::StoryText(const StoryText & other) : m_doc(other.m_doc)
 		m_doc->charStyles().connect(this, SLOT(invalidateAll()));
 	}
 	
-	m_selFirst = 0;
-	m_selLast = -1;
+	d->selFirst = 0;
+	d->selLast = -1;
 	m_shapedTextCache = nullptr;
 
 	invalidateLayout();
@@ -106,6 +109,45 @@ StoryText::~StoryText()
 	}	
 }
 
+bool StoryText::hasBulletOrNum() const
+{
+	if (!d)
+		return false;
+
+	bool lastWasPARSEP = true;
+	for (int i = 0; i < length(); ++i)
+	{
+		lastWasPARSEP = (d->at(i)->ch == SpecialChars::PARSEP);
+		if (!lastWasPARSEP)
+			continue;
+		const ParagraphStyle& paraStyle = paragraphStyle(i);
+		if (paraStyle.hasBullet() || paraStyle.hasNum())
+			return true;
+	}
+
+	const ParagraphStyle& trailingStyle = d->trailingStyle;
+	return (trailingStyle.hasBullet() || trailingStyle.hasNum());
+}
+
+bool StoryText::hasTextMarks() const
+{
+	if (d)
+		return (d->marksCount > 0);
+	return false;
+}
+
+bool StoryText::marksCountChanged() const
+{
+	if (d)
+		return d->marksCountChanged;
+	return false;
+}
+
+void StoryText::resetMarksCountChanged()
+{
+	d->marksCountChanged = false;
+}
+
 void StoryText::setDoc(ScribusDoc *docin)
 {
 	if (m_doc)
@@ -156,8 +198,8 @@ StoryText& StoryText::operator= (const StoryText & other)
 		m_doc->charStyles().connect(this, SLOT(invalidateAll()));
 	}
 	
-	m_selFirst = 0;
-	m_selLast = -1;
+	d->selFirst = 0;
+	d->selLast = -1;
 
 	invalidateLayout();
 	return *this;
@@ -294,8 +336,8 @@ void StoryText::moveCursorWordRight()
 
 void StoryText::clear()
 {
-	m_selFirst = 0;
-	m_selLast = -1;
+	d->selFirst = 0;
+	d->selLast = -1;
 	
 	d->defaultStyle.erase();
 	d->trailingStyle.erase();
@@ -431,7 +473,7 @@ void StoryText::insert(const StoryText& other, bool onlySelection)
 void StoryText::insert(int pos, const StoryText& other, bool onlySelection)
 {
 	if (pos < 0)
-		pos += length()+1;
+		pos += length() + 1;
 	
 	CharStyle cstyle(charStyle(pos));
 	ParagraphStyle pstyle(paragraphStyle(pos));
@@ -440,6 +482,8 @@ void StoryText::insert(int pos, const StoryText& other, bool onlySelection)
 	ParagraphStyle otherDefault(other.defaultStyle());
 	otherDefault.eraseStyle(defaultStyle());
 	
+	int oldPos = pos;
+	int oldLen = length();
 	int otherStart  = onlySelection? other.startOfSelection() : 0;
 	int otherEnd    = onlySelection? other.endOfSelection() : other.length();
 	int cstyleStart = otherStart;
@@ -471,6 +515,11 @@ void StoryText::insert(int pos, const StoryText& other, bool onlySelection)
 			insertChars(pos, SpecialChars::OBJECT);
 			item(pos)->embedded = other.item(i)->embedded;
 			item(pos)->mark = other.item(i)->mark;
+			if (item(pos)->mark)
+			{
+				d->marksCount++;
+				d->marksCountChanged = true;
+			}
 			applyCharStyle(pos, 1, other.charStyle(i));
 			cstyleStart = i+1;
 			pos += 1;
@@ -495,6 +544,8 @@ void StoryText::insert(int pos, const StoryText& other, bool onlySelection)
 			applyStyle(pos, other.paragraphStyle(otherEnd-1));
 		}
 	}
+	if ((d->selLast >= d->selFirst) && (d->selFirst <= oldPos) && (oldPos <= d->selLast))
+		d->selLast += (length() - oldLen);
 	invalidate(pos, length());
 }
 
@@ -555,7 +606,9 @@ void StoryText::removeChars(int pos, uint len)
 	if (pos + static_cast<int>(len) > length())
 		len = length() - pos;
 
-	if (pos == 0 && len > 0 && len == length())
+	uint oldMarksCount = d->marksCount;
+
+	if ((pos == 0) && (len > 0) && (static_cast<int>(len) == length()))
 	{
 		int lastChar = length() - 1;
 		while (lastChar > 0 && text(lastChar) == SpecialChars::PARSEP)
@@ -565,27 +618,32 @@ void StoryText::removeChars(int pos, uint len)
 	for (int i = pos + static_cast<int>(len) - 1; i >= pos; --i)
 	{
 		ScText *it = d->at(i);
-		if ((it->ch == SpecialChars::PARSEP))
+		if (it->ch == SpecialChars::PARSEP)
 			removeParSep(i);
+		if ((it->ch == SpecialChars::OBJECT) && (it->mark != nullptr))
+			d->marksCount--;
 		d->takeAt(i);
 		d->len--;
 		delete it;
-		// #9592 : adjust m_selFirst and m_selLast, those values have to be
+		// #9592 : adjust d->selFirst and d->selLast, those values have to be
 		// consistent in functions such as select()
-		if (i <= m_selLast)
-			--m_selLast;
-		if (i < m_selFirst)
-			--m_selFirst;
-		if (static_cast<uint>(i + 1 ) <= d->cursorPosition && d->cursorPosition > 0)
+		if (i <= d->selLast)
+			--d->selLast;
+		if (i < d->selFirst)
+			--d->selFirst;
+		if (static_cast<uint>(i + 1) <= d->cursorPosition && d->cursorPosition > 0)
 			d->cursorPosition -= 1;
 	}
 
+	if (oldMarksCount != d->marksCount)
+		d->marksCountChanged = true;
+
 	d->len = d->count();
 	d->cursorPosition = qMin(d->cursorPosition, d->len);
-	if (m_selFirst > m_selLast)
+	if (d->selFirst > d->selLast)
 	{
-		m_selFirst =  0;
-		m_selLast  = -1;
+		d->selFirst =  0;
+		d->selLast  = -1;
 	}
 	invalidate(pos, length());
 }
@@ -624,7 +682,7 @@ void StoryText::insertChars(const QString& txt, bool applyNeighbourStyle) //, co
 void StoryText::insertChars(int pos, const QString& txt, bool applyNeighbourStyle) //, const CharStyle & charstyle)
 {
 	if (pos < 0)
-		pos += length()+1;
+		pos += length() + 1;
 
 	assert(pos >= 0);
 	assert(pos <= length());
@@ -659,13 +717,15 @@ void StoryText::insertChars(int pos, const QString& txt, bool applyNeighbourStyl
 	}
 
 	d->len = d->count();
+	if ((d->selLast >= d->selFirst) && (d->selFirst <= pos) && (pos <= d->selLast))
+		d->selLast += txt.length();
 	invalidate(pos, pos + txt.length());
 }
 
 void StoryText::insertCharsWithSoftHyphens(int pos, const QString& txt, bool applyNeighbourStyle)
 {
 	if (pos < 0)
-		pos += length()+1;
+		pos += length() + 1;
 
 	assert(pos >= 0);
 	assert(pos <= length());
@@ -678,7 +738,7 @@ void StoryText::insertCharsWithSoftHyphens(int pos, const QString& txt, bool app
 	ScText clone;
 	if (applyNeighbourStyle)
 	{
-		int referenceChar = qMax(0, qMin(pos, length()-1));
+		int referenceChar = qMax(0, qMin(pos, length() - 1));
 		clone.applyCharStyle(charStyle(referenceChar));
 		clone.setEffects(ScStyle_Default);
 	}
@@ -717,6 +777,8 @@ void StoryText::insertCharsWithSoftHyphens(int pos, const QString& txt, bool app
 	}
 
 	d->len = d->count();
+	if ((d->selLast >= d->selFirst) && (d->selFirst <= pos) && (pos <= d->selLast))
+		d->selLast += inserted;
 	invalidate(pos, pos + inserted);
 }
 
@@ -731,48 +793,78 @@ void StoryText::replaceChar(int pos, QChar ch)
 	ScText* item = d->at(pos);
 	if (item->ch == ch)
 		return;
+
+	uint oldMarksCount = d->marksCount;
 	
-	if (d->at(pos)->ch == SpecialChars::PARSEP)
+	if (item->ch == SpecialChars::PARSEP)
 		removeParSep(pos);
+	if ((item->ch == SpecialChars::OBJECT) && (item->mark != nullptr))
+		d->marksCount--;
 	item->ch = ch;
 	if (d->at(pos)->ch == SpecialChars::PARSEP)
 		insertParSep(pos);
+
+	if (oldMarksCount != d->marksCount)
+		d->marksCountChanged = true;
 	
 	invalidate(pos, pos + 1);
 }
 
+void StoryText::replaceSelection(const QString& newText)
+{
+	if (selectionLength() <= 0)
+		return;
+
+	int selStart = startOfSelection();
+	int selLength = selectionLength();
+
+	int lengthDiff = newText.length() - selLength;
+	if (lengthDiff == 0)
+	{
+		for (int i = 0; i < selLength; ++i)
+			replaceChar(selStart + i, newText[i]);
+	}
+	else if (lengthDiff > 0)
+	{
+		for (int i = 0; i < selLength; ++i)
+			replaceChar(selStart + i, newText[i]);
+		for (int i = selLength; i < newText.length(); ++i)
+			insertChars(selStart + i, newText.mid(i, 1), true);
+	}
+	else
+	{
+		for (int i = 0; i < newText.length(); ++i)
+			replaceChar(selStart + i, newText[i]);
+		removeChars(selStart + newText.length(), -lengthDiff);
+	}
+
+	deselectAll();
+	if (newText.length() > 0)
+		select(selStart, newText.length());
+	setCursorPosition(selStart + newText.length());
+}
+
 int StoryText::replaceWord(int pos, QString newWord)
 {
-	int eoWord=pos;
-	while (eoWord < length())
-	{
-		if (text(eoWord).isLetterOrNumber() || SpecialChars::isIgnorableCodePoint(text(eoWord).unicode()))
-			++eoWord;
-		else
-			break;
-	}
-	QString word = text(pos, eoWord - pos);
+	QString word = this->word(pos);
 	int lengthDiff = newWord.length() - word.length();
 	if (lengthDiff == 0)
 	{
 		for (int j = 0; j < word.length(); ++j)
-			replaceChar(pos+j, newWord[j]);
+			replaceChar(pos + j, newWord[j]);
+	}
+	else if (lengthDiff > 0)
+	{
+		for (int j = 0; j < word.length(); ++j)
+			replaceChar(pos + j, newWord[j]);
+		for (int j = word.length(); j < newWord.length(); ++j)
+			insertChars(pos + j, newWord.mid(j, 1), true);
 	}
 	else
 	{
-		if (lengthDiff>0)
-		{
-			for (int j = 0; j < word.length(); ++j)
-				replaceChar(pos+j, newWord[j]);
-			for (int j = word.length(); j < newWord.length(); ++j)
-				insertChars(pos+j, newWord.mid(j,1), true);
-		}
-		else
-		{
-			for (int j = 0; j < newWord.length(); ++j)
-				replaceChar(pos+j, newWord[j]);
-			removeChars(pos+newWord.length(), -lengthDiff);
-		}
+		for (int j = 0; j < newWord.length(); ++j)
+			replaceChar(pos + j, newWord[j]);
+		removeChars(pos + newWord.length(), -lengthDiff);
 	}
 	return lengthDiff;
 }
@@ -815,15 +907,20 @@ void StoryText::insertObject(int pos, int ob)
 	m_doc->FrameItems[ob]->OwnPage = -1; // #10379: OwnPage is not meaningful for inline object
 }
 
-void StoryText::insertMark(Mark* Mark, int pos)
+void StoryText::insertMark(Mark* mark, int pos)
 {
-	if (Mark == nullptr)
+	if (mark == nullptr)
 		return;
 	if (pos < 0)
 		pos = d->cursorPosition;
 
 	insertChars(pos, SpecialChars::OBJECT, false);
-	const_cast<StoryText *>(this)->d->at(pos)->mark = Mark;
+	d->at(pos)->mark = mark;
+	if (mark)
+	{
+		d->marksCount++;
+		d->marksCountChanged = true;
+	}
 }
 
 void StoryText::replaceObject(int pos, int ob)
@@ -901,7 +998,7 @@ QString StoryText::text(int pos, uint len) const
 
 bool StoryText::isBlockStart(int pos) const 
 {
-	return pos  == 0 || text(pos-1) == SpecialChars::PARSEP;
+	return pos == 0 || text(pos-1) == SpecialChars::PARSEP;
 }
 
 
@@ -952,10 +1049,32 @@ ExpansionPoint StoryText::expansionPoint(int pos) const
 
 QString StoryText::sentence(int pos, int &posn)
 {
-	int sentencePos=qMax(0, prevSentence(pos));
-	posn=sentencePos;
-	int nextSentencePos=qMin(length(), endOfSentence(pos));
-	return text(sentencePos, nextSentencePos-sentencePos);
+	int sentencePos = qMax(0, prevSentence(pos));
+	posn = sentencePos;
+	int nextSentencePos = qMin(length(), endOfSentence(pos));
+	return text(sentencePos, nextSentencePos - sentencePos);
+}
+
+QString StoryText::word(int pos)
+{
+	BreakIterator* it = getWordIterator();
+	if (it)
+	{
+		it->setText((const UChar*) plainText().utf16());
+		int end = it->following(pos);
+		return text(pos, end - pos);
+	}
+
+	// Fallback to old code
+	int eoWord = pos;
+	while (eoWord < length())
+	{
+		if (text(eoWord).isLetterOrNumber() || SpecialChars::isIgnorableCodePoint(text(eoWord).unicode()))
+			++eoWord;
+		else
+			break;
+	}
+	return text(pos, eoWord - pos);
 }
 
 QString StoryText::textWithSoftHyphens(int pos, uint len) const
@@ -1007,8 +1126,23 @@ PageItem* StoryText::getItem(int pos) const
 	return that->d->at(pos)->getItem(m_doc);
 }
 
+int StoryText::findMark(const Mark* mrk, int startPos) const
+{
+	assert(startPos >= 0);
 
-bool StoryText::hasMark(int pos, Mark* mrk) const
+	int len = d->len;
+	for (int i = startPos; i < len; ++i)
+	{
+		if (d->at(i)->ch != SpecialChars::OBJECT)
+			continue;
+		if (d->at(i)->hasMark(mrk))
+			return i;
+	}
+
+	return -1;
+}
+
+bool StoryText::hasMark(int pos, const Mark* mrk) const
 {
 	if (pos < 0)
 		pos += length();
@@ -1080,7 +1214,15 @@ void StoryText::replaceMark(int pos, Mark* mrk)
 	assert(pos >= 0);
 	assert(pos < length());
 
+	ScText* textItem = this->d->at(pos);
+	if (textItem->mark)
+		this->d->marksCount--;
 	this->d->at(pos)->mark = mrk;
+	if (textItem->mark)
+		this->d->marksCount++;
+
+	// Set marksCountChanged unconditionnaly to force text relayout
+	d->marksCountChanged = true;
 }
 
 
@@ -1163,7 +1305,7 @@ const CharStyle & StoryText::charStyle(int pos) const
 	}
 	if (pos == length())
 	{
-		qDebug() << "storytext::charstyle: access at end of text %i" << pos;
+		//qDebug() << "storytext::charstyle: access at end of text %i" << pos;
 		--pos;
 	}
 	
@@ -1620,7 +1762,7 @@ int StoryText::endOfRun(uint index) const
 int StoryText::nextChar(int pos)
 {
 	if (pos < length())
-		return pos+1;
+		return pos + 1;
 	return length();
 }
 
@@ -1653,7 +1795,10 @@ int StoryText::nextWord(int pos)
 
 	it->setText((const UChar*) plainText().utf16());
 	pos = it->following(pos);
-	pos = it->next();
+	
+	int len = length();
+	while ((pos < len) && (text(pos).isSpace() || text(pos).isPunct()))
+		++pos;
 	return pos;
 }
 
@@ -1718,52 +1863,61 @@ int StoryText::prevSentence(int pos)
 int StoryText::nextParagraph(int pos)
 {
 	int len = length();
-	pos = qMin(len, pos+1);
+	pos = qMin(len, pos + 1);
 	while (pos < len && text(pos) != SpecialChars::PARSEP)
 		++pos;
 	return pos;
 }
 int StoryText::prevParagraph(int pos)
 {
-	pos = qMax(0, pos-1);
+	pos = qMax(0, pos - 1);
 	while (pos > 0 && text(pos) != SpecialChars::PARSEP)
 		--pos;
 	return pos;
 }
 
-
-
 // selection
-
 int StoryText::startOfSelection() const
 {
-	return m_selFirst <= m_selLast? m_selFirst : 0;
+	return d->selFirst <= d->selLast? d->selFirst : 0;
 }
 
 int StoryText::endOfSelection() const
 {
-	return m_selFirst <= m_selLast? m_selLast + 1 : -1;
+	return d->selFirst <= d->selLast? d->selLast + 1 : -1;
 }
 
 int StoryText::selectionLength() const
 {
 	//FIX ME - sometimes I saw values equal or greater than length of text
-	int last = m_selLast;
-	if (m_selFirst >= length())
+	int last = d->selLast;
+	if (d->selFirst >= length())
 		return 0;
-	if (m_selLast >= length())
+	if (d->selLast >= length())
 		last = length() -1;
-	return m_selFirst <= last? last - m_selFirst + 1 : 0;
+	return d->selFirst <= last? last - d->selFirst + 1 : 0;
+}
+
+bool StoryText::hasSelection() const
+{
+	return selectionLength() > 0;
 }
 
 
 bool StoryText::selected(int pos) const
 {
-	return (m_selFirst <= pos && pos <= m_selLast) 
+	return (d->selFirst <= pos && pos <= d->selLast) 
 //	       || (pos >= 0 && pos < length() && const_cast<StoryText*>(this)->d->at(pos)->cselect)
 	;
 }
 
+QString StoryText::selectedText() const
+{
+	int selLen = selectionLength();
+	if (selLen <= 0)
+		return QString();
+	return text(startOfSelection(), selLen);
+}
 
 int StoryText::selectWord(int pos)
 {
@@ -1776,7 +1930,10 @@ int StoryText::selectWord(int pos)
 	int end = it->next();
 	int wordLength = end - start;
 	if (wordLength > 0)
+	{
 		select(start, wordLength);
+		setCursorPosition(endOfSelection());
+	}
 	else
 	{
 		deselectAll();
@@ -1796,7 +1953,7 @@ void StoryText::select(int pos, int len, bool on)
 	assert( pos >= 0 );
 	assert( pos + signed(len) <= length() );
 
-//	qDebug("old selection: %d - %d", m_selFirst, m_selLast);
+//	qDebug("old selection: %d - %d", d->selFirst, d->selLast);
 
 //	StoryText* that = const_cast<StoryText *>(this);
 //	for (int i=pos; i < pos+signed(len); ++i)
@@ -1805,45 +1962,45 @@ void StoryText::select(int pos, int len, bool on)
 	if (on) {
 		// extend if possible
 		if (selected(pos - 1))
-			m_selLast = qMax(m_selLast, pos + static_cast<int>(len) - 1);
+			d->selLast = qMax(d->selLast, pos + len - 1);
 		else if (selected(pos + len))
-			m_selFirst = qMin(m_selFirst, pos);
+			d->selFirst = qMin(d->selFirst, pos);
 		else {
-			m_selFirst = pos;
-			m_selLast = pos + len - 1;
+			d->selFirst = pos;
+			d->selLast = pos + len - 1;
 		}
 	}
 	else {
-		if (pos <= m_selFirst && m_selLast < pos + signed(len))
+		if (pos <= d->selFirst && d->selLast < pos + signed(len))
 			deselectAll();
 		// shrink
 		else if (!selected(pos - 1) && selected(pos + len - 1))
-			m_selFirst = pos + len;
+			d->selFirst = pos + len;
 		else if (selected(pos) && !selected(pos + len))
-			m_selLast = pos - 1;
+			d->selLast = pos - 1;
 		else if (selected(pos) || selected(pos + len - 1))
 			// Grr, deselection splits selection
-			m_selLast = pos - 1;
+			d->selLast = pos - 1;
 	}
 
 	fixSurrogateSelection();
 	
-//	qDebug("new selection: %d - %d", m_selFirst, m_selLast);
+//	qDebug("new selection: %d - %d", d->selFirst, d->selLast);
 }
 
 void StoryText::extendSelection(int oldPos, int newPos)
 {
-	if (m_selFirst <= m_selLast)
+	if (d->selFirst <= d->selLast)
 	{
 		// have selection
-		if (m_selLast == oldPos - 1)
+		if (d->selLast == oldPos - 1)
 		{
-			m_selLast = newPos - 1;
+			d->selLast = newPos - 1;
 			return;
 		}
-		if (m_selFirst == oldPos)
+		if (d->selFirst == oldPos)
 		{
-			m_selFirst = newPos;
+			d->selFirst = newPos;
 			return;
 		}
 		// can't extend, fall through
@@ -1851,13 +2008,13 @@ void StoryText::extendSelection(int oldPos, int newPos)
 	// no previous selection
 	if (newPos > oldPos)
 	{
-		m_selFirst = oldPos;
-		m_selLast = newPos - 1;
+		d->selFirst = oldPos;
+		d->selLast = newPos - 1;
 	}
 	else
 	{
-		m_selFirst = newPos;
-		m_selLast = oldPos - 1;
+		d->selFirst = newPos;
+		d->selLast = oldPos - 1;
 	}
 
 	fixSurrogateSelection();
@@ -1866,10 +2023,10 @@ void StoryText::extendSelection(int oldPos, int newPos)
 
 void StoryText::fixSurrogateSelection()
 {
-	if (isLowSurrogate(m_selFirst) && isHighSurrogate(m_selFirst - 1))
-		m_selFirst -= 1;
-	if (isHighSurrogate(m_selLast) && isLowSurrogate(m_selLast + 1))
-		m_selLast += 1;
+	if (isLowSurrogate(d->selFirst) && isHighSurrogate(d->selFirst - 1))
+		d->selFirst -= 1;
+	if (isHighSurrogate(d->selLast) && isLowSurrogate(d->selLast + 1))
+		d->selLast += 1;
 }
 
 BreakIterator* StoryText::m_graphemeIterator = nullptr;
@@ -1948,8 +2105,8 @@ void StoryText::selectAll()
 		that->next();
 	}
 */
-	m_selFirst = 0;
-	m_selLast = length() - 1;
+	d->selFirst = 0;
+	d->selLast = length() - 1;
 }
 
 void StoryText::deselectAll()
@@ -1961,20 +2118,20 @@ void StoryText::deselectAll()
 		that->next();
 	}
 */	
-	m_selFirst = 0;
-	m_selLast = -1;
+	d->selFirst = 0;
+	d->selLast = -1;
 }
 
 void StoryText::removeSelection()
 {
-//	qDebug("removeSelection: %d - %d", m_selFirst, m_selLast);
-	if (m_selFirst > m_selLast)
+//	qDebug("removeSelection: %d - %d", d->selFirst, d->selLast);
+	if (d->selFirst > d->selLast)
 		return;
 
-	assert( m_selFirst >= 0 );
-	assert( m_selLast < length() );
+	assert( d->selFirst >= 0 );
+	assert( d->selLast < length() );
 
-	removeChars(m_selFirst, m_selLast - m_selFirst+1);
+	removeChars(d->selFirst, d->selLast - d->selFirst+1);
 	deselectAll();
 }
 
@@ -1996,7 +2153,7 @@ void StoryText::invalidateAll()
 
 void StoryText::invalidate(int firstItem, int endItem)
 {
-	for (int i=firstItem; i < endItem; ++i)
+	for (int i = firstItem; i < endItem; ++i)
 	{
 		ParagraphStyle* par = item(i)->parstyle;
 		if (par)
@@ -2006,7 +2163,6 @@ void StoryText::invalidate(int firstItem, int endItem)
 		emit changed(firstItem, endItem);
 }
 
-
 // physical view
 
 /*
@@ -2021,54 +2177,19 @@ void StoryText::validate()
 }
 */
 
-
-
-ScText*  StoryText::item(uint itm)
+ScText*  StoryText::item(int index)
 {
-	assert( static_cast<int>(itm) < length() );
-	return const_cast<StoryText *>(this)->d->at(itm);
+	assert( index < length() );
+	return const_cast<StoryText *>(this)->d->at(index);
 }
 
-
-const ScText*  StoryText::item(uint itm) const
+const ScText*  StoryText::item(int index) const
 {
-	assert( static_cast<int>(itm) < length() );
-	return const_cast<StoryText *>(this)->d->at(itm);
+	assert( index < length() );
+	return const_cast<StoryText *>(this)->d->at(index);
 }
 
 
-//const QString StoryText::itemText(uint itm) const
-//{
-	
-//	assert( static_cast<int>(itm) < length() );
-
-//	return text(itm, 1);
-//}
-
-
-//const CharStyle StoryText::itemStyle(uint itm) const
-//{
-//	assert( static_cast<int>(itm) < length() );
-
-//	return charStyle(itm);
-//}
-	
-
-//int StoryText::startOfItem(uint itm) const
-//{
-//	assert( static_cast<int>(itm) < length() );
-
-//	return itm;
-//}
-
-//int StoryText::endOfItem(uint itm) const
-//{
-//	assert( static_cast<int>(itm) < length() );
-
-//	return itm + 1;
-//}
-
-
 using namespace desaxe;
 
 void StoryText::saxx(SaxHandler& handler, const Xml_string& elemtag) const
