@@ -27,6 +27,7 @@ for which a new license (GPL+exception) is in place.
 #include <QLabel>
 #include <QLayout>
 #include <QLineEdit>
+#include <QLocale>
 #include <QMessageBox>
 #include <QPixmap>
 #include <QPushButton>
@@ -37,7 +38,9 @@ for which a new license (GPL+exception) is in place.
 
 #include "commonstrings.h"
 #include "iconmanager.h"
+#include "localemgr.h"
 #include "scpage.h"
+#include "scribusapp.h"
 #include "scribusdoc.h"
 #include "scribusstructs.h"
 #include "selection.h"
@@ -47,12 +50,10 @@ for which a new license (GPL+exception) is in place.
 
 //TODO Distribute with 
 
-AlignDistributePalette::AlignDistributePalette( QWidget* parent, const char* name) : ScDockPalette( parent, name, nullptr )
+AlignDistributePalette::AlignDistributePalette( QWidget* parent, const char* name) : ScDockPalette(parent, name, Qt::WindowFlags())
 {
 	setupUi(this);
 	setSizePolicy( QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
-	currDoc=nullptr;
-	guideDirection=-1;
 	setObjectName(name);
 	
 	//hide spare controls 
@@ -60,7 +61,7 @@ AlignDistributePalette::AlignDistributePalette( QWidget* parent, const char* nam
 	toolButtonDummy2->hide();
 
 	//set up scrspinboxes
-	distributeDistSpinBox->setValues(-1000.0, 1000.0, 2, 0.0);
+	distributeDistSpinBox->setValues(-10000.0, 10000.0, 2, 0.0);
 
 	// buddies
 	alignRelativeToLabel->setBuddy( alignRelativeToCombo );
@@ -71,6 +72,9 @@ AlignDistributePalette::AlignDistributePalette( QWidget* parent, const char* nam
 	languageChange();
 	init();
 	setDoc(nullptr);
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+	connect(ScQApp, SIGNAL(localeChanged()), this, SLOT(localeChange()));
 }
 
 AlignDistributePalette::~AlignDistributePalette()
@@ -82,9 +86,9 @@ void AlignDistributePalette::changeEvent(QEvent *e)
 	if (e->type() == QEvent::LanguageChange)
 	{
 		languageChange();
+		return;
 	}
-	else
-		ScDockPalette::changeEvent(e);
+	ScDockPalette::changeEvent(e);
 }
 
 void AlignDistributePalette::languageChange()
@@ -150,7 +154,53 @@ void AlignDistributePalette::languageChange()
 void AlignDistributePalette::init()
 {
 	undoManager = UndoManager::instance();
+	
+	iconSetChange();
+
+	connect(alignLeftOutToolButton, SIGNAL(clicked()), this, SLOT(alignLeftOut()));
+	connect(alignRightOutToolButton, SIGNAL(clicked()), this, SLOT(alignRightOut()));
+	connect(alignBottomInToolButton, SIGNAL(clicked()), this, SLOT(alignBottomIn()));
+	connect(alignRightInToolButton, SIGNAL(clicked()), this, SLOT(alignRightIn()));
+	connect(alignBottomOutToolButton, SIGNAL(clicked()), this, SLOT(alignBottomOut()));
+	connect(alignCenterHorToolButton, SIGNAL(clicked()), this, SLOT(alignCenterHor()));
+	connect(alignLeftInToolButton, SIGNAL(clicked()), this, SLOT(alignLeftIn()));
+	connect(alignCenterVerToolButton, SIGNAL(clicked()), this, SLOT(alignCenterVer()));
+	connect(alignTopOutToolButton, SIGNAL(clicked()), this, SLOT(alignTopOut()));
+	connect(alignTopInToolButton, SIGNAL(clicked()), this, SLOT(alignTopIn()));
+	connect(distributeDistHToolButton, SIGNAL(clicked()), this, SLOT(distributeDistH()));
+	connect(distributeDistValueHToolButton, SIGNAL(clicked()), this, SLOT(distributeDistValH()));
+	connect(distributeRightToolButton, SIGNAL(clicked()), this, SLOT(distributeRight()));
+	connect(distributeBottomToolButton, SIGNAL(clicked()), this, SLOT(distributeBottom()));
+	connect(distributeCenterHToolButton, SIGNAL(clicked()), this, SLOT(distributeCenterH()));
+	connect(distributeDistVToolButton, SIGNAL(clicked()), this, SLOT(distributeDistV()));
+	connect(distributeDistValueVToolButton, SIGNAL(clicked()), this, SLOT(distributeDistValV()));
+	connect(distributeLeftToolButton, SIGNAL(clicked()), this, SLOT(distributeLeft()));
+	connect(distributeCenterVToolButton, SIGNAL(clicked()), this, SLOT(distributeCenterV()));
+	connect(distributeTopToolButton, SIGNAL(clicked()), this, SLOT(distributeTop()));
+	connect(distributeAcrossPageToolButton, SIGNAL(clicked()), this, SLOT(distributeDistAcrossPage()));
+	connect(distributeDownPageToolButton, SIGNAL(clicked()), this, SLOT(distributeDistDownPage()));
+	connect(distributeAcrossMarginsToolButton, SIGNAL(clicked()), this, SLOT(distributeDistAcrossMargins()));
+	connect(distributeDownMarginsToolButton, SIGNAL(clicked()), this, SLOT(distributeDistDownMargins()));
+	connect(swapLeftToolButton, SIGNAL(clicked()), this, SLOT(swapLeft()));
+	connect(swapRightToolButton, SIGNAL(clicked()), this, SLOT(swapRight()));
+	
+	alignRelativeToCombo->setCurrentIndex(0);
+	alignToChanged(0);
+	alignMethodChanged(0);
+	connect(alignRelativeToCombo, SIGNAL(activated(int)), this, SLOT(alignToChanged(int)));
+	connect(alignMoveOrResizeCombo, SIGNAL(activated(int)), this, SLOT(alignMethodChanged(int)));
+	
+	unitRatio = 1.0;
+	guideDirection = -1;
+	
+	guideInfoText = guideInfoTextNone;
+	alignGuideLineEdit->setText(guideInfoTextNone);
+}
+
+void AlignDistributePalette::iconSetChange()
+{
 	IconManager& im = IconManager::instance();
+
 	alignLeftOutToolButton->setIcon(im.loadIcon("22/align-horizontal-left-out.png"));
 	alignLeftInToolButton->setIcon(im.loadIcon("22/align-horizontal-left.png"));
 	alignCenterHorToolButton->setIcon(im.loadIcon("22/align-horizontal-center.png"));
@@ -247,226 +297,186 @@ void AlignDistributePalette::init()
 
 	swapLeftToolButton->setMaximumSize(s);
 	swapRightToolButton->setMaximumSize(s);
-
-
-	connect(alignLeftOutToolButton, SIGNAL(clicked()), this, SLOT(alignLeftOut()));
-	connect(alignRightOutToolButton, SIGNAL(clicked()), this, SLOT(alignRightOut()));
-	connect(alignBottomInToolButton, SIGNAL(clicked()), this, SLOT(alignBottomIn()));
-	connect(alignRightInToolButton, SIGNAL(clicked()), this, SLOT(alignRightIn()));
-	connect(alignBottomOutToolButton, SIGNAL(clicked()), this, SLOT(alignBottomOut()));
-	connect(alignCenterHorToolButton, SIGNAL(clicked()), this, SLOT(alignCenterHor()));
-	connect(alignLeftInToolButton, SIGNAL(clicked()), this, SLOT(alignLeftIn()));
-	connect(alignCenterVerToolButton, SIGNAL(clicked()), this, SLOT(alignCenterVer()));
-	connect(alignTopOutToolButton, SIGNAL(clicked()), this, SLOT(alignTopOut()));
-	connect(alignTopInToolButton, SIGNAL(clicked()), this, SLOT(alignTopIn()));
-	connect(distributeDistHToolButton, SIGNAL(clicked()), this, SLOT(distributeDistH()));
-	connect(distributeDistValueHToolButton, SIGNAL(clicked()), this, SLOT(distributeDistValH()));
-	connect(distributeRightToolButton, SIGNAL(clicked()), this, SLOT(distributeRight()));
-	connect(distributeBottomToolButton, SIGNAL(clicked()), this, SLOT(distributeBottom()));
-	connect(distributeCenterHToolButton, SIGNAL(clicked()), this, SLOT(distributeCenterH()));
-	connect(distributeDistVToolButton, SIGNAL(clicked()), this, SLOT(distributeDistV()));
-	connect(distributeDistValueVToolButton, SIGNAL(clicked()), this, SLOT(distributeDistValV()));
-	connect(distributeLeftToolButton, SIGNAL(clicked()), this, SLOT(distributeLeft()));
-	connect(distributeCenterVToolButton, SIGNAL(clicked()), this, SLOT(distributeCenterV()));
-	connect(distributeTopToolButton, SIGNAL(clicked()), this, SLOT(distributeTop()));
-	connect(distributeAcrossPageToolButton, SIGNAL(clicked()), this, SLOT(distributeDistAcrossPage()));
-	connect(distributeDownPageToolButton, SIGNAL(clicked()), this, SLOT(distributeDistDownPage()));
-	connect(distributeAcrossMarginsToolButton, SIGNAL(clicked()), this, SLOT(distributeDistAcrossMargins()));
-	connect(distributeDownMarginsToolButton, SIGNAL(clicked()), this, SLOT(distributeDistDownMargins()));
-	connect(swapLeftToolButton, SIGNAL(clicked()), this, SLOT(swapLeft()));
-	connect(swapRightToolButton, SIGNAL(clicked()), this, SLOT(swapRight()));
-	
-	alignRelativeToCombo->setCurrentIndex(0);
-	alignToChanged(0);
-	alignMethodChanged(0);
-	connect(alignRelativeToCombo, SIGNAL(activated(int)), this, SLOT(alignToChanged(int)));
-	connect(alignMoveOrResizeCombo, SIGNAL(activated(int)), this, SLOT(alignMethodChanged(int)));
-	
-	unitRatio=1.0;
-	guideDirection=-1;
-	
-	guideInfoText = guideInfoTextNone;
-	alignGuideLineEdit->setText(guideInfoTextNone);
 }
 
 void AlignDistributePalette::unitChange()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 	{
-		unitRatio=unitGetRatioFromIndex(currDoc->unitIndex());
+		unitRatio = unitGetRatioFromIndex(currDoc->unitIndex());
 		distributeDistSpinBox->setNewUnit(currDoc->unitIndex());
 		enableGuideButtons();
 	}
 }
 
-void AlignDistributePalette::setDoc( ScribusDoc* newDoc )
+void AlignDistributePalette::setDoc(ScribusDoc* newDoc)
 {
-	currDoc=newDoc;
-	if (currDoc!=nullptr)
-		alignObjects=&(currDoc->AObjects);
+	currDoc = newDoc;
+	if (currDoc != nullptr)
+		alignObjects = &(currDoc->AObjects);
 	else
-		alignObjects=nullptr;
+		alignObjects = nullptr;
 	unitChange();
 }
 
 void AlignDistributePalette::alignLeftOut()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignLeftOut(currAlignTo, currAlignMethod, guidePosition);
 }
 
 void AlignDistributePalette::alignLeftIn()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignLeftIn(currAlignTo, currAlignMethod, guidePosition);
 }
 
 void AlignDistributePalette::alignCenterHor()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignCenterHor(currAlignTo, currAlignMethod, guidePosition);
 }
 
 void AlignDistributePalette::alignRightIn()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignRightIn(currAlignTo, currAlignMethod, guidePosition);
 }
 
 void AlignDistributePalette::alignRightOut()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignRightOut(currAlignTo, currAlignMethod, guidePosition);
 }
 
 void AlignDistributePalette::alignTopOut()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignTopOut(currAlignTo, currAlignMethod, guidePosition);
 }
 
 void AlignDistributePalette::alignTopIn()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignTopIn(currAlignTo, currAlignMethod, guidePosition);
 }
 
 
 void AlignDistributePalette::alignCenterVer()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignCenterVer(currAlignTo, currAlignMethod, guidePosition);
 }
 
 
 void AlignDistributePalette::alignBottomIn()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignBottomIn(currAlignTo, currAlignMethod, guidePosition);
 }
 
 void AlignDistributePalette::alignBottomOut()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_AlignBottomOut(currAlignTo, currAlignMethod, guidePosition);
 }
 
 void AlignDistributePalette::distributeLeft()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeLeft();
 }
 
 void AlignDistributePalette::distributeCenterH()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeCenterH();
 }
 
 void AlignDistributePalette::distributeRight()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeRight();
 }
 
 void AlignDistributePalette::distributeDistH(bool usingDistance)
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeDistH(usingDistance, distributeDistSpinBox->value(), reverseDistributionCheckBox->isChecked());
 }
 
 void AlignDistributePalette::distributeDistValH()
 {
 	distributeDistSpinBox->interpretText();
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		distributeDistH(true);
 }
 
 void AlignDistributePalette::distributeDistAcrossPage()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeAcrossPage();
 }
 
 void AlignDistributePalette::distributeDistDownPage()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeDownPage();
 }
 
 void AlignDistributePalette::distributeDistAcrossMargins()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeAcrossPage(true);
 }
 
 void AlignDistributePalette::distributeDistDownMargins()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeDownPage(true);
 }
 
 
 void AlignDistributePalette::distributeBottom()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeBottom();
 }
 
 void AlignDistributePalette::distributeCenterV()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeCenterV();
 }
 
 void AlignDistributePalette::distributeTop()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeTop();
 }
 
 void AlignDistributePalette::distributeDistV(bool usingDistance)
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_DistributeDistV(usingDistance, distributeDistSpinBox->value(), reverseDistributionCheckBox->isChecked());
 }
 
 void AlignDistributePalette::distributeDistValV()
 {
 	distributeDistSpinBox->interpretText();
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		distributeDistV(true);
 }
 
 void AlignDistributePalette::swapLeft()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_SwapLeft();
 }
 
 void AlignDistributePalette::swapRight()
 {
-	if (currDoc!=nullptr)
+	if (currDoc != nullptr)
 		currDoc->itemSelection_SwapRight();
 }
 
@@ -485,50 +495,57 @@ void AlignDistributePalette::setGuide(int direction, qreal position)
 {
 	//direction 0=H, 1=V
 // 	qDebug()<<"AlignDistributePalette::setGuide("<<direction<<""<<position<<")";
-	guideDirection=direction;
-	guidePosition=position;
+	guideDirection = direction;
+	guidePosition = position;
 	enableGuideButtons();
 }
 
+
+void AlignDistributePalette::localeChange()
+{
+	const QLocale& l(LocaleManager::instance().userPreferredLocale());
+	distributeDistSpinBox->setLocale(l);
+}
+
 void AlignDistributePalette::enableGuideButtons()
 {
 	QString suffix;
-	double unitRatio=1.0;
-	int precision=1;
-	if (currDoc!=nullptr)
+	double unitRatio = 1.0;
+	int precision = 1;
+	if (currDoc != nullptr)
 	{
-		suffix=unitGetSuffixFromIndex(currDoc->unitIndex());
-		unitRatio=unitGetRatioFromIndex(currDoc->unitIndex());
-		precision=unitGetPrecisionFromIndex(currDoc->unitIndex());
+		suffix = unitGetSuffixFromIndex(currDoc->unitIndex());
+		unitRatio = unitGetRatioFromIndex(currDoc->unitIndex());
+		precision = unitGetPrecisionFromIndex(currDoc->unitIndex());
 	}
-	bool setterH=true, setterV=true;
+	bool setterH = true, setterV = true;
 	switch (guideDirection)
 	{
 		case -1:
 			guideInfoText = guideInfoTextNone;
-			if (currAlignTo==ScribusDoc::alignGuide)
-				setterH=setterV=false;
+			if (currAlignTo == ScribusDoc::alignGuide)
+				setterH = setterV = false;
 			break;
 		case 0:
 			guideInfoText = tr("Y: %1%2").arg(guidePosition * unitRatio, 0, 'f', precision).arg(suffix);
-			if (currAlignTo==ScribusDoc::alignGuide)
+			if (currAlignTo == ScribusDoc::alignGuide)
 			{
-				setterV=false;
-				setterH=true;
+				setterV = false;
+				setterH = true;
 			}
 			break;
 		case 1:
 			guideInfoText = tr("X: %1%2").arg(guidePosition * unitRatio, 0, 'f', precision).arg(suffix);
-			if (currAlignTo==ScribusDoc::alignGuide)
+			if (currAlignTo == ScribusDoc::alignGuide)
 			{
-				setterV=true;
-				setterH=false;
+				setterV = true;
+				setterH = false;
 			}
 			break;
 	}
-	bool setterO=true;
-	if (currAlignTo==ScribusDoc::alignGuide)
-		setterO=false;
+	bool setterO = true;
+	if (currAlignTo == ScribusDoc::alignGuide)
+		setterO = false;
 		
 	alignLeftInToolButton->setEnabled(setterV);
 	alignLeftOutToolButton->setEnabled(setterO);
