@@ -6,6 +6,7 @@ for which a new license (GPL+exception) is in place.
 */
 #include "checkDocument.h"
 
+#include <QComboBox>
 #include <QEvent>
 #include <QHBoxLayout>
 #include <QHeaderView>
@@ -23,14 +24,13 @@ for which a new license (GPL+exception) is in place.
 #include "documentchecker.h"
 #include "pdfoptions.h"
 #include "prefsmanager.h"
-#include "sccombobox.h"
 #include "scpage.h"
+#include "scribusapp.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "iconmanager.h"
 #include "util.h"
 
-
 // readable constants for QTreeWidgetItem column ids
 #define COLUMN_ITEM 0
 #define COLUMN_PROBLEM 1
@@ -38,19 +38,13 @@ for which a new license (GPL+exception) is in place.
 // #define COLUMN_INFO 3
 
 CheckDocument::CheckDocument( QWidget* parent, bool modal )
-	: ScrPaletteBase( parent, "checkDocument", modal, nullptr ),
-	m_Doc(nullptr),
-	pageGraveError(false),
-	itemError(false),
-	minResDPI(0),
-	maxResDPI(0)
+	: ScrPaletteBase( parent, "checkDocument", modal )
 {
-	showPagesWithoutErrors=PrefsManager::instance().appPrefs.verifierPrefs.showPagesWithoutErrors;
-	showNonPrintingLayerErrors=PrefsManager::instance().appPrefs.verifierPrefs.showNonPrintingLayerErrors;
+	showPagesWithoutErrors = PrefsManager::instance().appPrefs.verifierPrefs.showPagesWithoutErrors;
+	showNonPrintingLayerErrors = PrefsManager::instance().appPrefs.verifierPrefs.showNonPrintingLayerErrors;
+
+	iconSetChange();
 
-	graveError = IconManager::instance().loadPixmap("22/dialog-error.png");
-	onlyWarning = IconManager::instance().loadPixmap("22/dialog-warning.png");
-	noErrors = IconManager::instance().loadPixmap("ok.png");
 	checkDocumentLayout = new QVBoxLayout( this );
 	checkDocumentLayout->setMargin(5);
 	checkDocumentLayout->setSpacing(5);
@@ -60,7 +54,7 @@ CheckDocument::CheckDocument( QWidget* parent, bool modal )
 	layout1->setSpacing(5);
 	textLabel1 = new QLabel( this );
 	layout1->addWidget( textLabel1 );
-	curCheckProfile = new ScComboBox( this );
+	curCheckProfile = new QComboBox( this );
 	layout1->addWidget( curCheckProfile );
 	checkDocumentLayout->addLayout( layout1 );
 
@@ -91,6 +85,8 @@ CheckDocument::CheckDocument( QWidget* parent, bool modal )
 	masterPageItemMap.clear();
 	resize( QSize(320, 260).expandedTo(minimumSizeHint()) );
 
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+
 	connect(ignoreErrors, SIGNAL(clicked()), this, SIGNAL(ignoreAllErrors()));
 	connect(curCheckProfile, SIGNAL(activated(const QString&)), this, SLOT(newScan(const QString&)));
 	connect(reScan, SIGNAL(clicked()), this, SLOT(doReScan()));
@@ -106,6 +102,13 @@ void CheckDocument::changeEvent(QEvent *e)
 		QWidget::changeEvent(e);
 }
 
+void CheckDocument::iconSetChange()
+{
+	graveError = IconManager::instance().loadPixmap("22/dialog-error.png");
+	onlyWarning = IconManager::instance().loadPixmap("22/dialog-warning.png");
+	noErrors = IconManager::instance().loadPixmap("ok.png");
+}
+
 void CheckDocument::languageChange()
 {
 	setWindowTitle( tr( "Preflight Verifier" ) );
@@ -157,23 +160,25 @@ QString CheckDocument::bestCheckerProfileForCheckMode(CheckMode mode, const QStr
 {
 	QString bestProfile = defaultProfile;
 
-	if (mode == CheckDocument::checkPDF)
+	if (mode == CheckDocument::checkPDF || mode == CheckDocument::checkOutputPreviewPDF)
 	{
-		PDFOptions::PDFVersion pdfVersion = m_Doc->pdfOptions().Version;
-		if (pdfVersion == PDFOptions::PDFVersion_13)
+		PDFVersion pdfVersion = m_Doc->pdfOptions().Version;
+		if (pdfVersion == PDFVersion::PDF_13)
 			bestProfile = CommonStrings::PDF_1_3;
-		else if (pdfVersion == PDFOptions::PDFVersion_14)
+		else if (pdfVersion == PDFVersion::PDF_14)
 			bestProfile = CommonStrings::PDF_1_4;
-		else if (pdfVersion == PDFOptions::PDFVersion_15)
+		else if (pdfVersion == PDFVersion::PDF_15)
 			bestProfile = CommonStrings::PDF_1_5;
-		else if (pdfVersion == PDFOptions::PDFVersion_X1a)
+		else if (pdfVersion == PDFVersion::PDF_16)
+			bestProfile = CommonStrings::PDF_1_6;
+		else if (pdfVersion == PDFVersion::PDF_X1a)
 			bestProfile = CommonStrings::PDF_X1a;
-		else if (pdfVersion == PDFOptions::PDFVersion_X3)
+		else if (pdfVersion == PDFVersion::PDF_X3)
 			bestProfile = CommonStrings::PDF_X3;
-		else if (pdfVersion == PDFOptions::PDFVersion_X4)
+		else if (pdfVersion == PDFVersion::PDF_X4)
 			bestProfile = CommonStrings::PDF_X4;
 	}
-	else if (mode == CheckDocument::checkEPS)
+	else if (mode == CheckDocument::checkEPS || mode == CheckDocument::checkOutputPreviewPS)
 		bestProfile = CommonStrings::PostScript;
 
 	const auto& checkerProfiles = m_Doc->checkerProfiles();
@@ -290,19 +295,19 @@ void CheckDocument::buildItem(QTreeWidgetItem * item,
 		case MissingGlyph:
 			item->setText(COLUMN_PROBLEM, warnMap[PV_MISSING_GLYPH].first);
 			item->setToolTip(COLUMN_PROBLEM, warnMap[PV_MISSING_GLYPH].second);
-			item->setIcon(COLUMN_ITEM, graveError );
+			item->setIcon(COLUMN_ITEM, graveError);
 			pageGraveError = true;
 			itemError = true;
 			break;
 		case TextOverflow:
 			item->setText(COLUMN_PROBLEM, warnMap[PV_TEXT_OVERFLOW].first);
 			item->setToolTip(COLUMN_PROBLEM, warnMap[PV_TEXT_OVERFLOW].second);
-			item->setIcon(COLUMN_ITEM, onlyWarning );
+			item->setIcon(COLUMN_ITEM, onlyWarning);
 			break;
 		case ObjectNotOnPage:
 			item->setText(COLUMN_PROBLEM, warnMap[PV_NON_ON_PAGE].first);
 			item->setToolTip(COLUMN_PROBLEM, warnMap[PV_NON_ON_PAGE].second);
-			item->setIcon(COLUMN_ITEM, onlyWarning );
+			item->setIcon(COLUMN_ITEM, onlyWarning);
 			break;
 		case MissingImage:
 			if (pageItem->externalFile().isEmpty())
