@@ -179,13 +179,13 @@ void ColorsAndFillsDialog::leaveDialog()
 QTreeWidgetItem* ColorsAndFillsDialog::updatePatternList(const QString& addedName)
 {
 	QList<QTreeWidgetItem*> lg = patternItems->takeChildren();
-	for (int a = 0; a < lg.count(); a++)
+	for (int i = 0; i < lg.count(); i++)
 	{
-		delete lg[a];
+		delete lg[i];
 	}
 	QTreeWidgetItem* ret = nullptr;
 	QStringList patK = dialogPatterns.keys();
-	qSort(patK);
+	patK.sort();
 	for (int a = 0; a < patK.count(); a++)
 	{
 		ScPattern sp = dialogPatterns.value(patK[a]);
@@ -213,13 +213,13 @@ QTreeWidgetItem* ColorsAndFillsDialog::updatePatternList(const QString& addedNam
 QTreeWidgetItem* ColorsAndFillsDialog::updateGradientList(const QString& addedName)
 {
 	QList<QTreeWidgetItem*> lg = gradientItems->takeChildren();
-	for (int a = 0; a < lg.count(); a++)
+	for (int i = 0; i < lg.count(); i++)
 	{
-		delete lg[a];
+		delete lg[i];
 	}
 	QTreeWidgetItem* ret = nullptr;
 	QStringList patK = dialogGradients.keys();
-	qSort(patK);
+	patK.sort();
 	for (int a = 0; a < patK.count(); a++)
 	{
 		VGradient gr = dialogGradients.value(patK[a]);
@@ -642,7 +642,7 @@ void ColorsAndFillsDialog::duplicateColorItem()
 		dialogGradients.insert(gradN, dialogGradients[it->text(0)]);
 		origNames.insert(gradN, gradN);
 		QString patternName = origNames[gradN];
-		QString newName = "";
+		QString newName;
 		gradientEditDialog *dia = new gradientEditDialog(this, gradN, dialogGradients[gradN], m_colorList, m_doc, &dialogGradients, false);
 		if (dia->exec())
 		{
@@ -756,18 +756,18 @@ void ColorsAndFillsDialog::removeColorItem()
 		{
 			ColorList dCols = m_colorList;
 			QString dColor = tr("Selected Colors");
-			for (int a = 0; a < usedColors.count(); a++)
+			for (int i = 0; i < usedColors.count(); i++)
 			{
-				dCols.remove(usedColors[a]);
+				dCols.remove(usedColors[i]);
 			}
 			dCols.insert(dColor , ScColor());
 			DelColor *dia = new DelColor(this, dCols, dColor, true);
 			if (dia->exec())
 			{
 				QString replacementColor(dia->getReplacementColor());
-				for (int a = 0; a < colors.count(); a++)
+				for (int i = 0; i < colors.count(); i++)
 				{
-					dColor = colors[a];
+					dColor = colors[i];
 					if (replacementColor == CommonStrings::tr_NoneColor)
 						replacementColor = CommonStrings::None;
 					if (replaceColorMap.values().contains(dColor))
@@ -944,7 +944,7 @@ QStringList ColorsAndFillsDialog::getUsedPatternsHelper(const QString& pattern,
 	pats.clear();
 	for (int c = 0; c < pat->items.count(); ++c)
 	{
-		if ((pat->items.at(c)->GrType == 8) || (pat->items.at(c)->itemType() == PageItem::Symbol))
+		if ((pat->items.at(c)->GrType == Gradient_Pattern) || (pat->items.at(c)->itemType() == PageItem::Symbol))
 		{
 			const QString& patName = pat->items.at(c)->pattern();
 			if (!patName.isEmpty() && !results.contains(patName))
@@ -969,7 +969,7 @@ QStringList ColorsAndFillsDialog::getUsedPatternsHelper(const QString& pattern,
 	pats.clear();
 	for (int c = 0; c < pat->items.count(); ++c)
 	{
-		if ((!results.contains(pat->items.at(c)->pattern())) && ((pat->items.at(c)->GrType == 8) || (pat->items.at(c)->itemType() == PageItem::Symbol)))
+		if ((!results.contains(pat->items.at(c)->pattern())) && ((pat->items.at(c)->GrType == Gradient_Pattern) || (pat->items.at(c)->itemType() == PageItem::Symbol)))
 			pats.append(pat->items.at(c)->pattern());
 	}
 	if (!pats.isEmpty())
@@ -1184,7 +1184,7 @@ void ColorsAndFillsDialog::importColorItems()
 		imgFormats.append("eps");
 		imgFormats.append("epsi");
 		imgFormats.append("ps");
-		qSort(formats);
+		formats.sort();
 		allFormats += formats.join(";;");
 		PrefsContext* dirs = PrefsManager::instance().prefsFile->getContext("dirs");
 		QString wdir = dirs->get("patterns", ".");
@@ -1226,77 +1226,76 @@ void ColorsAndFillsDialog::loadPatternDir()
 	PrefsContext* dirs = PrefsManager::instance().prefsFile->getContext("dirs");
 	QString wdir = dirs->get("patterndir", ".");
 	QString fileName = QFileDialog::getExistingDirectory(this, tr("Choose a Directory"), wdir);
-	if (!fileName.isEmpty())
+	if (fileName.isEmpty())
+		return;
+
+	QStringList formats;
+	formats += "eps";
+	formats += "epsi";
+	formats += "pdf";
+	QString form1 = "";
+	for (int i = 0; i < QImageReader::supportedImageFormats().count(); ++i)
 	{
-		QStringList formats;
-		formats += "eps";
-		formats += "epsi";
-		formats += "pdf";
-		QString form1 = "";
-		for ( int i = 0; i < QImageReader::supportedImageFormats().count(); ++i )
+		form1 = QString(QImageReader::supportedImageFormats().at(i)).toLower();
+		if (form1 == "jpeg")
+			form1 = "jpg";
+		if ((form1 == "png") || (form1 == "xpm") || (form1 == "gif"))
+		formats += form1;
+		else if (form1 == "jpg")
 		{
-			form1 = QString(QImageReader::supportedImageFormats().at(i)).toLower();
-			if (form1 == "jpeg")
-				form1 = "jpg";
-			if ((form1 == "png") || (form1 == "xpm") || (form1 == "gif"))
-			formats += form1;
-			else if (form1 == "jpg")
-			{
-				formats += "jpg";
-				formats += "jpeg";
-			}
-		}
-		formats += "tif";
-	 	formats += "tiff";
-		formats += "psd";
-		formats += "pat";
-		QDir d(fileName, "*", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
-		if ((d.exists()) && (d.count() != 0))
-		{
-			mainWin->setStatusBarInfoText( tr("Loading Patterns"));
-			mainWin->mainWindowProgressBar->reset();
-			mainWin->mainWindowProgressBar->setMaximum(d.count() * 2);
-			qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
-			qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
-			for (uint dc = 0; dc < d.count(); ++dc)
-			{
-				mainWin->mainWindowProgressBar->setValue(dc);
-				qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
-				QFileInfo fi(QDir::cleanPath(QDir::toNativeSeparators(fileName + "/" + d[dc])));
-				QString ext = fi.suffix().toLower();
-				if ((ext == "sce") || (!formats.contains(ext)))
-					loadVectors(QDir::cleanPath(QDir::toNativeSeparators(fileName + "/" + d[dc])));
-			}
-			for (uint dc = 0; dc < d.count(); ++dc)
-			{
-				mainWin->mainWindowProgressBar->setValue(d.count() + dc);
-				qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
-				QFileInfo fi(QDir::cleanPath(QDir::toNativeSeparators(fileName + "/" + d[dc])));
-				QString ext = fi.suffix().toLower();
-				if ((ext == "sce") || (!formats.contains(ext)))
-					continue;
-				if (formats.contains(ext))
-				{
-					QString patNam = fi.baseName().trimmed().simplified().replace(" ", "_");
-					if (!dialogPatterns.contains(patNam))
-					{
-						ScPattern pat = ScPattern();
-						pat.setDoc(m_doc);
-						pat.setPattern(QDir::cleanPath(QDir::toNativeSeparators(fileName + "/" + d[dc])));
-						dialogPatterns.insert(patNam, pat);
-						origNamesPatterns.insert(patNam, patNam);
-					}
-				}
-				else
-					continue;
-			}
-			d.cdUp();
-			dirs->set("patterndir", d.absolutePath());
-			qApp->restoreOverrideCursor();
-			mainWin->setStatusBarInfoText("");
-			mainWin->mainWindowProgressBar->reset();
+			formats += "jpg";
+			formats += "jpeg";
 		}
 	}
+	formats += "tif";
+	formats += "tiff";
+	formats += "psd";
+	formats += "pat";
+	QDir d(fileName, "*", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
+	if ((!d.exists()) || (d.count() == 0))
+		return;
+
+	mainWin->setStatusBarInfoText( tr("Loading Patterns"));
+	mainWin->mainWindowProgressBar->reset();
+	mainWin->mainWindowProgressBar->setMaximum(d.count() * 2);
+	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
+	qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+	for (uint dc = 0; dc < d.count(); ++dc)
+	{
+		mainWin->mainWindowProgressBar->setValue(dc);
+		qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+		QFileInfo fi(QDir::cleanPath(QDir::toNativeSeparators(fileName + "/" + d[dc])));
+		QString ext = fi.suffix().toLower();
+		if ((ext == "sce") || (!formats.contains(ext)))
+			loadVectors(QDir::cleanPath(QDir::toNativeSeparators(fileName + "/" + d[dc])));
+	}
+	for (uint dc = 0; dc < d.count(); ++dc)
+	{
+		mainWin->mainWindowProgressBar->setValue(d.count() + dc);
+		qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+
+		QFileInfo fi(QDir::cleanPath(QDir::toNativeSeparators(fileName + "/" + d[dc])));
+		QString ext = fi.suffix().toLower();
+		if ((ext == "sce") || (!formats.contains(ext)))
+			continue;
+		if (!formats.contains(ext))
+			continue;
+
+		QString patNam = fi.baseName().trimmed().simplified().replace(" ", "_");
+		if (!dialogPatterns.contains(patNam))
+		{
+			ScPattern pat = ScPattern();
+			pat.setDoc(m_doc);
+			pat.setPattern(QDir::cleanPath(QDir::toNativeSeparators(fileName + "/" + d[dc])));
+			dialogPatterns.insert(patNam, pat);
+			origNamesPatterns.insert(patNam, patNam);
+		}
+	}
+	d.cdUp();
+	dirs->set("patterndir", d.absolutePath());
+	qApp->restoreOverrideCursor();
+	mainWin->setStatusBarInfoText("");
+	mainWin->mainWindowProgressBar->reset();
 }
 
 void ColorsAndFillsDialog::loadVectors(const QString& data)
@@ -1325,7 +1324,7 @@ void ColorsAndFillsDialog::loadVectors(const QString& data)
 	if (fi.suffix().toLower() == "sce")
 	{
 		ScriXmlDoc ss;
-		ss.readElem(data, PrefsManager::instance().appPrefs.fontPrefs.AvailFonts, m_doc, m_doc->currentPage()->xOffset(), m_doc->currentPage()->yOffset(), true, true, PrefsManager::instance().appPrefs.fontPrefs.GFontSub);
+		ss.readElem(data, m_doc, m_doc->currentPage()->xOffset(), m_doc->currentPage()->yOffset(), true, true);
 	}
 	else
 	{
