@@ -47,7 +47,6 @@ for which a new license (GPL+exception) is in place.
 #include "iconmanager.h"
 #include "loadsaveplugin.h"
 #include "prefsmanager.h"
-#include "sccombobox.h"
 #include "scfilewidget.h"
 #include "scimage.h"
 #include "scpreview.h"
@@ -65,11 +64,11 @@ extern QString DocDir;
 
 ImIconProvider::ImIconProvider()
 {
-	fmts.clear();
 	QString tmp[] = {"eps", "epsi", "gif", "png", "jpg", "jpeg", "xpm", "tif", "tiff", "bmp", "pbm", "pgm", "ppm", "xbm", "xpm", "psd", "pat"};
-	size_t array = sizeof(tmp) / sizeof(*tmp);
-	for (uint a = 0; a < array; ++a)
-		fmts.append(tmp[a]);
+	size_t arraySize = sizeof(tmp) / sizeof(*tmp);
+	fmts.reserve(arraySize);
+	for (size_t i = 0; i < arraySize; ++i)
+		fmts.append(tmp[i]);
 	IconManager& im=IconManager::instance();
 	imagepm = im.loadIcon("16/image-x-generic.png");
 	pspm = im.loadIcon("postscript.png");
@@ -131,7 +130,7 @@ void FDialogPreview::updatePix()
 void FDialogPreview::genPreview(const QString& name)
 {
 	QPixmap pm;
-	QString Buffer = "";
+	QString Buffer;
 	updatePix();
 	if (name.isEmpty())
 		return;
@@ -171,8 +170,8 @@ void FDialogPreview::genPreview(const QString& name)
 		}
 		int xres = im.imgInfo.xres;
 		int yres = im.imgInfo.yres;
-		QString tmp = "";
-		QString tmp2 = "";
+		QString tmp;
+		QString tmp2;
 		QImage im2 = im.scaled(w - 5, h - 44, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 		QPainter p;
 		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
@@ -332,13 +331,6 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 	hboxLayout1->addWidget( cancelButton );
 	vboxLayout->addLayout(hboxLayout1);
 
-	saveZip = nullptr;
-	withFonts = nullptr;
-	withProfiles = nullptr;
-	optionCombo = nullptr;
-	optionLabel = nullptr;
-	Layout = LayoutC = nullptr;
-	Layout1 = Layout1C = nullptr;
 	if (flags & fdDirectoriesOnly)
 	{
 		Layout = new QFrame(this);
@@ -408,7 +400,7 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 			optionLabel = new QLabel(this);
 			optionLabel->setText( tr("Encoding:"));
 			Layout1C->addWidget(optionLabel);
-			optionCombo = new ScComboBox(LayoutC);
+			optionCombo = new QComboBox(LayoutC);
 			optionCombo->setEditable(false);
 			QString tmp_txc[] = {"ISO 8859-1", "ISO 8859-2", "ISO 8859-3",
 								"ISO 8859-4", "ISO 8859-5", "ISO 8859-6",
@@ -454,7 +446,7 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 			optionLabel = new QLabel(this);
 			optionLabel->setText( tr("Import Option:"));
 			Layout1C->addWidget(optionLabel);
-			optionCombo = new ScComboBox(LayoutC);
+			optionCombo = new QComboBox(LayoutC);
 			optionCombo->setEditable(false);
 			optionCombo->addItem( tr("Keep original size"));
 			optionCombo->addItem( tr("Downscale to page size"));
@@ -484,7 +476,7 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 			connect(saveZip, SIGNAL(clicked()), this, SLOT(handleCompress()));
 	}
 	fileDialog->forceDoubleClickActivation(m_previewIsShown);
-	fileDialog->setNameFilterDetailsVisible(false);
+	fileDialog->setOption(QFileDialog::HideNameFilterDetails, true);
 	m_extZip = "gz";
 	connect(okButton, SIGNAL(clicked()), this, SLOT(okClicked()));
 	connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
@@ -496,6 +488,9 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 	resize(minimumSizeHint());
 }
 
+CustomFDialog::~CustomFDialog()
+{
+}
 
 void CustomFDialog::fileClicked(const QString &path)
 {
@@ -538,14 +533,14 @@ void CustomFDialog::togglePreview()
 	repaint();
 }
 
-void CustomFDialog::setSelection(const QString& sel)
+void CustomFDialog::setSelection(const QString& fileName)
 {
-	fileDialog->selectFile( QFileInfo(sel).fileName() );
+	fileDialog->selectFile( QFileInfo(fileName).fileName() );
 	if (m_previewIsShown)
-		filePreview->genPreview(sel);
+		filePreview->genPreview(fileName);
 }
 
-QString CustomFDialog::selectedFile()
+QString CustomFDialog::selectedFile() const
 {
 	QStringList sel = fileDialog->selectedFiles();
 	if (!sel.isEmpty())
@@ -553,15 +548,16 @@ QString CustomFDialog::selectedFile()
 	return QString();
 }
 
+QStringList CustomFDialog::selectedFiles() const
+{
+	return fileDialog->selectedFiles();
+}
+
 void CustomFDialog::addWidgets(QWidget *widgets)
 {
 	vboxLayout->addWidget(widgets);
 }
 
-CustomFDialog::~CustomFDialog()
-{
-}
-
 void CustomFDialog::handleCompress()
 {
 	QString   fileName;
@@ -594,7 +590,7 @@ void CustomFDialog::setExtension(const QString& e)
 	m_ext = e;
 }
 
-QString CustomFDialog::extension()
+const QString&  CustomFDialog::extension() const
 {
 	return m_ext;
 }
@@ -604,7 +600,112 @@ void CustomFDialog::setZipExtension(const QString& e)
 	m_extZip = e;
 }
 
-QString CustomFDialog::zipExtension()
+const QString& CustomFDialog::zipExtension() const
 {
 	return m_extZip;
 }
+
+bool CustomFDialog::isTextCodecShown() const
+{
+	if ((m_optionFlags & fdShowCodecs) == 0)
+		return false;
+	if (optionCombo)
+		return optionCombo->isVisible();
+	return false;
+}
+
+void CustomFDialog::setTextCodec(const QString& textCodec)
+{
+	if ((m_optionFlags & fdShowCodecs) == 0)
+		return;
+	if (!optionCombo)
+		return;
+
+	QString textEncoding = textCodec;
+	if (textCodec.isEmpty())
+		textEncoding = "System";
+
+	int index = optionCombo->findText(textEncoding, Qt::MatchFixedString);
+	if (index < 0)
+		return;
+	optionCombo->setCurrentIndex(index);
+}
+
+QString CustomFDialog::textCodec() const
+{
+	if ((m_optionFlags & fdShowCodecs) == 0)
+		return QString();
+	if (optionCombo)
+		return optionCombo->currentText();
+	return QString();
+}
+
+bool CustomFDialog::isSaveZipFileShown() const
+{
+	if (saveZip)
+		return saveZip->isVisible();
+	return false;
+}
+
+void CustomFDialog::setSaveZipFile(bool value)
+{
+	if (!saveZip)
+		return;
+	saveZip->setChecked(value);
+}
+
+bool CustomFDialog::saveZipFile() const
+{
+	if (saveZip)
+		return saveZip->isChecked();
+	return false;
+}
+
+bool CustomFDialog::isIncludeFontsShown() const
+{
+	if (withFonts)
+		return withFonts->isVisible();
+	return false;
+}
+
+void CustomFDialog::setIncludeFonts(bool value)
+{
+	if (!withFonts)
+		return;
+	withFonts->setChecked(value);
+}
+
+bool CustomFDialog::includeFonts() const
+{
+	if (withFonts)
+		return withFonts->isChecked();
+	return false;
+}
+
+bool CustomFDialog::isIncludeProfilesShown() const
+{
+	if (withProfiles)
+		return withProfiles->isVisible();
+	return false;
+}
+
+void CustomFDialog::setIncludeProfiles(bool value)
+{
+	if (!withProfiles)
+		return;
+	withProfiles->setChecked(value);
+}
+
+bool CustomFDialog::includeProfiles() const
+{
+	if (withProfiles)
+		return withProfiles->isChecked();
+	return false;
+}
+
+int CustomFDialog::currentOptionIndex() const
+{
+	if (optionCombo)
+		return optionCombo->currentIndex();
+	return -1;
+}
