@@ -34,7 +34,6 @@ for which a new license (GPL+exception) is in place.
 #include "fontcombo.h"
 #include "iconmanager.h"
 #include "prefsmanager.h"
-#include "sccombobox.h"
 #include "scpage.h"
 #include "scribusapp.h"
 #include "scribusdoc.h"
@@ -42,27 +41,32 @@ for which a new license (GPL+exception) is in place.
 
 #include "fonts/scface.h"
 
-extern ScribusQApp* ScQApp;
-
 FontCombo::FontCombo(QWidget* pa) : QComboBox(pa),
 									prefsManager(PrefsManager::instance())
 {
-	ttfFont = IconManager::instance().loadPixmap("font_truetype16.png");
-	otfFont = IconManager::instance().loadPixmap("font_otf16.png");
-	psFont = IconManager::instance().loadPixmap("font_type1_16.png");
-	substFont = IconManager::instance().loadPixmap("font_subst16.png");
+	iconSetChange();
 	setEditable(true);
 	setValidator(new FontComboValidator(this));
 	setInsertPolicy(QComboBox::NoInsert);
 	setItemDelegate(new FontFamilyDelegate(this));
 	RebuildList(nullptr);
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+}
+
+void FontCombo::iconSetChange()
+{
+	IconManager& iconManager = IconManager::instance();
+	ttfFont = iconManager.loadPixmap("font_truetype16.png");
+	otfFont = iconManager.loadPixmap("font_otf16.png");
+	psFont = iconManager.loadPixmap("font_type1_16.png");
+	substFont = iconManager.loadPixmap("font_subst16.png");
 }
 
 void FontCombo::RebuildList(ScribusDoc *currentDoc, bool forAnnotation, bool forSubstitute)
 {
 	clear();
 	QMap<QString, QString> rlist;
-	rlist.clear();
 	SCFontsIterator it(prefsManager.appPrefs.fontPrefs.AvailFonts);
 	for ( ; it.hasNext(); it.next())
 	{
@@ -104,10 +108,8 @@ void FontCombo::RebuildList(ScribusDoc *currentDoc, bool forAnnotation, bool for
 
 FontComboH::FontComboH(QWidget* parent, bool labels) :
 		QWidget(parent),
-		fontFaceLabel(nullptr),
-		fontStyleLabel(nullptr),
-		showLabels(labels),
-		prefsManager(PrefsManager::instance())
+		prefsManager(PrefsManager::instance()),
+		showLabels(labels)
 {
 	currDoc = nullptr;
 	ttfFont = IconManager::instance().loadPixmap("font_truetype16.png");
@@ -127,13 +129,13 @@ FontComboH::FontComboH(QWidget* parent, bool labels) :
 		fontComboLayout->setColumnStretch(1,10);
 		col=1;
 	}
-	fontFamily = new ScComboBox(this);
+	fontFamily = new QComboBox(this);
 	fontFamily->setEditable(true);
 	fontFamily->setValidator(new FontComboValidator(fontFamily));
 	fontFamily->setInsertPolicy(QComboBox::NoInsert);
 	fontFamily->setItemDelegate(new FontFamilyDelegate(this));
 	fontComboLayout->addWidget(fontFamily,0,col);
-	fontStyle = new ScComboBox(this);
+	fontStyle = new QComboBox(this);
 	fontComboLayout->addWidget(fontStyle,1,col);
 	isForAnnotation = true;  // this is merely to ensure that the list is rebuilt
 	rebuildList(nullptr);
@@ -168,10 +170,10 @@ void FontComboH::familySelected(int id)
 	fontStyle->clear();
 	QString fntFamily = fontFamily->itemText(id);
 	QStringList slist, styleList = prefsManager.appPrefs.fontPrefs.AvailFonts.fontMap[fntFamily];
-	for (QStringList::ConstIterator it = styleList.begin(); it != styleList.end(); ++it)
+	for (QStringList::ConstIterator it = styleList.constBegin(); it != styleList.constEnd(); ++it)
 	{
 		SCFonts::ConstIterator fIt = prefsManager.appPrefs.fontPrefs.AvailFonts.find(fntFamily + " " + *it);
-		if (fIt != prefsManager.appPrefs.fontPrefs.AvailFonts.end())
+		if (fIt != prefsManager.appPrefs.fontPrefs.AvailFonts.constEnd())
 		{
 			if (!fIt->usable() || fIt->isReplacement())
 				continue;
@@ -218,10 +220,10 @@ void FontComboH::setCurrentFont(const QString& f)
 	QStringList ilist;
 	if (currDoc != nullptr)
 	{
-		for (QStringList::ConstIterator it3 = slist.begin(); it3 != slist.end(); ++it3)
+		for (QStringList::ConstIterator it3 = slist.constBegin(); it3 != slist.constEnd(); ++it3)
 		{
 			SCFonts::ConstIterator fIt = prefsManager.appPrefs.fontPrefs.AvailFonts.find(family + " " + *it3);
-			if (fIt != prefsManager.appPrefs.fontPrefs.AvailFonts.end())
+			if (fIt != prefsManager.appPrefs.fontPrefs.AvailFonts.constEnd())
 			{
 				if (!fIt->usable() || fIt->isReplacement())
 					continue;
@@ -253,13 +255,13 @@ void FontComboH::rebuildList(ScribusDoc *currentDoc, bool forAnnotation, bool fo
 	QStringList rlist = prefsManager.appPrefs.fontPrefs.AvailFonts.fontMap.keys();
 	QMap<QString, ScFace::FontType> flist;
 	flist.clear();
-	for (QStringList::ConstIterator it2 = rlist.begin(); it2 != rlist.end(); ++it2)
+	for (QStringList::ConstIterator it2 = rlist.constBegin(); it2 != rlist.constEnd(); ++it2)
 	{
 		if (currentDoc != nullptr)
 		{
 			QStringList slist = prefsManager.appPrefs.fontPrefs.AvailFonts.fontMap[*it2];
 			slist.sort();
-			for (QStringList::ConstIterator it3 = slist.begin(); it3 != slist.end(); ++it3)
+			for (QStringList::ConstIterator it3 = slist.constBegin(); it3 != slist.constEnd(); ++it3)
 			{
 				if ( prefsManager.appPrefs.fontPrefs.AvailFonts.contains(*it2 + " " + *it3))
 				{
@@ -279,7 +281,7 @@ void FontComboH::rebuildList(ScribusDoc *currentDoc, bool forAnnotation, bool fo
 		else
 		{
 			QMap<QString, QStringList>::ConstIterator fmIt = prefsManager.appPrefs.fontPrefs.AvailFonts.fontMap.find(*it2);
-			if (fmIt == prefsManager.appPrefs.fontPrefs.AvailFonts.fontMap.end())
+			if (fmIt == prefsManager.appPrefs.fontPrefs.AvailFonts.fontMap.constEnd())
 				continue;
 			if (fmIt->count() <= 0)
 				continue;
@@ -315,10 +317,10 @@ void FontComboH::rebuildList(ScribusDoc *currentDoc, bool forAnnotation, bool fo
 	QStringList ilist;
 	if (currentDoc != nullptr)
 	{
-		for (QStringList::ConstIterator it = slist.begin(); it != slist.end(); ++it)
+		for (QStringList::ConstIterator it = slist.constBegin(); it != slist.constEnd(); ++it)
 		{
 			SCFonts::ConstIterator fIt = prefsManager.appPrefs.fontPrefs.AvailFonts.find(family + " " + *it);
-			if (fIt != prefsManager.appPrefs.fontPrefs.AvailFonts.end())
+			if (fIt != prefsManager.appPrefs.fontPrefs.AvailFonts.constEnd())
 			{
 				if (!fIt->usable() || fIt->isReplacement())
 					continue;
@@ -520,8 +522,8 @@ void FontFamilyDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
 	QPainter invpixPainter(&invPixmap);
 
 	QRect r(0, 0, option.rect.width(), option.rect.height());
-	pixPainter.fillRect(r, option.palette.background());
-	invpixPainter.fillRect(r, option.palette.background());
+	pixPainter.fillRect(r, option.palette.window());
+	invpixPainter.fillRect(r, option.palette.window());
 
 	QFont font = option.font;
 	font.setPointSize(QFontInfo(font).pointSize() * 3 / 2.0);
@@ -538,6 +540,8 @@ void FontFamilyDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
 	if (hasLatin)
 		font = font2;
 
+	pixPainter.setPen(QPen(option.palette.text(), 0));
+
 	invpixPainter.setBrush(option.palette.highlight());
 	invpixPainter.setPen(Qt::NoPen);
 	invpixPainter.drawRect(0, 0, option.rect.width(), option.rect.height());
@@ -577,7 +581,7 @@ void FontFamilyDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
 
 	if (system != QFontDatabase::Any)
 	{
-		int w = pixPainter.fontMetrics().width(text + QLatin1String("  "));
+		int w = pixPainter.fontMetrics().horizontalAdvance(text + QLatin1String("  "));
 		pixPainter.setFont(font2);
 		invpixPainter.setFont(font2);
 		QString sample = fontDb.writingSystemSample(system);
@@ -653,7 +657,7 @@ QSize FontFamilyDelegate::sizeHint(const QStyleOptionViewItem &option, const QMo
 	QFont font(option.font);
 	font.setPointSize(QFontInfo(font).pointSize() * 3/2);
 	QFontMetrics fontMetrics(font);
-	return QSize(fontMetrics.width(text), fontMetrics.height() + 5);
+	return QSize(fontMetrics.horizontalAdvance(text), fontMetrics.height() + 5);
 }
 
 
@@ -664,7 +668,7 @@ FontComboValidator::FontComboValidator(QObject* parent)
 
 QValidator::State FontComboValidator::validate(QString & input, int & pos) const
 {
-	QComboBox* comboBox = dynamic_cast<QComboBox*>(this->parent());
+	QComboBox* comboBox = qobject_cast<QComboBox*>(this->parent());
 	if (!comboBox)
 		return QValidator::Invalid;
 
