@@ -53,6 +53,7 @@ for which a new license (GPL+exception) is in place.
 #include <QStandardItem>
 #include <QTextEdit>
 #include <QTreeView>
+#include <QVector>
 #include <QXmlDefaultHandler>
 
 #include "prefsmanager.h"
@@ -84,7 +85,7 @@ class HistoryParser2 : public QXmlDefaultHandler
 				struct histd2 his;
 				his.title = attrs.value(0);
 				his.url = attrs.value(1);
-				helpBrowser->mHistory[helpBrowser->histMenu->addAction(his.title)] = his;
+				helpBrowser->addHistoryItem(his);
 			}
 			return true;
 		}
@@ -138,7 +139,7 @@ bool HelpBrowser::firstRun = true;
 HelpBrowser::HelpBrowser( QWidget* parent, const QString& /*caption*/, const QString& guiLanguage, const QString& jumpToSection, const QString& jumpToFile)
 	: QMainWindow( parent )
 {
-	firstRun=true;
+	firstRun = true;
 	setupUi(this);
 	helpNav = new HelpNavigation(this);
 #if defined(Q_OS_MAC) && defined(HELP_NAV_AS_DRAWER)
@@ -153,12 +154,13 @@ HelpBrowser::HelpBrowser( QWidget* parent, const QString& /*caption*/, const QSt
 	statusBar()->addPermanentWidget(progressBar);
 
 	setupLocalUI();
-	language = guiLanguage.isEmpty() ? QString("en") : guiLanguage.left(2);
-	finalBaseDir = ScPaths::instance().docDir() + "en/"; //Sane default for help location
-	textBrowser->setSearchPaths(QStringList(finalBaseDir));
-	menuModel=nullptr;
+	m_language = guiLanguage.isEmpty() ? QString("en") : guiLanguage.left(2);
+	m_defaultBaseDir = ScPaths::instance().docDir() + "en/"; //Sane default for help location
+	m_finalBaseDir = ScPaths::instance().docDir() + "en/"; //Sane default for help location
+	textBrowser->setSearchPaths(QStringList(m_finalBaseDir));
+
 	loadMenu();
-	if (menuModel!=nullptr)
+	if (m_menuModel != nullptr)
 	{
 		readBookmarks();
 		readHistory();
@@ -173,12 +175,12 @@ HelpBrowser::HelpBrowser( QWidget* parent, const QString& /*caption*/, const QSt
 
 HelpBrowser::~HelpBrowser()
 {
-	firstRun=true;
+	firstRun = true;
 }
 
 void HelpBrowser::closeEvent(QCloseEvent * event)
 {
-	delete menuModel;
+	delete m_menuModel;
 
 	// no need to delete child widgets, Qt does it all for us
 	// bookmarks
@@ -192,11 +194,11 @@ void HelpBrowser::closeEvent(QCloseEvent * event)
 		QTreeWidgetItemIterator it(helpNav->bookmarksView);
 		while (*it) 
 		{
-			if (bookmarkIndex.contains((*it)->text(0)))
+			if (m_bookmarkIndex.contains((*it)->text(0)))
 			{
-				QString pagetitle(bookmarkIndex.value((*it)->text(0)).first);
-				QString filename(bookmarkIndex.value((*it)->text(0)).second);
-				stream << "\t<item title=\"" << (*it)->text(0) << "\" pagetitle=\"" << pagetitle << "\" url=\"" << filename << "\" />\n";
+				QString pageTitle(m_bookmarkIndex.value((*it)->text(0)).first);
+				QString fileName(m_bookmarkIndex.value((*it)->text(0)).second);
+				stream << "\t<item title=\"" << (*it)->text(0) << "\" pagetitle=\"" << pageTitle << "\" url=\"" << fileName << "\" />\n";
 			}
 			++it;
 		}
@@ -211,14 +213,14 @@ void HelpBrowser::closeEvent(QCloseEvent * event)
 		stream.setCodec("UTF-8");
 		stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
 		stream << "<history>\n";
-		for (QMap<QAction*,histd2>::Iterator it = mHistory.begin() ; it != mHistory.end(); ++it)
+		for (QMap<QAction*,histd2>::Iterator it = m_history.begin() ; it != m_history.end(); ++it)
 			stream << "\t<item title=\"" << it.value().title << "\" url=\"" << it.value().url << "\" />\n";
 		stream << "</history>\n";
 		histFile.close();
 	}
 	// size
-	prefs->set("xsize", width());
-	prefs->set("ysize", height());
+	m_prefs->set("xsize", width());
+	m_prefs->set("ysize", height());
 
 	emit closed();
 }
@@ -227,26 +229,26 @@ void HelpBrowser::setupLocalUI()
 {
 	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
 	//Add Menus
-	fileMenu=menuBar()->addMenu("");
-	editMenu=menuBar()->addMenu("");
-	bookMenu=menuBar()->addMenu("");
-	histMenu=new QMenu(this);
+	fileMenu = menuBar()->addMenu("");
+	editMenu = menuBar()->addMenu("");
+	bookMenu = menuBar()->addMenu("");
+	histMenu = new QMenu(this);
 
 	//Add Menu items
-	filePrint=fileMenu->addAction(IconManager::instance().loadIcon("16/document-print.png"), "", this, SLOT(print()), Qt::CTRL+Qt::Key_P);
+	filePrint = fileMenu->addAction(IconManager::instance().loadIcon("16/document-print.png"), "", this, SLOT(print()), Qt::CTRL+Qt::Key_P);
 	fileMenu->addSeparator();
-	fileExit=fileMenu->addAction(IconManager::instance().loadIcon("exit.png"), "", this, SLOT(close()), Qt::CTRL+Qt::Key_W);
-	editFind=editMenu->addAction(IconManager::instance().loadIcon("find.png"), "", this, SLOT(find()), Qt::CTRL+Qt::Key_F);
-	editFindNext=editMenu->addAction( "", this, SLOT(findNext()), Qt::Key_F3);
-	editFindPrev=editMenu->addAction( "", this, SLOT(findPrevious()), Qt::SHIFT+Qt::Key_F3);
-	bookAdd=bookMenu->addAction( "", this, SLOT(bookmarkButton_clicked()), Qt::CTRL+Qt::Key_D);
-	bookDel=bookMenu->addAction( "", this, SLOT(deleteBookmarkButton_clicked()));
-	bookDelAll=bookMenu->addAction( "", this, SLOT(deleteAllBookmarkButton_clicked()));
+	fileExit = fileMenu->addAction(IconManager::instance().loadIcon("exit.png"), "", this, SLOT(close()), Qt::CTRL+Qt::Key_W);
+	editFind = editMenu->addAction(IconManager::instance().loadIcon("find.png"), "", this, SLOT(find()), Qt::CTRL+Qt::Key_F);
+	editFindNext = editMenu->addAction( "", this, SLOT(findNext()), Qt::Key_F3);
+	editFindPrev = editMenu->addAction( "", this, SLOT(findPrevious()), Qt::SHIFT+Qt::Key_F3);
+	bookAdd = bookMenu->addAction( "", this, SLOT(bookmarkButton_clicked()), Qt::CTRL+Qt::Key_D);
+	bookDel = bookMenu->addAction( "", this, SLOT(deleteBookmarkButton_clicked()));
+	bookDelAll = bookMenu->addAction( "", this, SLOT(deleteAllBookmarkButton_clicked()));
 
 	//Add Toolbar items
-	goHome=toolBar->addAction(IconManager::instance().loadIcon("16/go-home.png"), "", textBrowser, SLOT(home()));
-	goBack=toolBar->addAction(IconManager::instance().loadIcon("16/go-previous.png"), "", textBrowser, SLOT(backward()));
-	goFwd=toolBar->addAction(IconManager::instance().loadIcon("16/go-next.png"), "", textBrowser, SLOT(forward()));
+	goHome = toolBar->addAction(IconManager::instance().loadIcon("16/go-home.png"), "", textBrowser, SLOT(home()));
+	goBack = toolBar->addAction(IconManager::instance().loadIcon("16/go-previous.png"), "", textBrowser, SLOT(backward()));
+	goFwd = toolBar->addAction(IconManager::instance().loadIcon("16/go-next.png"), "", textBrowser, SLOT(forward()));
 	goBack->setMenu(histMenu);
 	
 	helpNav->listView->header()->hide();
@@ -256,9 +258,9 @@ void HelpBrowser::setupLocalUI()
 //	splitter->setStretchFactor(splitter->indexOf(tabWidget), 0);
 //	splitter->setStretchFactor(splitter->indexOf(textBrowser), 1);
 	// reset previous size
-	prefs = PrefsManager::instance().prefsFile->getPluginContext("helpbrowser");
-	int xsize = prefs->getUInt("xsize", 640);
-	int ysize = prefs->getUInt("ysize", 480);
+	m_prefs = PrefsManager::instance().prefsFile->getPluginContext("helpbrowser");
+	int xsize = m_prefs->getUInt("xsize", 640);
+	int ysize = m_prefs->getUInt("ysize", 480);
 	resize(QSize(xsize, ysize).expandedTo(minimumSizeHint()) );
 
 	//basic ui
@@ -286,6 +288,11 @@ void HelpBrowser::setupLocalUI()
 //	statusBar()->showMessage(link);
 //}
 
+void HelpBrowser::addHistoryItem(const histd2& histItem)
+{
+	m_history[histMenu->addAction(histItem.title)] = histItem;
+}
+
 void HelpBrowser::changeEvent(QEvent *e)
 {
 	if (e->type() == QEvent::LanguageChange)
@@ -318,21 +325,23 @@ void HelpBrowser::languageChange()
 	bookDel->setText(tr("&Delete"));
 	bookDelAll->setText(tr("D&elete All"));
 	Ui::HelpBrowser::retranslateUi(this);
-	if (!firstRun)
+
+	if (firstRun)
 	{
-		QString fname(QDir::cleanPath(textBrowser->source().toLocalFile()));
-		QFileInfo fi(fname);
-		QString filename(fi.fileName());
-		if (ScCore->getGuiLanguage().isEmpty())
-			language="en";
-		else
-			language=ScCore->getGuiLanguage();
-		loadMenu();
-		if (menuModel!=nullptr)
-			loadHelp(finalBaseDir + "/" + filename);
+		firstRun = false;
+		return;
 	}
+
+	QString fname(QDir::cleanPath(textBrowser->source().toLocalFile()));
+	QFileInfo fi(fname);
+	QString fileName(fi.fileName());
+	if (ScCore->getGuiLanguage().isEmpty())
+		m_language = "en";
 	else
-		firstRun=false;
+		m_language = ScCore->getGuiLanguage();
+	loadMenu();
+	if (m_menuModel != nullptr)
+		loadHelp(fileName);
 }
 
 void HelpBrowser::print()
@@ -349,7 +358,7 @@ void HelpBrowser::searchingButton_clicked()
 	// root files
 	helpNav->searchingView->clear();
 	QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
-	searchingInDirectory(finalBaseDir);
+	searchingInDirectory(m_finalBaseDir);
 	QApplication::changeOverrideCursor(Qt::ArrowCursor);
 }
 
@@ -370,12 +379,12 @@ void HelpBrowser::searchingInDirectory(const QString& aDir)
 			int cnt = str.count(helpNav->searchingEdit->text(), Qt::CaseInsensitive);
 			if (cnt > 0)
 			{
-				QString toFind(fname.remove(finalBaseDir + "/"));
-				QMapIterator<QString, QString> i(quickHelpIndex);
+				QString toFind(fname.remove(m_finalBaseDir + "/"));
+				QMapIterator<QString, QString> i(m_quickHelpIndex);
 				while (i.hasNext())
 				{
 					i.next();
-					if (i.value()==toFind)
+					if (i.value() == toFind)
 						helpNav->searchingView->addTopLevelItem(new QTreeWidgetItem(helpNav->searchingView, QStringList() << i.key()));
 				}
 			}
@@ -393,32 +402,32 @@ void HelpBrowser::searchingInDirectory(const QString& aDir)
 
 void HelpBrowser::find()
 {
-	findText = QInputDialog::getText( this, tr("Find"), tr("Search Term:"), QLineEdit::Normal, findText, nullptr);
-	if (findText.isNull())
+	m_findText = QInputDialog::getText( this, tr("Find"), tr("Search Term:"), QLineEdit::Normal, m_findText, nullptr);
+	if (m_findText.isNull())
 		return;
 	findNext();
 }
 
 void HelpBrowser::findNext()
 {
-	if (findText.isNull())
+	if (m_findText.isNull())
 	{
 		find();
 		return;
 	}
 	// find it. finally
-	textBrowser->find(findText, 0);
+	textBrowser->find(m_findText, 0);
 }
 
 void HelpBrowser::findPrevious()
 {
-	if (findText.isNull())
+	if (m_findText.isNull())
 	{
 		find();
 		return;
 	}
 	// find it. finally
-	textBrowser->find(findText);
+	textBrowser->find(m_findText);
 }
 
 void HelpBrowser::bookmarkButton_clicked()
@@ -430,15 +439,15 @@ void HelpBrowser::bookmarkButton_clicked()
 	if (title.isNull())
 		return;
 	//TODO: start storing full paths
- 	QString toFind(fname.remove(QDir::toNativeSeparators(finalBaseDir)));
+ 	QString toFind(fname.remove(QDir::toNativeSeparators(m_finalBaseDir)));
 	toFind=toFind.mid(1, toFind.length()-1);
-	QMapIterator<QString, QString> i(quickHelpIndex);
+	QMapIterator<QString, QString> i(m_quickHelpIndex);
 	while (i.hasNext())
 	{
 		i.next();
-		if (i.value()==toFind)
+		if (i.value() == toFind)
 		{
-			bookmarkIndex.insert(title, qMakePair(i.key(), i.value()));
+			m_bookmarkIndex.insert(title, qMakePair(i.key(), i.value()));
 			helpNav->bookmarksView->addTopLevelItem(new QTreeWidgetItem(helpNav->bookmarksView, QStringList() << title));
 		}
 	}
@@ -447,81 +456,98 @@ void HelpBrowser::bookmarkButton_clicked()
 
 void HelpBrowser::deleteBookmarkButton_clicked()
 {
-	QTreeWidgetItem *twi=helpNav->bookmarksView->currentItem();
-	if (twi!=nullptr)
+	QTreeWidgetItem *twi = helpNav->bookmarksView->currentItem();
+	if (twi != nullptr)
 	{
-		if (bookmarkIndex.contains(twi->text(0)))
-			bookmarkIndex.remove(twi->text(0));
+		if (m_bookmarkIndex.contains(twi->text(0)))
+			m_bookmarkIndex.remove(twi->text(0));
 		delete twi;
 	}
 }
 
 void HelpBrowser::deleteAllBookmarkButton_clicked()
 {
-	bookmarkIndex.clear();
+	m_bookmarkIndex.clear();
 	helpNav->bookmarksView->clear();
 }
 
 void HelpBrowser::histChosen(QAction* i)
 {
-	if (mHistory.contains(i))
-		textBrowser->setSource( QUrl::fromLocalFile(mHistory[i].url) );
-
+	if (m_history.contains(i))
+		textBrowser->setSource( QUrl::fromLocalFile(m_history[i].url) );
 }
 
 void HelpBrowser::jumpToHelpSection(const QString& jumpToSection, const QString& jumpToFile, bool dontChangeIfAlreadyLoaded)
 {
 	QString toLoad;
-	bool noDocs=false;
 	if (jumpToFile.isEmpty())
 	{
-		toLoad = finalBaseDir + "/"; //clean this later to handle 5 char locales
 		if (jumpToSection.isEmpty())
 		{
-			QModelIndex index=menuModel->index(0,1);
+			QModelIndex index = m_menuModel->index(0, 1);
 			if (index.isValid())
 			{
 				helpNav->listView->selectionModel()->select(index, QItemSelectionModel::ClearAndSelect);
-				toLoad += menuModel->data(index, Qt::DisplayRole).toString();
+				toLoad = m_menuModel->data(index, Qt::DisplayRole).toString();
 			}
-			else
-				noDocs=true;
 		}
-		else if (jumpToSection=="scripter")
+		else if (jumpToSection == "scripter")
 		{
- 			toLoad+="scripter1.html";
+ 			toLoad += "scripter1.html";
 		}
 	}
 	else
 	{
-		toLoad=finalBaseDir + "/" + jumpToFile;
+		toLoad = jumpToFile;
 	}
-	if (!noDocs)
+	if (!toLoad.isEmpty())
 		loadHelp(toLoad);
-	else
-		if (!dontChangeIfAlreadyLoaded)
-			displayNoHelp();
+	else if (!dontChangeIfAlreadyLoaded)
+		displayNoHelp();
 }
 
-void HelpBrowser::loadHelp(const QString& filename)
+void HelpBrowser::loadHelp(const QString& fileName)
 {
 	struct histd2 his;
-	bool Avail = false;
+	bool isAvail = false;
 	QString toLoad;
-	QFileInfo fi;
-	fi = QFileInfo(filename);
-	if (fi.fileName().length()>0)
+
+	QFileInfo fi(fileName);
+	if (fi.fileName().length() > 0)
 	{
-		if (fi.exists())
-			toLoad = filename;
-		else
+		if (fi.isAbsolute() && fi.exists())
+			toLoad = fileName;
+		if (toLoad.isEmpty())
 		{
-			toLoad = finalBaseDir + "/index.html";
-			fi = QFileInfo(toLoad);
+			QStringList searchPaths = textBrowser->searchPaths();
+			for (int i = 0; i < searchPaths.count(); ++i)
+			{
+				const QString& searchPath = searchPaths.at(i);
+				fi = QFileInfo(searchPath + "/" + fi.fileName());
+				if (fi.exists())
+				{
+					toLoad = fi.fileName();
+					break;
+				}
+			}
 		}
-		Avail = fi.exists();
+		if (toLoad.isEmpty())
+		{
+			QStringList searchPaths = textBrowser->searchPaths();
+			for (int i = 0; i < searchPaths.count(); ++i)
+			{
+				const QString& searchPath = searchPaths.at(i);
+				fi = QFileInfo(searchPath + "/index.html");
+				if (fi.exists())
+				{
+					toLoad = "index.html";
+					break;
+				}
+			}
+		}
+		isAvail = fi.exists();
 	}
-	if (Avail)
+	if (isAvail)
 	{
 		textBrowser->setSource(QUrl::fromLocalFile(toLoad));
 		
@@ -529,108 +555,90 @@ void HelpBrowser::loadHelp(const QString& filename)
 		if (his.title.isEmpty())
 			his.title = toLoad;
 		his.url = toLoad;
-		mHistory[histMenu->addAction(his.title)] = his;
+		m_history[histMenu->addAction(his.title)] = his;
 	}
 	else
 	{
 		displayNoHelp();
 	}
-	if (mHistory.count() > 15)
+	if (m_history.count() > 15)
 	{
-		QAction* first=histMenu->actions().first();
-		mHistory.remove(first);
+		QAction* first = histMenu->actions().first();
+		m_history.remove(first);
 		histMenu->removeAction(first);
 	}
 }
 
 void HelpBrowser::loadMenu()
 {
-//	QString baseHelpDir = ScPaths::instance().docDir();
-//	QString altHelpDir  = ScPaths::instance().getApplicationDataDir();
 	QString baseHelpDir = ScPaths::instance().userHelpFilesDir(false);
 	QString installHelpDir  = ScPaths::instance().docDir();
 
-	QString baseHelpMenuFile = QDir::toNativeSeparators(baseHelpDir + language + "/menu.xml");
-	QString installHelpMenuFile = QDir::toNativeSeparators(installHelpDir + language + "/menu.xml");
-	QFileInfo baseFi = QFileInfo(baseHelpMenuFile);
-	QFileInfo installFi = QFileInfo(installHelpMenuFile);
-	QString toLoad = baseHelpMenuFile;
-	if (!baseFi.exists())
+	QVector<QPair<QString, QString> > helpMenuFiles;
+	helpMenuFiles.reserve(6);
+	helpMenuFiles.append(qMakePair(baseHelpDir, m_language));
+	helpMenuFiles.append(qMakePair(installHelpDir, m_language));
+	if (!m_language.isEmpty())
 	{
-		if (installFi.exists())
+		QStringList langDecomp = m_language.split(QChar('_'), QString::SkipEmptyParts);
+		QString altLanguage = langDecomp.first();
+		helpMenuFiles.append(qMakePair(baseHelpDir, altLanguage));
+		helpMenuFiles.append(qMakePair(installHelpDir, altLanguage));
+	}
+	QString enLanguage("en");
+	helpMenuFiles.append(qMakePair(baseHelpDir, enLanguage));
+	helpMenuFiles.append(qMakePair(installHelpDir, enLanguage));
+
+	QString toLoad;;
+	for (int i = 0; i < helpMenuFiles.count(); ++i)
+	{
+		auto helpPair = helpMenuFiles.at(i);
+		QString helpFile = QDir::toNativeSeparators(helpPair.first + helpPair.second + "/menu.xml");
+		QFileInfo helpInfo(helpFile);
+		if (helpInfo.exists())
 		{
-			toLoad=installHelpMenuFile;
-			baseFi=installFi;
-		}
-		else		
-		{
-			if (!language.isEmpty())
-			{
-				//Check if we can load, eg "de" when "de_CH" docs don't exist
-				QString baseHelpMenuFile3(QDir::toNativeSeparators(baseHelpDir + language.left(2) + "/menu.xml"));
-				QString altHelpMenuFile3(QDir::toNativeSeparators(installHelpDir + language.left(2) + "/menu.xml"));
-				QFileInfo fi3(baseHelpMenuFile3);
-				QFileInfo altfi3(altHelpMenuFile3);
-				if (fi3.exists())
-				{
-					language=language.left(2);
-					toLoad = QDir::toNativeSeparators(baseHelpMenuFile3);
-				}
-				else if (altfi3.exists())
-				{
-					language=language.left(2);
-					toLoad = QDir::toNativeSeparators(altHelpMenuFile3);
-				}
-				else
-				{
-					//Fall back to English
-					sDebug("Scribus help in your selected language does not exist, trying English. Otherwise, please visit http://docs.scribus.net.");
-					language="en";
-					if (QFile::exists(baseHelpDir + language + "/menu.xml"))
-						toLoad = QDir::toNativeSeparators(baseHelpDir + language + "/menu.xml");
-					else
-						toLoad = QDir::toNativeSeparators(installHelpDir + language + "/menu.xml");
-				}
-			}
-			else
-			{
-				language="en";
-				toLoad = QDir::toNativeSeparators(baseHelpDir + language + "/menu.xml");
-			}
-			baseFi = QFileInfo(toLoad);
+			toLoad = helpFile;
+			m_language = helpPair.second;
+			break;
 		}
 	}
-	else
+
+	if (toLoad.isEmpty())
 	{
-		if (installFi.exists())
-			baseFi=installFi;
+		m_language = "en";
+		toLoad = QDir::toNativeSeparators(installHelpDir + m_language + "/menu.xml");
 	}
+
 	//Set our final location for loading the help files
-	finalBaseDir=baseFi.path();
-	textBrowser->setSearchPaths(QStringList(finalBaseDir));
+	QFileInfo baseFi = QFileInfo(toLoad);
+	m_finalBaseDir = baseFi.path();
+	QStringList searchPaths;
+	searchPaths << m_finalBaseDir << m_defaultBaseDir;
+	textBrowser->setSearchPaths(searchPaths);
+
+	delete m_menuModel;
+	m_menuModel = nullptr;
+
 	if (baseFi.exists())
 	{
-		delete menuModel;
-		menuModel=new ScHelpTreeModel(toLoad, "Topic", "Location", &quickHelpIndex);
+		m_menuModel = new ScHelpTreeModel(toLoad, "Topic", "Location", &m_quickHelpIndex);
 	
-		helpNav->listView->setModel(menuModel);
+		helpNav->listView->setModel(m_menuModel);
 		helpNav->listView->setSelectionMode(QAbstractItemView::SingleSelection);
-		QItemSelectionModel *selectionModel = new QItemSelectionModel(menuModel);
+		QItemSelectionModel *selectionModel = new QItemSelectionModel(m_menuModel);
 		helpNav->listView->setSelectionModel(selectionModel);
 		connect(helpNav->listView->selectionModel(), SIGNAL(selectionChanged( const QItemSelection &, const QItemSelection &)), this, SLOT(itemSelected( const QItemSelection &, const QItemSelection &)));
 	
 		helpNav->listView->setColumnHidden(1,true);
 	}
-	else
-		menuModel=nullptr;
 }
 
 void HelpBrowser::readBookmarks()
 {
 	BookmarkParser2 handler;
 	handler.view = helpNav->bookmarksView;
-	handler.quickHelpIndex=&quickHelpIndex;
-	handler.bookmarkIndex=&bookmarkIndex;
+	handler.quickHelpIndex = &m_quickHelpIndex;
+	handler.bookmarkIndex = &m_bookmarkIndex;
 	QFile xmlFile(bookmarkFile());
 	QXmlInputSource source(&xmlFile);
 	QXmlSimpleReader reader;
@@ -659,10 +667,10 @@ void HelpBrowser::itemSelected(const QItemSelection & selected, const QItemSelec
 	{
 		if (i == 1) // skip 0, as this is always the rootitem, even if we are selecting the rootitem. hmm
 		{
-			QString filename(menuModel->data(index, Qt::DisplayRole).toString());
-			if (!filename.isEmpty())
+			QString fileName(m_menuModel->data(index, Qt::DisplayRole).toString());
+			if (!fileName.isEmpty())
 			{
-				loadHelp(finalBaseDir + "/" + filename);
+				loadHelp(fileName);
 			}
 		}
 		++i;
@@ -674,13 +682,13 @@ void HelpBrowser::itemSearchSelected(QTreeWidgetItem *twi, int i)
 	Q_UNUSED(i);
 	if (!twi)
 		return;
-	if (quickHelpIndex.contains(twi->text(0)))
+	if (m_quickHelpIndex.contains(twi->text(0)))
 	{
-		QString filename(quickHelpIndex.value(twi->text(0)));
-		if (!filename.isEmpty())
+		QString fileName(m_quickHelpIndex.value(twi->text(0)));
+		if (!fileName.isEmpty())
 		{
-			loadHelp(finalBaseDir + "/" + filename);
-			findText = helpNav->searchingEdit->text();
+			loadHelp(fileName);
+			m_findText = helpNav->searchingEdit->text();
 			findNext();
 		}
 	}
@@ -691,11 +699,11 @@ void HelpBrowser::itemBookmarkSelected(QTreeWidgetItem *twi, int i)
 	Q_UNUSED(i);
 	if (!twi)
 		return;
-	if (bookmarkIndex.contains(twi->text(0)))
+	if (m_bookmarkIndex.contains(twi->text(0)))
 	{
-		QString filename(bookmarkIndex.value(twi->text(0)).second);
-		if (!filename.isEmpty())
-			loadHelp(finalBaseDir + "/" + filename);
+		QString fileName(m_bookmarkIndex.value(twi->text(0)).second);
+		if (!fileName.isEmpty())
+			loadHelp(fileName);
 	}
 }
 
