@@ -17,6 +17,7 @@ for which a new license (GPL+exception) is in place.
 
 #include <QCheckBox>
 #include <QColorDialog>
+#include <QComboBox>
 #include <QEvent>
 #include <QHBoxLayout>
 #include <QHeaderView>
@@ -24,6 +25,7 @@ for which a new license (GPL+exception) is in place.
 #include <QMessageBox>
 #include <QPixmap>
 #include <QPushButton>
+#include <QSignalBlocker>
 #include <QSpacerItem>
 #include <QTableWidget>
 #include <QTableWidgetItem>
@@ -32,14 +34,15 @@ for which a new license (GPL+exception) is in place.
 #include <QVBoxLayout>
 
 #include "iconmanager.h"
-#include "sccombobox.h"
 #include "scribus.h"
+#include "scribusapp.h"
 #include "scribusdoc.h"
+#include "selection.h"
 #include "ui/scrspinbox.h"
 #include "undomanager.h"
 
 
-LayerPalette::LayerPalette(QWidget* parent) : ScDockPalette( parent, "Layers", nullptr ), m_Doc(nullptr)
+LayerPalette::LayerPalette(QWidget* parent) : ScDockPalette(parent, "Layers", Qt::WindowFlags()), m_Doc(nullptr)
 {
 	setObjectName(QString::fromLocal8Bit("Layers"));
 	setSizePolicy( QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
@@ -53,7 +56,7 @@ LayerPalette::LayerPalette(QWidget* parent) : ScDockPalette( parent, "Layers", n
 	layout1->setSpacing(2);
 	textLabel1 = new QLabel( this);
 	layout1->addWidget( textLabel1 );
-	blendMode = new ScComboBox( this);
+	blendMode = new QComboBox( this);
 	layout1->addWidget( blendMode );
 	textLabel2 = new QLabel( this);
 	textLabel2->setText( tr( "Opacity:" ) );
@@ -145,26 +148,28 @@ LayerPalette::LayerPalette(QWidget* parent) : ScDockPalette( parent, "Layers", n
 	LayerPaletteLayout->addLayout( Layout1 );
 	containerWidget->setLayout( LayerPaletteLayout );
 	setWidget( containerWidget );
-	ClearInhalt();
+	clearContent();
 	languageChange();
 
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+
 	connect(newLayerButton, SIGNAL(clicked()), this, SLOT(addLayer()));
 	connect(duplicateLayerButton, SIGNAL(clicked()), this, SLOT(dupLayer()));
 	connect(deleteLayerButton, SIGNAL(clicked()), this, SLOT(removeLayer()));
 	connect(raiseLayerButton, SIGNAL(clicked()), this, SLOT(upLayer()));
 	connect(lowerLayerButton, SIGNAL(clicked()), this, SLOT(downLayer()));
-	connect(Table, SIGNAL(cellChanged(int, int)), this, SLOT(changeName(int, int)));
+	connect(Table, SIGNAL(cellChanged(int,int)), this, SLOT(changeName(int,int)));
 	connect(opacitySpinBox, SIGNAL(valueChanged(double)), this, SLOT(changeOpacity()));
 	connect(blendMode, SIGNAL(activated(int)), this, SLOT(changeBlendMode(int)));
 	connect(header, SIGNAL(sectionClicked(int)), this, SLOT(toggleAllfromHeader(int)));
 }
 
-void LayerPalette::ClearInhalt()
+void LayerPalette::clearContent()
 {
 	disconnect(blendMode, SIGNAL(activated(int)), this, SLOT(changeBlendMode(int)));
 	disconnect(opacitySpinBox, SIGNAL(valueChanged(double)), this, SLOT(changeOpacity()));
-	disconnect(Table, SIGNAL(cellClicked(int, int)), this, SLOT(setActiveLayer(int, int)));
-	disconnect(Table, SIGNAL(cellChanged(int, int)), this, SLOT(changeName(int, int)));
+	disconnect(Table, SIGNAL(cellClicked(int,int)), this, SLOT(setActiveLayer(int,int)));
+	disconnect(Table, SIGNAL(cellChanged(int,int)), this, SLOT(changeName(int,int)));
 	Table->clearContents();
 	Table->setRowCount(0);
 	m_Doc = nullptr;
@@ -191,7 +196,7 @@ void LayerPalette::setDoc(ScribusDoc* doc)
 		lowerLayerButton->setEnabled(false);
 		markActiveLayer(0);
 	}
-	layers=&m_Doc->Layers;
+	layers = &m_Doc->Layers;
 	rebuildList();
 
 	markActiveLayer(m_Doc->activeLayer());
@@ -208,19 +213,18 @@ void LayerPalette::rebuildList()
 {
 	disconnect(blendMode, SIGNAL(activated(int)), this, SLOT(changeBlendMode(int)));
 	disconnect(opacitySpinBox, SIGNAL(valueChanged(double)), this, SLOT(changeOpacity()));
-	disconnect(Table, SIGNAL(cellClicked(int, int)), this, SLOT(setActiveLayer(int, int)));
-	disconnect(Table, SIGNAL(cellChanged(int, int)), this, SLOT(changeName(int, int)));
+	disconnect(Table, SIGNAL(cellClicked(int,int)), this, SLOT(setActiveLayer(int,int)));
+	disconnect(Table, SIGNAL(cellChanged(int,int)), this, SLOT(changeName(int,int)));
 	QString tmp;
-	ScLayers::iterator it;
 	int layerCount = m_Doc->layerCount();
 	Table->setRowCount(layerCount);
-	for (it = layers->begin(); it != layers->end(); ++it)
+	for (auto it = layers->begin(); it != layers->end(); ++it)
 	{
-		int layerID=(*it).ID;
+		int layerID = it->ID;
 		//TODO once "layers" is not set anymore, need to get layer number differently
 		int layerLevel = m_Doc->layerLevelFromID(layerID);
 		tmp = tmp.setNum(layerLevel);
-		int row = layerCount-layerLevel-1;
+		int row = layerCount-layerLevel - 1;
 		QToolButton *pb = new QToolButton(this);
 		pb->setObjectName(tmp);
 		pb->setAutoRaise(true);
@@ -237,7 +241,7 @@ void LayerPalette::rebuildList()
 		QHBoxLayout *cl1 = new QHBoxLayout(cw1);
 		cl1->addWidget(cp1);
 		cl1->setAlignment(Qt::AlignCenter);
-		cl1->setContentsMargins(0,0,0,0);
+		cl1->setContentsMargins(0, 0, 0, 0);
 		Table->setCellWidget(row, 1, cw1);
 		cp1->setChecked(m_Doc->layerVisible(layerID));
 		connect(cp1, SIGNAL(clicked()), this, SLOT(visibleLayer()));
@@ -249,7 +253,7 @@ void LayerPalette::rebuildList()
 		QHBoxLayout *cl2 = new QHBoxLayout(cw2);
 		cl2->addWidget(cp2);
 		cl2->setAlignment(Qt::AlignCenter);
-		cl2->setContentsMargins(0,0,0,0);
+		cl2->setContentsMargins(0, 0, 0, 0);
 		Table->setCellWidget(row, 2, cw2);
 		connect(cp2, SIGNAL(clicked()), this, SLOT(printLayer()));
 
@@ -260,7 +264,7 @@ void LayerPalette::rebuildList()
 		QHBoxLayout *cl3 = new QHBoxLayout(cw3);
 		cl3->addWidget(cp3);
 		cl3->setAlignment(Qt::AlignCenter);
-		cl3->setContentsMargins(0,0,0,0);
+		cl3->setContentsMargins(0, 0, 0, 0);
 		Table->setCellWidget(row, 3, cw3);
 		connect(cp3, SIGNAL(clicked()), this, SLOT(lockLayer()));
 
@@ -271,7 +275,7 @@ void LayerPalette::rebuildList()
 		QHBoxLayout *cl4 = new QHBoxLayout(cw4);
 		cl4->addWidget(cp4);
 		cl4->setAlignment(Qt::AlignCenter);
-		cl4->setContentsMargins(0,0,0,0);
+		cl4->setContentsMargins(0, 0, 0, 0);
 		Table->setCellWidget(row, 4, cw4);
 		connect(cp4, SIGNAL(clicked()), this, SLOT(flowToggleLayer()));
 
@@ -282,7 +286,7 @@ void LayerPalette::rebuildList()
 		QHBoxLayout *cl5 = new QHBoxLayout(cw5);
 		cl5->addWidget(cp5);
 		cl5->setAlignment(Qt::AlignCenter);
-		cl5->setContentsMargins(0,0,0,0);
+		cl5->setContentsMargins(0, 0, 0, 0);
 		Table->setCellWidget(row, 5, cw5);
 		connect(cp5, SIGNAL(clicked()), this, SLOT(outlineToggleLayer()));
 
@@ -293,14 +297,14 @@ void LayerPalette::rebuildList()
 		QHBoxLayout *cl6 = new QHBoxLayout(cw6);
 		cl6->addWidget(cp6);
 		cl6->setAlignment(Qt::AlignCenter);
-		cl6->setContentsMargins(0,0,0,0);
+		cl6->setContentsMargins(0, 0, 0, 0);
 		Table->setCellWidget(row, 6, cw6);
 		connect(cp6, SIGNAL(clicked()), this, SLOT(selectToggleLayer()));
 
 		Table->setItem(row, 7, new QTableWidgetItem(m_Doc->layerName(layerID)));
 	}
-	connect(Table, SIGNAL(cellChanged(int, int)), this, SLOT(changeName(int, int)));
-	connect(Table, SIGNAL(cellClicked(int, int)), this, SLOT(setActiveLayer(int, int)));
+	connect(Table, SIGNAL(cellChanged(int,int)), this, SLOT(changeName(int,int)));
+	connect(Table, SIGNAL(cellClicked(int,int)), this, SLOT(setActiveLayer(int,int)));
 	connect(opacitySpinBox, SIGNAL(valueChanged(double)), this, SLOT(changeOpacity()));
 	connect(blendMode, SIGNAL(activated(int)), this, SLOT(changeBlendMode(int)));
 }
@@ -338,11 +342,11 @@ void LayerPalette::removeLayer()
 {
 	if (!m_Doc)
 		return;
-	int layerCount=m_Doc->layerCount();
+	int layerCount = m_Doc->layerCount();
 	if (layerCount < 2)
 		return;
 	int level = layerCount-1-Table->currentRow();
-	int layerID=m_Doc->layerIDFromLevel(level);
+	int layerID = m_Doc->layerIDFromLevel(level);
 	bool delToo = false;
 	if (m_Doc->layerContainsItems(layerID))
 	{
@@ -368,7 +372,7 @@ void LayerPalette::upLayer()
 {
 	if (!m_Doc)
 		return;
-	int layerCount=m_Doc->layerCount();
+	int layerCount = m_Doc->layerCount();
 	if ((layerCount < 2) || (Table->currentRow() == 0))
 		return;
 	int layerLevel = layerCount-1-Table->currentRow();
@@ -384,7 +388,7 @@ void LayerPalette::downLayer()
 {
 	if (!m_Doc)
 		return;
-	int layerCount=m_Doc->layerCount();
+	int layerCount = m_Doc->layerCount();
 	if ((layerCount < 2) || (Table->currentRow() == static_cast<int>(layerCount) - 1))
 		return;
 	int layerLevel = layerCount-1-Table->currentRow();
@@ -403,8 +407,8 @@ void LayerPalette::changeName(int row, int col)
 	if (col == 7)
 	{
 		int layerLevel = m_Doc->layerCount()-1-row;
-		int layerID=m_Doc->layerIDFromLevel(layerLevel);
-		if (layerID!=-1)
+		int layerID = m_Doc->layerIDFromLevel(layerLevel);
+		if (layerID != -1)
 			m_Doc->changeLayerName(layerID, Table->item(row, col)->text());
 	}
 	m_Doc->scMW()->changeLayer(m_Doc->activeLayer());
@@ -414,14 +418,17 @@ void LayerPalette::visibleLayer()
 {
 	if (!m_Doc)
 		return;
-	int level = QString(sender()->objectName()).toInt();
-	int layerID=m_Doc->layerIDFromLevel(level);
-	if (layerID==-1)
+	int level = sender()->objectName().toInt();
+	int layerID = m_Doc->layerIDFromLevel(level);
+	if (layerID == -1)
 		return;
-	const QObject* senderBox=sender();
+	const QObject* senderBox = sender();
 	if (strcmp(senderBox->metaObject()->className(), "QCheckBox") == 0)
 	{
-		m_Doc->setLayerVisible(layerID,((QCheckBox*)(senderBox))->isChecked());
+		bool isLayerVisible = ((QCheckBox*)(senderBox))->isChecked();
+		m_Doc->setLayerVisible(layerID, isLayerVisible);
+		if (!isLayerVisible)
+			m_Doc->m_Selection->removeItemsOfLayer(layerID);
 		setActiveLayer(Table->currentRow(), -1);
 		emit LayerChanged();
 	}
@@ -431,14 +438,14 @@ void LayerPalette::printLayer()
 {
 	if (!m_Doc)
 		return;
-	int level = QString(sender()->objectName()).toInt();
-	int layerID=m_Doc->layerIDFromLevel(level);
-	if (layerID==-1)
+	int level = sender()->objectName().toInt();
+	int layerID = m_Doc->layerIDFromLevel(level);
+	if (layerID == -1)
 		return;
-	const QObject* senderBox=sender();
+	const QObject* senderBox = sender();
 	if (strcmp(senderBox->metaObject()->className(), "QCheckBox") == 0)
 	{
-		m_Doc->setLayerPrintable(layerID,((QCheckBox*)(senderBox))->isChecked());
+		m_Doc->setLayerPrintable(layerID, ((QCheckBox*)(senderBox))->isChecked());
 		setActiveLayer(Table->currentRow(), -1);
 		emit LayerChanged();
 	}
@@ -448,15 +455,18 @@ void LayerPalette::lockLayer()
 {
 	if (!m_Doc)
 		return;
-	int level = QString(sender()->objectName()).toInt();
-	int layerID=m_Doc->layerIDFromLevel(level);
-	if (layerID==-1)
+	int level = sender()->objectName().toInt();
+	int layerID = m_Doc->layerIDFromLevel(level);
+	if (layerID == -1)
 		return;
-	const QObject* senderBox=sender();
+	const QObject* senderBox = sender();
 	if (strcmp(senderBox->metaObject()->className(), "QCheckBox") == 0)
 	{
-		m_Doc->setLayerLocked(layerID,((QCheckBox*)(senderBox))->isChecked());
-		deleteLayerButton->setEnabled(!((QCheckBox*)(senderBox))->isChecked());
+		bool isLayerLocked = ((QCheckBox*)(senderBox))->isChecked();
+		m_Doc->setLayerLocked(layerID, isLayerLocked);
+		if (isLayerLocked)
+			m_Doc->m_Selection->removeItemsOfLayer(layerID);
+		deleteLayerButton->setEnabled(!isLayerLocked);
 		setActiveLayer(Table->currentRow(), -1);
 	}
 	m_Doc->scMW()->changeLayer(m_Doc->activeLayer());
@@ -466,14 +476,14 @@ void LayerPalette::flowToggleLayer()
 {
 	if (!m_Doc)
 		return;
-	int level = QString(sender()->objectName()).toInt();
-	int layerID=m_Doc->layerIDFromLevel(level);
-	if (layerID==-1)
+	int level = sender()->objectName().toInt();
+	int layerID = m_Doc->layerIDFromLevel(level);
+	if (layerID == -1)
 		return;
-	const QObject* senderBox=sender();
+	const QObject* senderBox = sender();
 	if (strcmp(senderBox->metaObject()->className(), "QCheckBox") == 0)
 	{
-		m_Doc->setLayerFlow(layerID,((QCheckBox*)(senderBox))->isChecked());
+		m_Doc->setLayerFlow(layerID, ((QCheckBox*)(senderBox))->isChecked());
 		emit LayerChanged();
 		setActiveLayer(Table->currentRow(), -1);
 	}
@@ -483,14 +493,14 @@ void LayerPalette::outlineToggleLayer()
 {
 	if (!m_Doc)
 		return;
-	int level = QString(sender()->objectName()).toInt();
-	int layerID=m_Doc->layerIDFromLevel(level);
-	if (layerID==-1)
+	int level = sender()->objectName().toInt();
+	int layerID = m_Doc->layerIDFromLevel(level);
+	if (layerID == -1)
 		return;
-	const QObject* senderBox=sender();
+	const QObject* senderBox = sender();
 	if (strcmp(senderBox->metaObject()->className(), "QCheckBox") == 0)
 	{
-		m_Doc->setLayerOutline(layerID,((QCheckBox*)(senderBox))->isChecked());
+		m_Doc->setLayerOutline(layerID, ((QCheckBox*)(senderBox))->isChecked());
 		emit LayerChanged();
 		setActiveLayer(Table->currentRow(), -1);
 	}
@@ -500,14 +510,15 @@ void LayerPalette::selectToggleLayer()
 {
 	if (!m_Doc)
 		return;
-	int level = QString(sender()->objectName()).toInt();
-	int layerID=m_Doc->layerIDFromLevel(level);
-	if (layerID==-1)
+	int level = sender()->objectName().toInt();
+	int layerID = m_Doc->layerIDFromLevel(level);
+	if (layerID == -1)
 		return;
-	const QObject* senderBox=sender();
+	const QObject* senderBox = sender();
 	if (strcmp(senderBox->metaObject()->className(), "QCheckBox") == 0)
 	{
-		m_Doc->setLayerSelectable(layerID,((QCheckBox*)(senderBox))->isChecked());
+		bool isLayerSelectable = ((QCheckBox*)(senderBox))->isChecked();
+		m_Doc->setLayerSelectable(layerID, isLayerSelectable);
 		emit LayerChanged();
 		setActiveLayer(Table->currentRow(), -1);
 	}
@@ -517,34 +528,34 @@ void LayerPalette::toggleAllfromHeader(int index)
 {
 	if (!m_Doc)
 		return;
-	ScLayers::iterator it;
+
 	int layerCount = m_Doc->layerCount();
-	for (it = layers->begin(); it != layers->end(); ++it)
+	for (auto it = layers->begin(); it != layers->end(); ++it)
 	{
 		int row = layerCount - m_Doc->layerLevelFromID(it->ID) - 1;
 		if (index == 1)
 		{
-			((QCheckBox*)(Table->cellWidget(row, 1)))->toggle();
+			(dynamic_cast<QCheckBox*>(Table->cellWidget(row, 1)))->toggle();
 			it->isViewable = ((QCheckBox*)(Table->cellWidget(row, 1)))->isChecked();
 		}
 		if (index == 2)
 		{
-			((QCheckBox*)(Table->cellWidget(row, 2)))->toggle();
+			(dynamic_cast<QCheckBox*>(Table->cellWidget(row, 2)))->toggle();
 			it->isPrintable = ((QCheckBox*)(Table->cellWidget(row, 2)))->isChecked();
 		}
 		if (index == 3)
 		{
-			((QCheckBox*)(Table->cellWidget(row, 3)))->toggle();
+			(dynamic_cast<QCheckBox*>(Table->cellWidget(row, 3)))->toggle();
 			it->isEditable = !((QCheckBox*)(Table->cellWidget(row, 3)))->isChecked();
 		}
 		if (index == 4)
 		{
-			((QCheckBox*)(Table->cellWidget(row, 4)))->toggle();
+			(dynamic_cast<QCheckBox*>(Table->cellWidget(row, 4)))->toggle();
 			it->flowControl = ((QCheckBox*)(Table->cellWidget(row, 4)))->isChecked();
 		}
 		else if (index == 5)
 		{
-			((QCheckBox*)(Table->cellWidget(row, 5)))->toggle();
+			(dynamic_cast<QCheckBox*>(Table->cellWidget(row, 5)))->toggle();
 			it->outlineMode = ((QCheckBox*)(Table->cellWidget(row, 5)))->isChecked();
 		}
 	}
@@ -555,15 +566,14 @@ void LayerPalette::markLayer()
 {
 	if (!m_Doc)
 		return;
-	int level = QString(sender()->objectName()).toInt();
-	int layerID=m_Doc->layerIDFromLevel(level);
-	if (layerID==-1)
+	int level = sender()->objectName().toInt();
+	int layerID = m_Doc->layerIDFromLevel(level);
+	if (layerID == -1)
 		return;
-	const QObject* senderBox=sender();
+	const QObject* senderBox = sender();
 	if (strcmp(senderBox->metaObject()->className(), "QToolButton") == 0)
 	{
-		QColor neu = QColor();
-		neu = QColorDialog::getColor(m_Doc->layerMarker(layerID), this);
+		QColor neu(QColorDialog::getColor(m_Doc->layerMarker(layerID), this));
 		if (neu.isValid())
 		{
 			QPixmap pm(20,15);
@@ -600,19 +610,19 @@ void LayerPalette::markActiveLayer(int layerID)
 		return;
 	disconnect(blendMode, SIGNAL(activated(int)), this, SLOT(changeBlendMode(int)));
 	disconnect(opacitySpinBox, SIGNAL(valueChanged(double)), this, SLOT(changeOpacity()));
-	disconnect(Table, SIGNAL(cellClicked(int, int)), this, SLOT(setActiveLayer(int, int)));
-	int layerToMark=layerID;
-	if (layerID==-1)
-		layerToMark=m_Doc->activeLayer();
+	disconnect(Table, SIGNAL(cellClicked(int,int)), this, SLOT(setActiveLayer(int,int)));
+	int layerToMark = layerID;
+	if (layerID == -1)
+		layerToMark = m_Doc->activeLayer();
 	Table->setCurrentCell(m_Doc->layerCount()-1-m_Doc->layerLevelFromID(layerToMark), 6);
 	opacitySpinBox->setValue(qRound(m_Doc->layerTransparency(layerToMark) * 100));
 	blendMode->setCurrentIndex(m_Doc->layerBlendMode(layerToMark));
-	deleteLayerButton->setEnabled(m_Doc->layerCount()>1 && !m_Doc->layerLocked( m_Doc->activeLayer() ));
+	deleteLayerButton->setEnabled(m_Doc->layerCount() > 1 && !m_Doc->layerLocked( m_Doc->activeLayer() ));
 		
-	if (layers->count()>1)
+	if (layers->count() > 1)
 	{
-		raiseLayerButton->setEnabled(Table->currentRow()!=0);
-		lowerLayerButton->setEnabled(Table->currentRow()!=Table->rowCount()-1);
+		raiseLayerButton->setEnabled(Table->currentRow() != 0);
+		lowerLayerButton->setEnabled(Table->currentRow() != Table->rowCount() - 1);
 	}
 	else
 	{
@@ -635,15 +645,15 @@ void LayerPalette::setActiveLayer(int row, int col)
 	}
 	disconnect(blendMode, SIGNAL(activated(int)), this, SLOT(changeBlendMode(int)));
 	disconnect(opacitySpinBox, SIGNAL(valueChanged(double)), this, SLOT(changeOpacity()));
-	int layerID=m_Doc->layerIDFromLevel(m_Doc->layerCount()-1-row);
+	int layerID = m_Doc->layerIDFromLevel(m_Doc->layerCount()-1-row);
 	bool found=m_Doc->setActiveLayer(layerID);
 	if (found)
 	{
 		m_Doc->scMW()->changeLayer(m_Doc->activeLayer());
 		opacitySpinBox->setValue(qRound(m_Doc->layerTransparency(m_Doc->activeLayer()) * 100));
 		blendMode->setCurrentIndex(m_Doc->layerBlendMode(m_Doc->activeLayer()));
-		deleteLayerButton->setEnabled(m_Doc->layerCount()>1 && !m_Doc->layerLocked( m_Doc->activeLayer() ));
-		if (layers->count()>1)
+		deleteLayerButton->setEnabled(m_Doc->layerCount() > 1 && !m_Doc->layerLocked( m_Doc->activeLayer() ));
+		if (layers->count() > 1)
 		{
 			raiseLayerButton->setEnabled(Table->currentRow()!= 0);
 			lowerLayerButton->setEnabled(Table->currentRow()!= Table->rowCount()-1);
@@ -666,14 +676,31 @@ void LayerPalette::changeEvent(QEvent *e)
 		ScDockPalette::changeEvent(e);
 }
 
+void LayerPalette::iconSetChange()
+{
+	IconManager& iconManager = IconManager::instance();
+
+	Table->horizontalHeaderItem(1)->setIcon(iconManager.loadIcon("16/show-object.png"));
+	Table->horizontalHeaderItem(2)->setIcon(iconManager.loadIcon("16/document-print.png"));
+	Table->horizontalHeaderItem(3)->setIcon(iconManager.loadIcon("16/lock.png"));
+	Table->horizontalHeaderItem(4)->setIcon(iconManager.loadIcon("16/layer-flow-around.png"));
+	Table->horizontalHeaderItem(5)->setIcon(iconManager.loadIcon("layer-outline.png"));
+	Table->horizontalHeaderItem(6)->setIcon(iconManager.loadIcon("16/pointer.png"));
+
+	newLayerButton->setIcon(iconManager.loadIcon("16/list-add.png"));
+	deleteLayerButton->setIcon(iconManager.loadIcon("16/list-remove.png"));
+	duplicateLayerButton->setIcon(iconManager.loadIcon("16/edit-copy.png"));
+	raiseLayerButton->setIcon(iconManager.loadIcon("16/go-up.png"));
+	lowerLayerButton->setIcon(iconManager.loadIcon("16/go-down.png"));
+}
+
 void LayerPalette::languageChange()
 {
 	setWindowTitle( tr( "Layers" ) );
 	textLabel1->setText( tr( "Blend Mode:" ) );
 
 	int  oldBlendMode = blendMode->currentIndex();
-	bool blendModeBlocked = blendMode->blockSignals(true);
-
+	QSignalBlocker signalBlocker(blendMode);
 	blendMode->clear();
 	blendMode->addItem( tr("Normal"));
 	blendMode->addItem( tr("Darken"));
@@ -693,7 +720,6 @@ void LayerPalette::languageChange()
 	blendMode->addItem( tr("Luminosity"));
 
 	blendMode->setCurrentIndex(oldBlendMode);
-	blendMode->blockSignals(blendModeBlocked);
 
 	textLabel2->setText( tr( "Opacity:" ) );
 	opacitySpinBox->setSuffix( tr(" %"));
