@@ -9,20 +9,24 @@ for which a new license (GPL+exception) is in place.
 
 #include "ui_multipleduplicate.h"
 struct ItemMultipleDuplicateData;
+class ScribusDoc;
 
 class MultipleDuplicate : public QDialog, Ui::MultipleDuplicate
 {
 	Q_OBJECT
 	public:
-		MultipleDuplicate(int unitIndex, QWidget* parent);
+		MultipleDuplicate(QWidget* parent, ScribusDoc *doc);
 		~MultipleDuplicate();
 		void getMultiplyData(ItemMultipleDuplicateData&);
 	protected:
-		int m_unitIndex;
+		// int m_unitIndex;
+		ScribusDoc *m_Doc;
 		double m_unitRatio;
 	protected slots:
 		void setCopiesShift();
 		void setCopiesGap();
+		void selectRangeOfPages();
+		void createPageNumberRange();
 };
 
 #endif
