@@ -10,6 +10,7 @@ for which a new license (GPL+exception) is in place.
 #include "nodeeditpalette.h"
 #include "pageitem.h"
 #include "scpage.h"
+#include "scribusapp.h"
 #include "scribusdoc.h"
 #include "scribusview.h" 
 #include "selection.h"
@@ -18,12 +19,12 @@ for which a new license (GPL+exception) is in place.
 #include "units.h"
 #include "iconmanager.h"
 
-NodePalette::NodePalette( QWidget* parent) : ScrPaletteBase( parent, "nodePalette", false, nullptr)
+NodePalette::NodePalette( QWidget* parent) : ScrPaletteBase(parent, "nodePalette", false, Qt::WindowFlags())
 {
 	IconManager& im = IconManager::instance();
 	QSize iconSize = QSize(22, 22);
-	m_doc=nullptr;
-	unitRatio=1.0;
+	m_doc = nullptr;
+	unitRatio = 1.0;
 	vboxLayout = new QVBoxLayout(this);
 	vboxLayout->setSpacing(2);
 	vboxLayout->setMargin(5);
@@ -305,6 +306,8 @@ NodePalette::NodePalette( QWidget* parent) : ScrPaletteBase( parent, "nodePalett
 	resize(QSize(170, 380).expandedTo(minimumSizeHint()));
 
 	languageChange();
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 }
 
 void NodePalette::connectSignals()
@@ -625,7 +628,7 @@ void NodePalette::MovePoint()
 			np -= zp;
 		}
 		m_doc->nodeEdit.moveClipPoint(currItem, np);
-		m_doc->adjustItemSize(currItem, true, true);
+		m_doc->adjustItemSize(currItem, true);
 		if (currItem->itemType() == PageItem::PathText)
 			currItem->updatePolyClip();
 		m_doc->regionsChanged()->update(QRectF());
@@ -813,7 +816,7 @@ void NodePalette::HaveNode(bool have, bool mov)
 			cc = currItem->ContourLine.size();
 		else
 			cc = currItem->PoLine.size();
-		if (currItem->asPolyLine())
+		if (currItem->isPolyLine())
 		{
 			if (cc < 5)
 				leaveEd = true;
@@ -968,9 +971,20 @@ void NodePalette::CancelEdit()
 		EditCont->setChecked(false);
 		ToggleConMode();
 		PageItem *currItem = m_doc->m_Selection->itemAt(0);
-		currItem->setXYPos(xPos, yPos, true);
-		currItem->ContourLine = itemContourPath.copy();
+
+		// Calculate the difference of the current position and the original
+		// position in the item's coordinate space (which is rotated and translated,
+		// but the translation does not matter for the delta)
+		QTransform m = QTransform().rotate(-currItem->rotation());
+		QPointF delta = m.map(QPointF(xPos, yPos)) - m.map(QPointF(currItem->xPos(), currItem->yPos()));
+		// During operation the image offsets and possibly other values are changed.
+		// To not remember everything we move the clip path to the original position
+		// relative to the current position (in the item's coordinate space).
+		// adjustItemSize will then take care of moving the position and changing
+		// image offsets, etc.
 		currItem->PoLine = itemPath.copy();
+		currItem->PoLine.translate(delta.x(), delta.y());
+		currItem->ContourLine = itemContourPath.copy();
 		m_doc->adjustItemSize(currItem);
 		if (currItem->itemType() == PageItem::PathText)
 			currItem->updatePolyClip();
@@ -994,12 +1008,21 @@ void NodePalette::ResetToEditDefaults()
 	m_doc->nodeEdit.selNode().clear();
 	m_doc->nodeEdit.setPreviewMode(false);
 	PageItem *currItem = m_doc->m_Selection->itemAt(0);
+
+	// See comment in NodePalette::CancelEdit
+	QTransform m = QTransform().rotate(-currItem->rotation());
+	QPointF delta = m.map(QPointF(xPos, yPos)) - m.map(QPointF(currItem->xPos(), currItem->yPos()));
 	if (EditCont->isChecked())
+	{
 		currItem->ContourLine = itemContourPath.copy();
+		currItem->ContourLine.translate(delta.x(), delta.y());
+	}
 	else
 	{
-		currItem->setXYPos(xPos, yPos, true);
-		currItem->PoLine = itemPath.copy();
+		// See comment in NodePalette::CancelEdit
+		currItem->PoLine = itemPath;
+ 		currItem->PoLine.translate(delta.x(), delta.y());
+ 		currItem->ContourLine = itemContourPath;
 		m_doc->adjustItemSize(currItem);
 	}
 	if (currItem->itemType() == PageItem::PathText)
@@ -1032,6 +1055,78 @@ void NodePalette::setDefaults(PageItem* currItem)
 	itemContourPath = currItem->ContourLine.copy();
 }
 
+void NodePalette::iconSetChange()
+{
+	IconManager& im = IconManager::instance();
+	QSize iconSize = QSize(22, 22);
+
+	MoveNode->setIcon(im.loadIcon("MoveNode.png"));
+	MoveNode->setIconSize(iconSize);
+
+	AddNode->setIcon(im.loadIcon("AddNode.png"));
+	AddNode->setIconSize(iconSize);
+
+	DeleteNode->setIcon(im.loadIcon("DeleteNode.png"));
+	DeleteNode->setIconSize(iconSize);
+
+	ResNode->setIcon(im.loadIcon("ResetNode.png"));
+	ResNode->setIconSize(iconSize);
+
+	MoveControl->setIcon(im.loadIcon("MoveKontrol.png"));
+	MoveControl->setIconSize(iconSize);
+
+	AsymMove->setIcon(im.loadIcon("MoveAsym.png"));
+	AsymMove->setIconSize(iconSize);
+
+	SymMove->setIcon(im.loadIcon("MoveSym.png"));
+	SymMove->setIconSize(iconSize);
+
+	Res1Node->setIcon(im.loadIcon("Reset1Node.png"));
+	Res1Node->setIconSize(iconSize);
+
+	PolySplit->setIcon(im.loadIcon("PolyCut.png"));
+	PolySplit->setIconSize(iconSize);
+
+	BezierClose->setIcon(im.loadIcon("BezierClose.png"));
+	BezierClose->setIconSize(iconSize);
+
+	PolyMirrorH->setIcon(im.loadIcon("hmirror.png"));
+	PolyMirrorH->setIconSize(iconSize);
+
+	PolyMirrorV->setIcon(im.loadIcon("vmirror.png"));
+	PolyMirrorV->setIconSize(iconSize);
+
+	PolyShearL->setIcon(im.loadIcon("22/transform-shear-left.png"));
+	PolyShearL->setIconSize(iconSize);
+
+	PolyShearR->setIcon(im.loadIcon("22/transform-shear-right.png"));
+	PolyShearR->setIconSize(iconSize);
+
+	PolyShearU->setIcon(im.loadIcon("22/transform-shear-up.png"));
+	PolyShearU->setIconSize(iconSize);
+
+	PolyShearD->setIcon(im.loadIcon("22/transform-shear-down.png"));
+	PolyShearD->setIconSize(iconSize);
+
+	RotateCCW->setIcon(im.loadIcon("rotate_ccw.png"));
+	RotateCCW->setIconSize(iconSize);
+
+	RotateCW->setIcon(im.loadIcon("rotate_cw.png"));
+	RotateCW->setIconSize(iconSize);
+
+	Expand->setIcon(im.loadIcon("expand.png"));
+	Expand->setIconSize(iconSize);
+
+	Shrink->setIcon(im.loadIcon("crop.png"));
+	Shrink->setIconSize(iconSize);
+
+	Enlarge->setIcon(im.loadIcon("expand.png"));
+	Enlarge->setIconSize(iconSize);
+
+	Reduce->setIcon(im.loadIcon("crop.png"));
+	Reduce->setIconSize(iconSize);
+}
+
 void NodePalette::languageChange()
 {
 	setWindowTitle( tr( "Nodes" ) );
