@@ -27,6 +27,7 @@ for which a new license (GPL+exception) is in place.
 #include "appmodes.h"
 #include "canvasmode.h"
 #include "commonstrings.h"
+#include "contentpalette.h"
 #include "contextmenu.h"
 #include "iconmanager.h"
 #include "layers.h"
@@ -34,17 +35,16 @@ for which a new license (GPL+exception) is in place.
 #include "propertiespalette.h"
 #include "scpage.h"
 #include "scribus.h"
+#include "scribusapp.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
-#include "textpalette.h"
 #include "undomanager.h"
 #include "units.h"
 #include "util.h"
 #include "util_color.h"
 #include "util_formats.h"
 
-
 OutlineTreeItem::OutlineTreeItem(OutlineTreeItem* parent, OutlineTreeItem* after) : QTreeWidgetItem(parent, after)
 {
 	PageObject = nullptr;
@@ -317,7 +317,7 @@ bool OutlineWidget::viewportEvent(QEvent *event)
 	if (!item)
 		return QTreeWidget::viewportEvent(event);
 
- 	QString tipText("");
+	QString tipText;
 	if (item->type == 5)
 	{
 		tipText += "<b>" + tr("Layer is:") + "</b><br><br>";
@@ -335,7 +335,7 @@ bool OutlineWidget::viewportEvent(QEvent *event)
 			tipText += "<br>" + tr("locked");
 	}
 	else if ((item->type == 1) || (item->type == 3) || (item->type == 4))
- 	{
+	{
 		PageItem *pgItem = item->PageItemObject;
 		QPainter p;
 		QImage pm = QImage(80, 80, QImage::Format_ARGB32_Premultiplied);
@@ -351,80 +351,80 @@ bool OutlineWidget::viewportEvent(QEvent *event)
 		QByteArray ba = buffer.buffer().toBase64();
 		buffer.close();
 		tipText = "<p align=\"center\"><img src=\"data:image/png;base64," + QString(ba) + "\"></p><p>";
- 		switch (pgItem->itemType())
- 		{
- 			case PageItem::ImageFrame:
- 				if (pgItem->asLatexFrame())
+		switch (pgItem->itemType())
+		{
+			case PageItem::ImageFrame:
+				if (pgItem->isLatexFrame())
 					tipText += CommonStrings::itemType_LatexFrame;
- 				else if (pgItem->asOSGFrame())
+				else if (pgItem->isOSGFrame())
 					tipText += CommonStrings::itemType_OSGFrame;
- 				else
+				else
 					tipText += CommonStrings::itemType_ImageFrame;
- 				break;
- 			case PageItem::TextFrame:
- 				switch (pgItem->annotation().Type())
- 				{
+				break;
+			case PageItem::TextFrame:
+				switch (pgItem->annotation().Type())
+				{
 					case Annotation::Button:
 						tipText += CommonStrings::itemSubType_PDF_PushButton;
- 						break;
+						break;
 					case Annotation::Textfield:
 						tipText += CommonStrings::itemSubType_PDF_TextField;
- 						break;
+						break;
 					case Annotation::Checkbox:
 						tipText += CommonStrings::itemSubType_PDF_CheckBox;
- 						break;
+						break;
 					case Annotation::Combobox:
 						tipText += CommonStrings::itemSubType_PDF_ComboBox;
- 						break;
+						break;
 					case Annotation::Listbox:
 						tipText += CommonStrings::itemSubType_PDF_ListBox;
- 						break;
+						break;
 					case Annotation::Text:
 						tipText += CommonStrings::itemSubType_PDF_TextAnnotation;
- 						break;
+						break;
 					case Annotation::Link:
 						tipText += CommonStrings::itemSubType_PDF_LinkAnnotation;
 						break;
 					case Annotation::RadioButton:
 						tipText += CommonStrings::itemSubType_PDF_RadioButton;
- 						break;
- 					default:
+						break;
+					default:
 						tipText += CommonStrings::itemType_TextFrame;
- 						break;
- 				}
- 				break;
- 			case PageItem::Line:
+						break;
+				}
+				break;
+			case PageItem::Line:
 				tipText += CommonStrings::itemType_Line;
- 				break;
- 			case PageItem::Arc:
+				break;
+			case PageItem::Arc:
 				tipText += CommonStrings::itemType_Arc;
 				break;
- 			case PageItem::Polygon:
+			case PageItem::Polygon:
 				tipText += CommonStrings::itemType_Polygon;
 				break;
 			case PageItem::RegularPolygon:
 				tipText += CommonStrings::itemType_RegularPolygon;
- 				break;
- 			case PageItem::PolyLine:
+				break;
+			case PageItem::PolyLine:
 				tipText += CommonStrings::itemType_Polyline;
 				break;
 			case PageItem::Spiral:
 				tipText += CommonStrings::itemType_Spiral;
- 				break;
- 			case PageItem::PathText:
+				break;
+			case PageItem::PathText:
 				tipText += CommonStrings::itemType_PathText;
- 				break;
- 			case PageItem::Symbol:
+				break;
+			case PageItem::Symbol:
 				tipText += CommonStrings::itemType_Symbol;
- 				break;
+				break;
 			case PageItem::Group:
 				tipText += CommonStrings::itemType_Group;
 				break;
 			case PageItem::Table:
 				tipText += CommonStrings::itemType_Table;
 				break;
- 			default:
- 				break;
+			default:
+				break;
 		}
 		tipText +="<br>" + tr("X-Pos:") + " ";
 		if (pgItem->OwnPage != -1)
@@ -442,7 +442,7 @@ bool OutlineWidget::viewportEvent(QEvent *event)
 	return true;
 }
 
-OutlinePalette::OutlinePalette( QWidget* parent) : ScDockPalette( parent, "Tree", nullptr)
+OutlinePalette::OutlinePalette( QWidget* parent) : ScDockPalette(parent, "Tree", Qt::WindowFlags())
 {
 //	resize( 220, 240 );
 	setMinimumSize( QSize( 220, 240 ) );
@@ -478,33 +478,19 @@ OutlinePalette::OutlinePalette( QWidget* parent) : ScDockPalette( parent, "Tree"
 	setWidget( containerWidget );
 
 	unsetDoc();
-	IconManager& im = IconManager::instance();
-	imageIcon = im.loadPixmap("22/insert-image.png");
-	latexIcon = im.loadPixmap("22/insert-latex.png");
-	lineIcon = im.loadPixmap("stift.png");
-	textIcon = im.loadPixmap("22/insert-text-frame.png");
-	polylineIcon = im.loadPixmap("22/draw-path.png");
-	polygonIcon = im.loadPixmap("22/draw-polygon.png");
-	arcIcon = im.loadPixmap("22/draw-arc.png");
-	spiralIcon = im.loadPixmap("22/draw-spiral.png");
-	tableIcon = im.loadPixmap("22/insert-table.png");
-	groupIcon = im.loadPixmap("u_group.png");
-	buttonIcon = im.loadPixmap("22/insert-button.png");
-	radiobuttonIcon = im.loadPixmap("22/radiobutton.png");
-	textFieldIcon = im.loadPixmap("22/text-field.png");
-	checkBoxIcon = im.loadPixmap("22/checkbox.png");
-	comboBoxIcon = im.loadPixmap("22/combobox.png");
-	listBoxIcon = im.loadPixmap("22/list-box.png");
-	annotTextIcon = im.loadPixmap("22/pdf-annotations.png");
-	annotLinkIcon = im.loadPixmap("goto.png");
-	annot3DIcon = im.loadPixmap("22/annot3d.png");
+
 	selectionTriggered = false;
 	m_MainWindow  = nullptr;
 	freeObjects   = nullptr;
 	rootObject    = nullptr;
 	currentObject = nullptr;
+
+	iconSetChange();
 	languageChange();
+
 	// signals and slots connections
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+
 	connect(reportDisplay, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(slotRightClick(QPoint)));
 	connect(reportDisplay, SIGNAL(itemSelectionChanged()), this, SLOT(slotMultiSelect()));
 	connect(reportDisplay, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SLOT(slotDoRename(QTreeWidgetItem*, int)));
@@ -624,7 +610,10 @@ void OutlinePalette::setActiveLayer(int layerID)
 
 void OutlinePalette::setLayerVisible(int layerID)
 {
-	currDoc->setLayerVisible(layerID, !currDoc->layerVisible(layerID));
+	bool isLayerVisible = !currDoc->layerVisible(layerID);
+	currDoc->setLayerVisible(layerID, isLayerVisible);
+	if (!isLayerVisible)
+		currDoc->m_Selection->removeItemsOfLayer(layerID);
 	currDoc->scMW()->showLayer();
 	currDoc->scMW()->layerPalette->rebuildList();
 	currDoc->scMW()->layerPalette->markActiveLayer();
@@ -632,7 +621,10 @@ void OutlinePalette::setLayerVisible(int layerID)
 
 void OutlinePalette::setLayerLocked(int layerID)
 {
-	currDoc->setLayerLocked(layerID, !currDoc->layerLocked(layerID));
+	bool isLayerLocked = !currDoc->layerLocked(layerID);
+	currDoc->setLayerLocked(layerID, isLayerLocked);
+	if (isLayerLocked)
+		currDoc->m_Selection->removeItemsOfLayer(layerID);
 	currDoc->scMW()->layerPalette->rebuildList();
 	currDoc->scMW()->layerPalette->markActiveLayer();
 }
@@ -698,7 +690,7 @@ void OutlinePalette::slotDoRename(QTreeWidgetItem *ite , int col)
 					{
 						item->PageItemObject->setItemName(NameNew);
 						m_MainWindow->propertiesPalette->setCurrentItem(item->PageItemObject);
-						m_MainWindow->textPalette->setCurrentItem(item->PageItemObject);
+						m_MainWindow->contentPalette->setCurrentItem(item->PageItemObject);
 						currDoc->setModified(true);
 					}
 				}
@@ -709,78 +701,68 @@ void OutlinePalette::slotDoRename(QTreeWidgetItem *ite , int col)
 	connect(reportDisplay, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SLOT(slotDoRename(QTreeWidgetItem*, int)));
 }
 
-QTreeWidgetItem* OutlinePalette::getListItem(int SNr, PageItem *Nr)
+QTreeWidgetItem* OutlinePalette::getListItem(int pageNr, PageItem *pageItem)
 {
 	OutlineTreeItem *item = nullptr;
 	QTreeWidgetItem *retVal = nullptr;
 	if (currDoc->masterPageMode())
 	{
-		if (Nr == nullptr)
+		if (pageItem == nullptr)
 		{
-			QTreeWidgetItemIterator it( reportDisplay );
-			while ( (*it) )
+			for (QTreeWidgetItemIterator it(reportDisplay); *it; ++it)
 			{
 				item = dynamic_cast<OutlineTreeItem*>(*it);
-				if ((item->type == 0) && (item->PageObject->pageNr() == SNr))
+				if (item && (item->type == 0) && (item->PageObject->pageNr() == pageNr))
 				{
 					retVal = (*it);
 					break;
 				}
-				++it;
 			}
 		}
 		else
 		{
-			QTreeWidgetItemIterator it( reportDisplay );
-			while ( (*it) )
+			for (QTreeWidgetItemIterator it(reportDisplay); *it; ++it)
 			{
 				item = dynamic_cast<OutlineTreeItem*>(*it);
-				if ((item->type == 1) && (item->PageItemObject == Nr))
+				if (item && (item->type == 1) && (item->PageItemObject == pageItem))
 				{
 					retVal = (*it);
 					break;
 				}
-				++it;
 			}
 		}
 	}
 	else
 	{
-		if (Nr == nullptr)
+		if (pageItem == nullptr)
 		{
-			QTreeWidgetItemIterator it( reportDisplay );
-			while ( (*it) )
+			for (QTreeWidgetItemIterator it(reportDisplay); *it; ++it)
 			{
 				item = dynamic_cast<OutlineTreeItem*>(*it);
-				if (!item)
-					qFatal("OutlinePalette::getListItem !item");
-				if ((item->type == 2) && (item->PageObject->pageNr() == SNr))
+				if (item && (item->type == 2) && (item->PageObject->pageNr() == pageNr))
 				{
 					retVal = (*it);
 					break;
 				}
-				++it;
 			}
 		}
 		else
 		{
-			QTreeWidgetItemIterator it( reportDisplay );
-			while ( (*it) )
+			for (QTreeWidgetItemIterator it(reportDisplay); *it; ++it)
 			{
 				item = dynamic_cast<OutlineTreeItem*>(*it);
-				if (((item->type == 3) || (item->type == 4)) && (item->PageItemObject == Nr))
+				if (item && ((item->type == 3) || (item->type == 4)) && (item->PageItemObject == pageItem))
 				{
 					retVal = (*it);
 					break;
 				}
-				++it;
 			}
 		}
 	}
 	return retVal;
 }
 
-void OutlinePalette::slotShowSelect(int SNr, PageItem *Nr)
+void OutlinePalette::slotShowSelect(int pageNr, PageItem *pageItem)
 {
 	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
@@ -807,7 +789,7 @@ void OutlinePalette::slotShowSelect(int SNr, PageItem *Nr)
 	}
 	else
 	{
-		QTreeWidgetItem *retVal = getListItem(SNr, Nr);
+		QTreeWidgetItem *retVal = getListItem(pageNr, pageItem);
 		if (retVal != nullptr && !retVal->isHidden())
 			retVal->setSelected(true);
 	}
@@ -822,9 +804,9 @@ void OutlinePalette::setItemIcon(QTreeWidgetItem *item, PageItem *pgItem)
 	switch (pgItem->itemType())
 	{
 	case PageItem::ImageFrame:
- 		if (pgItem->asLatexFrame())
+		if (pgItem->isLatexFrame())
 			item->setIcon( 0, latexIcon );
-		else if (pgItem->asOSGFrame())
+		else if (pgItem->isOSGFrame())
 			item->setIcon( 0, annot3DIcon );
  		else
 			item->setIcon( 0, imageIcon );
@@ -966,7 +948,7 @@ void OutlinePalette::slotMultiSelect()
 		if (currDoc->appMode == modeEditClip)
 			currDoc->view()->requestMode(submodeEndNodeEdit);
 		currDoc->m_Selection->delaySignalsOn();
-		currDoc->view()->Deselect(true);
+		currDoc->view()->deselectItems(true);
 		for (int a = 0; a < items.count(); a++)
 		{
 			QTreeWidgetItem* ite = items[a];
@@ -988,7 +970,7 @@ void OutlinePalette::slotMultiSelect()
 					if (!pgItem->isSelected())
 					{
 						m_MainWindow->closeActiveWindowMasterPageEditor();
-						currDoc->view()->SelectItem(pgItem, false, false);
+						currDoc->view()->selectItem(pgItem, false, false);
 					}
 					break;
 				default:
@@ -1478,6 +1460,33 @@ void OutlinePalette::changeEvent(QEvent *e)
 		ScDockPalette::changeEvent(e);
 }
 
+void OutlinePalette::iconSetChange()
+{
+	IconManager& im = IconManager::instance();
+	imageIcon = im.loadPixmap("22/insert-image.png");
+	latexIcon = im.loadPixmap("22/insert-latex.png");
+	lineIcon = im.loadPixmap("stift.png");
+	textIcon = im.loadPixmap("22/insert-text-frame.png");
+	polylineIcon = im.loadPixmap("22/draw-path.png");
+	polygonIcon = im.loadPixmap("22/draw-polygon.png");
+	arcIcon = im.loadPixmap("22/draw-arc.png");
+	spiralIcon = im.loadPixmap("22/draw-spiral.png");
+	tableIcon = im.loadPixmap("22/insert-table.png");
+	groupIcon = im.loadPixmap("u_group.png");
+	buttonIcon = im.loadPixmap("22/insert-button.png");
+	radiobuttonIcon = im.loadPixmap("22/radiobutton.png");
+	textFieldIcon = im.loadPixmap("22/text-field.png");
+	checkBoxIcon = im.loadPixmap("22/checkbox.png");
+	comboBoxIcon = im.loadPixmap("22/combobox.png");
+	listBoxIcon = im.loadPixmap("22/list-box.png");
+	annotTextIcon = im.loadPixmap("22/pdf-annotations.png");
+	annotLinkIcon = im.loadPixmap("goto.png");
+	annot3DIcon = im.loadPixmap("22/annot3d.png");
+
+	if (this->isVisible() && (currDoc != nullptr))
+		BuildTree();
+}
+
 void OutlinePalette::languageChange()
 {
 	setWindowTitle( tr("Outline"));
