@@ -33,6 +33,9 @@ Prefs_KeyboardShortcuts::Prefs_KeyboardShortcuts(QWidget* parent, ScribusDoc* do
 	setupUi(this);
 	languageChange();
 
+	m_caption = tr("Keyboard Shortcuts");
+	m_icon = "16/preferences-desktop-keyboard-shortcuts.png";
+
 	defMenus=ActionManager::defaultMenus();
 	defNonMenuActions=ActionManager::defaultNonMenuActions();
 
@@ -49,7 +52,7 @@ Prefs_KeyboardShortcuts::Prefs_KeyboardShortcuts(QWidget* parent, ScribusDoc* do
 		Q_ASSERT(plugin); // all the returned names should represent loaded plugins
 		if (plugin->inherits("ScActionPlugin"))
 		{
-			ixplug = dynamic_cast<ScActionPlugin*>(plugin);
+			ixplug = qobject_cast<ScActionPlugin*>(plugin);
 			Q_ASSERT(ixplug);
 			ScActionPlugin::ActionInfo ai(ixplug->actionInfo());
 			itnmenua->second << ai.name;
@@ -62,7 +65,7 @@ Prefs_KeyboardShortcuts::Prefs_KeyboardShortcuts(QWidget* parent, ScribusDoc* do
 	keyTable->clear();
 	keyMap.clear();
 	keyCode = 0;
-	keyDisplay->setMinimumWidth(fontMetrics().width("CTRL+ALT+SHIFT+W"));
+	keyDisplay->setMinimumWidth(fontMetrics().horizontalAdvance("CTRL+ALT+SHIFT+W"));
 	keyDisplay->setText("");
 	selectedLVI = nullptr;
 
@@ -80,9 +83,7 @@ Prefs_KeyboardShortcuts::Prefs_KeyboardShortcuts(QWidget* parent, ScribusDoc* do
 
 }
 
-Prefs_KeyboardShortcuts::~Prefs_KeyboardShortcuts()
-{
-}
+Prefs_KeyboardShortcuts::~Prefs_KeyboardShortcuts() = default;
 
 void Prefs_KeyboardShortcuts::languageChange()
 {
@@ -157,7 +158,7 @@ void Prefs_KeyboardShortcuts::importKeySet(const QString& filename)
 		int ecol;
 		if ( !doc.setContent( ts.readAll(), &errorMsg, &eline, &ecol ))
 		{
-			qDebug("%s", QString("Could not open key set file: %1\nError:%2 at line: %3, row: %4").arg(filename).arg(errorMsg).arg(eline).arg(ecol).toLatin1().constData());
+			qDebug("%s", QString("Could not open key set file: %1\nError:%2 at line: %3, row: %4").arg(filename, errorMsg).arg(eline).arg(ecol).toLatin1().constData());
 			file1.close();
 			return;
 		}
@@ -245,16 +246,15 @@ void Prefs_KeyboardShortcuts::resetKeySet()
 QStringList Prefs_KeyboardShortcuts::scanForSets()
 {
 	keySetList.clear();
-	QString location = ScPaths::instance().shareDir();
-	QString keySetLocation = QDir::toNativeSeparators(location+"keysets/");
-	QDir keySetsDir(keySetLocation, "*.xml", QDir::Name, QDir::Files | QDir::NoSymLinks);
+	QString location(ScPaths::instance().shareDir());
+	QDir keySetsDir(QDir::toNativeSeparators(location+"keysets/"), "*.xml", QDir::Name, QDir::Files | QDir::NoSymLinks);
 	if ((!keySetsDir.exists()) || (keySetsDir.count() <= 0))
 		return QStringList();
 
 	QStringList appNames;
 	for (uint fileCounter = 0; fileCounter < keySetsDir.count(); ++fileCounter)
 	{
-		QString filename = QDir::toNativeSeparators(location+"keysets/"+keySetsDir[fileCounter]);
+		QString filename(QDir::toNativeSeparators(location+"keysets/"+keySetsDir[fileCounter]));
 
 		QDomDocument doc( "keymapentries" );
 		QFile file( filename );
@@ -266,7 +266,7 @@ QStringList Prefs_KeyboardShortcuts::scanForSets()
 
 		if (!doc.setContent( &file, &errorMsg, &eline, &ecol ))
 		{
-			qDebug("%s", QString("Could not open key set file: %1\nError:%2 at line: %3, row: %4").arg(keySetsDir[fileCounter]).arg(errorMsg).arg(eline).arg(ecol).toLatin1().constData());
+			qDebug("%s", QString("Could not open key set file: %1\nError:%2 at line: %3, row: %4").arg(keySetsDir[fileCounter], errorMsg).arg(eline).arg(ecol).toLatin1().constData());
 			file.close();
 			continue;
 		}
