@@ -9,6 +9,7 @@ for which a new license (GPL+exception) is in place.
 #include <QAbstractItemView>
 
 #include "iconmanager.h"
+#include "pageitemiterator.h"
 #include "prefsstructs.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
@@ -32,6 +33,9 @@ Prefs_PDFExport::Prefs_PDFExport(QWidget* parent, ScribusDoc* doc)
 	unitChange(0);
 	languageChange();
 
+	m_caption = tr("PDF Export");
+	m_icon = "acroread16.png";
+
 	connect(fontEmbeddingCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(EmbeddingModeChange()));
 	connect(exportChosenPagesRadioButton, SIGNAL(toggled(bool)), this, SLOT(enableRangeControls(bool)));
 	connect(exportRangeMorePushButton, SIGNAL(clicked()), this, SLOT(createPageNumberRange()));
@@ -53,7 +57,7 @@ Prefs_PDFExport::Prefs_PDFExport(QWidget* parent, ScribusDoc* doc)
 											"a range of pages or a single page number") + "</qt>" );
 	exportRangeMorePushButton->setToolTip( "<qt>" + tr( "Create a range of pages" ) + "</qt>");
 
-	pdfVersionComboBox->setToolTip( "<qt>" + tr( "Determines the PDF compatibility.<br/>The default is <b>PDF 1.3</b> which gives the widest compatibility.<br/>Choose <b>PDF 1.4</b> if your file uses features such as transparency or you require 128 bit encryption.<br/><b>PDF 1.5</b> is necessary when you wish to preserve objects in separate layers within the PDF.<br/><b>PDF/X-1a</b> is for blind exchange with colors strictly specified in CMYK or spot colors.<br/><b>PDF/X-3</b> is for exporting the PDF when you want color managed RGB for commercial printing and is selectable when you have activated color management. Use only when advised by your printer or in some cases printing to a 4 color digital color laser printer.<br/><b>PDF/X-4</b> is an extension of PDF/X-3 to support transparency and layering." ) + "</qt>");
+	pdfVersionComboBox->setToolTip( "<qt>" + tr( "Determines the PDF compatibility.<br/><b>PDF 1.3</b>, which is the earliest supported version, gives the widest compatibility with printers' RIPS.<br/><b>PDF 1.4</b>, which is the default version, supports features such as transparency and 128 bit encryption.<br/><b>PDF 1.5</b> is necessary when you wish to preserve objects in separate layers within the PDF.<br/><b>PDF/X-1a</b> is for blind exchange with colors strictly specified in CMYK or spot colors.<br/><b>PDF/X-3</b> is for exporting the PDF when you want color managed RGB for commercial printing and is selectable when you have activated color management. Use only when advised by your printer or in some cases printing to a 4 color digital color laser printer.<br/><b>PDF/X-4</b> is an extension of PDF/X-3 to support transparency and layering." ) + "</qt>");
 	pageBindingComboBox->setToolTip( "<qt>" + tr( "Determines the binding of pages in the PDF. Unless you know you need to change it leave the default choice - Left." ) + "</qt>" );
 	generateThumbnailsCheckBox->setToolTip( "<qt>" + tr( "Generates thumbnails of each page in the PDF. Some viewers can use the thumbnails for navigation." ) + "</qt>" );
 	saveLinkedTextFramesAsArticlesCheckBox->setToolTip( "<qt>" + tr( "Generate PDF Articles, which is useful for navigating linked articles in a PDF" ) + "</qt>" );
@@ -104,9 +108,7 @@ Prefs_PDFExport::Prefs_PDFExport(QWidget* parent, ScribusDoc* doc)
 
 }
 
-Prefs_PDFExport::~Prefs_PDFExport()
-{
-}
+Prefs_PDFExport::~Prefs_PDFExport() = default;
 
 PDFOptions::PDFFontEmbedding Prefs_PDFExport::fontEmbeddingMode()
 {
@@ -256,7 +258,7 @@ void Prefs_PDFExport::restoreDefaults(struct ApplicationPrefs *prefsData, const
 {
 	exportingPDF=exporting;
 	enablePDFExportTabs(exportingPDF);
-	AllFonts=prefsData->fontPrefs.AvailFonts;
+	AllFonts = prefsData->fontPrefs.AvailFonts;
 	int unitIndex = prefsData->docSetupPrefs.docUnitIndex;
 	unitRatio = unitGetRatioFromIndex(unitIndex);
 	unitChange(unitIndex);
@@ -271,14 +273,14 @@ void Prefs_PDFExport::restoreDefaults(struct ApplicationPrefs *prefsData, const
 	clipToPrinterMarginsCheckBox->setChecked(prefsData->pdfPrefs.doClip);
 	bool cmsUse = m_doc ? (ScCore->haveCMS() && m_doc->HasCMS) : false;
 	if (!cmsUse)
-		pdfVersionComboBox->setVersion(PDFOptions::PDFVersion_14);
+		pdfVersionComboBox->setVersion(PDFVersion::PDF_14);
 	pdfVersionComboBox->setVersion(prefsData->pdfPrefs.Version);
 	pageBindingComboBox->setCurrentIndex(prefsData->pdfPrefs.Binding);
 	generateThumbnailsCheckBox->setChecked(prefsData->pdfPrefs.Thumbnails);
 	saveLinkedTextFramesAsArticlesCheckBox->setChecked(prefsData->pdfPrefs.Articles);
 	includeBookmarksCheckBox->setChecked(prefsData->pdfPrefs.Bookmarks);
 	includeLayersCheckBox->setChecked(prefsData->pdfPrefs.useLayers);
-	includeLayersCheckBox->setEnabled(prefsData->pdfPrefs.Version == PDFOptions::PDFVersion_15 || prefsData->pdfPrefs.Version == PDFOptions::PDFVersion_X4);
+	includeLayersCheckBox->setEnabled(prefsData->pdfPrefs.Version.supportsOCGs());
 
 	epsExportResolutionSpinBox->setValue(prefsData->pdfPrefs.Resolution);
 	embedPDFAndEPSFilesCheckBox->setChecked(prefsData->pdfPrefs.embedPDF);
@@ -292,53 +294,13 @@ void Prefs_PDFExport::restoreDefaults(struct ApplicationPrefs *prefsData, const
 	fontEmbeddingCombo->setEmbeddingMode(prefsData->pdfPrefs.FontEmbedding);
 	if (m_doc != nullptr && exportingPDF)
 	{
-//	Build a list of all Fonts used in Annotations;
-		PageItem *pgit;
-		QList<PageItem*> allItems;
-		for (auto it = m_doc->FrameItems.begin(); it != m_doc->FrameItems.end(); ++it)
+		//	Build a list of all Fonts used in Annotations;
+		int pageItOptions = PageItemIterator::IterateInGroups | PageItemIterator::IterateInDocItems | PageItemIterator::IterateInMasterItems | PageItemIterator::IterateInFrameItems;
+		for (PageItemIterator it(m_doc, pageItOptions); *it; ++it)
 		{
-			PageItem *currItem = it.value();
-			if (currItem->isGroup())
-				allItems = currItem->getAllChildren();
-			else
-				allItems.append(currItem);
-			for (int ii = 0; ii < allItems.count(); ii++)
-			{
-				pgit = allItems.at(ii);
-				if (((pgit->itemType() == PageItem::TextFrame) || (pgit->itemType() == PageItem::PathText)) && (pgit->isAnnotation()) && (pgit->itemText.length() > 0))
-					AnnotationFonts.insert(pgit->itemText.defaultStyle().charStyle().font().replacementName(), "");
-			}
-			allItems.clear();
-		}
-		for (int a = 0; a < m_doc->MasterItems.count(); ++a)
-		{
-			PageItem *currItem = m_doc->MasterItems.at(a);
-			if (currItem->isGroup())
-				allItems = currItem->getAllChildren();
-			else
-				allItems.append(currItem);
-			for (int ii = 0; ii < allItems.count(); ii++)
-			{
-				pgit = allItems.at(ii);
-				if (((pgit->itemType() == PageItem::TextFrame) || (pgit->itemType() == PageItem::PathText)) && (pgit->isAnnotation()) && (pgit->itemText.length() > 0))
-					AnnotationFonts.insert(pgit->itemText.defaultStyle().charStyle().font().replacementName(), "");
-			}
-			allItems.clear();
-		}
-		for (int a = 0; a < m_doc->DocItems.count(); ++a)
-		{
-			PageItem *currItem = m_doc->DocItems.at(a);
-			if (currItem->isGroup())
-				allItems = currItem->getAllChildren();
-			else
-				allItems.append(currItem);
-			for (int ii = 0; ii < allItems.count(); ii++)
-			{
-				pgit = allItems.at(ii);
-				if (((pgit->itemType() == PageItem::TextFrame) || (pgit->itemType() == PageItem::PathText)) && (pgit->isAnnotation()) && (pgit->itemText.length() > 0))
-					AnnotationFonts.insert(pgit->itemText.defaultStyle().charStyle().font().replacementName(), "");
-			}
-			allItems.clear();
+			PageItem *currItem = *it;
+			if (((currItem->itemType() == PageItem::TextFrame) || (currItem->itemType() == PageItem::PathText)) && (currItem->isAnnotation()) && (currItem->itemText.length() > 0))
+				AnnotationFonts.insert(currItem->itemText.defaultStyle().charStyle().font().replacementName(), QString());
 		}
 		toSubsetButton->setEnabled(false);
 		fromSubsetButton->setEnabled(false);
@@ -350,10 +312,11 @@ void Prefs_PDFExport::restoreDefaults(struct ApplicationPrefs *prefsData, const
 			QStringList docFonts = m_doc->usedFonts().keys();
 			embeddedFontsListWidget->clear();
 			subsettedFontsListWidget->clear();
-			for (int fe = 0; fe < docFonts.count(); ++ fe)
+			for (int fe = 0; fe < docFonts.count(); ++fe)
 			{
 				const QString& fontName = docFonts.at(fe);
-				if (Opts.EmbedList.contains(fontName))
+				const ScFace fontFace = AllFonts[fontName];
+				if (Opts.EmbedList.contains(fontName) && (!fontFace.isOTF() || Opts.supportsEmbeddedOpenTypeFonts()) && !fontFace.subset())
 					addFontItem(fontName, embeddedFontsListWidget);
 				else
 				{
@@ -417,10 +380,7 @@ void Prefs_PDFExport::restoreDefaults(struct ApplicationPrefs *prefsData, const
 			facingPagesLeftRadioButton->setChecked(true);
 		else if (Opts.PageLayout == PDFOptions::TwoColumnRight)
 			facingPagesRightRadioButton->setChecked(true);
-		if ((Opts.Version == PDFOptions::PDFVersion_15) || (Opts.Version == PDFOptions::PDFVersion_X4))
-			useLayersRadioButton->setEnabled(true);
-		else
-			useLayersRadioButton->setEnabled(false);
+		useLayersRadioButton->setEnabled(Opts.Version.supportsOCGs());
 	}
 
 	useEncryptionCheckBox->setChecked( prefsData->pdfPrefs.Encrypt );
@@ -567,11 +527,11 @@ void Prefs_PDFExport::restoreDefaults(struct ApplicationPrefs *prefsData, const
 	printPageInfoCheckBox->setChecked(prefsData->pdfPrefs.docInfoMarks);
 	if (!cmsUse)
 		enablePDFXWidgets(false);
-	if (cmsUse && (Opts.Version == PDFOptions::PDFVersion_X1a) && (!PDFXProfiles.isEmpty()))
+	if (cmsUse && (Opts.Version == PDFVersion::PDF_X1a) && (!PDFXProfiles.isEmpty()))
 		enablePDFX(3);
-	else if (cmsUse && (Opts.Version == PDFOptions::PDFVersion_X3) && (!PDFXProfiles.isEmpty()))
+	else if (cmsUse && (Opts.Version == PDFVersion::PDF_X3) && (!PDFXProfiles.isEmpty()))
 		enablePDFX(4);
-	else if (cmsUse && (Opts.Version == PDFOptions::PDFVersion_X4) && (!PDFXProfiles.isEmpty()))
+	else if (cmsUse && (Opts.Version == PDFVersion::PDF_X4) && (!PDFXProfiles.isEmpty()))
 		enablePDFX(5);
 	else
 		enablePDFXWidgets(false);
@@ -586,7 +546,7 @@ void Prefs_PDFExport::restoreDefaults(struct ApplicationPrefs *prefsData, const
 		effectTypeComboBox->addItem( tr("Glitter"));
 		effectTypeComboBox->addItem( tr("Split"));
 		effectTypeComboBox->addItem( tr("Wipe"));
-		if (Opts.Version == PDFOptions::PDFVersion_15)
+		if (Opts.Version.supportsPDF15PresentationEffects())
 		{
 			effectTypeComboBox->addItem( tr("Push"));
 			effectTypeComboBox->addItem( tr("Cover"));
@@ -696,7 +656,7 @@ void Prefs_PDFExport::saveGuiToPrefs(struct ApplicationPrefs *prefsData) const
 	if (useEncryptionCheckBox->isChecked())
 	{
 		int Perm = -64;
-		if (pdfVersionComboBox->currentIndex() == 1)
+		if (pdfVersionComboBox->version() == PDFVersion::PDF_14)
 			Perm &= ~0x00240000;
 		if (allowPrintingCheckBox->isChecked())
 			Perm += 4;
@@ -827,7 +787,7 @@ void Prefs_PDFExport::enableProfiles(int i)
 {
 	enableLPI(i);
 	bool setter = false;
-	if (i == 1 && (!pdfVersionComboBox->versionIs(PDFOptions::PDFVersion_X1a)))
+	if (i == 1 && (!pdfVersionComboBox->versionIs(PDFVersion::PDF_X1a)))
 		setter = true;
 	enableSolidsImagesWidgets(setter);
 }
@@ -989,11 +949,14 @@ void Prefs_PDFExport::enablePG()
 	solidColorRenderingIntentComboBox->setEnabled(setter);
 }
 
-void Prefs_PDFExport::enablePDFX(int i)
+void Prefs_PDFExport::enablePDFX(int)
 {
-	includeLayersCheckBox->setEnabled((i == 2) || (i == 5));
+	PDFVersion pdfVer = pdfVersionComboBox->version();
+
+	includeLayersCheckBox->setEnabled(pdfVer.supportsOCGs());
 	if (useLayersRadioButton)
-		useLayersRadioButton->setEnabled((i == 2) || (i == 5));
+		useLayersRadioButton->setEnabled(pdfVer.supportsOCGs());
+
 	if (m_doc != nullptr && exportingPDF)
 	{
 		int currentEff = effectTypeComboBox->currentIndex();
@@ -1006,7 +969,7 @@ void Prefs_PDFExport::enablePDFX(int i)
 		effectTypeComboBox->addItem( tr("Glitter"));
 		effectTypeComboBox->addItem( tr("Split"));
 		effectTypeComboBox->addItem( tr("Wipe"));
-		if (i == 2)
+		if (pdfVer.supportsPDF15PresentationEffects())
 		{
 			effectTypeComboBox->addItem( tr("Push"));
 			effectTypeComboBox->addItem( tr("Cover"));
@@ -1033,8 +996,9 @@ void Prefs_PDFExport::enablePDFX(int i)
 		connect(effectTypeComboBox, SIGNAL(activated(int)), this, SLOT(SetEffOpts(int)));
 	}
 
-	if (i < 3)  // not PDF/X
+	if (!pdfVer.isPDFX())  // not PDF/X
 	{
+		checkEmbeddableFonts();
 		fontEmbeddingCombo->setNoEmbeddingEnabled(true);
 		enablePDFXWidgets(false);
 		tabWidget->setTabEnabled(2, true);
@@ -1054,7 +1018,7 @@ void Prefs_PDFExport::enablePDFX(int i)
 	outputIntentionComboBox->setCurrentIndex(1);
 	outputIntentionComboBox->setEnabled(false);
 	enableProfiles(1);
-	if ((i == 4) || (i == 5)) // X3 or X4, enforcing color profiles on images
+	if (pdfVer == PDFVersion::PDF_X3 || pdfVer == PDFVersion::PDF_X4) // X3 or X4, enforcing color profiles on images
 	{
 		useImageProfileCheckBox->setChecked(true);
 		useImageProfileCheckBox->setEnabled(false);
@@ -1097,10 +1061,10 @@ void Prefs_PDFExport::enablePDFX(int i)
 void Prefs_PDFExport::addPDFVersions(bool addPDFXStrings)
 {
 	disconnect(pdfVersionComboBox, SIGNAL(activated(int)), this, SLOT(enablePDFX(int)));
-	PDFOptions::PDFVersion currVersion = pdfVersionComboBox->version();
+	PDFVersion currVersion = pdfVersionComboBox->version();
 	pdfVersionComboBox->setPDFXEnabled(addPDFXStrings);
 	if (!addPDFXStrings)
-		currVersion = qMax(PDFOptions::PDFVersion_13, qMin(currVersion, PDFOptions::PDFVersion_15));
+		currVersion = qMax(PDFVersion::PDF_13, qMin((PDFVersion::Version) currVersion, PDFVersion::PDF_16));
 	pdfVersionComboBox->setVersion(currVersion);
 	connect(pdfVersionComboBox, SIGNAL(activated(int)), this, SLOT(enablePDFX(int)));
 }
@@ -1126,6 +1090,8 @@ void Prefs_PDFExport::enableEffects(bool enabled)
 
 void Prefs_PDFExport::EmbedAll()
 {
+	PDFVersion pdfVer = pdfVersionComboBox->version();
+
 	embeddedFontsListWidget->clear();
 	subsettedFontsListWidget->clear();
 	toSubsetButton->setEnabled(false);
@@ -1135,10 +1101,11 @@ void Prefs_PDFExport::EmbedAll()
 	if (m_doc)
 		docFonts = m_doc->usedFonts().keys();
 
-	for (int a=0; a < docFonts.count(); ++a)
+	for (int i = 0; i < docFonts.count(); ++i)
 	{
-		const QString& fontName = docFonts.at(a);
-		if (!AllFonts[fontName].subset())
+		const QString& fontName = docFonts.at(i);
+		const ScFace fontFace = AllFonts[fontName];
+		if (!fontFace.subset() && (!fontFace.isOTF() || pdfVer.supportsEmbeddedOpenTypeFonts()))
 		{
 			QListWidgetItem* item = addFontItem(fontName, embeddedFontsListWidget);
 			if (AnnotationFonts.contains(item->text()))
@@ -1187,6 +1154,26 @@ void Prefs_PDFExport::OutlineAll()
 	// Nothing to do at this point
 }
 
+void Prefs_PDFExport::checkEmbeddableFonts()
+{
+	PDFVersion pdfVer = pdfVersionComboBox->version();
+
+	for (int i = 0; i < embeddedFontsListWidget->count(); ++i)
+	{
+		QListWidgetItem* item = embeddedFontsListWidget->item(i);
+		QString fontName = item->text();
+		if (AnnotationFonts.contains(fontName))
+			continue;
+		const ScFace fontFace = AllFonts[fontName];
+		if (fontFace.isOTF() && !pdfVer.supportsEmbeddedOpenTypeFonts())
+		{
+			delete embeddedFontsListWidget->takeItem(i);
+			addFontItem(fontName, subsettedFontsListWidget);
+			--i;
+		}
+	}
+}
+
 void Prefs_PDFExport::doDocBleeds()
 {
 	if (useDocumentBleedsCheckBox->isChecked())
@@ -1348,38 +1335,47 @@ void Prefs_PDFExport::EmbeddingModeChange()
 
 void Prefs_PDFExport::RemoveSubset()
 {
-	QString currentFont = subsettedFontsListWidget->currentItem()->text();
-	const ScFace fontFace = AllFonts[currentFont];
-	if ((fontFace.type() != ScFace::OTF) && (!fontFace.subset()))
+	PDFVersion pdfVer = pdfVersionComboBox->version();
+
+	QList<QListWidgetItem*> selection = subsettedFontsListWidget->selectedItems();
+	for (int i = 0; i < selection.count() ; ++i)
 	{
-		embeddedFontsListWidget->addItem(currentFont);
-		delete subsettedFontsListWidget->takeItem(subsettedFontsListWidget->currentRow());
+		QListWidgetItem* fontItem = selection[i];
+		QString currentFont = fontItem->text();
+		const ScFace fontFace = AllFonts[currentFont];
+		if (fontFace.isOTF() && !pdfVer.supportsEmbeddedOpenTypeFonts())
+			continue;
+		if (fontFace.subset())
+			continue;
+		addFontItem(currentFont, embeddedFontsListWidget);
+		int currentRow = subsettedFontsListWidget->row(fontItem);
+		delete subsettedFontsListWidget->takeItem(currentRow);
 	}
+
 	subsettedFontsListWidget->clearSelection();
-	if (subsettedFontsListWidget->count() == 0)
-		fromSubsetButton->setEnabled(false);
+	fromSubsetButton->setEnabled(false);
 }
 
 void Prefs_PDFExport::PutToSubset()
 {
-	QString currentFont = embeddedFontsListWidget->currentItem()->text();
-	if (subsettedFontsListWidget->count() != 0)
+	QList<QListWidgetItem*> selection = embeddedFontsListWidget->selectedItems();
+	for (int i = 0; i < selection.count() ; ++i)
 	{
-		if (subsettedFontsListWidget->findItems(currentFont, Qt::MatchExactly).count() == 0)
+		QListWidgetItem* fontItem = selection[i];
+		QString currentFont = fontItem->text();
+		if (subsettedFontsListWidget->count() != 0)
+		{
+			if (subsettedFontsListWidget->findItems(currentFont, Qt::MatchExactly).count() == 0)
+				addFontItem(currentFont, subsettedFontsListWidget);
+		}
+		else
+		{
 			addFontItem(currentFont, subsettedFontsListWidget);
+		}
+		int itemRow = embeddedFontsListWidget->row(fontItem);
+		delete embeddedFontsListWidget->takeItem(itemRow);
 	}
-	else
-	{
-		addFontItem(currentFont, subsettedFontsListWidget);
-	}
-	delete embeddedFontsListWidget->takeItem(embeddedFontsListWidget->currentRow());
+
 	embeddedFontsListWidget->clearSelection();
-	if (embeddedFontsListWidget->count() == 0)
-	{
-		toSubsetButton->setEnabled(false);
-	}
-	else if (!(embeddedFontsListWidget->currentItem()->flags() & Qt::ItemIsSelectable))
-	{
-		toSubsetButton->setEnabled(false);
-	}
+	toSubsetButton->setEnabled(false);
 }
