@@ -17,11 +17,12 @@ for which a new license (GPL+exception) is in place.
 #include "commonstrings.h"
 #include "dasheditor.h"
 #include "iconmanager.h"
+#include "localemgr.h"
 #include "pageitem.h"
 #include "pageitem_textframe.h"
 #include "sccolorengine.h"
-#include "sccombobox.h"
 #include "scraction.h"
+#include "scribusapp.h"
 #include "scribuscore.h"
 #include "selection.h"
 #include "ui/propertiespalette_utils.h"
@@ -35,15 +36,6 @@ for which a new license (GPL+exception) is in place.
 
 PropertiesPalette_Line::PropertiesPalette_Line( QWidget* parent) : QWidget(parent)
 {
-	m_ScMW = nullptr;
-	m_doc  = nullptr;
-	m_haveDoc  = false;
-	m_haveItem = false;
-	m_item     = nullptr;
-	m_lineMode = false;
-	m_unitRatio = 1.0;
-	m_unitIndex = 0;
-
 	setupUi(this);
 	setSizePolicy( QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum));
 
@@ -72,6 +64,9 @@ PropertiesPalette_Line::PropertiesPalette_Line( QWidget* parent) : QWidget(paren
 
 	languageChange();
 
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+	connect(ScQApp, SIGNAL(localeChanged()), this, SLOT(localeChange()));
+
 	connect(lineWidth, SIGNAL(valueChanged(double)), this, SLOT(handleLineWidth()));
 	connect(lineType, SIGNAL(activated(int)), this, SLOT(handleLineStyle()));
 	connect(lineJoinStyle, SIGNAL(activated(int)), this, SLOT(handleLineJoin()));
@@ -327,26 +322,18 @@ void PropertiesPalette_Line::setCurrentItem(PageItem *item)
 	endArrowScale->blockSignals(false);
 	lineMode->blockSignals(false);
 
-	setter = false;
-
 	if ((m_item->isGroup()) && (!m_item->isSingleSel))
-	{
 		setEnabled(false);
-	}
 
 	m_haveItem = true;
 
 	showLineWidth(m_item->lineWidth());
 	showLineValues(m_item->lineStyle(), m_item->lineEnd(), m_item->lineJoin());
 
-	if (m_item->asOSGFrame())
-	{
+	if (m_item->isOSGFrame())
 		setEnabled(false);
-	}
-	if (m_item->asSymbolFrame())
-	{
+	if (m_item->isSymbol())
 		setEnabled(false);
-	}
 }
 
 void PropertiesPalette_Line::updateArrowStyles()
@@ -356,11 +343,10 @@ void PropertiesPalette_Line::updateArrowStyles()
 
 void PropertiesPalette_Line::updateArrowStyles(ScribusDoc *doc)
 {
-	if (doc)
-	{
-		startArrow->rebuildList(&doc->arrowStyles());
-		endArrow->rebuildList(&doc->arrowStyles());
-	}
+	if (!doc)
+		return;
+	startArrow->rebuildList(&doc->arrowStyles());
+	endArrow->rebuildList(&doc->arrowStyles());
 }
 
 void PropertiesPalette_Line::updateLineStyles()
@@ -368,18 +354,18 @@ void PropertiesPalette_Line::updateLineStyles()
 	updateLineStyles(m_doc);
 }
 
-void PropertiesPalette_Line::updateLineStyles(ScribusDoc *dd)
+void PropertiesPalette_Line::updateLineStyles(ScribusDoc *doc)
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
 		return;
 	
 	lineStyles->blockSignals(true);
 	lineStyles->clear();
-	if (dd != nullptr)
+	if (doc != nullptr)
 	{
 		QHash<QString,multiLine>::Iterator it;
-		for (it = dd->MLineStyles.begin(); it != dd->MLineStyles.end(); ++it)
-			lineStyles->addItem( new LineFormatItem(dd, it.value(), it.key()) );
+		for (it = doc->docLineStyles.begin(); it != doc->docLineStyles.end(); ++it)
+			lineStyles->addItem( new LineFormatItem(doc, it.value(), it.key()) );
 		lineStyles->sortItems();
 		lineStyles->insertItem( 0, tr("No Style"));
 		if (lineStyles->currentItem())
@@ -646,6 +632,28 @@ void PropertiesPalette_Line::handleLineStyle(QListWidgetItem *widgetItem)
 	lineEndStyle->setEnabled(setter);
 }
 
+void PropertiesPalette_Line::iconSetChange()
+{
+	IconManager& im = IconManager::instance();
+
+	QSignalBlocker lineJoinStyleBlocker(lineJoinStyle);
+	int oldLJoinStyle = lineJoinStyle->currentIndex();
+	lineJoinStyle->clear();
+	lineJoinStyle->addItem(im.loadIcon("16/stroke-join-miter.png"), tr("Miter Join"));
+	lineJoinStyle->addItem(im.loadIcon("16/stroke-join-bevel.png"), tr("Bevel Join"));
+	lineJoinStyle->addItem(im.loadIcon("16/stroke-join-round.png"), tr("Round Join"));
+	lineJoinStyle->setCurrentIndex(oldLJoinStyle);
+
+	QSignalBlocker lineEndStyleBlocker(lineEndStyle);
+	int oldLEndStyle = lineEndStyle->currentIndex();
+	lineEndStyle->clear();
+	lineEndStyle->addItem(im.loadIcon("16/stroke-cap-butt.png"), tr("Flat Cap"));
+	lineEndStyle->addItem(im.loadIcon("16/stroke-cap-square.png"), tr("Square Cap"));
+	lineEndStyle->addItem(im.loadIcon("16/stroke-cap-round.png"), tr("Round Cap"));
+	lineEndStyle->setCurrentIndex(oldLEndStyle);
+	lineEndLabel->setText( tr("&Endings:"));
+}
+
 void PropertiesPalette_Line::languageChange()
 {
 	QSignalBlocker lineTypeBlocker(lineType);
@@ -685,7 +693,7 @@ void PropertiesPalette_Line::languageChange()
 	QSignalBlocker lineJoinStyleBlocker(lineJoinStyle);
 	int oldLJoinStyle = lineJoinStyle->currentIndex();
 	lineJoinStyle->clear();
-	IconManager& im=IconManager::instance();
+	IconManager& im = IconManager::instance();
 	lineJoinStyle->addItem(im.loadIcon("16/stroke-join-miter.png"), tr("Miter Join"));
 	lineJoinStyle->addItem(im.loadIcon("16/stroke-join-bevel.png"), tr("Bevel Join"));
 	lineJoinStyle->addItem(im.loadIcon("16/stroke-join-round.png"), tr("Round Join"));
@@ -737,3 +745,9 @@ void PropertiesPalette_Line::unitChange()
 	lineWidth->setNewUnit( m_unitIndex );
 	lineWidth->blockSignals(false);
 }
+
+void PropertiesPalette_Line::localeChange()
+{
+	const QLocale& l(LocaleManager::instance().userPreferredLocale());
+	lineWidth->setLocale(l);
+}
