@@ -20,6 +20,7 @@ for which a new license (GPL+exception) is in place.
 #include "propertiespalette_table.h"
 #include "sccolorengine.h"
 #include "scribus.h"
+#include "scribusapp.h"
 #include "selection.h"
 #include "tableborder.h"
 #include "tablesideselector.h"
@@ -28,28 +29,37 @@ for which a new license (GPL+exception) is in place.
 
 
 
-PropertiesPalette_Table::PropertiesPalette_Table(QWidget* parent) : QWidget(parent),
-	m_mainWindow(nullptr), m_doc(nullptr), m_item(nullptr), m_previousItem(nullptr)
+PropertiesPalette_Table::PropertiesPalette_Table(QWidget* parent) : QWidget(parent)
 {
 	setupUi(this);
 	setSizePolicy( QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum));
 
-	addBorderLineButton->setIcon(IconManager::instance().loadIcon("penciladd.png"));
-	removeBorderLineButton->setIcon(IconManager::instance().loadIcon("pencilsub.png"));
+	iconSetChange();
 	labelTable->setBuddy(tableStyleCombo);
-	buttonClearTableStyle->setIcon(IconManager::instance().loadIcon("16/edit-clear.png"));
 	labelCells->setBuddy(cellStyleCombo);
-	buttonClearCellStyle->setIcon(IconManager::instance().loadIcon("16/edit-clear.png"));
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+
 	connect(tableStyleCombo, SIGNAL(newStyle(const QString&)), this, SLOT(setTableStyle(const QString&)));
 	connect(cellStyleCombo, SIGNAL(newStyle(const QString&)), this, SLOT(setCellStyle(const QString&)));
 }
 
+void PropertiesPalette_Table::iconSetChange()
+{
+	IconManager& iconManager = IconManager::instance();
+
+	addBorderLineButton->setIcon(iconManager.loadIcon("penciladd.png"));
+	removeBorderLineButton->setIcon(iconManager.loadIcon("pencilsub.png"));
+	buttonClearTableStyle->setIcon(iconManager.loadIcon("16/edit-clear.png"));
+	buttonClearCellStyle->setIcon(iconManager.loadIcon("16/edit-clear.png"));
+}
+
 void PropertiesPalette_Table::handleUpdateRequest(int updateFlags)
 {
 	if (updateFlags & reqColorsUpdate)
 		updateColorList();
-	tableStyleCombo->updateFormatList();
-	cellStyleCombo->updateFormatList();
+	tableStyleCombo->updateStyleList();
+	cellStyleCombo->updateStyleList();
 }
 
 void PropertiesPalette_Table::updateColorList()
@@ -153,14 +163,14 @@ void PropertiesPalette_Table::handleCellSelectionChanged()
 void PropertiesPalette_Table::showTableStyle(const QString& name)
 {
 	bool blocked = tableStyleCombo->blockSignals(true);
-	tableStyleCombo->setFormat(name);
+	tableStyleCombo->setStyle(name);
 	tableStyleCombo->blockSignals(blocked);
 }
 
 void PropertiesPalette_Table::showCellStyle(const QString& name)
 {
 	bool blocked = cellStyleCombo->blockSignals(true);
-	cellStyleCombo->setFormat(name);
+	cellStyleCombo->setStyle(name);
 	cellStyleCombo->blockSignals(blocked);
 }
 
@@ -313,7 +323,7 @@ void PropertiesPalette_Table::updateBorderLineList()
 	borderLineList->clear();
 	for (const TableBorderLine& borderLine : m_currentBorder.borderLines())
 	{
-		QString text = QString(" %1%2 %3").arg(borderLine.width()).arg(borderLineWidth->suffix()).arg(CommonStrings::translatePenStyleName(borderLine.style()));
+		QString text = QString(" %1%2 %3").arg(borderLine.width()).arg(borderLineWidth->suffix(), CommonStrings::translatePenStyleName(borderLine.style()));
 		if (borderLine.color() != CommonStrings::None)
 		{
 			QPixmap *icon = getWidePixmap(getColor(borderLine.color(), borderLine.shade()));
@@ -344,7 +354,7 @@ void PropertiesPalette_Table::updateBorderLineList(const TableBorderLine& curren
 void PropertiesPalette_Table::updateBorderLineListItem()
 {
 	QListWidgetItem* item = borderLineList->currentItem();
-	QString text = QString(" %1%2 %3").arg(borderLineWidth->getValue()).arg(borderLineWidth->suffix()).arg(CommonStrings::translatePenStyleName(static_cast<Qt::PenStyle>(borderLineStyle->currentIndex() + 1)));
+	QString text = QString(" %1%2 %3").arg(borderLineWidth->getValue()).arg(borderLineWidth->suffix(), CommonStrings::translatePenStyleName(static_cast<Qt::PenStyle>(borderLineStyle->currentIndex() + 1)));
 	if (borderLineColor->currentColor() != CommonStrings::None)
 	{
 		QPixmap *icon = getWidePixmap(getColor(borderLineColor->currentColor(), borderLineShade->value()));
@@ -612,16 +622,24 @@ void PropertiesPalette_Table::updateBorders()
 	}
 	else
 	{
-		TableCell cell = table->activeCell();
-		if (selectedSides & TableSideSelector::Left)
-			cell.setLeftBorder(m_currentBorder);
-		if (selectedSides & TableSideSelector::Right)
-			cell.setRightBorder(m_currentBorder);
-		if (selectedSides & TableSideSelector::Top)
-			cell.setTopBorder(m_currentBorder);
-		if (selectedSides & TableSideSelector::Bottom)
-			cell.setBottomBorder(m_currentBorder);
+		QSet<TableCell> cells = table->selectedCells();
+		if (cells.isEmpty())
+			cells.insert(table->activeCell());
+		QSet<TableCell>::Iterator cellIter;
+		for (cellIter = cells.begin(); cellIter != cells.end(); cellIter++)
+		{
+			TableCell currentCell(*cellIter);
+			if (selectedSides & TableSideSelector::Left)
+				currentCell.setLeftBorder(m_currentBorder);
+			if (selectedSides & TableSideSelector::Right)
+				currentCell.setRightBorder(m_currentBorder);
+			if (selectedSides & TableSideSelector::Top)
+				currentCell.setTopBorder(m_currentBorder);
+			if (selectedSides & TableSideSelector::Bottom)
+				currentCell.setBottomBorder(m_currentBorder);
+		}
 	}
+
 	table->adjustTable();
 	table->update();
 }
