@@ -14,45 +14,39 @@ for which a new license (GPL+exception) is in place.
 #endif
 #include <cmath>
 
+
 #include "appmodehelper.h"
 #include "appmodes.h"
 #include "autoform.h"
 #include "basepointwidget.h"
-#include "commonstrings.h"
 #include "colorlistbox.h"
-#include "sccolorengine.h"
+#include "commonstrings.h"
+#include "iconmanager.h"
+#include "localemgr.h"
 #include "pageitem.h"
 #include "pageitem_arc.h"
 #include "pageitem_group.h"
+#include "pageitem_line.h"
 #include "pageitem_spiral.h"
 #include "pageitem_textframe.h"
 #include "propertiespalette_utils.h"
-#include "sccombobox.h"
-
-#include "scribuscore.h"
+#include "sccolorengine.h"
 #include "scraction.h"
+#include "scribusapp.h"
+#include "scribuscore.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
 #include "tabmanager.h"
-#include "units.h"
 #include "undomanager.h"
+#include "units.h"
 #include "util.h"
-#include "iconmanager.h"
 #include "util_math.h"
 
 //using namespace std;
 
 PropertiesPalette_XYZ::PropertiesPalette_XYZ( QWidget* parent) : QWidget(parent)
 {
-	m_ScMW=nullptr;
-	m_doc=nullptr;
-	m_haveDoc  = false;
-	m_haveItem = false;
-	m_lineMode = false;
-	m_oldRotation = 0;
-	m_unitRatio = 1.0;
-
 	setupUi(this);
 	setSizePolicy( QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum));
 
@@ -73,48 +67,26 @@ PropertiesPalette_XYZ::PropertiesPalette_XYZ( QWidget* parent) : QWidget(parent)
 	keepFrameWHRatioButton->setMaximumSize( QSize( 15, 32767 ) );
 	keepFrameWHRatioButton->setChecked(false);
 
-	rotationSpin->setNewUnit(6);
+	rotationSpin->setNewUnit(SC_DEG);
 	rotationSpin->setWrapping( true );
 	installSniffer(rotationSpin);
 	rotationLabel->setBuddy(rotationSpin);
 
-	IconManager& im=IconManager::instance();
-	levelUp->setIcon(im.loadIcon("16/go-up.png"));
-	levelDown->setIcon(im.loadIcon("16/go-down.png"));
-	levelTop->setIcon(im.loadIcon("16/go-top.png"));
-	levelBottom->setIcon(im.loadIcon("16/go-bottom.png"));
 	levelLabel->setAlignment( Qt::AlignCenter );
 
-	doGroup->setIcon(im.loadIcon("group.png"));
-	doUnGroup->setIcon(im.loadIcon("ungroup.png"));
-
-	flipH->setIcon(im.loadIcon("16/flip-object-horizontal.png"));
-	flipH->setCheckable( true );
-	flipV->setIcon(im.loadIcon("16/flip-object-vertical.png"));
-	flipV->setCheckable( true );
+	flipH->setCheckable(true);
+	flipV->setCheckable(true);
 	
-	doLock->setCheckable( true );
-	QIcon a = QIcon();
-	a.addPixmap(im.loadPixmap("16/lock.png"), QIcon::Normal, QIcon::On);
-	a.addPixmap(im.loadPixmap("16/lock-unlocked.png"), QIcon::Normal, QIcon::Off);
-	doLock->setIcon(a);
-
-	noPrint->setCheckable( true );
-	QIcon a2 = QIcon();
-	a2.addPixmap(im.loadPixmap("NoPrint.png"), QIcon::Normal, QIcon::On);
-	a2.addPixmap(im.loadPixmap("16/document-print.png"), QIcon::Normal, QIcon::Off);
-	noPrint->setIcon(a2);
-
-	noResize->setCheckable( true );
-	QIcon a3 = QIcon();
-	a3.addPixmap(im.loadPixmap("framenoresize.png"), QIcon::Normal, QIcon::On);
-	a3.addPixmap(im.loadPixmap("frameresize.png"), QIcon::Normal, QIcon::Off);
-	noResize->setIcon(a3);
-
-	m_lineMode = false;
+	doLock->setCheckable(true);
+	noPrint->setCheckable(true);
+	noResize->setCheckable(true);
 
+	iconSetChange();
 	languageChange();
 
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+	connect(ScQApp, SIGNAL(localeChanged()), this, SLOT(localeChange()));
+
 	connect(xposSpin, SIGNAL(valueChanged(double)), this, SLOT(handleNewX()));
 	connect(yposSpin, SIGNAL(valueChanged(double)), this, SLOT(handleNewY()));
 	connect(widthSpin, SIGNAL(valueChanged(double)), this, SLOT(handleNewW()));
@@ -274,7 +246,7 @@ PageItem* PropertiesPalette_XYZ::currentItemFromSelection()
 	return currentItem;
 }
 
-void PropertiesPalette_XYZ::setCurrentItem(PageItem *i)
+void PropertiesPalette_XYZ::setCurrentItem(PageItem *item)
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
 		return;
@@ -286,12 +258,12 @@ void PropertiesPalette_XYZ::setCurrentItem(PageItem *i)
 	//	return;
 
 	if (!m_doc)
-		setDoc(i->doc());
+		setDoc(item->doc());
 
 	disconnect(nameEdit, SIGNAL(Leaved()), this, SLOT(handleNewName()));
 
 	m_haveItem = false;
-	m_item = i;
+	m_item = item;
 
 	nameEdit->setText(m_item->itemName());
 	levelLabel->setText( QString::number(m_item->level()) );
@@ -319,15 +291,15 @@ void PropertiesPalette_XYZ::setCurrentItem(PageItem *i)
 //	showXY(selX, selY);
 //	showWH(selW, selH);
 	
-	bool checkableFlip = (i->isImageFrame() || i->isTextFrame() || i->isLatexFrame() || i->isOSGFrame() || i->isSymbol() || i->isGroup() || i->isSpiral());
+	bool checkableFlip = (item->isImageFrame() || item->isTextFrame() || item->isLatexFrame() || item->isOSGFrame() || item->isSymbol() || item->isGroup() || item->isSpiral());
 	flipH->setCheckable(checkableFlip);
 	flipV->setCheckable(checkableFlip);
 
-	noPrint->setChecked(!i->printEnabled());
-	showFlippedH(i->imageFlippedH());
-	showFlippedV(i->imageFlippedV());
-	double rr = i->rotation();
-	if (i->rotation() > 0)
+	noPrint->setChecked(!item->printEnabled());
+	showFlippedH(item->imageFlippedH());
+	showFlippedV(item->imageFlippedV());
+	double rr = item->rotation();
+	if (item->rotation() > 0)
 		rr = 360 - rr;
 	m_oldRotation = fabs(rr);
 	rotationSpin->setValue(fabs(rr));
@@ -348,7 +320,7 @@ void PropertiesPalette_XYZ::setCurrentItem(PageItem *i)
 	xposSpin->setEnabled(!setter);
 	yposSpin->setEnabled(!setter);
 	bool haveSameParent = m_doc->m_Selection->objectsHaveSameParent();
-	levelGroup->setEnabled(haveSameParent && !i->locked());
+	levelGroup->setEnabled(haveSameParent && !item->locked());
 	if ((m_item->isGroup()) && (!m_item->isSingleSel))
 	{
 		setEnabled(true);
@@ -382,10 +354,10 @@ void PropertiesPalette_XYZ::setCurrentItem(PageItem *i)
 	}
 	showXY(selX, selY);
 	showWH(selW, selH);
-	showLocked(i->locked());
-	showSizeLocked(i->sizeLocked());
-	double rrR = i->imageRotation();
-	if (i->imageRotation() > 0)
+	showLocked(item->locked());
+	showSizeLocked(item->sizeLocked());
+	double rrR = item->imageRotation();
+	if (item->imageRotation() > 0)
 		rrR = 360 - rrR;
 	noResize->setEnabled(!m_item->isArc());
 	
@@ -397,12 +369,12 @@ void PropertiesPalette_XYZ::setCurrentItem(PageItem *i)
 		doUnGroup->setEnabled(m_item->isGroup());
 	if ((m_doc->appMode == modeEditClip) && (m_item->isGroup()))
 		doUnGroup->setEnabled(false);
-	if (m_item->asOSGFrame())
+	if (m_item->isOSGFrame())
 	{
 		setEnabled(true);
 		rotationSpin->setEnabled(false);
 	}
-	if (m_item->asSymbolFrame())
+	if (m_item->asSymbol())
 	{
 		setEnabled(true);
 	}
@@ -427,7 +399,7 @@ void PropertiesPalette_XYZ::handleSelectionChanged()
 	PageItem* currItem = currentItemFromSelection();
 	if (m_doc->m_Selection->count() > 1)
 	{
-		m_oldRotation = 0;
+		m_oldRotation = 0.0;
 		double gx, gy, gh, gw;
 		m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
 		int bp = basePointWidget->checkedId();
@@ -525,7 +497,7 @@ void PropertiesPalette_XYZ::handleSelectionChanged()
 		case PageItem::ImageFrame:
 		case PageItem::LatexFrame:
 		case PageItem::OSGFrame:
-			if (currItem->asOSGFrame())
+			if (currItem->isOSGFrame())
 			{
 				setEnabled(true);
 				rotationSpin->setEnabled(false);
@@ -559,12 +531,22 @@ void PropertiesPalette_XYZ::unitChange()
 	m_haveItem = tmp;
 }
 
+void PropertiesPalette_XYZ::localeChange()
+{
+	const QLocale& l(LocaleManager::instance().userPreferredLocale());
+	xposSpin->setLocale(l);
+	yposSpin->setLocale(l);
+	widthSpin->setLocale(l);
+	heightSpin->setLocale(l);
+	rotationSpin->setLocale(l);
+}
+
 void PropertiesPalette_XYZ::showXY(double x, double y)
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
 		return;
-	disconnect(xposSpin, SIGNAL(valueChanged(double)), this, SLOT(handleNewX()));
-	disconnect(yposSpin, SIGNAL(valueChanged(double)), this, SLOT(handleNewY()));
+	bool sigBlocked1 = xposSpin->blockSignals(true);
+	bool sigBlocked2 = yposSpin->blockSignals(true);
 	bool useLineMode = false;
 	bool tmp = m_haveItem;
 	double inX, inY, b, h, r, dummy1, dummy2;
@@ -620,35 +602,37 @@ void PropertiesPalette_XYZ::showXY(double x, double y)
 			inY -= m_doc->currentPage()->yOffset();
 		}
 	}
-	xposSpin->setValue(inX*m_unitRatio);
-	yposSpin->setValue(inY*m_unitRatio);
+	xposSpin->setValue(inX * m_unitRatio);
+	yposSpin->setValue(inY * m_unitRatio);
 	if (useLineMode)
 		showWH(m_item->width(), m_item->height());
 	m_haveItem = tmp;
-	connect(xposSpin, SIGNAL(valueChanged(double)), this, SLOT(handleNewX()));
-	connect(yposSpin, SIGNAL(valueChanged(double)), this, SLOT(handleNewY()));
+	xposSpin->blockSignals(sigBlocked1);
+	yposSpin->blockSignals(sigBlocked2);
 }
 
 void PropertiesPalette_XYZ::showWH(double x, double y)
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
 		return;
-	QTransform ma;
-	QPoint dp;
 	bool sigBlocked1 = widthSpin->blockSignals(true);
 	bool sigBlocked2 = heightSpin->blockSignals(true);
 	if ((m_lineMode) && (m_item->asLine()))
 	{
-		ma.translate(static_cast<double>(xposSpin->value()) / m_unitRatio, static_cast<double>(yposSpin->value()) / m_unitRatio);
-		ma.rotate(static_cast<double>(rotationSpin->value())*(-1));
-		dp = QPoint(static_cast<int>(x), static_cast<int>(y)) * ma;
-		widthSpin->setValue(dp.x()*m_unitRatio);
-		heightSpin->setValue(dp.y()*m_unitRatio);
+		QTransform ma;
+		ma.translate(m_item->xPos(), m_item->yPos());
+		ma.rotate(m_item->rotation());
+		QPointF dp = QPointF(x, 0.0) * ma;
+		dp -= QPointF(m_doc->rulerXoffset, m_doc->rulerYoffset);
+		if (m_doc->guidesPrefs().rulerMode)
+			dp -= QPointF(m_doc->currentPage()->xOffset(), m_doc->currentPage()->yOffset());
+		widthSpin->setValue(dp.x() * m_unitRatio);
+		heightSpin->setValue(dp.y() * m_unitRatio);
 	}
 	else
 	{
-		widthSpin->setValue(x*m_unitRatio);
-		heightSpin->setValue(y*m_unitRatio);
+		widthSpin->setValue(x * m_unitRatio);
+		heightSpin->setValue(y * m_unitRatio);
 	}
 	widthSpin->blockSignals(sigBlocked1);
 	heightSpin->blockSignals(sigBlocked2);
@@ -668,82 +652,72 @@ void PropertiesPalette_XYZ::showRotation(double r)
 
 void PropertiesPalette_XYZ::handleNewX()
 {
-	if (!m_ScMW || m_ScMW->scriptIsRunning())
+	if (!m_haveDoc || !m_haveItem || !m_ScMW || m_ScMW->scriptIsRunning())
 		return;
-	if ((m_haveDoc) && (m_haveItem))
+
+	double x, y, gx, gy, gh, gw, base;
+	QTransform ma;
+	x = xposSpin->value() / m_unitRatio;
+	y = yposSpin->value() / m_unitRatio;
+	base = 0;
+	x += m_doc->rulerXoffset;
+	y += m_doc->rulerYoffset;
+	if (m_doc->guidesPrefs().rulerMode)
 	{
-		double x,y,w,h, gx, gy, gh, gw, base;
-		QTransform ma;
-		x = xposSpin->value() / m_unitRatio;
-		y = yposSpin->value() / m_unitRatio;
-		w = widthSpin->value() / m_unitRatio;
-		h = heightSpin->value() / m_unitRatio;
-		base = 0;
-		x += m_doc->rulerXoffset;
-		y += m_doc->rulerYoffset;
-		if (m_doc->guidesPrefs().rulerMode)
+		x += m_doc->currentPage()->xOffset();
+		y += m_doc->currentPage()->yOffset();
+	}
+	if (m_doc->m_Selection->isMultipleSelection())
+	{
+		m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
+		int bp = basePointWidget->checkedId();
+		if ((bp == 0) || (bp == 3))
+			base = gx;
+		else if (bp == 2)
+			base = gx + gw / 2.0;
+		else if ((bp == 1) || (bp == 4))
+			base = gx + gw;
+		if (!_userActionOn)
+			m_ScMW->view->startGroupTransaction();
+		m_doc->moveGroup(x - base, 0);
+		if (!_userActionOn)
 		{
-			x += m_doc->currentPage()->xOffset();
-			y += m_doc->currentPage()->yOffset();
+			m_ScMW->view->endGroupTransaction();
 		}
-		if (m_doc->m_Selection->isMultipleSelection())
+		m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
+		showXY(gx, gy);
+	}
+	else
+	{
+		if ((m_item->asLine()) && (m_lineMode))
 		{
-			m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
-			int bp = basePointWidget->checkedId();
-			if ((bp == 0) || (bp == 3))
-				base = gx;
-			else if (bp == 2)
-				base = gx + gw / 2.0;
-			else if ((bp == 1) || (bp == 4))
-				base = gx + gw;
-			if (!_userActionOn)
-				m_ScMW->view->startGroupTransaction();
-			m_doc->moveGroup(x - base, 0);
-			if (!_userActionOn)
-			{
-				m_ScMW->view->endGroupTransaction();
-			}
-			m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
-			showXY(gx, gy);
+			QPointF endPoint = m_item->asLine()->endPoint();
+			double r = atan2(endPoint.y() - m_item->yPos(), endPoint.x() - x) * (180.0 / M_PI);
+			double length = sqrt(pow(endPoint.x() - x, 2) + pow(endPoint.y() - m_item->yPos(), 2));
+			m_item->setXYPos(x, m_item->yPos(), true);
+			m_item->setRotation(r, true);
+			m_doc->sizeItem(length, m_item->height(), m_item, true);
 		}
 		else
 		{
-			if ((m_item->asLine()) && (m_lineMode))
-			{
-				w += m_doc->rulerXoffset;
-				h += m_doc->rulerYoffset;
-				if (m_doc->guidesPrefs().rulerMode)
-				{
-					w += m_doc->currentPage()->xOffset();
-					h += m_doc->currentPage()->yOffset();
-				}
-				double r = atan2(h-y,w-x)*(180.0/M_PI);
-				w = sqrt(pow(w-x,2)+pow(h-y,2));
-				m_item->setXYPos(x, m_item->yPos(), true);
-				m_item->setRotation(r, true);
-				m_doc->sizeItem(w, m_item->height(), m_item, true);
-			}
-			else
-			{
-				ma.translate(m_item->xPos(), m_item->yPos());
-				ma.rotate(m_item->rotation());
-				int bp = basePointWidget->checkedId();
-				if (bp == 0)
-					base = m_item->xPos();
-				else if (bp == 2)
-					base = ma.m11() * (m_item->width() / 2.0) + ma.m21() * (m_item->height() / 2.0) + ma.dx();
-				else if (bp == 1)
-					base = ma.m11() * m_item->width() + ma.m21() * 0.0 + ma.dx();
-				else if (bp == 4)
-					base = ma.m11() * m_item->width() + ma.m21() * m_item->height() + ma.dx();
-				else if (bp == 3)
-					base = ma.m11() * 0.0 + ma.m21() * m_item->height() + ma.dx();
-				m_doc->moveItem(x - base, 0, m_item);
-			}
+			ma.translate(m_item->xPos(), m_item->yPos());
+			ma.rotate(m_item->rotation());
+			int bp = basePointWidget->checkedId();
+			if (bp == 0)
+				base = m_item->xPos();
+			else if (bp == 2)
+				base = ma.m11() * (m_item->width() / 2.0) + ma.m21() * (m_item->height() / 2.0) + ma.dx();
+			else if (bp == 1)
+				base = ma.m11() * m_item->width() + ma.m21() * 0.0 + ma.dx();
+			else if (bp == 4)
+				base = ma.m11() * m_item->width() + ma.m21() * m_item->height() + ma.dx();
+			else if (bp == 3)
+				base = ma.m11() * 0.0 + ma.m21() * m_item->height() + ma.dx();
+			m_doc->moveItem(x - base, 0, m_item);
 		}
-		m_doc->regionsChanged()->update(QRect());
-		m_doc->changed();
 	}
+	m_doc->regionsChanged()->update(QRect());
+	m_doc->changed();
 }
 
 void PropertiesPalette_XYZ::handleNewY()
@@ -751,12 +725,10 @@ void PropertiesPalette_XYZ::handleNewY()
 	if (!m_haveDoc || !m_haveItem || !m_ScMW || m_ScMW->scriptIsRunning())
 		return;
 
-	double x,y,w,h, gx, gy, gh, gw, base;
+	double x, y, gx, gy, gh, gw, base;
 	QTransform ma;
 	x = xposSpin->value() / m_unitRatio;
 	y = yposSpin->value() / m_unitRatio;
-	w = widthSpin->value() / m_unitRatio;
-	h = heightSpin->value() / m_unitRatio;
 	base = 0;
 	x += m_doc->rulerXoffset;
 	y += m_doc->rulerYoffset;
@@ -789,20 +761,12 @@ void PropertiesPalette_XYZ::handleNewY()
 	{
 		if ((m_item->asLine()) && (m_lineMode))
 		{
-			w += m_doc->rulerXoffset;
-			h += m_doc->rulerYoffset;
-			if (m_doc->guidesPrefs().rulerMode)
-			{
-				w += m_doc->currentPage()->xOffset();
-				h += m_doc->currentPage()->yOffset();
-			}
-			double r = atan2(h-y,w-x)*(180.0/M_PI);
-			w = sqrt(pow(w-x,2)+pow(h-y,2));
-			m_doc->moveItem(0, y - m_item->yPos(), m_item);
+			QPointF endPoint = m_item->asLine()->endPoint();
+			double r = atan2(endPoint.y() - y, endPoint.x() - m_item->xPos()) * (180.0 / M_PI);
+			double length = sqrt(pow(endPoint.x() - m_item->xPos(), 2) + pow(endPoint.y() - y, 2));
 			m_item->setXYPos(m_item->xPos(), y, true);
 			m_item->setRotation(r, true);
-			m_doc->sizeItem(w, m_item->height(), m_item, true);
-			m_doc->rotateItem(r, m_item);
+			m_doc->sizeItem(length, m_item->height(), m_item, true);
 		}
 		else
 		{
@@ -831,7 +795,7 @@ void PropertiesPalette_XYZ::handleNewW()
 	if (!m_haveDoc || !m_haveItem || !m_ScMW || m_ScMW->scriptIsRunning())
 		return;
 	
-	double x,y,w,h, gx, gy, gh, gw;
+	double x, y, w, h, gx, gy, gh, gw;
 	x = xposSpin->value() / m_unitRatio;
 	y = yposSpin->value() / m_unitRatio;
 	w = widthSpin->value() / m_unitRatio;
@@ -869,9 +833,9 @@ void PropertiesPalette_XYZ::handleNewW()
 		{
 			if (m_lineMode)
 			{
-				double r = atan2(h-y,w-x)*(180.0/M_PI);
+				double r = atan2(h - y, w - x) * (180.0 / M_PI);
 				m_item->setRotation(r, true);
-				w = sqrt(pow(w-x,2)+pow(h-y,2));
+				w = sqrt(pow(w - x, 2) + pow(h - y, 2));
 			}
 			m_doc->sizeItem(w, m_item->height(), m_item, true, true, false);
 		}
@@ -951,9 +915,9 @@ void PropertiesPalette_XYZ::handleNewH()
 		{
 			if (m_lineMode)
 			{
-				double r = atan2(h-y,w-x)*(180.0/M_PI);
+				double r = atan2(h - y, w - x) * (180.0 / M_PI);
 				m_item->setRotation(r, true);
-				w = sqrt(pow(w-x,2)+pow(h-y,2));
+				w = sqrt(pow(w - x, 2) + pow(h - y, 2));
 			}
 			m_doc->sizeItem(w, m_item->height(), m_item, true, true, false);
 		}
@@ -1064,7 +1028,6 @@ void PropertiesPalette_XYZ::handleBasePoint(int m)
 		m_doc->setRotationMode(m);
 		if (m_doc->m_Selection->isMultipleSelection())
 		{
-			m_doc->m_Selection->setGroupRect();
 			m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
 			if (m == 0)
 			{
@@ -1280,6 +1243,37 @@ void PropertiesPalette_XYZ::changeEvent(QEvent *e)
 		QWidget::changeEvent(e);
 }
 
+void PropertiesPalette_XYZ::iconSetChange()
+{
+	IconManager& im = IconManager::instance();
+
+	levelUp->setIcon(im.loadIcon("16/go-up.png"));
+	levelDown->setIcon(im.loadIcon("16/go-down.png"));
+	levelTop->setIcon(im.loadIcon("16/go-top.png"));
+	levelBottom->setIcon(im.loadIcon("16/go-bottom.png"));
+
+	doGroup->setIcon(im.loadIcon("group.png"));
+	doUnGroup->setIcon(im.loadIcon("ungroup.png"));
+
+	flipH->setIcon(im.loadIcon("16/flip-object-horizontal.png"));
+	flipV->setIcon(im.loadIcon("16/flip-object-vertical.png"));
+	
+	QIcon a = QIcon();
+	a.addPixmap(im.loadPixmap("16/lock.png"), QIcon::Normal, QIcon::On);
+	a.addPixmap(im.loadPixmap("16/lock-unlocked.png"), QIcon::Normal, QIcon::Off);
+	doLock->setIcon(a);
+
+	QIcon a2 = QIcon();
+	a2.addPixmap(im.loadPixmap("NoPrint.png"), QIcon::Normal, QIcon::On);
+	a2.addPixmap(im.loadPixmap("16/document-print.png"), QIcon::Normal, QIcon::Off);
+	noPrint->setIcon(a2);
+
+	QIcon a3 = QIcon();
+	a3.addPixmap(im.loadPixmap("framenoresize.png"), QIcon::Normal, QIcon::On);
+	a3.addPixmap(im.loadPixmap("frameresize.png"), QIcon::Normal, QIcon::Off);
+	noResize->setIcon(a3);
+}
+
 void PropertiesPalette_XYZ::languageChange()
 {
 	setWindowTitle( tr("Properties"));
