@@ -58,6 +58,7 @@ void PropertyWidget_FontFeatures::showFontFeatures(const QString& s, const QStri
 	QStringList fontFeatures = s.split(',');
 	ContextualCheck->setChecked(true);
 	CommonCheck->setChecked(true);
+	SlashedZeroCheck->setEnabled(true);
 	for (int i = 0; i < fontFeatures.count(); i++)
 	{
 		if (fontFeatures[i] == "-clig")
@@ -141,6 +142,11 @@ void PropertyWidget_FontFeatures::showFontFeatures(const QString& s, const QStri
 		else if (fontFeatures[i] == "+ss20")
 			StyleSet20->setChecked(true);
 	}
+	if (OldStyleRadio->isChecked())
+	{
+		SlashedZeroCheck->setChecked(false);
+		SlashedZeroCheck->setEnabled(false);
+	}
 }
 
 void PropertyWidget_FontFeatures::handleFontFeatures()
@@ -624,11 +630,11 @@ void PropertyWidget_FontFeatures::configureWidgets()
 	bool enabled = false;
 	if (m_item && m_doc)
 	{
-		if (m_item->asPathText() || m_item->asTextFrame() || m_item->asTable())
+		if (m_item->isPathText() || m_item->isTextFrame() || m_item->isTable())
 			enabled = true;
 		if ((m_item->isGroup()) && (!m_item->isSingleSel))
 			enabled = false;
-		if (m_item->asOSGFrame() || m_item->asSymbolFrame())
+		if (m_item->isOSGFrame() || m_item->isSymbol())
 			enabled = false;
 		if (m_doc->m_Selection->count() > 1)
 			enabled = false;
@@ -707,7 +713,7 @@ void PropertyWidget_FontFeatures::setCurrentItem(PageItem *item)
 
 	if (m_item)
 	{
-		if (m_item->asTextFrame() || m_item->asPathText() || m_item->asTable())
+		if (m_item->isTextFrame() || m_item->isPathText() || m_item->isTable())
 		{
 			ParagraphStyle parStyle =  m_item->itemText.defaultStyle();
 			if (m_doc->appMode == modeEdit)
