@@ -12,16 +12,17 @@ for which a new license (GPL+exception) is in place.
 #include "appmodehelper.h"
 #include "appmodes.h"
 #include "iconmanager.h"
+#include "localemgr.h"
 #include "pageitem.h"
 #include "pageitem_table.h"
 #include "scribus.h"
+#include "scribusapp.h"
 #include "scribusdoc.h"
 #include "selection.h"
 #include "ui/sctreewidget.h"
-#include "units.h"
 #include "util.h"
 
-PropertyWidget_ParEffect::PropertyWidget_ParEffect(QWidget *parent) : QFrame(parent), m_enhanced(nullptr), m_item(nullptr), m_ScMW(nullptr)
+PropertyWidget_ParEffect::PropertyWidget_ParEffect(QWidget *parent) : QFrame(parent)
 {
 	setupUi(this);
 	setFrameStyle(QFrame::Box | QFrame::Plain);
@@ -32,7 +33,7 @@ PropertyWidget_ParEffect::PropertyWidget_ParEffect(QWidget *parent) : QFrame(par
 	dropCapLines->setValue(2);
 
 	if (m_doc)
-		peCharStyleCombo->updateFormatList();
+		peCharStyleCombo->updateStyleList();
 	fillBulletStrEditCombo();
 	enableParEffect(false);
 	bulletCharTableButton->setIcon(IconManager::instance().loadIcon("22/insert-table.png"));
@@ -42,6 +43,8 @@ PropertyWidget_ParEffect::PropertyWidget_ParEffect(QWidget *parent) : QFrame(par
 	numLevelSpin->setMaximum(3);
 	dropCapLines->setMinimum(2);
 	dropCapLines->setMaximum(99);
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 }
 
 void PropertyWidget_ParEffect::setMainWindow(ScribusMainWindow* mw)
@@ -94,7 +97,7 @@ void PropertyWidget_ParEffect::setCurrentItem(PageItem *item)
 
 	if (!m_item) return;
 
-	if (m_item->asTextFrame() || m_item->asPathText() || m_item->asTable())
+	if (m_item->isTextFrame() || m_item->isPathText() || m_item->isTable())
 	{
 		configureWidgets();
 		ParagraphStyle parStyle =  m_item->itemText.defaultStyle();
@@ -105,6 +108,12 @@ void PropertyWidget_ParEffect::setCurrentItem(PageItem *item)
 	}
 }
 
+void PropertyWidget_ParEffect::iconSetChange()
+{
+	IconManager& iconManager = IconManager::instance();
+	bulletCharTableButton->setIcon(iconManager.loadIcon("22/insert-table.png"));
+}
+
 void PropertyWidget_ParEffect::unitChange()
 {
 	if (!m_doc)
@@ -118,6 +127,12 @@ void PropertyWidget_ParEffect::unitChange()
 	peOffset->blockSignals(sigBlocked);
 }
 
+void PropertyWidget_ParEffect::localeChange()
+{
+	const QLocale& l(LocaleManager::instance().userPreferredLocale());
+	peOffset->setLocale(l);
+}
+
 void PropertyWidget_ParEffect::fillNumerationsCombo()
 {
 	QStringList numNames;
@@ -125,7 +140,11 @@ void PropertyWidget_ParEffect::fillNumerationsCombo()
 	{
 		const auto numerationKeys = m_doc->numerations.keys();
 		for (const QString& numName : numerationKeys)
+		{
+			if (numName.isEmpty())
+				continue;
 			numNames.append(numName);
+		}
 		numNames.sort();
 	}
 	numNames.prepend("<local block>");
@@ -135,13 +154,13 @@ void PropertyWidget_ParEffect::fillNumerationsCombo()
 
 void PropertyWidget_ParEffect::updateCharStyles()
 {
-	peCharStyleCombo->updateFormatList();
+	peCharStyleCombo->updateStyleList();
 }
 
 void PropertyWidget_ParEffect::showCharStyle(const QString& name)
 {
 	bool blocked = peCharStyleCombo->blockSignals(true);
-	peCharStyleCombo->setFormat(name);
+	peCharStyleCombo->setStyle(name);
 	peCharStyleCombo->blockSignals(blocked);
 }
 
@@ -265,7 +284,6 @@ void PropertyWidget_ParEffect::updateStyle(const ParagraphStyle& newPStyle)
 		enablePE = false;
 
 	QString numName = numComboBox->currentText();
-	int nFormat = 0;
 	dropCapLines->setValue(newPStyle.dropCapLines());
 	bulletStrEdit->setEditText(newPStyle.bulletStr());
 	numName = newPStyle.numName();
@@ -274,10 +292,10 @@ void PropertyWidget_ParEffect::updateStyle(const ParagraphStyle& newPStyle)
 	numComboBox->setCurrentIndex(numComboBox->findText(numName));
 	NumStruct * numS = m_doc->numerations.value(numName);
 	if (numS)
-		numLevelSpin->setMaximum(numS->m_counters.count()+1);
+		numLevelSpin->setMaximum(numS->m_counters.count() + 1);
 	else
 		numLevelSpin->setMaximum(3);
-	numLevelSpin->setValue(newPStyle.numLevel() +1);
+	numLevelSpin->setValue(newPStyle.numLevel() + 1);
 	numPrefix->setText(newPStyle.numPrefix());
 	numSuffix->setText(newPStyle.numSuffix());
 	numStart->setValue(newPStyle.numStart());
@@ -333,7 +351,7 @@ void PropertyWidget_ParEffect::configureWidgets()
 		PageItem_TextFrame *textItem = m_item->asTextFrame();
 		if (m_doc->appMode == modeEditTable)
 			textItem = m_item->asTable()->activeCell().textFrame();
-		if (textItem || m_item->asPathText())
+		if (textItem || m_item->isPathText())
 			enabled = true;
 	}
 	setEnabled(enabled);
@@ -401,7 +419,7 @@ void PropertyWidget_ParEffect::handleParEffectUse()
 		newStyle.setHasNum(true);
 		newStyle.setNumName(numComboBox->currentText());
 		newStyle.setNumFormat(numFormatCombo->currentFormat());
-		newStyle.setNumLevel(numLevelSpin->value() -1);
+		newStyle.setNumLevel(numLevelSpin->value() - 1);
 		newStyle.setNumStart(numStart->value());
 		newStyle.setNumPrefix(numPrefix->text());
 		newStyle.setNumSuffix(numSuffix->text());
@@ -460,8 +478,8 @@ void PropertyWidget_ParEffect::handleNumName(const QString& numName)
 	{
 		NumStruct * numS = m_doc->numerations.value(numName);
 		Q_ASSERT(numS);
-		int level = qMin(numLevelSpin->value(), numS->m_counters.count()) -1;
-		numLevelSpin->setValue(level +1);
+		int level = qMin(numLevelSpin->value(), numS->m_counters.count()) - 1;
+		numLevelSpin->setValue(level + 1);
 		newStyle.setNumLevel(level);
 		Numeration num = numS->m_nums[level];
 		numFormatCombo->setCurrentFormat(num.numFormat);
@@ -627,7 +645,7 @@ void PropertyWidget_ParEffect::closeEnhanced(bool show)
 	disconnect(m_enhanced, SIGNAL(insertSpecialChars(const QVector<uint> &)), this, SLOT(insertSpecialChars(const QVector<uint> &)));
 	disconnect(m_enhanced, SIGNAL(paletteShown(bool)), bulletCharTableButton, SLOT(setChecked(bool)));
 	m_enhanced->close();
-	delete m_enhanced;
+	m_enhanced->deleteLater();
 	m_enhanced = nullptr;
 }
 
