@@ -5,19 +5,18 @@ a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
 
-
+#include <QLocale>
 #include "appmodes.h"
 #include "iconmanager.h"
+#include "localemgr.h"
 #include "pageitem_table.h"
 #include "propertywidget_textcolor.h"
 #include "scribus.h"
+#include "scribusapp.h"
 #include "selection.h"
 
 PropertyWidget_TextColor::PropertyWidget_TextColor(QWidget* parent) : QFrame(parent)
 {
-	m_item = nullptr;
-	m_ScMW = nullptr;
-
 	setupUi(this);
 
 	setFrameStyle(QFrame::Box | QFrame::Plain);
@@ -27,29 +26,28 @@ PropertyWidget_TextColor::PropertyWidget_TextColor(QWidget* parent) : QFrame(par
 
 	fillLayout->setAlignment( Qt::AlignLeft );
 	fillColor->setPixmapType(ColorCombo::fancyPixmaps);
-	fillIcon->setPixmap(IconManager::instance().loadPixmap("16/color-fill.png"));
 	fillIcon->setScaledContents( false );
-	fillShadeLabel->setPixmap(IconManager::instance().loadPixmap("shade.png"));
 
 	strokeLayout->setAlignment( Qt::AlignLeft );
 	strokeColor->setPixmapType(ColorCombo::fancyPixmaps);
-	strokeIcon->setPixmap(IconManager::instance().loadPixmap("16/color-stroke.png"));
 	strokeIcon->setScaledContents( false );
-	strokeShadeLabel->setPixmap(IconManager::instance().loadPixmap("shade.png"));
 
 	backLayout->setAlignment( Qt::AlignLeft );
 	backColor->setPixmapType(ColorCombo::fancyPixmaps);
-	backIcon->setPixmap(IconManager::instance().loadPixmap("16/color-fill.png"));
 	backIcon->setScaledContents( false );
-	backShadeLabel->setPixmap(IconManager::instance().loadPixmap("shade.png"));
 
 	effectsLayout->setAlignment( Qt::AlignLeft );
 
+	iconSetChange();
 	languageChange();
 
 	strokeIcon->setEnabled(false);
 	strokeColor->setEnabled(false);
 	strokeShade->setEnabled(false);
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+	connect(ScQApp, SIGNAL(localeChanged()), this, SLOT(localeChange()));
+
 }
 
 void PropertyWidget_TextColor::setMainWindow(ScribusMainWindow *mw)
@@ -106,10 +104,10 @@ void PropertyWidget_TextColor::setCurrentItem(PageItem *item)
 
 	if (m_item == nullptr)
 		return;
-	if (!m_item->isTable() && !m_item->isTextFrame() && !m_item->asPathText())
+	if (!m_item->isTable() && !m_item->isTextFrame() && !m_item->isPathText())
 		return;
 
-	if (m_item->asTextFrame() || m_item->asPathText() || m_item->asTable())
+	if (m_item->isTextFrame() || m_item->isPathText() || m_item->isTable())
 	{
 		ParagraphStyle parStyle =  m_item->itemText.defaultStyle();
 		if (m_doc->appMode == modeEdit || m_doc->appMode == modeEditTable)
@@ -162,11 +160,11 @@ void PropertyWidget_TextColor::configureWidgets()
 	bool enabled = false;
 	if (m_item && m_doc)
 	{
-		if (m_item->asPathText() || m_item->asTextFrame() || m_item->asTable())
+		if (m_item->isPathText() || m_item->isTextFrame() || m_item->isTable())
 			enabled = true;
 		if ((m_item->isGroup()) && (!m_item->isSingleSel))
 			enabled = false;
-		if (m_item->asOSGFrame() || m_item->asSymbolFrame())
+		if (m_item->isOSGFrame() || m_item->isSymbol())
 			enabled = false;
 		if (m_doc->m_Selection->count() > 1)
 			enabled = false;
@@ -260,49 +258,28 @@ void PropertyWidget_TextColor::showStrikeThru(double p, double w)
 	textEffects->StrikeVal->LWidth->showValue(w / 10.0);
 }
 
-void PropertyWidget_TextColor::showTextColors(const QString& p, const QString& b, const QString& bc, double shp, double shb, double sbc)
+void PropertyWidget_TextColor::showTextColors(const QString& strokeCol, const QString& fillCol, const QString& backCol, double strokeShd, double fillShd, double backShd)
 {
 	if (!m_doc || !m_item || !m_ScMW || m_ScMW->scriptIsRunning())
 		return;
-	ColorList::Iterator it;
-	int c = 0;
-	fillShade->setValue(qRound(shb));
-	strokeShade->setValue(qRound(shp));
-	backShade->setValue(qRound(sbc));
-	if ((b != CommonStrings::None) && (!b.isEmpty()))
-	{
-		c++;
-		for (it = m_doc->PageColors.begin(); it != m_doc->PageColors.end(); ++it)
-		{
-			if (it.key() == b)
-				break;
-			c++;
-		}
-	}
-	fillColor->setCurrentIndex(c);
-	c = 0;
-	if ((p != CommonStrings::None) && (!p.isEmpty()))
-	{
-		for (it = m_doc->PageColors.begin(); it != m_doc->PageColors.end(); ++it)
-		{
-			if (it.key() == p)
-				break;
-			c++;
-		}
-	}
-	strokeColor->setCurrentIndex(c);
-	c = 0;
-	if ((bc != CommonStrings::None) && (!bc.isEmpty()))
-	{
-		c++;
-		for (it = m_doc->PageColors.begin(); it != m_doc->PageColors.end(); ++it)
-		{
-			if (it.key() == bc)
-				break;
-			c++;
-		}
-	}
-	backColor->setCurrentIndex(c);
+
+	QSignalBlocker fillShadeBlocker(fillShade);
+	QSignalBlocker strokeShadeBlocker(strokeShade);
+	QSignalBlocker backShadeBlocker(backShade);
+	QSignalBlocker fillColorBlocker(fillColor);
+	QSignalBlocker strokeColorBlocker(strokeColor);
+	QSignalBlocker backColorBlocker(backColor);
+
+	fillShade->setValue(qRound(fillShd));
+	strokeShade->setValue(qRound(strokeShd));
+	backShade->setValue(qRound(backShd));
+
+	if (!fillCol.isEmpty())
+		fillColor->setCurrentColor(fillCol);
+	if (!strokeCol.isEmpty())
+		strokeColor->setCurrentColor(strokeCol);
+	if (!backCol.isEmpty())
+		backColor->setCurrentColor(backCol);
 }
 
 void PropertyWidget_TextColor::showTextEffects(int s)
@@ -513,8 +490,34 @@ void PropertyWidget_TextColor::changeEvent(QEvent *e)
 	QWidget::changeEvent(e);
 }
 
+void PropertyWidget_TextColor::iconSetChange()
+{
+	IconManager& iconManager = IconManager::instance();
+
+	fillIcon->setPixmap(iconManager.loadPixmap("16/color-fill.png"));
+	fillShadeLabel->setPixmap(iconManager.loadPixmap("shade.png"));
+
+	strokeIcon->setPixmap(iconManager.loadPixmap("16/color-stroke.png"));
+	strokeShadeLabel->setPixmap(iconManager.loadPixmap("shade.png"));
+
+	backIcon->setPixmap(iconManager.loadPixmap("16/color-fill.png"));
+	backShadeLabel->setPixmap(iconManager.loadPixmap("shade.png"));
+}
+
 void PropertyWidget_TextColor::languageChange()
 {
 	retranslateUi(this);
 	textEffects->languageChange();
 }
+
+void PropertyWidget_TextColor::localeChange()
+{
+	const QLocale& l(LocaleManager::instance().userPreferredLocale());
+	textEffects->ShadowVal->Xoffset->setLocale(l);
+	textEffects->ShadowVal->Yoffset->setLocale(l);
+	textEffects->OutlineVal->LWidth->setLocale(l);
+	textEffects->UnderlineVal->LPos->setLocale(l);
+	textEffects->UnderlineVal->LWidth->setLocale(l);
+	textEffects->StrikeVal->LPos->setLocale(l);
+	textEffects->StrikeVal->LWidth->setLocale(l);
+}
