@@ -46,8 +46,6 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 #include "util_file.h"
 
-extern ScribusQApp* ScQApp;
-
 ResourceManager::ResourceManager(QWidget* parent)
 {
 	setupUi(this);
@@ -939,10 +937,10 @@ void ResourceManager::updateDownloadLists()
 	downloadProgressBar->setVisible(true);
 	dataReceivedLabel->setVisible(true);
 	downloadProgressBar->setRange(0, m_dataFiles.count());
-	for (QString f : qAsConst(m_dataFiles))
-		ScQApp->dlManager()->addURL("http://services.scribus.net/"+f, true, ScPaths::downloadDir(), ScPaths::downloadDir());
-	for (QString f : qAsConst(m_dataFiles))
-		ScQApp->dlManager()->addURL("http://services.scribus.net/"+f+".sha256", true, ScPaths::downloadDir(), ScPaths::downloadDir());
+	for (const QString& f : qAsConst(m_dataFiles))
+		ScQApp->dlManager()->addURL("http://services.scribus.net/" + f, true, ScPaths::downloadDir(), ScPaths::downloadDir());
+	for (const QString& f : qAsConst(m_dataFiles))
+		ScQApp->dlManager()->addURL("http://services.scribus.net/" + f + ".sha256", true, ScPaths::downloadDir(), ScPaths::downloadDir());
 	connect(ScQApp->dlManager(), SIGNAL(finished()), this, SLOT(downloadListFinished()));
 	connect(ScQApp->dlManager(), SIGNAL(fileReceived(const QString&)), this, SLOT(updateProgressBar()));
 	connect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(updateProgressBar()));
