@@ -40,12 +40,10 @@ for which a new license (GPL+exception) is in place.
 
 ScDockPalette::ScDockPalette( QWidget * parent, const QString& prefsContext, Qt::WindowFlags f)
 #if defined(Q_OS_MAC) || defined(Q_OS_WIN)
-	: QDockWidget ( parent, f | Qt::Tool  | Qt::CustomizeWindowHint | Qt::WindowMinMaxButtonsHint | Qt::WindowCloseButtonHint ),
+	: QDockWidget ( parent, f | Qt::Tool  | Qt::CustomizeWindowHint | Qt::WindowMinMaxButtonsHint | Qt::WindowCloseButtonHint )
 #else
-	: QDockWidget ( parent, f | Qt::Tool  | Qt::CustomizeWindowHint ),
+	: QDockWidget ( parent, f | Qt::Tool  | Qt::CustomizeWindowHint )
 #endif
-	m_palettePrefs(nullptr),
-	m_visibleOnStartup(false)
 {
 	if (PrefsManager::instance().appPrefs.uiPrefs.useSmallWidgets)
 	{
@@ -62,8 +60,7 @@ ScDockPalette::ScDockPalette( QWidget * parent, const QString& prefsContext, Qt:
 						QToolBox::tab { font-size: 10px; padding: 0px; margin: 0px; } \
 			  		");
 	}
-	m_originalParent=parent;
-	m_tempParent=nullptr;
+	m_originalParent = parent;
 	setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
 	setWindowIcon(IconManager::instance().loadPixmap("AppIcon.png"));
 	setPrefsContext(prefsContext);
@@ -256,7 +253,7 @@ void ScDockPalette::storeDockState()
 	{
 		m_palettePrefs->set("floating", isFloating());
 		Qt::DockWidgetArea area = Qt::NoDockWidgetArea;
-		QMainWindow* mainWindow = dynamic_cast<QMainWindow*>(parent());
+		QMainWindow* mainWindow = qobject_cast<QMainWindow*>(parent());
 		if (mainWindow)
 			area = mainWindow->dockWidgetArea(this);
 		m_palettePrefs->set("area", (int) area);
