@@ -6,20 +6,22 @@ for which a new license (GPL+exception) is in place.
 */
 #include "search.h"
 
+#include <QCheckBox>
+#include <QComboBox>
+#include <QGroupBox>
 #include <QHBoxLayout>
 #include <QGridLayout>
 #include <QVBoxLayout>
-#include <QListView>
-#include <QGroupBox>
-#include <QCheckBox>
-#include <QLineEdit>
-#include <QComboBox>
-#include <QPushButton>
 #include <QLabel>
-#include <QPixmap>
+#include <QLineEdit>
+#include <QListView>
 #include <QMessageBox>
+#include <QPixmap>
+#include <QPushButton>
+#include <QScopedValueRollback>
 
 #include "appmodes.h"
+#include "canvas.h"
 #include "colorcombo.h"
 #include "colorlistbox.h"
 #include "commonstrings.h"
@@ -30,22 +32,23 @@ for which a new license (GPL+exception) is in place.
 #include "prefsmanager.h"
 #include "scpage.h"
 #include "scribus.h"
+#include "scribusview.h"
 #include "scrspinbox.h"
+#include "selection.h"
 #include "shadebutton.h"
 #include "styleselect.h"
 #include "ui/storyeditor.h"
+#include "undomanager.h"
+#include "undotransaction.h"
 #include "util.h"
 #include "util_text.h"
 
 SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* ite, bool mode )
-	: QDialog( parent ),
-	matchesFound(0)
+	: QDialog( parent )
 {
 	m_item = ite;
 	m_doc = doc;
-	m_notFound = false;
 	m_itemMode = mode;
-	m_firstMatchPosition = -1;
 
 	setModal(true);
 	setWindowTitle( tr( "Search/Replace" ) );
@@ -100,7 +103,7 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* ite, b
 	SStyleVal->setEditable(false);
 	for (int x = 0; x < doc->paragraphStyles().count(); ++x)
 		SStyleVal->addItem(doc->paragraphStyles()[x].name());
-	QListView *tmpView = dynamic_cast<QListView*>(SStyleVal->view()); Q_ASSERT(tmpView);
+	QListView *tmpView = qobject_cast<QListView*>(SStyleVal->view()); Q_ASSERT(tmpView);
 	int tmpWidth = tmpView->sizeHintForColumn(0);
 	if (tmpWidth > 0)
 		tmpView->setMinimumWidth(tmpWidth + 24);
@@ -113,7 +116,7 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* ite, b
 	size_t ar_sty = sizeof(tmp_sty) / sizeof(*tmp_sty);
 	for (uint a = 0; a < ar_sty; ++a)
 		SAlignVal->addItem( tmp_sty[a] );
-	tmpView = dynamic_cast<QListView*>(SAlignVal->view()); Q_ASSERT(tmpView);
+	tmpView = qobject_cast<QListView*>(SAlignVal->view()); Q_ASSERT(tmpView);
 	tmpWidth = tmpView->sizeHintForColumn(0);
 	if (tmpWidth > 0)
 		tmpView->setMinimumWidth(tmpWidth + 24);
@@ -199,7 +202,7 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* ite, b
 	RStyleVal->setEditable(false);
 	for (int x = 0; x < doc->paragraphStyles().count(); ++x)
 		RStyleVal->addItem(doc->paragraphStyles()[x].name());
-	tmpView = dynamic_cast<QListView*>(RStyleVal->view()); Q_ASSERT(tmpView);
+	tmpView = qobject_cast<QListView*>(RStyleVal->view()); Q_ASSERT(tmpView);
 	tmpWidth = tmpView->sizeHintForColumn(0);
 	if (tmpWidth > 0)
 		tmpView->setMinimumWidth(tmpWidth + 24);
@@ -210,7 +213,7 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* ite, b
 	RAlignVal->setEditable(false);
 	for (uint a = 0; a < ar_sty; ++a)
 		RAlignVal->addItem(tmp_sty[a]);
-	tmpView = dynamic_cast<QListView*>(RAlignVal->view()); Q_ASSERT(tmpView);
+	tmpView = qobject_cast<QListView*>(RAlignVal->view()); Q_ASSERT(tmpView);
 	tmpWidth = tmpView->sizeHintForColumn(0);
 	if (tmpWidth > 0)
 		tmpView->setMinimumWidth(tmpWidth + 24);
@@ -365,17 +368,15 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* ite, b
 
 void SearchReplace::slotSearch()
 {
-//	if (m_itemMode)
-//		m_doc->view()->slotDoCurs(false);
-	slotDoSearch();
+	doSearch();
+
 	if (m_itemMode)
-	{
-//		m_doc->view()->slotDoCurs(true);
 		m_item->update();
-	}
+	if (!m_found)
+		showNotFoundMessage();
 }
 
-void SearchReplace::slotDoSearch()
+void SearchReplace::doSearch()
 {
 	int maxChar = m_item->itemText.length() - 1;
 	DoReplace->setEnabled(false);
@@ -385,11 +386,11 @@ void SearchReplace::slotDoSearch()
 		m_item->itemText.deselectAll();
 		m_item->HasSel = false;
 	}
+
 	QString fCol = "";
 	QString sCol = "";
 	QString sFont = "";
 	QString sText = "";
-	m_notFound = true;
 	int sStyle = 0;
 	int sAlign = 0;
 	int sSize = 0;
@@ -399,6 +400,9 @@ void SearchReplace::slotDoSearch()
 	bool searchForReplace = false;
 	bool rep = false;
 	bool found = true;
+
+	m_found = true;
+
 	if ((RFill->isChecked()) || (RStroke->isChecked()) || (RStyle->isChecked()) || (RFont->isChecked())
 		|| (RStrokeS->isChecked()) || (RFillS->isChecked()) || (RSize->isChecked()) || (RText->isChecked())
 		|| (REffect->isChecked())  || (RAlign->isChecked()))
@@ -431,17 +435,18 @@ void SearchReplace::slotDoSearch()
 		sSize = qRound(SSizeVal->value() * 10);
 	if (sText.length() > 0)
 		found = false;
-
-	uint as = m_item->itemText.cursorPosition();
-	m_replStart = as;
+	
 	int a, textLen(0);
+	int cursorPos = m_item->itemText.cursorPosition();
+	m_replStart = cursorPos;
+
 	if (m_itemMode)
 	{
 		Qt::CaseSensitivity cs = Qt::CaseSensitive;
 		if (CaseIgnore->isChecked())
 			cs = Qt::CaseInsensitive;
 
-		for (a = as; a < m_item->itemText.length(); ++a)
+		for (a = cursorPos; a < m_item->itemText.length(); ++a)
 		{
 			found = true;
 			if (SText->isChecked())
@@ -525,20 +530,55 @@ void SearchReplace::slotDoSearch()
 			}
 			if (SText->isChecked())
 			{
-				for (int xx = m_replStart; xx < a+1; ++xx)
+				for (int xx = m_replStart; xx < a + 1; ++xx)
 					m_item->itemText.select(qMin(xx, maxChar), 1, false);
 				m_item->HasSel = false;
 			}
 		}
+		if (found && !m_replacingAll)
+		{
+			QPointF textCanvasPos;
+			int foundPos = m_item->itemText.cursorPosition();
+			if (m_item->itemText.selectionLength() > 0)
+				foundPos = m_item->itemText.startOfSelection();
+			bool cPosFound = m_doc->textCanvasPosition(m_item, foundPos, textCanvasPos);
+			if (cPosFound)
+			{
+				QRectF updateRect;
+				PageItem* textItem = m_item->frameOfChar(foundPos);
+				if (textItem != m_item)
+				{
+					updateRect = m_item->getVisualBoundingRect();
+					updateRect = updateRect.united(textItem->getVisualBoundingRect());
+					int selLength = m_item->itemText.selectionLength();
+					m_item->itemText.deselectAll();
+					m_item->HasSel = false;
+					m_doc->m_Selection->delaySignalsOn();
+					m_doc->m_Selection->removeItem(m_item);
+					m_doc->m_Selection->addItem(textItem);
+					m_item = textItem;
+					m_item->itemText.deselectAll();
+					if (selLength > 0)
+						m_item->itemText.select(foundPos, selLength);
+					m_item->itemText.setCursorPosition(foundPos + selLength);
+					m_item->HasSel = true;
+					m_doc->m_Selection->delaySignalsOff();
+				}
+				QRectF visibleCanvasRect = m_doc->view()->visibleCanvasRect();
+				if (!visibleCanvasRect.contains(textCanvasPos))
+					m_doc->view()->setCanvasCenterPos(textCanvasPos.x(), textCanvasPos.y());
+				if (!updateRect.isEmpty())
+					m_doc->regionsChanged()->update(updateRect.adjusted(-10.0, -10.0, 10.0, 10.0));
+			}
+		}
 		if ((!found) || (a == m_item->itemText.length()))
 		{
 			m_doc->DoDrawing = true;
 			m_item->update();
 			DoReplace->setEnabled(false);
 			AllReplace->setEnabled(false);
-			ScMessageBox::information(this, tr("Search/Replace"), tr("Search finished"));
 			m_item->itemText.setCursorPosition(0);
-			m_notFound = false;
+			m_found = false;
 		}
 	}
 	else if (m_doc->scMW()->CurrStED != nullptr)
@@ -662,15 +702,12 @@ void SearchReplace::slotDoSearch()
 				DoReplace->setEnabled(true);
 				AllReplace->setEnabled(true);
 			}
-			matchesFound++;
+			m_matchesFound++;
 			m_firstMatchPosition = storyTextEdit->textCursor().selectionStart();
 		}
 		else
 		{
-			ScMessageBox::information(this, tr("Search/Replace"),
-					tr("Search finished, found %1 matches").arg(matchesFound));
-			matchesFound = 0;
-			m_notFound = false;
+			m_found = false;
 			QTextCursor cursor = storyTextEdit->textCursor();
 			cursor.clearSelection();
 			cursor.movePosition(QTextCursor::Start, QTextCursor::MoveAnchor);
@@ -681,55 +718,57 @@ void SearchReplace::slotDoSearch()
 
 void SearchReplace::slotReplace()
 {
-//	if (m_itemMode)
-//		m_doc->view()->slotDoCurs(false);
-	slotDoReplace();
+	doReplace();
+
 	if (m_itemMode)
-	{
-//		m_doc->view()->slotDoCurs(true);
 		m_item->update();
-	}
+	if (!m_found)
+		showNotFoundMessage();
 }
 
-void SearchReplace::slotDoReplace()
+void SearchReplace::doReplace()
 {
 	if (m_itemMode)
 	{
-		QString repl, sear;
-		int cs, cx;
-		int textLen = 0;
+		UndoTransaction transaction;
+		if (UndoManager::undoEnabled())
+			transaction = UndoManager::instance()->beginTransaction(m_item->getUName(), m_item->getUPixmap());
+
 		if (RText->isChecked())
 		{
-			repl = RTextVal->text();
-			sear = STextVal->text();
-			textLen = m_item->itemText.selectionLength();
-			if (textLen == repl.length())
+			QString selectedText = m_item->itemText.selectedText();
+			QString repl = RTextVal->text();
+			if (UndoManager::undoEnabled())
 			{
-				for (cs = 0; cs < textLen; ++cs)
-					m_item->itemText.replaceChar(m_replStart+cs, repl[cs]);
-			}
-			else
-			{
-				if (textLen < repl.length())
+				UndoObject* undoTarget = m_item->isNoteFrame() ? dynamic_cast<UndoObject*>(m_item->doc()) : dynamic_cast<UndoObject*>(m_item);
+				if (selectedText.length() > 0)
 				{
-					for (cs = 0; cs < textLen; ++cs)
-						m_item->itemText.replaceChar(m_replStart+cs, repl[cs]);
-					for (cx = cs; cx < repl.length(); ++cx)
-						m_item->itemText.insertChars(m_replStart+cx, repl.mid(cx,1), true);
+					auto is = new ScItemState<CharStyle>(Um::DeleteText, "", Um::IDelete);
+					int selStart =  m_item->itemText.startOfSelection();
+					is->set("DELETE_FRAMETEXT");
+					is->set("ETEA",  QString("delete_frametext"));
+					is->set("TEXT_STR", selectedText);
+					is->set("START", m_item->itemText.startOfSelection());
+					is->setItem(m_item->itemText.charStyle(selStart));
+					if (m_item->isNoteFrame())
+						is->set("noteframeName", m_item->getUName());
+					UndoManager::instance()->action(undoTarget, is);
 				}
-				else
+				if (repl.length() > 0)
 				{
-					for (cs = 0; cs < repl.length(); ++cs)
-						m_item->itemText.replaceChar(m_replStart+cs, repl[cs]);
-					m_item->itemText.removeChars(m_replStart+cs, textLen - cs);
+					int selStart = qMin(m_item->itemText.cursorPosition(), m_item->itemText.startOfSelection());
+					auto ss = new SimpleState(Um::InsertText, "", Um::ICreate);
+					ss->set("INSERT_FRAMETEXT");
+					ss->set("ETEA", QString("insert_frametext"));
+					ss->set("TEXT_STR", repl);
+					ss->set("START", selStart);
+					UndoObject * undoTarget = m_item;
+					if (m_item->isNoteFrame())
+						ss->set("noteframeName", m_item->getUName());
+					UndoManager::instance()->action(undoTarget, ss);
 				}
 			}
-			m_item->itemText.deselectAll();
-			if (repl.length() > 0)
-			{
-				m_item->itemText.select(m_replStart, repl.length());
-				m_item->itemText.setCursorPosition(m_replStart + repl.length());
-			}
+			m_item->itemText.replaceSelection(repl);
 		}
 		if (RStyle->isChecked())
 		{
@@ -757,25 +796,24 @@ void SearchReplace::slotDoReplace()
 			m_doc->itemSelection_SetFont(RFontVal->currentText());
 		if (RSize->isChecked())
 			m_doc->itemSelection_SetFontSize(qRound(RSizeVal->value() * 10.0));
-		if (REffect->isChecked() && (m_item->itemText.selectionLength() > 0))
+		if (REffect->isChecked() && (m_item->itemText.hasSelection()))
 		{
 			int s = REffVal->getStyle() & ScStyle_UserStyles;
 			m_doc->currentStyle.charStyle().setFeatures(static_cast<StyleFlag>(s).featureList()); // ???
-			for (int a = 0; a < m_item->itemText.length(); ++a)
+			for (int i = 0; i < m_item->itemText.length(); ++i)
 			{
-				if (m_item->itemText.selected(a))
+				if (m_item->itemText.selected(i))
 				{
-//                    StyleFlag fl = m_item->itemText.charStyle(a).effects();
-//					fl &= static_cast<StyleFlag>(~1919);
-//					fl |= static_cast<StyleFlag>(s);
-//					m_item->itemText.item(a)->setFeatures(fl.featureList());
 					CharStyle newFeatures;
 					newFeatures.setFeatures(static_cast<StyleFlag>(s).featureList());
-					m_item->itemText.applyCharStyle(a, 1, newFeatures);
+					m_item->itemText.applyCharStyle(i, 1, newFeatures);
 				}
 			}
 		}
 		m_item->itemText.deselectAll();
+
+		if (transaction)
+			transaction.commit();
 	}
 	else if (m_doc->scMW()->CurrStED != nullptr)
 	{
@@ -830,7 +868,7 @@ void SearchReplace::slotDoReplace()
 	}
 	DoReplace->setEnabled(false);
 	AllReplace->setEnabled(false);
-	slotDoSearch();
+	doSearch();
 }
 
 int SearchReplace::firstMatchCursorPosition()
@@ -838,24 +876,55 @@ int SearchReplace::firstMatchCursorPosition()
 	return m_firstMatchPosition;
 }
 
+void SearchReplace::setSearchedText(const QString& text)
+{
+	if (SText->isChecked())
+		STextVal->setText(text);
+}
+
 void SearchReplace::slotReplaceAll()
 {
+	QScopedValueRollback<bool> replaceAllRollback(m_replacingAll, true);
+
 	if (m_itemMode)
-	{
-//		m_doc->view()->slotDoCurs(false);
 		m_doc->DoDrawing = false;
-	}
+
+	UndoTransaction undoTransaction;
+	if (m_itemMode && UndoManager::undoEnabled())
+		undoTransaction = UndoManager::instance()->beginTransaction(m_item->getUName(), m_item->getUPixmap());
+
 	do
 	{
-		slotDoReplace();
-//		slotDoSearch();
+		doReplace();
 	}
-	while (m_notFound);
+	while (m_found);
+
+	if (undoTransaction)
+		undoTransaction.commit();
+
 	if (m_itemMode)
 	{
 		m_doc->DoDrawing = true;
-//		m_doc->view()->slotDoCurs(true);
-		m_item->update();
+		if (m_item->isTextFrame())
+			m_item->asTextFrame()->invalidateLayout(true);
+		m_doc->regionsChanged()->update(QRectF());
+	}
+
+	showNotFoundMessage();
+}
+
+void SearchReplace::showNotFoundMessage()
+{
+	if (m_found)
+		return;
+
+	if (m_itemMode)
+		ScMessageBox::information(this, tr("Search/Replace"), tr("Search finished"));
+	else
+	{
+		ScMessageBox::information(this, tr("Search/Replace"),
+					tr("Search finished, found %1 matches").arg(m_matchesFound));
+		m_matchesFound = 0;
 	}
 }
 
@@ -1055,12 +1124,12 @@ void SearchReplace::updateReplaceButtonsState()
 	}
 	replaceEnabled |= RText->isChecked();
 	if (m_itemMode)
-		replaceEnabled &= (m_item->itemText.selectionLength() > 0);
+		replaceEnabled &= (m_item->itemText.hasSelection());
 	else if (m_doc->scMW()->CurrStED != nullptr)
 		replaceEnabled &= m_doc->scMW()->CurrStED->Editor->textCursor().hasSelection();
 	else
 		replaceEnabled = false;
-	replaceEnabled &= m_notFound;
+	replaceEnabled &= m_found;
 	DoReplace->setEnabled(replaceEnabled);
 	AllReplace->setEnabled(replaceEnabled);
 }
