@@ -11,29 +11,17 @@ for which a new license (GPL+exception) is in place.
 #include "langmgr.h"
 #include "prefsmanager.h"
 #include "scribus.h"
+#include "scribusapp.h"
 #include "smcstylewidget.h"
 #include "util.h"
 #include "units.h"
 
 
-SMCStyleWidget::SMCStyleWidget(QWidget *parent) :
-	m_Doc(nullptr)
+SMCStyleWidget::SMCStyleWidget(QWidget *parent)
 {
 	setupUi(this);
 
-	IconManager& im = IconManager::instance();
-	fontSizeLabel_->setPixmap(im.loadPixmap("zeichen.png"));
-	trackingLabel_->setPixmap(im.loadPixmap("textkern.png"));
-	widthSpaceLabel->setPixmap(im.loadPixmap("spacewidth.png"));
-	baselineOffsetLabel_->setPixmap(im.loadPixmap("textbase.png"));
-	hscaleLabel_->setPixmap(im.loadPixmap("textscaleh.png"));
-	vscaleLabel_->setPixmap(im.loadPixmap("textscalev.png"));
-	FillIcon->setPixmap(im.loadPixmap("16/color-fill.png"));
-	fillShadeLabel->setPixmap(im.loadPixmap("shade.png"));
-	StrokeIcon->setPixmap(im.loadPixmap("16/color-stroke.png"));
-	strokeShadeLabel->setPixmap(im.loadPixmap("shade.png"));
-	backIcon->setPixmap(im.loadPixmap("16/color-fill.png"));
-	backShadeLabel->setPixmap(im.loadPixmap("shade.png"));
+	iconSetChange();
 
 	fillColor_->setPixmapType(ColorCombo::fancyPixmaps);
 	fillColor_->clear();
@@ -52,6 +40,10 @@ SMCStyleWidget::SMCStyleWidget(QWidget *parent) :
 	strokeColor_->setEnabled(false);
 	fontfeaturesSetting->resetFontFeatures();
 
+	hyphenCharLineEdit->setMaxLength(1);
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+
 	connect(effects_, SIGNAL(State(int)), this, SLOT(slotColorChange()));
 	connect(fontFace_, SIGNAL(fontSelected(QString)), this, SLOT(slotEnableFontFeatures(QString)));
 }
@@ -66,6 +58,24 @@ void SMCStyleWidget::changeEvent(QEvent *e)
 		QWidget::changeEvent(e);
 }
 
+void SMCStyleWidget::iconSetChange()
+{
+	IconManager& im = IconManager::instance();
+
+	fontSizeLabel_->setPixmap(im.loadPixmap("zeichen.png"));
+	trackingLabel_->setPixmap(im.loadPixmap("textkern.png"));
+	widthSpaceLabel->setPixmap(im.loadPixmap("spacewidth.png"));
+	baselineOffsetLabel_->setPixmap(im.loadPixmap("textbase.png"));
+	hscaleLabel_->setPixmap(im.loadPixmap("textscaleh.png"));
+	vscaleLabel_->setPixmap(im.loadPixmap("textscalev.png"));
+	FillIcon->setPixmap(im.loadPixmap("16/color-fill.png"));
+	fillShadeLabel->setPixmap(im.loadPixmap("shade.png"));
+	StrokeIcon->setPixmap(im.loadPixmap("16/color-stroke.png"));
+	strokeShadeLabel->setPixmap(im.loadPixmap("shade.png"));
+	backIcon->setPixmap(im.loadPixmap("16/color-fill.png"));
+	backShadeLabel->setPixmap(im.loadPixmap("shade.png"));
+}
+
 void SMCStyleWidget::languageChange()
 {
 	QStringList languageList;
@@ -140,7 +150,7 @@ void SMCStyleWidget::fillLangComboFromList(const QStringList& langList)
 	language_->clear();
 	language_->addItems(langList);
 
-	QListView *tmpView = dynamic_cast<QListView*>(language_->view());
+	QListView *tmpView = qobject_cast<QListView*>(language_->view());
 	Q_ASSERT(tmpView);
 	int tmpWidth = tmpView->sizeHintForColumn(0);
 	if (tmpWidth > 0)
@@ -249,8 +259,17 @@ void SMCStyleWidget::show(CharStyle *cstyle, QList<CharStyle> &cstyles, const QS
 		smallestWordSpinBox->setValue(cstyle->hyphenWordMin(), cstyle->isInhHyphenWordMin());
 		smallestWordSpinBox->setParentValue(parent->hyphenWordMin());
 
-		hyphenCharLineEdit->setValue(QString::fromUcs4(&cstyle->hyphenChar(), 1), cstyle->isInhHyphenChar());
-		hyphenCharLineEdit->setParentValue(QString::fromUcs4(&parent->hyphenChar(), 1));
+		uint hyphenChar = cstyle->hyphenChar();
+		QString hyphenText;
+		if (hyphenChar)
+			hyphenText = QString::fromUcs4(&hyphenChar, 1);
+		hyphenCharLineEdit->setValue(hyphenText, cstyle->isInhHyphenChar());
+
+		uint parentHyphenChar = parent->hyphenChar();
+		QString parentHyphenText;
+		if (parentHyphenChar)
+			parentHyphenText = QString::fromUcs4(&parentHyphenChar, 1);
+		hyphenCharLineEdit->setParentValue(parentHyphenText);
 	}
 	else
 	{
@@ -270,7 +289,12 @@ void SMCStyleWidget::show(CharStyle *cstyle, QList<CharStyle> &cstyles, const QS
 		fontFace_->setCurrentFont(cstyle->font().scName());
 		fontfeaturesSetting->setFontFeatures(cstyle->fontFeatures(), cstyle->font().fontFeatures());
 		smallestWordSpinBox->setValue(cstyle->hyphenWordMin());
-		hyphenCharLineEdit->setValue(QString::fromUcs4(&cstyle->hyphenChar(), 1));
+
+		uint hyphenChar = cstyle->hyphenChar();
+		QString hyphenText;
+		if (hyphenChar)
+			hyphenText = QString::fromUcs4(&hyphenChar, 1);
+		hyphenCharLineEdit->setValue(hyphenText);
 	}
 
 	effects_->ShadowVal->Xoffset->setValue(cstyle->shadowXOffset() / 10.0);
@@ -658,7 +682,11 @@ void SMCStyleWidget::showHyphenChar(const QList<CharStyle *> &cstyles)
 		}
 		ch = cstyles[i]->hyphenChar();
 	}
-	hyphenCharLineEdit->setValue(QString::fromUcs4(&ch, 1));
+
+	QString hyphenText;
+	if (ch)
+		hyphenText = QString::fromUcs4(&ch, 1);
+	hyphenCharLineEdit->setValue(hyphenText);
 }
 
 void SMCStyleWidget::showParent(const QList<CharStyle*> &cstyles)
