@@ -16,10 +16,7 @@ for which a new license (GPL+exception) is in place.
 #include <QSignalBlocker>
 
 SMFontFeatures::SMFontFeatures(QWidget *parent)
-	: QWidget(parent),
-	  m_hasParent(false),
-	  m_useParentValue(false),
-	  m_pValue("")
+	: QWidget(parent)
 {
 	setupUi(this);
 	styleSetsMenu = new StylisticSetsMenu(this);
@@ -111,10 +108,12 @@ void SMFontFeatures::setFontFeatures(const QString& s, QStringList fontFeaturesL
 {
 	disconnectSignals();
 	m_hasParent = false;
-	m_pValue = "";
+	m_pValue.clear();
 
 	resetFontFeatures();
 	enableFontFeatures(fontFeaturesList);
+	SlashedZeroCheck->setEnabled(true);
+
 	QStringList fontFeatures = s.split(',');
 	for (int i = 0; i < fontFeatures.count(); i++)
 	{
@@ -207,6 +206,12 @@ void SMFontFeatures::setFontFeatures(const QString& s, QStringList fontFeaturesL
 		else if (fontFeatures[i] == "+ss20")
 			styleSetsMenu->actions().at(19)->setChecked(true);
 	}
+
+	if (numeralComboBox->currentData().toString() == "+onum")
+	{
+		SlashedZeroCheck->setChecked(false);
+		SlashedZeroCheck->setEnabled(false);
+	}
 }
 
 void SMFontFeatures::setFontFeatures(const QString& val, QStringList fontFeatures, bool isParentVal)
@@ -467,7 +472,7 @@ void SMFontFeatures::enableFontFeatures(const QStringList& fontFeatures)
 	stylisticSetsButton->setVisible(featureFlags & FontFeatures::StyleSetsMask);
 
 	if (ligaturesGroupBox->isHidden() && capitalsGroupBox->isHidden()
-			&& numeralsGroupBox && stylisticSetsButton->isHidden())
+			&& numeralsGroupBox->isHidden() && stylisticSetsButton->isHidden())
 	{
 		statusLabel->show();
 	}
@@ -621,6 +626,12 @@ void SMFontFeatures::slotNumeralComboBox()
 		f.setBold(true);
 		numeralComboBox->setFont(f);
 	}
+
+	// Old Style numerals do not support slashed zero
+	bool oldStyleNumeral = (numeralComboBox->currentData().toString() == "+onum");
+	if (oldStyleNumeral)
+		SlashedZeroCheck->setChecked(false);
+	SlashedZeroCheck->setEnabled(!oldStyleNumeral);
 }
 
 void SMFontFeatures::slotWidthComboBox()
