@@ -6,6 +6,7 @@ for which a new license (GPL+exception) is in place.
 */
 
 #include <QEvent>
+#include <QRegExp>
 
 #include "colorcombo.h"
 #include "smlinestyle.h"
@@ -21,7 +22,7 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 
 
-SMLineStyle::SMLineStyle() : m_doc(nullptr), m_widget(nullptr), m_twidget(nullptr), m_selectionIsDirty(false), m_unitRatio(1.0)
+SMLineStyle::SMLineStyle()
 {
 	
 }
@@ -55,7 +56,7 @@ void SMLineStyle::setCurrentDoc(ScribusDoc *doc)
 	m_doc = doc;
 	if (m_doc)
 	{
-		m_tmpLines = m_doc->MLineStyles;
+		m_tmpLines = m_doc->docLineStyles;
 		m_selection.clear();
 		if (m_widget)
 		{
@@ -73,7 +74,7 @@ void SMLineStyle::setCurrentDoc(ScribusDoc *doc)
 QList<StyleName> SMLineStyle::styles(bool reloadFromDoc)
 {
 	if (m_doc && reloadFromDoc) {
-		m_tmpLines = m_doc->MLineStyles;
+		m_tmpLines = m_doc->docLineStyles;
 	}
 
 	QList<StyleName> tmp;
@@ -91,7 +92,7 @@ void SMLineStyle::reload()
 		return;
 
 	m_selection.clear();
-	m_tmpLines = m_doc->MLineStyles;
+	m_tmpLines = m_doc->docLineStyles;
 }
 
 void SMLineStyle::selected(const QStringList &styleNames)
@@ -199,26 +200,46 @@ QString SMLineStyle::newStyle(const QString &fromStyle)
 	Q_ASSERT(m_tmpLines.contains(fromStyle));
 
 	multiLine ml(m_tmpLines[fromStyle]);
-	QString name = getUniqueName( tr("Clone of %1").arg(fromStyle));
+	QString name = getUniqueName(fromStyle);
 	m_tmpLines[name] = ml;
 	return name;
 }
 
 QString SMLineStyle::getUniqueName(const QString &name)
 {
-	int id = 0;
-	QString s = name;
+	// Unfortunately we have to copy the logic from StyleSet::generateUniqueCopyName
+	if (!m_tmpLines.contains(name))
+		return name;
 
-	while (m_tmpLines.contains(s))
+	QString newName(name);
+
+	// Search the string for (number) at the end and capture
+	// both the number and the text leading up to it sans brackets.
+	//     Copy of fred (5)
+	//     ^^^^^^^^^^^^  ^   (where ^ means captured)
+	static QRegExp rx("^(.*)\\s+\\((\\d+)\\)$");
+	int numMatches = rx.lastIndexIn(name);
+	// Add a (number) suffix to the end of the name. We start at the
+	// old suffix's value if there was one, or at 2 if there was not.
+	int suffixNum = 1;
+	QString prefix(newName);
+	if (numMatches != -1)
 	{
-		++id;
-		s = tr("%1 (%2)", "This for unique name when creating "
-			"a new character style. %1 will be the name "
-			"of the style and %2 will be a number forming "
-			"a style name like: New Style (2)").arg(name).arg(id);
+		// Already had a suffix; use the name w/o suffix for prefix and
+		// grab the old suffix value as a starting point.
+		QStringList matches = rx.capturedTexts();
+		prefix = matches[1];
+		suffixNum = matches[2].toInt();
 	}
+	// Keep on incrementing the suffix 'till we find a free name
+	do
+	{
+		suffixNum ++;
+		newName = prefix + " (" + QString::number(suffixNum) + ")";
+	}
+	while (m_tmpLines.contains(newName));
 
-	return s;
+	return newName;
 }
 
 void SMLineStyle::apply()
@@ -227,7 +248,7 @@ void SMLineStyle::apply()
 		return;
 
 	PageItem* ite;
-	m_doc->MLineStyles = m_tmpLines;
+	m_doc->docLineStyles = m_tmpLines;
 	QMap<QString, QString> replacement;
 	for (int i = 0; i < m_deleted.count(); ++i)
 	{
@@ -243,7 +264,7 @@ void SMLineStyle::apply()
 		ite = m_doc->DocItems.at(d);
 		if (!ite->NamedLStyle.isEmpty())
 		{
-			if (!m_doc->MLineStyles.contains(ite->NamedLStyle))
+			if (!m_doc->docLineStyles.contains(ite->NamedLStyle))
 				ite->NamedLStyle = replacement[ite->NamedLStyle];
 		}
 	}
@@ -252,7 +273,7 @@ void SMLineStyle::apply()
 		ite = m_doc->MasterItems.at(d1);
 		if (!ite->NamedLStyle.isEmpty())
 		{
-			if (!m_doc->MLineStyles.contains(ite->NamedLStyle))
+			if (!m_doc->docLineStyles.contains(ite->NamedLStyle))
 				ite->NamedLStyle = replacement[ite->NamedLStyle];
 		}
 	}
@@ -261,7 +282,7 @@ void SMLineStyle::apply()
 		ite = it.value();
 		if (!ite->NamedLStyle.isEmpty())
 		{
-			if (!m_doc->MLineStyles.contains(ite->NamedLStyle))
+			if (!m_doc->docLineStyles.contains(ite->NamedLStyle))
 				ite->NamedLStyle = replacement[ite->NamedLStyle];
 		}
 	}
