@@ -7,12 +7,14 @@ for which a new license (GPL+exception) is in place.
 
 #include <QEvent>
 
+
+#include "iconmanager.h"
 #include "numeration.h"
 #include "smpstylewidget.h"
 #include "scribus.h"
+#include "scribusapp.h"
 #include "units.h"
 #include "util.h"
-#include "iconmanager.h"
 #include "ui/charselectenhanced.h"
 
 static bool isEqual(double a, double b)
@@ -25,23 +27,15 @@ static bool isEqual(double a, double b)
 
 
 SMPStyleWidget::SMPStyleWidget(ScribusDoc* doc, StyleSet<CharStyle> *cstyles) :
-	m_hasParent(false),
-	m_parentDC(false),
-	m_parentBul(false),
-	m_parentNum(false),
 	m_Doc(doc),
-	m_currPStyle(nullptr)
+	m_cstyles(cstyles)
 {
-	m_cstyles = cstyles;
-
 	setupUi(this);
+
 	//Not used yet
 // 	optMarginCheckLeftProtruding->setVisible(false);
-	lineSpacingLabel->setPixmap(IconManager::instance().loadPixmap("linespacing2.png"));
-	spaceAboveLabel->setPixmap(IconManager::instance().loadPixmap("above.png") );
-	spaceBelowLabel->setPixmap(IconManager::instance().loadPixmap("below.png") );
-	backIcon->setPixmap(IconManager::instance().loadPixmap("16/color-fill.png"));
-	backShadeLabel->setPixmap(IconManager::instance().loadPixmap("shade.png"));
+
+	iconSetChange();
 	
 	backColor_->setPixmapType(ColorCombo::fancyPixmaps);
 	backColor_->clear();
@@ -66,7 +60,7 @@ SMPStyleWidget::SMPStyleWidget(ScribusDoc* doc, StyleSet<CharStyle> *cstyles) :
 	parEffectOffset->setSuffix(unitGetSuffixFromIndex(0));
 
 	fillBulletStrEditCombo();
-	bulletCharTableButton->setIcon(IconManager::instance().loadPixmap("22/insert-table.png"));
+
 	numStartSpin->setMinimum(1);
 	numStartSpin->setMaximum(9999);
 	numLevelSpin->setMinimum(1);
@@ -79,6 +73,8 @@ SMPStyleWidget::SMPStyleWidget(ScribusDoc* doc, StyleSet<CharStyle> *cstyles) :
 	minGlyphExtSpin->setSuffix(unitGetSuffixFromIndex(SC_PERCENT));
 	maxGlyphExtSpin->setSuffix(unitGetSuffixFromIndex(SC_PERCENT));
 
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+
 	connect(optMarginDefaultButton, SIGNAL(clicked()), this, SLOT(slotDefaultOpticalMargins()));
 	if (m_Doc)
 		connect(m_Doc->scMW(), SIGNAL(UpdateRequest(int)), this , SLOT(handleUpdateRequest(int)));
@@ -100,6 +96,19 @@ void SMPStyleWidget::changeEvent(QEvent *e)
 		QWidget::changeEvent(e);
 }
 
+void SMPStyleWidget::iconSetChange()
+{
+	IconManager& iconManager = IconManager::instance();
+
+	lineSpacingLabel->setPixmap(iconManager.loadPixmap("linespacing2.png"));
+	spaceAboveLabel->setPixmap(iconManager.loadPixmap("above.png") );
+	spaceBelowLabel->setPixmap(iconManager.loadPixmap("below.png") );
+	backIcon->setPixmap(iconManager.loadPixmap("16/color-fill.png"));
+	backShadeLabel->setPixmap(iconManager.loadPixmap("shade.png"));
+
+	bulletCharTableButton->setIcon(IconManager::instance().loadPixmap("22/insert-table.png"));
+}
+
 void SMPStyleWidget::languageChange()
 {
 	retranslateUi(this);
@@ -192,8 +201,12 @@ void SMPStyleWidget::fillNumerationsCombo()
 {
 	QStringList numNames;
 	const auto numerationKeys = m_Doc->numerations.keys();
-	foreach (const QString& numName, numerationKeys)
+	for (const QString& numName : numerationKeys)
+	{
+		if (numName.isEmpty())
+			continue;
 		numNames.append(numName);
+	}
 	numNames.sort();
 	numComboBox->clear();
 	numComboBox->insertItems(0, numNames);
@@ -203,11 +216,8 @@ void SMPStyleWidget::fillNumerationsCombo()
 void SMPStyleWidget::fillNumRestartCombo()
 {
 	numRestartCombo->clear();
-	numRestartCombo->addItem(tr("Document"));
-	numRestartCombo->addItem(tr("Section"));
-	numRestartCombo->addItem(tr("Story"));
-	numRestartCombo->addItem(tr("Page"));
-	numRestartCombo->addItem(tr("Frame"));
+	numRestartCombo->addItem(tr("Document"), static_cast<int>(NSRdocument));
+	numRestartCombo->addItem(tr("Story") , static_cast<int>(NSRstory));
 }
 
 void SMPStyleWidget::checkParEffectState()
@@ -374,8 +384,9 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		setWidgetBoldFont(numSuffixLabel, !pstyle->isInhNumSuffix());
 		numStartSpin->setValue(pstyle->numStart(), pstyle->isInhNumStart());
 		numStartSpin->setParentValue(parent->numStart());
-		numRestartCombo->setCurrentItem(pstyle->numRestart(), pstyle->isInhNumRestart());
-		numRestartCombo->setParentItem(parent->numRestart());
+		int numRestartIndex = numRestartCombo->findData(pstyle->numRestart());
+		numRestartCombo->setCurrentItem(numRestartIndex, pstyle->isInhNumRestart());
+		numRestartCombo->setParentItem(numRestartIndex);
 		numRestartOtherBox->setChecked(pstyle->numOther(), pstyle->isInhNumOther());
 		numRestartOtherBox->setParentValue(parent->numOther());
 		numRestartHigherBox->setChecked(pstyle->numHigher(), pstyle->isInhNumHigher());
@@ -429,7 +440,8 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		numSuffix->setText(pstyle->numSuffix());
 		setWidgetBoldFont(numSuffixLabel, false);
 		numStartSpin->setValue(pstyle->numStart());
-		numRestartCombo->setCurrentItem(pstyle->numRestart());
+		int numRestartIndex = numRestartCombo->findData(pstyle->numRestart());
+		numRestartCombo->setCurrentItem((numRestartIndex >= 0) ? numRestartIndex : 0);
 		numRestartOtherBox->setChecked(pstyle->numOther());
 		numRestartHigherBox->setChecked(pstyle->numHigher());
 
@@ -1211,7 +1223,7 @@ void SMPStyleWidget::closeEnhanced(bool show)
 	disconnect(m_enhanced, SIGNAL(insertSpecialChars(const QVector<uint> &)), this, SLOT(insertSpecialChars(const QVector<uint> &)));
 	disconnect(m_enhanced, SIGNAL(paletteShown(bool)), bulletCharTableButton, SLOT(setChecked(bool)));
 	m_enhanced->close();
-	delete m_enhanced;
+	m_enhanced->deleteLater();
 	m_enhanced = nullptr;
 }
 
