@@ -30,6 +30,7 @@ for which a new license (GPL+exception) is in place.
 #include <QDomElement>
 #include <QMessageBox>
 #include <QProcess>
+#include <QSignalBlocker>
 
 #include "pageitem.h"
 #include "pageitem_table.h"
@@ -129,7 +130,7 @@ QString getLongPathName(const QString & shortPath)
 // Use loadRawText instead.
 // FIXME XXX
 //
-bool loadText(const QString& filename, QString *Buffer)
+bool loadText(const QString& filename, QString *buffer)
 {
 	QFile f(filename);
 	QFileInfo fi(f);
@@ -141,7 +142,7 @@ bool loadText(const QString& filename, QString *Buffer)
 	f.read(bb.data(), f.size());
 	f.close();
 	for (int i = 0; i < bb.size(); ++i)
-		*Buffer += QChar(bb[i]);
+		*buffer += QChar(bb[i]);
 	/*
 		int len = bb.size();
 		int oldLen = Buffer->length();
@@ -205,15 +206,15 @@ bool loadRawBytes(const QString & filename, QByteArray & buf)
 
 QString CompressStr(QString *in)
 {
-	QString out = "";
+	QString out;
 	QByteArray bb(in->length(), ' ');
 	if (bb.size() == in->length())
 	{
-		for (int ax = 0; ax < in->length(); ++ax)
+		for (int i = 0; i < in->length(); ++i)
 		{
 			// bb.insert(ax, in->at(ax)); JG monstruously inefficient due to frequent memory reallocation
-			bb[ax] = in->at(ax).cell();
-			assert(in->at(ax).row() == 0);
+			bb[i] = in->at(i).cell();
+			assert(in->at(i).row() == 0);
 		}
 		uLong exlen = (uLong)(bb.size() * 0.001 + 16) + bb.size();
 		QByteArray bc(exlen, ' ');
@@ -522,10 +523,10 @@ QString getFileNameByPage(ScribusDoc* currDoc, uint pageNo, const QString& exten
 		QFileInfo fi(defaultName);
 		defaultName = fi.completeBaseName();
 	}
-	return QString("%1-%2%3.%4").arg(defaultName).arg(QObject::tr("page", "page export")).arg(number, 3, 10, QChar('0')).arg(extension);
+	return QString("%1-%2%3.%4").arg(defaultName, QObject::tr("page", "page export")).arg(number, 3, 10, QChar('0')).arg(extension);
 }
 
-const QString getStringFromSequence(NumFormat type, uint position, const QString& asterix)
+QString getStringFromSequence(NumFormat type, uint position, const QString& asterix)
 {
 	QString retVal;
 
@@ -578,7 +579,7 @@ const QString getStringFromSequence(NumFormat type, uint position, const QString
 	return retVal;
 }
 
-const QString numberToLetterSequence(const QString& letters, uint num)
+QString numberToLetterSequence(const QString& letters, uint num)
 {
 	QString retVal;
 	unsigned digits = 1;
@@ -603,7 +604,7 @@ const QString numberToLetterSequence(const QString& letters, uint num)
 	return retVal;
 }
 
-const QString numberToRoman(uint i)
+QString numberToRoman(uint i)
 {
 	QString roman("");
 	int arabic = i;
@@ -736,8 +737,8 @@ void parsePagesString(const QString& pages, std::vector<int>* pageNs, int source
 		}
 		else if (token.indexOf("-") != -1) // import a range of source doc pages
 		{
-			int from = QString(token.left(token.indexOf("-"))).toInt();
-			int to = QString(token.right(token.length() - token.indexOf("-") - 1)).toInt();
+			int from = QStringRef(token.leftRef(token.indexOf("-"))).toInt();
+			int to = QStringRef(token.rightRef(token.length() - token.indexOf("-") - 1)).toInt();
 			if ((from != 0) && (to != 0))
 			{
 				if (from > sourcePageCount)
@@ -792,29 +793,26 @@ QString readLineFromDataStream(QDataStream &s)
 
 void setCurrentComboItem(QComboBox *box, const QString& text)
 {
-	bool sigBlocked = box->blockSignals(true);
+	QSignalBlocker signalBlocker(box);
 	int ind = box->findText(text);
 	if (ind > -1)
 		box->setCurrentIndex(ind);
-	box->blockSignals(sigBlocked);
 }
 
 void setCurrentComboItemFromData(QComboBox *box, const QString& data)
 {
-	bool sigBlocked = box->blockSignals(true);
+	QSignalBlocker signalBlocker(box);
 	int ind = box->findData(data);
 	if (ind > -1)
 		box->setCurrentIndex(ind);
-	box->blockSignals(sigBlocked);
 }
 
 void removeComboItem(QComboBox *box, const QString& text)
 {
-	bool sigBlocked = box->blockSignals(true);
+	QSignalBlocker signalBlocker(box);
 	int ind = box->findText(text);
 	if (ind > -1)
 		box->removeItem(ind);
-	box->blockSignals(sigBlocked);
 }
 
 QString readAdobeUniCodeString(QDataStream &s)
@@ -1144,7 +1142,7 @@ bool convertOldTable(ScribusDoc *m_Doc, PageItem* gItem, QList<PageItem*> &gpL,
 	while (!gpL.isEmpty())
 	{
 		PageItem* item = gpL.takeFirst();
-		if (item->asTextFrame())
+		if (item->isTextFrame())
 			item->dropLinks();
 		delete item;
 	}
@@ -1160,6 +1158,7 @@ void setWidgetBoldFont(QWidget* w, bool wantBold)
 	w->setFont(f);
 }
 
+
 void getUniqueName(QString &name, const QStringList& list, const QString& separator, bool prepend)
 {
 	if (!list.contains(name))
@@ -1176,7 +1175,7 @@ void getUniqueName(QString &name, const QStringList& list, const QString& separa
 	name = newName;
 }
 
-const QString numberToHebrew(uint i)
+QString numberToHebrew(uint i)
 {
 	const QString hebrew("אבגדהוזחטיכלמנסעפצקרשת");
 	QString result;
@@ -1216,7 +1215,7 @@ const QString numberToHebrew(uint i)
 	return result;
 }
 
-const QString numberToCJK(uint i)
+QString numberToCJK(uint i)
 {
 	QString result;
 	if (i<10)
