@@ -84,18 +84,18 @@ class SCRIBUS_API VGradient
 public:
 	enum VGradientType
 	{
-	    linear = 0,
-	    radial = 1,
-	    fourcolor  = 2,
-	    diamond = 3,
+		linear = 0,
+		radial = 1,
+		fourcolor  = 2,
+		diamond = 3,
 		mesh = 4,
 		freemesh = 5
 	};
 
 	enum VGradientRepeatMethod
 	{
-	    none    = 0,
-	    reflect = 1,
+		none    = 0,
+		reflect = 1,
 		repeat  = 2,
 		pad     = 3
 	};
@@ -115,8 +115,8 @@ public:
 
 	const QList<VColorStop*>& colorStops() const;
 	void addStop(const VColorStop& colorStop);
-	void addStop(const QColor &color, double rampPoint, double midPoint, double opa, const QString& name = "", int shade = 100);
-	void setStop(const QColor &color, double rampPoint, double midPoint, double opa, const QString& name = "", int shade = 100);
+	void addStop(const QColor &color, double rampPoint, double midPoint, double opa, const QString& name = QString(), int shade = 100);
+	void setStop(const QColor &color, double rampPoint, double midPoint, double opa, const QString& name = QString(), int shade = 100);
 	void removeStop(VColorStop& colorStop);
 	void removeStop(int n);
 	void clearStops();
